@@ -49,6 +49,8 @@
 
 #include "G4VisAttributes.hh"
 #include "G4Colour.hh"
+#include "G4SystemOfUnits.hh"
+#include "G4PhysicalConstants.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
