@@ -44,10 +44,13 @@
 //    on the UltraFresnelLens class.
 //
 #include <cmath>
+
 #include "UltraDetectorConstruction.hh"
 #include "UltraPMTSD.hh"
 #include "UltraFresnelLens.hh"
 
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4SDManager.hh"
 #include "G4Material.hh"
 #include "G4MaterialTable.hh"
@@ -538,7 +541,7 @@ G4Material   *LensMaterial        = G4Material::GetMaterial(name = "Acrylic") ;
 G4ThreeVector LensPosition        = UVscopePosition+G4ThreeVector(0.0*mm,0.0*mm,UVscopeHeight/2.0-UVscopeBaffle) ;
 
 
-UltraFresnelLens *FresnelLens = new UltraFresnelLens(LensDiameter,LensNumOfGrooves,LensMaterial,World_phys,LensPosition) ;
+FresnelLens = new UltraFresnelLens(LensDiameter,LensNumOfGrooves,LensMaterial,World_phys,LensPosition) ;
 
 
 ///////////////////////////////////
