@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: GammaRayTelDetectorConstruction.cc,v 1.15 2006-06-29 15:56:22 gunter Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 // ------------------------------------------------------------
 //      GEANT 4 class implementation file
 //      CERN Geneva Switzerland
@@ -47,6 +46,8 @@
 #include "GammaRayTelAnticoincidenceSD.hh"
 #include "GammaRayTelCalorimeterSD.hh"
 
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4Material.hh"
 #include "G4Box.hh"
 #include "G4LogicalVolume.hh"
@@ -83,8 +84,8 @@ GammaRayTelDetectorConstruction::GammaRayTelDetectorConstruction()
    solidCALDetectorY(0),logicCALDetectorY(0),physiCALDetectorY(0),
    solidPlane(0),logicPlane(0),physiPlane(0),
    solidConverter(0),logicConverter(0),physiConverter(0),
-   trackerSD(0),calorimeterSD(0),anticoincidenceSD(0),
-   aTKRRegion(0), aCALRegion(0)
+   trackerSD(0),calorimeterSD(0),anticoincidenceSD(0)
+   // aTKRRegion(0), aCALRegion(0)
 {
   // default parameter values of the payload
   
@@ -681,19 +682,20 @@ G4VPhysicalVolume* GammaRayTelDetectorConstruction::ConstructPayload()
   
   // Cuts by Regions 
 
-
-  G4String regName[] = {"Calorimeter","Tracker"};
-  if (aCALRegion) delete aCALRegion;
-
-  aCALRegion = new G4Region(regName[0]);
-  logicCAL->SetRegion(aCALRegion);
-  aCALRegion->AddRootLogicalVolume(logicCAL);
-
-  if (aTKRRegion) delete aTKRRegion;
-
-  aTKRRegion = new G4Region(regName[1]);
-  logicTKR->SetRegion(aTKRRegion);
-  aTKRRegion->AddRootLogicalVolume(logicTKR);
+  /*
+    G4String regName[] = {"Calorimeter","Tracker"};
+    if (aCALRegion) delete aCALRegion;
+    
+    aCALRegion = new G4Region(regName[0]);
+    logicCAL->SetRegion(aCALRegion);
+    aCALRegion->AddRootLogicalVolume(logicCAL);
+    
+    if (aTKRRegion) delete aTKRRegion;
+    
+    aTKRRegion = new G4Region(regName[1]);
+    logicTKR->SetRegion(aTKRRegion);
+    aTKRRegion->AddRootLogicalVolume(logicTKR);
+  */
 
   //Sensitive Detector Manager
   
