@@ -51,9 +51,12 @@
 //
 // --------------------------------------------------------------
 
+#include <iomanip>  
+
 #include "DMXPhysicsList.hh"
 
 #include "globals.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ProcessManager.hh"
 #include "G4ProcessVector.hh"
 
@@ -63,11 +66,8 @@
 #include "G4ParticleTable.hh"
 
 #include "G4ios.hh"
-#include <iomanip>  
-
 #include "G4UserLimits.hh"
 
-
 // Constructor /////////////////////////////////////////////////////////////
 DMXPhysicsList::DMXPhysicsList() : G4VUserPhysicsList() 
 {
@@ -416,6 +416,11 @@ void DMXPhysicsList::ConstructEM() {
   // turn off msc step-limitation - especially as electron cut 1nm
   opt.SetMscStepLimitation(fMinimal);
 
+  // switch on fluorescence, PIXE and Auger:
+  opt.SetFluo(true);
+  opt.SetPIXE(true);
+  opt.SetAuger(true);
+
 }
 
 
@@ -460,8 +465,6 @@ void DMXPhysicsList::ConstructOp()
   theAbsorptionProcess->SetVerboseLevel(OpVerbLevel);
   // theRayleighScatteringProcess->SetVerboseLevel(OpVerbLevel);
   theBoundaryProcess->SetVerboseLevel(OpVerbLevel);
-  G4OpticalSurfaceModel themodel = unified;
-  theBoundaryProcess->SetModel(themodel);
 
   theParticleIterator->reset();
   while( (*theParticleIterator)() )
