@@ -37,6 +37,9 @@
 #include "XrayFluoPlaneDetectorConstruction.hh"
 #include "XrayFluoPlaneDetectorMessenger.hh"
 #include "XrayFluoSD.hh"
+#include "XrayFluoNistMaterials.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4Material.hh"
 #include "G4ThreeVector.hh"
 #include "G4Box.hh"
@@ -51,8 +54,6 @@
 #include "G4ios.hh"
 #include "G4PVReplica.hh"
 #include "G4UserLimits.hh"
-#include "XrayFluoNistMaterials.hh"
-
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
@@ -524,15 +525,15 @@ G4VPhysicalVolume* XrayFluoPlaneDetectorConstruction::ConstructApparate()
    G4VisAttributes * yellow= new G4VisAttributes( G4Colour(255/255. ,255/255. ,51/255. ));
    G4VisAttributes * red= new G4VisAttributes( G4Colour(255/255. , 0/255. , 0/255. ));
    G4VisAttributes * blue= new G4VisAttributes( G4Colour(0/255. , 0/255. ,  255/255. ));
-   G4VisAttributes * gray= new G4VisAttributes( G4Colour(128/255. , 128/255. ,  128/255. ));
+   G4VisAttributes * grayc= new G4VisAttributes( G4Colour(128/255. , 128/255. ,  128/255. ));
    G4VisAttributes * lightGray= new G4VisAttributes( G4Colour(178/255. , 178/255. ,  178/255. ));
   yellow->SetVisibility(true);
   yellow->SetForceSolid(true);
   red->SetVisibility(true);
   red->SetForceSolid(true);
   blue->SetVisibility(true);
-  gray->SetVisibility(true);
-  gray->SetForceSolid(true);
+  grayc->SetVisibility(true);
+  grayc->SetForceSolid(true);
   lightGray->SetVisibility(true);
   lightGray->SetForceSolid(true);
   simpleBoxVisAtt->SetVisibility(true);
@@ -543,13 +544,13 @@ G4VPhysicalVolume* XrayFluoPlaneDetectorConstruction::ConstructApparate()
   logicPlane->SetVisAttributes(lightGray);
   
 
-  logicScreen->SetVisAttributes(gray);
+  logicScreen->SetVisAttributes(grayc);
   logicOhmicNeg->SetVisAttributes(yellow);
   logicOhmicPos->SetVisAttributes(yellow);
 
 
 
-  if (planeGranularity)  logicGrain->SetVisAttributes(gray);
+  if (planeGranularity)  logicGrain->SetVisAttributes(grayc);
 
   //always return the physical World
     
