@@ -23,9 +23,12 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
+/// \file analysis/AnaEx02/AnaEx02.cc
+/// \brief Main program of the analysis/AnaEx02 example
 //
-// $Id: AnaEx02.cc 49035 2011-03-31 10:21:28Z gcosmo $
-// GEANT4 tag $Name: geant4-09-04 $
+//
+// $Id: AnaEx02.cc 59868 2012-06-20 13:59:51Z gcosmo $
+// GEANT4 tag $Name: not supported by cvs2svn $
 //
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -89,7 +92,7 @@ int main(int argc,char** argv)
   // Initialize G4 kernel
   //
   runManager->Initialize();
-  
+
   // Get the pointer to the User Interface manager
   //
   G4UImanager* UImanager = G4UImanager::GetUIpointer();
@@ -105,15 +108,15 @@ int main(int argc,char** argv)
 #ifdef G4VIS_USE
       G4VisManager* visManager = new G4VisExecutive;
       visManager->Initialize();
+#ifdef G4UI_USE
+      G4UIExecutive* ui = new G4UIExecutive(argc, argv);
+#endif
+      UImanager->ApplyCommand("/control/execute vis.mac");     
 #endif
 
 #ifdef G4UI_USE
-      G4UIExecutive* ui = new G4UIExecutive(argc, argv);
-    #ifdef G4VIS_USE
-      UImanager->ApplyCommand("/control/execute vis.mac");     
-    #endif
-    ui->SessionStart();
-    delete ui;
+      ui->SessionStart();
+      delete ui;
 #endif
 
 #ifdef G4VIS_USE
