@@ -23,8 +23,10 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: TestEm14.cc,v 1.5 2010-04-02 13:22:02 maire Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+/// \file electromagnetic/TestEm14/TestEm14.cc
+/// \brief Main program of the electromagnetic/TestEm14 example
+//
+// $Id$
 // 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo...... 
@@ -41,7 +43,6 @@
 #include "RunAction.hh"
 #include "EventAction.hh"
 #include "SteppingAction.hh"
-#include "HistoManager.hh"
 
 #ifdef G4VIS_USE
  #include "G4VisExecutive.hh"
@@ -70,14 +71,12 @@ int main(int argc,char** argv) {
   runManager->SetUserInitialization(det = new DetectorConstruction);
   runManager->SetUserInitialization(new PhysicsList);
   runManager->SetUserAction(prim = new PrimaryGeneratorAction(det));
-  
-  HistoManager*  histo = new HistoManager();
       
   // set user action classes
   RunAction* run;  
-  runManager->SetUserAction(run = new RunAction(det,prim,histo)); 
+  runManager->SetUserAction(run = new RunAction(det,prim)); 
   runManager->SetUserAction(new EventAction);
-  runManager->SetUserAction(new SteppingAction(prim,run,histo));
+  runManager->SetUserAction(new SteppingAction(prim,run));
    
   // get the pointer to the User Interface manager 
     G4UImanager* UI = G4UImanager::GetUIpointer();  
@@ -108,8 +107,7 @@ int main(int argc,char** argv) {
     }
 
   // job termination
-  //     
-  delete histo; 
+  //    
   delete runManager;
 
   return 0;
