@@ -23,8 +23,10 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: DetectorMessenger.cc,v 1.11 2006-06-29 16:52:26 gunter Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+/// \file electromagnetic/TestEm3/src/DetectorMessenger.cc
+/// \brief Implementation of the DetectorMessenger class
+//
+// $Id$
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -46,101 +48,101 @@
 DetectorMessenger::DetectorMessenger(DetectorConstruction * Det)
 :Detector(Det)
 { 
-  testemDir = new G4UIdirectory("/testem/");
-  testemDir->SetGuidance("UI commands specific to this example");
+  fTestemDir = new G4UIdirectory("/testem/");
+  fTestemDir->SetGuidance("UI commands specific to this example");
   
-  detDir = new G4UIdirectory("/testem/det/");
-  detDir->SetGuidance("detector construction commands");
+  fDetDir = new G4UIdirectory("/testem/det/");
+  fDetDir->SetGuidance("detector construction commands");
   
-  SizeYZCmd = new G4UIcmdWithADoubleAndUnit("/testem/det/setSizeYZ",this);
-  SizeYZCmd->SetGuidance("Set tranverse size of the calorimeter");
-  SizeYZCmd->SetParameterName("Size",false);
-  SizeYZCmd->SetRange("Size>0.");
-  SizeYZCmd->SetUnitCategory("Length");
-  SizeYZCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fSizeYZCmd = new G4UIcmdWithADoubleAndUnit("/testem/det/setSizeYZ",this);
+  fSizeYZCmd->SetGuidance("Set tranverse size of the calorimeter");
+  fSizeYZCmd->SetParameterName("Size",false);
+  fSizeYZCmd->SetRange("Size>0.");
+  fSizeYZCmd->SetUnitCategory("Length");
+  fSizeYZCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
   
-  NbLayersCmd = new G4UIcmdWithAnInteger("/testem/det/setNbOfLayers",this);
-  NbLayersCmd->SetGuidance("Set number of layers.");
-  NbLayersCmd->SetParameterName("NbLayers",false);
-  NbLayersCmd->SetRange("NbLayers>0");
-  NbLayersCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fNbLayersCmd = new G4UIcmdWithAnInteger("/testem/det/setNbOfLayers",this);
+  fNbLayersCmd->SetGuidance("Set number of layers.");
+  fNbLayersCmd->SetParameterName("NbLayers",false);
+  fNbLayersCmd->SetRange("NbLayers>0");
+  fNbLayersCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
   
-  NbAbsorCmd = new G4UIcmdWithAnInteger("/testem/det/setNbOfAbsor",this);
-  NbAbsorCmd->SetGuidance("Set number of Absorbers.");
-  NbAbsorCmd->SetParameterName("NbAbsor",false);
-  NbAbsorCmd->SetRange("NbAbsor>0");
-  NbAbsorCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fNbAbsorCmd = new G4UIcmdWithAnInteger("/testem/det/setNbOfAbsor",this);
+  fNbAbsorCmd->SetGuidance("Set number of Absorbers.");
+  fNbAbsorCmd->SetParameterName("NbAbsor",false);
+  fNbAbsorCmd->SetRange("NbAbsor>0");
+  fNbAbsorCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
    
-  AbsorCmd = new G4UIcommand("/testem/det/setAbsor",this);
-  AbsorCmd->SetGuidance("Set the absor nb, the material, the thickness.");
-  AbsorCmd->SetGuidance("  absor number : from 1 to NbOfAbsor");
-  AbsorCmd->SetGuidance("  material name");
-  AbsorCmd->SetGuidance("  thickness (with unit) : t>0.");
+  fAbsorCmd = new G4UIcommand("/testem/det/setAbsor",this);
+  fAbsorCmd->SetGuidance("Set the absor nb, the material, the thickness.");
+  fAbsorCmd->SetGuidance("  absor number : from 1 to NbOfAbsor");
+  fAbsorCmd->SetGuidance("  material name");
+  fAbsorCmd->SetGuidance("  thickness (with unit) : t>0.");
   //
   G4UIparameter* AbsNbPrm = new G4UIparameter("AbsorNb",'i',false);
   AbsNbPrm->SetGuidance("absor number : from 1 to NbOfAbsor");
   AbsNbPrm->SetParameterRange("AbsorNb>0");
-  AbsorCmd->SetParameter(AbsNbPrm);
+  fAbsorCmd->SetParameter(AbsNbPrm);
   //
   G4UIparameter* MatPrm = new G4UIparameter("material",'s',false);
   MatPrm->SetGuidance("material name");
-  AbsorCmd->SetParameter(MatPrm);
+  fAbsorCmd->SetParameter(MatPrm);
   //    
   G4UIparameter* ThickPrm = new G4UIparameter("thickness",'d',false);
   ThickPrm->SetGuidance("thickness of absorber");
   ThickPrm->SetParameterRange("thickness>0.");
-  AbsorCmd->SetParameter(ThickPrm);
+  fAbsorCmd->SetParameter(ThickPrm);
   //
   G4UIparameter* unitPrm = new G4UIparameter("unit",'s',false);
   unitPrm->SetGuidance("unit of thickness");
   G4String unitList = G4UIcommand::UnitsList(G4UIcommand::CategoryOf("mm"));
   unitPrm->SetParameterCandidates(unitList);
-  AbsorCmd->SetParameter(unitPrm);
+  fAbsorCmd->SetParameter(unitPrm);
   //
-  AbsorCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fAbsorCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
   
-  MagFieldCmd = new G4UIcmdWithADoubleAndUnit("/testem/det/setField",this);  
-  MagFieldCmd->SetGuidance("Define magnetic field.");
-  MagFieldCmd->SetGuidance("Magnetic field will be in Z direction.");
-  MagFieldCmd->SetParameterName("Bz",false);
-  MagFieldCmd->SetUnitCategory("Magnetic flux density");
-  MagFieldCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
+  fMagFieldCmd = new G4UIcmdWithADoubleAndUnit("/testem/det/setField",this);  
+  fMagFieldCmd->SetGuidance("Define magnetic field.");
+  fMagFieldCmd->SetGuidance("Magnetic field will be in Z direction.");
+  fMagFieldCmd->SetParameterName("Bz",false);
+  fMagFieldCmd->SetUnitCategory("Magnetic flux density");
+  fMagFieldCmd->AvailableForStates(G4State_PreInit,G4State_Idle);
      
-  UpdateCmd = new G4UIcmdWithoutParameter("/testem/det/update",this);
-  UpdateCmd->SetGuidance("Update calorimeter geometry.");
-  UpdateCmd->SetGuidance("This command MUST be applied before \"beamOn\" ");
-  UpdateCmd->SetGuidance("if you changed geometrical value(s).");
-  UpdateCmd->AvailableForStates(G4State_Idle);
+  fUpdateCmd = new G4UIcmdWithoutParameter("/testem/det/update",this);
+  fUpdateCmd->SetGuidance("Update calorimeter geometry.");
+  fUpdateCmd->SetGuidance("This command MUST be applied before \"beamOn\" ");
+  fUpdateCmd->SetGuidance("if you changed geometrical value(s).");
+  fUpdateCmd->AvailableForStates(G4State_Idle);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 DetectorMessenger::~DetectorMessenger()
 {
-  delete SizeYZCmd;
-  delete NbLayersCmd;
-  delete NbAbsorCmd;
-  delete AbsorCmd;
-  delete MagFieldCmd;
-  delete UpdateCmd;
-  delete detDir;  
-  delete testemDir;
+  delete fSizeYZCmd;
+  delete fNbLayersCmd;
+  delete fNbAbsorCmd;
+  delete fAbsorCmd;
+  delete fMagFieldCmd;
+  delete fUpdateCmd;
+  delete fDetDir;  
+  delete fTestemDir;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 void DetectorMessenger::SetNewValue(G4UIcommand* command,G4String newValue)
 {
-  if( command == SizeYZCmd )
-   { Detector->SetCalorSizeYZ(SizeYZCmd->GetNewDoubleValue(newValue));}
+  if( command == fSizeYZCmd )
+   { Detector->SetCalorSizeYZ(fSizeYZCmd->GetNewDoubleValue(newValue));}
 
-  if( command == NbLayersCmd )
-   { Detector->SetNbOfLayers(NbLayersCmd->GetNewIntValue(newValue));}
+  if( command == fNbLayersCmd )
+   { Detector->SetNbOfLayers(fNbLayersCmd->GetNewIntValue(newValue));}
 
-  if( command == NbAbsorCmd )
-   { Detector->SetNbOfAbsor(NbAbsorCmd->GetNewIntValue(newValue));}
+  if( command == fNbAbsorCmd )
+   { Detector->SetNbOfAbsor(fNbAbsorCmd->GetNewIntValue(newValue));}
    
-  if (command == AbsorCmd)
+  if (command == fAbsorCmd)
    {
      G4int num; G4double tick;
      G4String unt, mat;
@@ -152,10 +154,10 @@ void DetectorMessenger::SetNewValue(G4UIcommand* command,G4String newValue)
      Detector->SetAbsorThickness(num,tick);
    }
 
-  if( command == MagFieldCmd )
-   { Detector->SetMagField(MagFieldCmd->GetNewDoubleValue(newValue));}
+  if( command == fMagFieldCmd )
+   { Detector->SetMagField(fMagFieldCmd->GetNewDoubleValue(newValue));}
            
-  if( command == UpdateCmd )
+  if( command == fUpdateCmd )
    { Detector->UpdateGeometry();}
 }
 
