@@ -23,8 +23,10 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: HistoManager.cc,v 1.17 2010-01-13 15:53:44 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+/// \file hadronic/Hadr01/src/HistoManager.cc
+/// \brief Implementation of the HistoManager class
+//
+// $Id$
 //
 //---------------------------------------------------------------------------
 //
@@ -34,7 +36,7 @@
 // Author:      V.Ivanchenko 30/01/01
 //
 // Modified:
-// 04.06.2006 Adoptation of hadr01 (V.Ivanchenko)
+// 04.06.2006 Adoptation of Hadr01 (V.Ivanchenko)
 // 16.11.2006 Add beamFlag (V.Ivanchenko)
 //
 //----------------------------------------------------------------------------
@@ -44,6 +46,8 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 #include "HistoManager.hh"
+#include "G4Track.hh"
+#include "G4Step.hh"
 #include "G4UnitsTable.hh"
 #include "G4Neutron.hh"
 #include "G4Proton.hh"
@@ -66,6 +70,7 @@
 #include "G4Alpha.hh"
 #include "Histo.hh"
 #include "globals.hh"
+#include "G4SystemOfUnits.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
@@ -86,97 +91,101 @@ HistoManager* HistoManager::GetPointer()
 
 HistoManager::HistoManager()
 {
-  verbose=  0;
-  nSlices   = 300;
-  nBinsE    = 100;
-  nHisto    = 25;
-  length    = 300.*mm;
-  edepMax   = 1.0*GeV;
-  beamFlag  = true;
-  material  = 0;
-  elm       = 0;
-  histo     = new Histo(verbose);
-  neutron   = G4Neutron::Neutron();
+  fVerbose=  0;
+  fNSlices   = 300;
+  fNBinsE    = 100;
+  fNHisto    = 25;
+  fLength    = 300.*mm;
+  fEdepMax   = 1.0*GeV;
+  fBeamFlag  = true;
+  fHistoBooked = false;
+  fHisto     = new Histo();
+  fHisto->SetVerbose(fVerbose);
+  fNeutron   = G4Neutron::Neutron();
+  fPrimaryKineticEnergy = 0.0;
+  fPrimaryDef = 0;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 HistoManager::~HistoManager()
 {
-  delete histo;
+  delete fHisto;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 void HistoManager::bookHisto()
 {
-  histo->add1D("1","Energy deposition (MeV/mm/event) in the target",
-	       nSlices,0.0,length/mm,MeV/mm);
-  histo->add1D("2","Log10 Energy (MeV) of gammas",nBinsE,-5.,5.,1.0);
-  histo->add1D("3","Log10 Energy (MeV) of electrons",nBinsE,-5.,5.,1.0);
-  histo->add1D("4","Log10 Energy (MeV) of positrons",nBinsE,-5.,5.,1.0);
-  histo->add1D("5","Log10 Energy (MeV) of protons",nBinsE,-5.,5.,1.0);
-  histo->add1D("6","Log10 Energy (MeV) of neutrons",nBinsE,-5.,5.,1.0);
-  histo->add1D("7","Log10 Energy (MeV) of charged pions",nBinsE,-4.,6.,1.0);
-  histo->add1D("8","Log10 Energy (MeV) of pi0",nBinsE,-4.,6.,1.0);
-  histo->add1D("9","Log10 Energy (MeV) of charged kaons",nBinsE,-4.,6.,1.0);
-  histo->add1D("10","Log10 Energy (MeV) of neutral kaons",nBinsE,-4.,6.,1.0);
-  histo->add1D("11","Log10 Energy (MeV) of deuterons and tritons",nBinsE,-5.,5.,1.0);
-  histo->add1D("12","Log10 Energy (MeV) of He3 and alpha",nBinsE,-5.,5.,1.0);
-  histo->add1D("13","Log10 Energy (MeV) of Generic Ions",nBinsE,-5.,5.,1.0);
-  histo->add1D("14","Log10 Energy (MeV) of muons",nBinsE,-4.,6.,1.0);
-  histo->add1D("15","log10 Energy (MeV) of side-leaked neutrons",nBinsE,-5.,5.,1.0);
-  histo->add1D("16","log10 Energy (MeV) of forward-leaked neutrons",nBinsE,-5.,5.,1.0);
-  histo->add1D("17","log10 Energy (MeV) of backward-leaked neutrons",nBinsE,-5.,5.,1.0);
-  histo->add1D("18","log10 Energy (MeV) of leaking protons",nBinsE,-4.,6.,1.0);
-  histo->add1D("19","log10 Energy (MeV) of leaking charged pions",nBinsE,-4.,6.,1.0);
-  histo->add1D("20","Log10 Energy (MeV) of pi+",nBinsE,-4.,6.,1.0);
-  histo->add1D("21","Log10 Energy (MeV) of pi-",nBinsE,-4.,6.,1.0);
-  histo->add1D("22","Energy deposition in the target normalized to beam energy",
-	       110,0.0,1.1,1.0);
-  histo->add1D("23","EM energy deposition in the target normalized to beam energy",
-	       110,0.0,1.1,1.0);
-  histo->add1D("24","Pion energy deposition in the target normalized to beam energy",
-	       110,0.0,1.1,1.0);
-  histo->add1D("25","Proton energy deposition in the target normalized to beam energy",
-	       110,0.0,1.1,1.0);
+  fHistoBooked = true;
+  fHisto->Add1D("1","Energy deposition (MeV/mm/event) in the target",
+               fNSlices,0.0,fLength/mm,MeV/mm);
+  fHisto->Add1D("2","Log10 Energy (MeV) of gammas",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("3","Log10 Energy (MeV) of electrons",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("4","Log10 Energy (MeV) of positrons",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("5","Log10 Energy (MeV) of protons",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("6","Log10 Energy (MeV) of neutrons",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("7","Log10 Energy (MeV) of charged pions",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("8","Log10 Energy (MeV) of pi0",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("9","Log10 Energy (MeV) of charged kaons",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("10","Log10 Energy (MeV) of neutral kaons",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("11","Log10 Energy (MeV) of deuterons and tritons",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("12","Log10 Energy (MeV) of He3 and alpha",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("13","Log10 Energy (MeV) of Generic Ions",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("14","Log10 Energy (MeV) of muons",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("15","log10 Energy (MeV) of side-leaked neutrons",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("16","log10 Energy (MeV) of forward-leaked neutrons",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("17","log10 Energy (MeV) of backward-leaked neutrons",fNBinsE,-5.,5.,1.0);
+  fHisto->Add1D("18","log10 Energy (MeV) of leaking protons",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("19","log10 Energy (MeV) of leaking charged pions",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("20","Log10 Energy (MeV) of pi+",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("21","Log10 Energy (MeV) of pi-",fNBinsE,-4.,6.,1.0);
+  fHisto->Add1D("22","Energy deposition in the target normalized to beam energy",
+               110,0.0,1.1,1.0);
+  fHisto->Add1D("23","EM energy deposition in the target normalized to beam energy",
+               110,0.0,1.1,1.0);
+  fHisto->Add1D("24","Pion energy deposition in the target normalized to beam energy",
+               110,0.0,1.1,1.0);
+  fHisto->Add1D("25","Proton energy deposition in the target normalized to beam energy",
+               110,0.0,1.1,1.0);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 void HistoManager::BeginOfRun()
 {
-  absZ0       = -0.5*length;
-  n_evt       = 0;
-  n_elec      = 0;
-  n_posit     = 0;
-  n_gam       = 0;
-  n_step      = 0;
-  n_prot_leak = 0;
-  n_pion_leak = 0;
-  n_ions      = 0;
-  n_deut      = 0;
-  n_alpha     = 0;
-  n_kaons     = 0;
-  n_muons     = 0;
-  n_cpions    = 0;
-  n_pi0       = 0;
-  n_neutron   = 0;
-  n_proton    = 0;
-  n_aproton   = 0;
-  n_neu_forw  = 0;
-  n_neu_leak  = 0;
-  n_neu_back  = 0;
+  fAbsZ0       = -0.5*fLength;
+  fNevt       = 0;
+  fNelec      = 0;
+  fNposit     = 0;
+  fNgam       = 0;
+  fNstep      = 0;
+  fNprot_leak = 0;
+  fNpiofNleak = 0;
+  fNions      = 0;
+  fNdeut      = 0;
+  fNalpha     = 0;
+  fNkaons     = 0;
+  fNmuons     = 0;
+  fNcpions    = 0;
+  fNpi0       = 0;
+  fNneutron   = 0;
+  fNproton    = 0;
+  fNaproton   = 0;
+  fNneu_forw  = 0;
+  fNneu_leak  = 0;
+  fNneu_back  = 0;
 
-  edepSum     = 0.0;
-  edepSum2    = 0.0;
+  fEdepSum     = 0.0;
+  fEdepSum2    = 0.0;
 
-  bookHisto();
-  histo->book();
+  if(!fHistoBooked) { bookHisto(); }
+  fHisto->Book();
 
-  if(verbose > 0) 
+  if(fVerbose > 0) {
     G4cout << "HistoManager: Histograms are booked and run has been started"
-           <<G4endl<<"  BeginOfRun (After histo->book)"<< G4endl;
+           <<G4endl;
+  }
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
@@ -189,42 +198,42 @@ void HistoManager::EndOfRun()
   // Average values
   G4cout<<"========================================================"<<G4endl;
 
-  G4double x = (G4double)n_evt;
-  if(n_evt > 0) x = 1.0/x;
+  G4double x = (G4double)fNevt;
+  if(fNevt > 0) { x = 1.0/x; }
 
-  G4double xe = x*(G4double)n_elec;
-  G4double xg = x*(G4double)n_gam;
-  G4double xp = x*(G4double)n_posit;
-  G4double xs = x*(G4double)n_step;
-  G4double xn = x*(G4double)n_neutron;
-  G4double xpn = x*(G4double)n_proton;
-  G4double xap = x*(G4double)n_aproton;
-  G4double xnf = x*(G4double)n_neu_forw;
-  G4double xnb = x*(G4double)n_neu_leak;
-  G4double xnbw= x*(G4double)n_neu_back;
-  G4double xpl = x*(G4double)n_prot_leak;
-  G4double xal = x*(G4double)n_pion_leak;
-  G4double xpc = x*(G4double)n_cpions;
-  G4double xp0 = x*(G4double)n_pi0;
-  G4double xpk = x*(G4double)n_kaons;
-  G4double xpm = x*(G4double)n_muons;
-  G4double xid = x*(G4double)n_deut;
-  G4double xia = x*(G4double)n_alpha;
-  G4double xio = x*(G4double)n_ions;
+  G4double xe = x*(G4double)fNelec;
+  G4double xg = x*(G4double)fNgam;
+  G4double xp = x*(G4double)fNposit;
+  G4double xs = x*(G4double)fNstep;
+  G4double xn = x*(G4double)fNneutron;
+  G4double xpn = x*(G4double)fNproton;
+  G4double xap = x*(G4double)fNaproton;
+  G4double xnf = x*(G4double)fNneu_forw;
+  G4double xnb = x*(G4double)fNneu_leak;
+  G4double xnbw= x*(G4double)fNneu_back;
+  G4double xpl = x*(G4double)fNprot_leak;
+  G4double xal = x*(G4double)fNpiofNleak;
+  G4double xpc = x*(G4double)fNcpions;
+  G4double xp0 = x*(G4double)fNpi0;
+  G4double xpk = x*(G4double)fNkaons;
+  G4double xpm = x*(G4double)fNmuons;
+  G4double xid = x*(G4double)fNdeut;
+  G4double xia = x*(G4double)fNalpha;
+  G4double xio = x*(G4double)fNions;
 
-  edepSum  *= x;
-  edepSum2 *= x;
-  edepSum2 -= edepSum*edepSum;
-  if(edepSum2 > 0.0) edepSum2 = std::sqrt(edepSum2);
-  else               edepSum2 = 0.0;
+  fEdepSum  *= x;
+  fEdepSum2 *= x;
+  fEdepSum2 -= fEdepSum*fEdepSum;
+  if(fEdepSum2 > 0.0) { fEdepSum2 = std::sqrt(fEdepSum2); }
+  else                { fEdepSum2 = 0.0; }
 
   G4cout                         << "Beam particle                        "
-				 << primaryDef->GetParticleName() <<G4endl;
+                                 << fPrimaryDef->GetParticleName() <<G4endl;
   G4cout                         << "Beam Energy(MeV)                     " 
-				 << primaryKineticEnergy/MeV <<G4endl;
-  G4cout                         << "Number of events                     " << n_evt <<G4endl;
-  G4cout << std::setprecision(4) << "Average energy deposit (MeV)         " << edepSum/MeV 
-	 << "   RMS(MeV) " << edepSum2/MeV << G4endl;
+                                 << fPrimaryKineticEnergy/MeV <<G4endl;
+  G4cout                         << "Number of events                     " << fNevt <<G4endl;
+  G4cout << std::setprecision(4) << "Average energy deposit (MeV)         " << fEdepSum/MeV 
+         << "   RMS(MeV) " << fEdepSum2/MeV << G4endl;
   G4cout << std::setprecision(4) << "Average number of steps              " << xs << G4endl;
   G4cout << std::setprecision(4) << "Average number of gamma              " << xg << G4endl;
   G4cout << std::setprecision(4) << "Average number of e-                 " << xe << G4endl;
@@ -248,34 +257,33 @@ void HistoManager::EndOfRun()
   G4cout<<G4endl;
 
   // normalise histograms
-  for(G4int i=0; i<nHisto; i++) { 
-    histo->scale(i,x);
+  for(G4int i=0; i<fNHisto; i++) { 
+    fHisto->ScaleH1(i,x);
   }
 
-  if(verbose > 1) histo->print(0);
-  histo->save();
+  fHisto->Save();
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 void HistoManager::BeginOfEvent()
 {
-  edepEvt = 0.0;
-  edepEM  = 0.0;
-  edepPI  = 0.0;
-  edepP   = 0.0;
+  fEdepEvt = 0.0;
+  fEdepEM  = 0.0;
+  fEdepPI  = 0.0;
+  fEdepP   = 0.0;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 void HistoManager::EndOfEvent()
 {
-  edepSum  += edepEvt;
-  edepSum2 += edepEvt*edepEvt;
-  histo->fill(21,edepEvt/primaryKineticEnergy,1.0);
-  histo->fill(22,edepEM/primaryKineticEnergy,1.0);
-  histo->fill(23,edepPI/primaryKineticEnergy,1.0);
-  histo->fill(24,edepP/primaryKineticEnergy,1.0);
+  fEdepSum  += fEdepEvt;
+  fEdepSum2 += fEdepEvt*fEdepEvt;
+  fHisto->Fill(21,fEdepEvt/fPrimaryKineticEnergy,1.0);
+  fHisto->Fill(22,fEdepEM/fPrimaryKineticEnergy,1.0);
+  fHisto->Fill(23,fEdepPI/fPrimaryKineticEnergy,1.0);
+  fHisto->Fill(24,fEdepP/fPrimaryKineticEnergy,1.0);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
@@ -289,76 +297,76 @@ void HistoManager::ScoreNewTrack(const G4Track* track)
   // Primary track
   if(0 == track->GetParentID()) {
 
-    n_evt++;
-    primaryKineticEnergy = e;
-    primaryDef = pd;
+    fNevt++;
+    fPrimaryKineticEnergy = e;
+    fPrimaryDef = pd;
     G4ThreeVector dir = track->GetMomentumDirection();
-    if(1 < verbose) 
+    if(1 < fVerbose) 
       G4cout << "### Primary " << name 
-	     << " kinE(MeV)= " << e/MeV
-	     << "; m(MeV)= " << pd->GetPDGMass()/MeV
-	     << "; pos(mm)= " << track->GetPosition()/mm 
-	     << ";  dir= " << track->GetMomentumDirection() 
-	     << G4endl;
+             << " kinE(MeV)= " << e/MeV
+             << "; m(MeV)= " << pd->GetPDGMass()/MeV
+             << "; pos(mm)= " << track->GetPosition()/mm 
+             << ";  dir= " << track->GetMomentumDirection() 
+             << G4endl;
 
     // Secondary track
   } else {
-    if(1 < verbose) 
+    if(1 < fVerbose) 
       G4cout << "=== Secondary " << name 
-	     << " kinE(MeV)= " << e/MeV
-	     << "; m(MeV)= " << pd->GetPDGMass()/MeV
-	     << "; pos(mm)= " << track->GetPosition()/mm 
-	     << ";  dir= " << track->GetMomentumDirection() 
-	     << G4endl;
+             << " kinE(MeV)= " << e/MeV
+             << "; m(MeV)= " << pd->GetPDGMass()/MeV
+             << "; pos(mm)= " << track->GetPosition()/mm 
+             << ";  dir= " << track->GetMomentumDirection() 
+             << G4endl;
     e = std::log10(e/MeV);
     if(pd == G4Gamma::Gamma()) {
-      n_gam++;
-      histo->fill(1,e,1.0);
+      fNgam++;
+      fHisto->Fill(1,e,1.0);
     } else if ( pd == G4Electron::Electron()) {
-      n_elec++;
-      histo->fill(2,e,1.0);
+      fNelec++;
+      fHisto->Fill(2,e,1.0);
     } else if ( pd == G4Positron::Positron()) {
-      n_posit++;
-      histo->fill(3,e,1.0);
+      fNposit++;
+      fHisto->Fill(3,e,1.0);
     } else if ( pd == G4Proton::Proton()) {
-      n_proton++;
-      histo->fill(4,e,1.0);
-    } else if ( pd == neutron) {
-      n_neutron++;
-      histo->fill(5,e,1.0);
+      fNproton++;
+      fHisto->Fill(4,e,1.0);
+    } else if ( pd == fNeutron) {
+      fNneutron++;
+      fHisto->Fill(5,e,1.0);
     } else if ( pd == G4AntiProton::AntiProton()) {
-      n_aproton++;
+      fNaproton++;
     } else if ( pd == G4PionPlus::PionPlus() ) {
-      n_cpions++;
-      histo->fill(6,e,1.0);
-      histo->fill(19,e,1.0);
+      fNcpions++;
+      fHisto->Fill(6,e,1.0);
+      fHisto->Fill(19,e,1.0);
 
     } else if ( pd == G4PionMinus::PionMinus()) {
-      n_cpions++;
-      histo->fill(6,e,1.0);
-      histo->fill(20,e,1.0);
+      fNcpions++;
+      fHisto->Fill(6,e,1.0);
+      fHisto->Fill(20,e,1.0);
 
     } else if ( pd == G4PionZero::PionZero()) {
-      n_pi0++;
-      histo->fill(7,e,1.0);
+      fNpi0++;
+      fHisto->Fill(7,e,1.0);
     } else if ( pd == G4KaonPlus::KaonPlus() || pd == G4KaonMinus::KaonMinus()) {
-      n_kaons++;
-      histo->fill(8,e,1.0);
+      fNkaons++;
+      fHisto->Fill(8,e,1.0);
     } else if ( pd == G4KaonZeroShort::KaonZeroShort() || pd == G4KaonZeroLong::KaonZeroLong()) {
-      n_kaons++;
-      histo->fill(9,e,1.0);
+      fNkaons++;
+      fHisto->Fill(9,e,1.0);
     } else if ( pd == G4Deuteron::Deuteron() || pd == G4Triton::Triton()) {
-      n_deut++;
-      histo->fill(10,e,1.0);
+      fNdeut++;
+      fHisto->Fill(10,e,1.0);
     } else if ( pd == G4He3::He3() || pd == G4Alpha::Alpha()) {
-      n_alpha++;
-      histo->fill(11,e,1.0);
+      fNalpha++;
+      fHisto->Fill(11,e,1.0);
     } else if ( pd->GetParticleType() == "nucleus") {
-      n_ions++;
-      histo->fill(12,e,1.0);
+      fNions++;
+      fHisto->Fill(12,e,1.0);
     } else if ( pd == G4MuonPlus::MuonPlus() || pd == G4MuonMinus::MuonMinus()) {
-      n_muons++;
-      histo->fill(13,e,1.0);    
+      fNmuons++;
+      fHisto->Fill(13,e,1.0);    
     }
   }
 }
@@ -367,40 +375,39 @@ void HistoManager::ScoreNewTrack(const G4Track* track)
 
 void HistoManager::AddTargetStep(const G4Step* step)
 {
-  n_step++;
-  G4double edep = step->GetTotalEnergyDeposit();
-  if(edep >= DBL_MIN) { 
+  fNstep++;
+  G4double fEdep = step->GetTotalEnergyDeposit();
+  if(fEdep >= DBL_MIN) { 
     const G4Track* track = step->GetTrack();
-    currentDef = track->GetDefinition(); 
-    currentKinEnergy = track->GetKineticEnergy();
 
     G4ThreeVector pos = 
       (step->GetPreStepPoint()->GetPosition() +
        step->GetPostStepPoint()->GetPosition())*0.5;
 
-    G4double z = pos.z() - absZ0;
+    G4double z = pos.z() - fAbsZ0;
 
     // scoring
-    edepEvt += edep;
-    histo->fill(0,z,edep);
-    const G4ParticleDefinition* pd = currentDef;
+    fEdepEvt += fEdep;
+    fHisto->Fill(0,z,fEdep);
+    const G4ParticleDefinition* pd = track->GetDefinition();
 
     if(pd == G4Gamma::Gamma() || pd == G4Electron::Electron() 
        || pd == G4Positron::Positron()) {
-      edepEM += edep;
+      fEdepEM += fEdep;
     } else if ( pd == G4PionPlus::PionPlus() || pd == G4PionMinus::PionMinus()) {
-      edepPI += edep;
+      fEdepPI += fEdep;
     } else if ( pd == G4Proton::Proton() || pd == G4AntiProton::AntiProton()) {
-      edepP  += edep;
+      fEdepP  += fEdep;
     }
 
-    if(1 < verbose) 
-      G4cout << "HistoManager::AddEnergy: e(keV)= " << edep/keV
-	     << "; z(mm)= " << z/mm
-	     << "; step(mm)= " << step->GetStepLength()/mm
-	     << " by " << currentDef->GetParticleName()
-	     << " E(MeV)= " << currentKinEnergy/MeV
-	     << G4endl;
+    if(1 < fVerbose) {
+      G4cout << "HistoManager::AddEnergy: e(keV)= " << fEdep/keV
+             << "; z(mm)= " << z/mm
+             << "; step(mm)= " << step->GetStepLength()/mm
+             << " by " << pd->GetParticleName()
+             << " E(MeV)= " << track->GetKineticEnergy()/MeV
+             << G4endl;
+    }
   }
 }
 
@@ -420,38 +427,38 @@ void HistoManager::AddLeakingParticle(const G4Track* track)
   G4bool isLeaking = false;
 
   // Forward 
-  if(z > -absZ0 && dir.z() > 0.0) {
+  if(z > -fAbsZ0 && dir.z() > 0.0) {
     isLeaking = true;
-    if(pd == neutron) {
-      ++n_neu_forw;
-      histo->fill(15,e,1.0);
+    if(pd == fNeutron) {
+      ++fNneu_forw;
+      fHisto->Fill(15,e,1.0);
     } else isLeaking = true;
 
     // Backward
-  } else if (z < absZ0 && dir.z() < 0.0) {
+  } else if (z < fAbsZ0 && dir.z() < 0.0) {
     isLeaking = true;
-    if(pd == neutron) {
-      ++n_neu_back;
-      histo->fill(16,e,1.0);
+    if(pd == fNeutron) {
+      ++fNneu_back;
+      fHisto->Fill(16,e,1.0);
     } else isLeaking = true;
 
     // Side
-  } else if (std::abs(z) <= -absZ0 && x*dir.x() + y*dir.y() > 0.0) {
+  } else if (std::abs(z) <= -fAbsZ0 && x*dir.x() + y*dir.y() > 0.0) {
     isLeaking = true;
-    if(pd == neutron) {
-      ++n_neu_leak;
-      histo->fill(14,e,1.0);
+    if(pd == fNeutron) {
+      ++fNneu_leak;
+      fHisto->Fill(14,e,1.0);
     } else isLeaking = true;
   }
 
   // protons and pions
   if(isLeaking) {
     if(pd == G4Proton::Proton()) {
-      histo->fill(17,e,1.0);
-      ++n_prot_leak;
+      fHisto->Fill(17,e,1.0);
+      ++fNprot_leak;
     } else if (pd == G4PionPlus::PionPlus() || pd == G4PionMinus::PionMinus()) {
-      histo->fill(18,e,1.0);
-      ++n_pion_leak;
+      fHisto->Fill(18,e,1.0);
+      ++fNpiofNleak;
     }
   }
 }
@@ -460,25 +467,15 @@ void HistoManager::AddLeakingParticle(const G4Track* track)
 
 void HistoManager::SetVerbose(G4int val)        
 {
-  verbose = val; 
-  histo->setVerbose(val);
-}
-
-//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
-
-void HistoManager::SetTargetMaterial(const G4Material* mat)         
-{
-  if(mat) {
-    material = mat;
-    elm = (*(material->GetElementVector()))[0];
-  }
+  fVerbose = val; 
+  fHisto->SetVerbose(val);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 void HistoManager::Fill(G4int id, G4double x, G4double w)
 {
-  histo->fill(id, x, w);
+  fHisto->Fill(id, x, w);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
