@@ -23,8 +23,10 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: PhysListEmStandard_WVI.cc,v 1.2 2010-05-22 21:02:48 maire Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+/// \file medical/fanoCavity/src/PhysListEmStandard_WVI.cc
+/// \brief Implementation of the PhysListEmStandard_WVI class
+//
+// $Id$
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo...... 
@@ -41,6 +43,7 @@
 #include "G4PhotoElectricEffect.hh"
 
 #include "G4eMultipleScattering.hh"
+#include "G4MuMultipleScattering.hh"
 #include "G4WentzelVIModel.hh"
 #include "G4CoulombScattering.hh"
 
@@ -55,11 +58,13 @@
 #include "G4EmProcessOptions.hh"
 #include "G4MscStepLimitType.hh"
 
+#include "G4SystemOfUnits.hh"
+
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 PhysListEmStandard_WVI::PhysListEmStandard_WVI(const G4String& name,
                                DetectorConstruction* det)
-: G4VPhysicsConstructor(name), detector(det)
+: G4VPhysicsConstructor(name), fDetector(det)
 {}
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -84,7 +89,7 @@ void PhysListEmStandard_WVI::ConstructProcess()
       // gamma
     
       G4ComptonScattering* compton = new G4ComptonScattering();
-      MyKleinNishinaCompton* comptonModel = new MyKleinNishinaCompton(detector);
+      MyKleinNishinaCompton* comptonModel = new MyKleinNishinaCompton(fDetector);
       comptonModel->SetCSFactor(1000.);      
       compton->SetModel(comptonModel );
             
@@ -95,7 +100,7 @@ void PhysListEmStandard_WVI::ConstructProcess()
     } else if (particleName == "e-") {
       //electron
 
-      G4eMultipleScattering* eMsc = new G4eMultipleScattering();
+      G4MuMultipleScattering* eMsc = new G4MuMultipleScattering();
       eMsc->AddEmModel(1, new G4WentzelVIModel()); 
       G4eIonisation* eIoni = new G4eIonisation();
       eIoni->SetEmModel(new MyMollerBhabhaModel);
@@ -104,11 +109,11 @@ void PhysListEmStandard_WVI::ConstructProcess()
       pmanager->AddProcess(eIoni,                     -1, 2, 2);
 ///      pmanager->AddProcess(new G4eBremsstrahlung,     -1, 3, 3);
       pmanager->AddProcess(new G4CoulombScattering,   -1,-1, 3);
-      	    
+                  
     } else if (particleName == "e+") {
       //positron
 
-      G4eMultipleScattering* pMsc = new G4eMultipleScattering();
+      G4MuMultipleScattering* pMsc = new G4MuMultipleScattering();
       pMsc->AddEmModel(1, new G4WentzelVIModel());
       G4eIonisation* pIoni = new G4eIonisation();
       pIoni->SetEmModel(new MyMollerBhabhaModel);
@@ -138,10 +143,10 @@ void PhysListEmStandard_WVI::ConstructProcess()
    
   //physics tables
   //
-  emOptions.SetMinEnergy(100*eV);	//default    
-  emOptions.SetMaxEnergy(10*GeV);	//default  
-  emOptions.SetDEDXBinning(8*20);	//default=8*7
-  emOptions.SetLambdaBinning(8*20);	//default=8*7 
+  emOptions.SetMinEnergy(100*eV);        //default    
+  emOptions.SetMaxEnergy(10*GeV);        //default  
+  emOptions.SetDEDXBinning(8*20);        //default=8*7
+  emOptions.SetLambdaBinning(8*20);      //default=8*7 
   
   //multiple coulomb scattering
   //
@@ -149,17 +154,17 @@ void PhysListEmStandard_WVI::ConstructProcess()
   
   //energy loss
   //
-  emOptions.SetStepFunction(0.2, 10*um);	//default=(0.2, 1*mm)
+  emOptions.SetStepFunction(0.2, 10*um);        //default=(0.2, 1*mm)
                   
   //build CSDA range
   //
-  emOptions.SetBuildCSDARange(true);		//default=false
+  emOptions.SetBuildCSDARange(true);            //default=false
   emOptions.SetMaxEnergyForCSDARange(10*GeV);  
-  emOptions.SetDEDXBinningForCSDARange(8*7);	//default=8*7
+  emOptions.SetDEDXBinningForCSDARange(8*7);    //default=8*7
           
   //ionization
   //
-  emOptions.SetSubCutoff(false);	//default  
+  emOptions.SetSubCutoff(false);        //default  
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
