@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4ParameterisationBox.cc,v 1.12 2010-11-10 09:15:56 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4ParameterisationBox.cc 69784 2013-05-15 09:16:06Z gcosmo $
 //
 // class G4ParameterisationBox Implementation file
 //
@@ -127,10 +126,11 @@ ComputeTransformation( const G4int copyNo, G4VPhysicalVolume* physVol ) const
     origin.setX( posi ); 
   }
   else
-  { 
+  {
+    std::ostringstream message;
+    message << "Only axes along X are allowed !  Axis: " << faxis;
     G4Exception("G4ParameterisationBoxX::ComputeTransformation()",
-                "GeomDiv0002", FatalException,
-                "Only axes along X are allowed !  Axis: "+faxis);
+                "GeomDiv0002", FatalException, message);
   }
 #ifdef G4DIVDEBUG
   if( verbose >= 2 )
@@ -229,9 +229,10 @@ ComputeTransformation( const G4int copyNo, G4VPhysicalVolume* physVol ) const
   }
   else
   {
+    std::ostringstream message;
+    message << "Only axes along Y are allowed !  Axis: " << faxis;
     G4Exception("G4ParameterisationBoxY::ComputeTransformation()",
-                "GeomDiv0002", FatalException,
-                "Only axes along Y are allowed !  Axis: "+faxis);
+                "GeomDiv0002", FatalException, message);
   }
 #ifdef G4DIVDEBUG
   if( verbose >= 2 )
@@ -330,9 +331,10 @@ ComputeTransformation( const G4int copyNo, G4VPhysicalVolume *physVol ) const
   }
   else
   { 
+    std::ostringstream message;
+    message << "Only axes along Z are allowed !  Axis: " << faxis;
     G4Exception("G4ParameterisationBoxZ::ComputeTransformation()",
-                "GeomDiv0002", FatalException,
-                "Only axes along Z are allowed !  Axis: "+faxis);
+                "GeomDiv0002", FatalException, message);
   }
 #ifdef G4DIVDEBUG
   if( verbose >= 2 )
