@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4ParameterisationPolyhedra.cc,v 1.19 2009-05-20 08:35:52 ivana Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4ParameterisationPolyhedra.cc 69784 2013-05-15 09:16:06Z gcosmo $
 //
 // class G4ParameterisationPolyhedra Implementation file
 //
@@ -36,6 +35,7 @@
 #include "G4ParameterisationPolyhedra.hh"
 
 #include <iomanip>
+#include "G4PhysicalConstants.hh"
 #include "G4ThreeVector.hh"
 #include "G4GeometryTolerance.hh"
 #include "G4RotationMatrix.hh"
