@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4EqEMFieldWithEDM.cc,v 1.3 2010-07-14 10:00:36 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4EqEMFieldWithEDM.cc 69786 2013-05-15 09:38:51Z gcosmo $
 //
 //
 //  This is the standard right-hand side for equation of motion.
@@ -40,6 +39,8 @@
 #include "G4ElectroMagneticField.hh"
 #include "G4ThreeVector.hh"
 #include "globals.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 G4EqEMFieldWithEDM::G4EqEMFieldWithEDM(G4ElectroMagneticField *emField )
       : G4EquationOfMotion( emField ), fElectroMagCof(0.), fMassCof(0.),
