@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4RKG3_Stepper.cc,v 1.17 2010-07-23 14:13:49 tnikitin Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4RKG3_Stepper.cc 69786 2013-05-15 09:38:51Z gcosmo $
 //
 // -------------------------------------------------------------------
 
@@ -34,7 +33,7 @@
 #include "G4Mag_EqRhs.hh"
 
 G4RKG3_Stepper::G4RKG3_Stepper(G4Mag_EqRhs *EqRhs)
-  : G4MagIntegratorStepper(EqRhs,6), hStep(0.), fPtrMagEqOfMot(EqRhs)
+  : G4MagIntegratorStepper(EqRhs,6), hStep(0.)
 {
 }
 
