@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4GeomTestVolume.cc,v 1.6 2007-11-16 09:39:14 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // --------------------------------------------------------------------
 // GEANT 4 class source file
@@ -598,7 +597,6 @@ void G4GeomTestVolume::TestOneLine( const G4ThreeVector &p,
             result =
               overshoots.insert( std::pair<const G4long,G4GeomTestOvershootList>
                                (iDaug,G4GeomTestOvershootList(target,iDaug)) );
-          assert(result.second);
           overshoot = result.first;
         }
 
@@ -631,7 +629,6 @@ void G4GeomTestVolume::TestOneLine( const G4ThreeVector &p,
             result =
             overlaps.insert( std::pair<const G4long,G4GeomTestOverlapList>
                            (key,G4GeomTestOverlapList(target,iDaug,kDaug)) );
-          assert(result.second);
           overlap = result.first;
         }
 
