@@ -24,13 +24,15 @@
 // ********************************************************************
 //
 //
-// $Id: G4Navigator.cc,v 1.46 2010-11-15 14:03:27 gcosmo Exp $
+// $Id: G4Navigator.cc 2012-11-01 japost Exp $
 // GEANT4 tag $ Name:  $
 // 
 // class G4Navigator Implementation
 //
 // Original author: Paul Kent, July 95/96
-//
+// Responsible 1996-present: John Apostolakis
+// Co-maintainer:            Gabriele Cosmo
+// Additional revisions by: Pedro Arce, Vladimir Grichine
 // --------------------------------------------------------------------
 
 #include <iomanip>
@@ -41,6 +43,8 @@
 #include "G4GeometryTolerance.hh"
 #include "G4VPhysicalVolume.hh"
 
+#include "G4VoxelSafety.hh"
+
 // ********************************************************************
 // Constructor
 // ********************************************************************
@@ -54,10 +58,10 @@ G4Navigator::G4Navigator()
 
   ResetStackAndState();
     // Initialises also all 
-    //  - exit / entry flags
-    //  - flags & variables for exit normals
-    //  - zero step counters
-    //  - blocked volume 
+    // - exit / entry flags
+    // - flags & variables for exit normals
+    // - zero step counters
+    // - blocked volume 
 
   fActionThreshold_NoZeroSteps  = 10; 
   fAbandonThreshold_NoZeroSteps = 25; 
@@ -131,6 +135,7 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
     globalDirection=*pGlobalDirection;
   }
 
+
 #ifdef G4VERBOSE
   if( fVerbose > 2 )
   {
@@ -286,6 +291,7 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
       // local point returned is the point in the system of this new level
     }
 
+
     if ( insideCode==kOutside )
     {
       noLevelsExited++; 
@@ -299,11 +305,12 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
         if( noLevelsExited > 1 )
         {
           // The first transformation was done by the sub-navigator
+          //
           const G4RotationMatrix* mRot = fBlockedPhysicalVolume->GetRotation();
           if( mRot )
           { 
-             fGrandMotherExitNormal *= (*mRot).inverse();
-             fChangedGrandMotherRefFrame= true;
+            fGrandMotherExitNormal *= (*mRot).inverse();
+            fChangedGrandMotherRefFrame= true;
           }
         }
       }
@@ -311,7 +318,7 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
       {
         fLastLocatedPointLocal = localPoint;
         fLocatedOutsideWorld = true;
-        // No extra transformation for ExitNormal - is in frame of Top Volume
+          // No extra transformation for ExitNormal - is in frame of Top Volume
         return 0;         // Have exited world volume
       }
     }
@@ -327,7 +334,9 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
           G4bool directionExiting = false;
           G4ThreeVector localDirection =
               fHistory.GetTopTransform().TransformAxis(globalDirection);
+
           // Make sure localPoint in correct reference frame
+          //     ( Was it already correct ? How ? )
           //
           localPoint= fHistory.GetTopTransform().TransformPoint(globalPoint);
           if ( fHistory.GetTopVolumeType()!=kReplica )
@@ -353,8 +362,8 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
             if( noLevelsExited > 1 )
             {
               // The first transformation was done by the sub-navigator
-              const G4RotationMatrix* mRot =
-                    fBlockedPhysicalVolume->GetRotation();
+              //
+              const G4RotationMatrix* mRot=fBlockedPhysicalVolume->GetRotation();
               if( mRot )
               { 
                 fGrandMotherExitNormal *= (*mRot).inverse();
@@ -366,8 +375,7 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
           {
             fLastLocatedPointLocal = localPoint;
             fLocatedOutsideWorld = true;
-            // No extra transformation for ExitNormal
-            // is in frame of Top Volume
+              // No extra transformation for ExitNormal, is in frame of Top Vol
             return 0;          // Have exited world volume
           }
         }
@@ -482,17 +490,17 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
         const G4RotationMatrix* mRot = enteredPhysical->GetRotation();
         if( mRot )
         { 
-           fGrandMotherExitNormal *= (*mRot).inverse();
+          fGrandMotherExitNormal *= (*mRot).inverse();
         }
       }
 
 #ifdef G4DEBUG_NAVIGATION
       if( fVerbose > 2 )
       { 
-        G4VPhysicalVolume* enteredPhysical = fHistory.GetTopVolume();
-        G4cout << "*** G4Navigator::LocateGlobalPointAndSetup() ***" << G4endl; 
-        G4cout << "    Entering volume: " << enteredPhysical->GetName()
-               << G4endl;
+         G4VPhysicalVolume* enteredPhysical = fHistory.GetTopVolume();
+         G4cout << "*** G4Navigator::LocateGlobalPointAndSetup() ***" << G4endl;
+         G4cout << "    Entering volume: " << enteredPhysical->GetName()
+                << G4endl;
       }
 #endif
     }
@@ -501,7 +509,7 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
   fLastLocatedPointLocal = localPoint;
 
 #ifdef G4VERBOSE
-  if( fVerbose == 4 )
+  if( fVerbose >= 4 )
   {
     G4int oldcoutPrec = G4cout.precision(8);
     G4String curPhysVol_Name("None");
@@ -509,10 +517,11 @@ G4Navigator::LocateGlobalPointAndSetup( const G4ThreeVector& globalPoint,
     G4cout << "    Return value = new volume = " << curPhysVol_Name << G4endl;
     G4cout << "    ----- Upon exiting:" << G4endl;
     PrintState();
-#ifdef G4DEBUG_NAVIGATION
-    G4cout << "    Upon exiting LocateGlobalPointAndSetup():" << G4endl;
-    G4cout << "    History = " << G4endl << fHistory << G4endl << G4endl;
-#endif
+    if( fVerbose == 5 )
+    {
+      G4cout << "Upon exiting LocateGlobalPointAndSetup():" << G4endl;
+      G4cout << "    History = " << G4endl << fHistory << G4endl << G4endl;
+    }
     G4cout.precision(oldcoutPrec);
   }
 #endif
@@ -580,7 +589,7 @@ G4Navigator::LocateGlobalPointWithinVolume(const G4ThreeVector& pGlobalpoint)
          break;
        case kReplica:
          G4Exception("G4Navigator::LocateGlobalPointWithinVolume()",
-                     "GeomNav0003", FatalException,
+                     "GeomNav0001", FatalException,
                      "Not applicable for replicated volumes.");
          break;
      }
@@ -609,7 +618,6 @@ G4Navigator::LocateGlobalPointWithinVolume(const G4ThreeVector& pGlobalpoint)
 //
 void G4Navigator::SetSavedState()
 {
-  // fSaveExitNormal = fExitNormal; 
   fSaveState.sExitNormal = fExitNormal;
   fSaveState.sValidExitNormal = fValidExitNormal;
   fSaveState.sExiting = fExiting;
@@ -618,7 +626,17 @@ void G4Navigator::SetSavedState()
   fSaveState.spBlockedPhysicalVolume = fBlockedPhysicalVolume;
   fSaveState.sBlockedReplicaNo = fBlockedReplicaNo, 
 
-  fSaveState.sLastStepWasZero = fLastStepWasZero; 
+  fSaveState.sLastStepWasZero = fLastStepWasZero;
+  
+  fSaveState.sLocatedOutsideWorld = fLocatedOutsideWorld;
+  fSaveState.sLastLocatedPointLocal= fLastLocatedPointLocal;
+  fSaveState.sEnteredDaughter= fEnteredDaughter;
+  fSaveState.sExitedMother= fExitedMother;
+
+  // Even the safety sphere - if you want to change it do it explicitly!
+  //
+  fSaveState.sPreviousSftOrigin= fPreviousSftOrigin;
+  fSaveState.sPreviousSafety= fPreviousSafety;
 }
 
 // ********************************************************************
@@ -637,7 +655,14 @@ void G4Navigator::RestoreSavedState()
   fBlockedPhysicalVolume = fSaveState.spBlockedPhysicalVolume;
   fBlockedReplicaNo = fSaveState.sBlockedReplicaNo, 
 
-  fLastStepWasZero = fSaveState.sLastStepWasZero; 
+  fLastStepWasZero = fSaveState.sLastStepWasZero;
+  
+  fLocatedOutsideWorld = fSaveState.sLocatedOutsideWorld;
+  fLastLocatedPointLocal= fSaveState.sLastLocatedPointLocal;
+  fEnteredDaughter= fSaveState.sEnteredDaughter;
+  fExitedMother= fSaveState.sExitedMother;
+  fSaveState.sPreviousSftOrigin= fPreviousSftOrigin;
+  fSaveState.sPreviousSafety= fPreviousSafety;
 }
 
 // ********************************************************************
@@ -681,11 +706,15 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
   G4VPhysicalVolume  *motherPhysical = fHistory.GetTopVolume();
   G4LogicalVolume *motherLogical = motherPhysical->GetLogicalVolume();
 
-  // All state relating to exiting normals must be reset.
-  fExitNormalGlobalFrame= G4ThreeVector( 0., 0., 0.);  // Reset value - to erase its memory
-  fChangedGrandMotherRefFrame= false;                  // Reset - used for local exit normal
+  // All state relating to exiting normals must be reset
+  //
+  fExitNormalGlobalFrame= G4ThreeVector( 0., 0., 0.);
+    // Reset value - to erase its memory
+  fChangedGrandMotherRefFrame= false;
+    // Reset - used for local exit normal
   fGrandMotherExitNormal= G4ThreeVector( 0., 0., 0.); 
-  fCalculatedExitNormal  = false;                      // Reset for new step
+  fCalculatedExitNormal  = false;
+    // Reset for new step
 
   static G4int sNavCScalls=0;
   sNavCScalls++;
@@ -707,7 +736,7 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
              << "  Direction   = " << std::setw(25) << pDirection << G4endl;
       if( fVerbose >= 4 )
       {
-        G4cout << "  ---- Upon entering :" << G4endl;
+        G4cout << "  ---- Upon entering : State" << G4endl;
         PrintState();
       }
     }
@@ -773,7 +802,7 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
           else  // Regular (non-voxelised) structure
           {
             LocateGlobalPointAndSetup( pGlobalpoint, &pDirection, true, true );
-            fLastTriedStepComputation= true;     // Ensure that this is set again !!
+            fLastTriedStepComputation= true; // Ensure that this is set again !!
             //
             // if physical process limits the step, the voxel will not be the
             // one given by ComputeStepSkippingEqualMaterials() and the local
@@ -851,7 +880,7 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
         }
         break;
       case kReplica:
-        G4Exception("G4Navigator::ComputeStep()", "GeomNav0003",
+        G4Exception("G4Navigator::ComputeStep()", "GeomNav0001",
                     FatalException, "Not applicable for replicated volumes.");
         break;
     }
@@ -862,6 +891,7 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
     // edge/corner problem by itself
     //
     G4bool exitingReplica = fExitedMother;
+    G4bool calculatedExitNormal;
     Step = freplicaNav.ComputeStep(pGlobalpoint,
                                    pDirection,
                                    fLastLocatedPointLocal,
@@ -870,12 +900,14 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
                                    pNewSafety,
                                    fHistory,
                                    fValidExitNormal,
+                                   calculatedExitNormal,
                                    fExitNormal,
                                    exitingReplica,
                                    fEntering,
                                    &fBlockedPhysicalVolume,
                                    fBlockedReplicaNo);
-    fExiting= exitingReplica;                          // still ok to set it ??
+    fExiting= exitingReplica;                          
+    fCalculatedExitNormal= calculatedExitNormal;
   }
 
   // Remember last safety origin & value.
@@ -895,7 +927,7 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
   //
   fLocatedOnEdge   = fLastStepWasZero && (Step==0.0);
   fLastStepWasZero = (Step==0.0);
-  if (fPushed)  fPushed = fLastStepWasZero;
+  if (fPushed)  { fPushed = fLastStepWasZero; }
 
   // Handle large number of consecutive zero steps
   //
@@ -976,62 +1008,72 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
     }
 #endif
 
-    if(fValidExitNormal)
+    if(fValidExitNormal || fCalculatedExitNormal)
     {
-      // Convention: fExitNormal is in the 'grand-mother' coordinate system
-      //
-      fGrandMotherExitNormal= fExitNormal;
-      fCalculatedExitNormal= true;
+      if (  fHistory.GetTopVolumeType()!=kReplica )
+      {
+        // Convention: fExitNormal is in the 'grand-mother' coordinate system
+        //
+        fGrandMotherExitNormal= fExitNormal;
+        fCalculatedExitNormal= true;
+      }
+      else
+      {
+        fGrandMotherExitNormal = fExitNormal;
+      }
     }
     else
     {  
       // We must calculate the normal anyway (in order to have it if requested)
       //
       G4ThreeVector finalLocalPoint =
-        fLastLocatedPointLocal + localDirection*Step;
+            fLastLocatedPointLocal + localDirection*Step;
 
       if (  fHistory.GetTopVolumeType()!=kReplica )
       {
-         // Find normal in the 'mother' coordinate system
-         G4ThreeVector exitNormalMotherFrame =
+        // Find normal in the 'mother' coordinate system
+        //
+        G4ThreeVector exitNormalMotherFrame=
            motherLogical->GetSolid()->SurfaceNormal(finalLocalPoint);
+        
+        // Transform it to the 'grand-mother' coordinate system
+        //
+        const G4RotationMatrix* mRot = motherPhysical->GetRotation();
+        if( mRot )
+        {
+          fChangedGrandMotherRefFrame= true;           
+          fGrandMotherExitNormal = (*mRot).inverse() * exitNormalMotherFrame;
+        }
+        else
+        {
+          fGrandMotherExitNormal = exitNormalMotherFrame;
+        }
 
-         // Transform it to the 'grand-mother' coordinate system
-         const G4RotationMatrix* mRot = motherPhysical->GetRotation();
-         if( mRot )
-         {
-           fChangedGrandMotherRefFrame= true;           
-           fGrandMotherExitNormal = (*mRot).inverse() * exitNormalMotherFrame;
-         }
-         else
-         {
-           fGrandMotherExitNormal = exitNormalMotherFrame;
-         }
-         
-         // Do not set fValidExitNormal: signifies the solid is convex!
-
-         fCalculatedExitNormal= true;
+        // Do not set fValidExitNormal -- this signifies
+        // that the solid is convex!
+        //
+        fCalculatedExitNormal= true;
       }
       else
       {
-         fCalculatedExitNormal = false;
+        fCalculatedExitNormal = false;
+        //
+        // Nothing can be done at this stage currently - to solve this
+        // Replica Navigation must have calculated the normal for this case
+        // already.
+        // Cases: mother is not convex, and exit is at previous replica level
 
-         // Nothing can be done at this stage currently - to solve this
-         // Replica Navigation must have calculated the normal for this case
-         // already.
-         // Cases: mother is not convex, and exit is at previous replica level
-         
 #ifdef G4DEBUG_NAVIGATION
-         G4ExceptionDescription desc;
+        G4ExceptionDescription desc;
 
-         desc << "Problem in ComputeStep: Replica Navigation did not provide"
-              << " valid exit Normal. " << G4endl;
-         desc << " Do not know how calculate it in this case." << G4endl;
-         desc << "  Location    = " << finalLocalPoint << G4endl;
-         desc << "  Volume name = " << motherPhysical->GetName()
-                << "  copy/replica No = " << motherPhysical->GetCopyNo() << G4endl;
-         G4Exception("G4Navigator::ComputeStep", "Geom0003",
-                     JustWarning, desc, "Normal not available for exiting.");
+        desc << "Problem in ComputeStep:  Replica Navigation did not provide"
+             << " valid exit Normal. " << G4endl;
+        desc << " Do not know how calculate it in this case." << G4endl;
+        desc << "  Location    = " << finalLocalPoint << G4endl;
+        desc << "  Volume name = " << motherPhysical->GetName()
+             << "  copy/replica No = " << motherPhysical->GetCopyNo() << G4endl;
+        G4Exception("G4Navigator::ComputeStep()", "GeomNav0003",
+                    JustWarning, desc, "Normal not available for exiting.");
 #endif
       }
     }
@@ -1043,9 +1085,9 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
       G4int depth= fHistory.GetDepth();
       if( depth > 0 )
       {
-        G4AffineTransform GrandMotherToGlobalTransf=
+        G4AffineTransform GrandMotherToGlobalTransf =
           fHistory.GetTransform(depth-1).Inverse();
-        fExitNormalGlobalFrame=
+        fExitNormalGlobalFrame =
           GrandMotherToGlobalTransf.TransformAxis( fGrandMotherExitNormal );
       }
       else
@@ -1077,11 +1119,11 @@ G4double G4Navigator::ComputeStep( const G4ThreeVector &pGlobalpoint,
       PrintState();
     }
     G4cout << "  Returned step= " << Step;
-    if( fVerbose > 5 )  { G4cout << G4endl; }
+    if( fVerbose > 5 )   G4cout << G4endl;
     if( Step == kInfinity )
     {
-      G4cout << " Requested step= " << pCurrentProposedStepLength ;
-      if( fVerbose > 5)  { G4cout << G4endl; }
+       G4cout << " Requested step= " << pCurrentProposedStepLength ;
+       if( fVerbose > 5) G4cout << G4endl;
     }
     G4cout << "  Safety = " << pNewSafety << G4endl;
   }
@@ -1221,8 +1263,8 @@ G4ThreeVector G4Navigator::GetLocalExitNormal( G4bool* valid )
   G4LogicalVolume *candidateLogical;
   if ( fLastTriedStepComputation ) 
   {
-    // use fLastLocatedPointLocal
-    // and next candidate volume
+    // use fLastLocatedPointLocal and next candidate volume
+    //
     G4ThreeVector nextSolidExitNormal(0.,0.,0.);
 
     if( fEntering && (fBlockedPhysicalVolume!=0) ) 
@@ -1232,9 +1274,9 @@ G4ThreeVector G4Navigator::GetLocalExitNormal( G4bool* valid )
       {
         // fLastStepEndPointLocal is in the coordinates of the mother
         // we need it in the daughter's coordinate system.
-        {
-          // The following code should also work in case of Replica (JA 15/10/12)
 
+        // The following code should also work in case of Replica
+        {
           // First transform fLastLocatedPointLocal to the new daughter
           // coordinates
           //
@@ -1315,58 +1357,53 @@ G4ThreeVector G4Navigator::GetLocalExitNormal( G4bool* valid )
     }
     else if ( fExiting ) 
     {
-        ExitNormal = fGrandMotherExitNormal;
-        *valid = true;
-        fCalculatedExitNormal= true;  // Should be true already
+      ExitNormal = fGrandMotherExitNormal;
+      *valid = true;
+      fCalculatedExitNormal= true;  // Should be true already
     }
-    else  // ie  ( fBlockedPhysicalVolume == 0 )
+    else  // i.e.  ( fBlockedPhysicalVolume == 0 )
     {
-        *valid = false;
-#ifdef G4DEBUG_NAVIGATION
-        G4Exception("G4Navigator::GetLocalExitNormal()",
-                    "GeomNav003", JustWarning, 
-                    "Incorrect call to GetLocalSurfaceNormal.");
-#endif
+      *valid = false;
+      G4Exception("G4Navigator::GetLocalExitNormal()",
+                  "GeomNav0003", JustWarning, 
+                  "Incorrect call to GetLocalSurfaceNormal." );
     }
   }
   else //  ( ! fLastTriedStepComputation ) ie. last call was to Locate
   {
     if ( EnteredDaughterVolume() )
     {
-       G4VSolid* daughterSolid =fHistory.GetTopVolume()->GetLogicalVolume()
-                                                       ->GetSolid();
-       ExitNormal= -(daughterSolid->SurfaceNormal(fLastLocatedPointLocal));
-       if( std::fabs(ExitNormal.mag2()-1.0 ) > CLHEP::perMillion )
-       {
-          G4ExceptionDescription desc;
-          desc << " Parameters of solid: " << *daughterSolid
-               << " Point for surface = " << fLastLocatedPointLocal
-               << std::endl;
-          G4Exception("G4Navigator::GetLocalExitNormal()",
-                      "GeomNav003", FatalException, desc,
-                      "Surface Normal returned by Solid is not a Unit Vector.");
-       }
-       fCalculatedExitNormal= true;
-       *valid = true;
+      G4VSolid* daughterSolid =fHistory.GetTopVolume()->GetLogicalVolume()
+                                                      ->GetSolid();
+      ExitNormal= -(daughterSolid->SurfaceNormal(fLastLocatedPointLocal));
+      if( std::fabs(ExitNormal.mag2()-1.0 ) > CLHEP::perMillion )
+      {
+        G4ExceptionDescription desc;
+        desc << " Parameters of solid: " << *daughterSolid
+             << " Point for surface = " << fLastLocatedPointLocal << std::endl;
+        G4Exception("G4Navigator::GetLocalExitNormal()",
+                    "GeomNav0003", FatalException, desc,
+                    "Surface Normal returned by Solid is not a Unit Vector." );
+      }
+      fCalculatedExitNormal= true;
+      *valid = true;
     }
     else
     {
       if( fExitedMother )
       {
-         ExitNormal = fGrandMotherExitNormal;
-         *valid = true;
-         fCalculatedExitNormal= true;
+        ExitNormal = fGrandMotherExitNormal;
+        *valid = true;
+        fCalculatedExitNormal= true;
       }
       else  // We are not at a boundary. ExitNormal remains (0,0,0)
       { 
-         *valid = false;
-         fCalculatedExitNormal= false; 
-#ifdef G4DEBUG_NAVIGATION
-         G4ExceptionDescription edN3; 
-         edN3 << " Called when *NOT* at a Boundary." << G4endl;
-         G4Exception("G4Navigator::GetLocalExitNormal()",
-                     "GeomNav003", JustWarning, edN3); 
-#endif
+        *valid = false;
+        fCalculatedExitNormal= false; 
+        G4ExceptionDescription message; 
+        message << "Function called when *NOT* at a Boundary." << G4endl;
+        G4Exception("G4Navigator::GetLocalExitNormal()",
+                    "GeomNav0003", JustWarning, message); 
       }
     }
   }
@@ -1426,20 +1463,30 @@ G4Navigator::GetMotherToDaughterTransform( G4VPhysicalVolume *pEnteringPhysVol,
 // ********************************************************************
 //
 G4ThreeVector G4Navigator::
-GetLocalExitNormalAndCheck(const G4ThreeVector& ExpectedBoundaryPointGlobal,
+GetLocalExitNormalAndCheck( 
+#ifdef G4DEBUG_NAVIGATION
+                           const G4ThreeVector& ExpectedBoundaryPointGlobal,
+#else
+                           const G4ThreeVector&,
+#endif
                                  G4bool*        pValid)
 {
-  G4ThreeVector ExpectedBoundaryPointLocal;
-
+#ifdef G4DEBUG_NAVIGATION
   // Check Current point against expected 'local' value
   //
   if ( fLastTriedStepComputation ) 
   {
-     const G4AffineTransform& GlobalToLocal= GetGlobalToLocalTransform(); 
-     ExpectedBoundaryPointLocal =
-       GlobalToLocal.TransformPoint( ExpectedBoundaryPointGlobal ); 
-  }
+    G4ThreeVector ExpectedBoundaryPointLocal;
 
+    const G4AffineTransform& GlobalToLocal= GetGlobalToLocalTransform(); 
+    ExpectedBoundaryPointLocal =
+      GlobalToLocal.TransformPoint( ExpectedBoundaryPointGlobal ); 
+
+    // Add here:  Comparison against expected position,
+    //            i.e. the endpoint of ComputeStep
+  }
+#endif
+  
   return GetLocalExitNormal( pValid); 
 }
 
@@ -1459,84 +1506,91 @@ G4Navigator::GetGlobalExitNormal(const G4ThreeVector& IntersectPointGlobal,
 
   if( fLastTriedStepComputation && fExiting )  
   {
-     // This was computed in ComputeStep -- and only on arrival at boundary
-     //
-     globalNormal = fExitNormalGlobalFrame; 
-     *pNormalCalculated = true; // ComputeStep always computes it if Exiting
+    // This was computed in ComputeStep -- and only on arrival at boundary
+    //
+    globalNormal = fExitNormalGlobalFrame; 
+    *pNormalCalculated = true; // ComputeStep always computes it if Exiting
+                               // (fExiting==true)
   }
   else
   {
-     localNormal = GetLocalExitNormalAndCheck( IntersectPointGlobal, &validNormal);
-     *pNormalCalculated = fCalculatedExitNormal;
+    localNormal = GetLocalExitNormalAndCheck(IntersectPointGlobal,&validNormal);
+    *pNormalCalculated = fCalculatedExitNormal;
 
 #ifdef G4DEBUG_NAVIGATION
-     if( !validNormal )
-     {
-        G4cerr << "G4Navigator::GetGlobaExitNormal: "
-               << " Obtained non-valid Normal from LocalExitNormalAndCheck()"
-               << G4endl;
-        G4cerr << "  Calculated = " << fCalculatedExitNormal << G4endl;
+    if( (!validNormal) && !fCalculatedExitNormal)
+    {
+      G4ExceptionDescription edN;
+      edN << "  Calculated = " << fCalculatedExitNormal << G4endl;
+      edN << "   Entering= "  << fEntering << G4endl;
+      G4int oldVerbose= this->GetVerboseLevel();
+      this->SetVerboseLevel(4);
+      edN << "   State of Navigator: " << G4endl;
+      edN << *this << G4endl;
+      this->SetVerboseLevel( oldVerbose );
+       
+      G4Exception("G4Navigator::GetGlobalExitNormal()",
+                  "GeomNav0003", JustWarning, edN,
+                  "LocalExitNormalAndCheck() did not calculate Normal.");
      }
 #endif
-
+     
      G4double localMag2= localNormal.mag2();
-     if( validNormal && (std::fabs(localMag2-1.0)) > perMillion )
+     if( validNormal && (std::fabs(localMag2-1.0)) > CLHEP::perMillion )
      {
-#ifdef G4DEBUG_NAVIGATION
-        G4ExceptionDescription edN;
+       G4ExceptionDescription edN;
 
-        edN << "Using Local Normal - from call to GetLocalExitNormalAndCheck()."
-            << G4endl
-            << "  Local  Exit Normal = " << localNormal
-            << " || = " << std::sqrt(localMag2) << G4endl
-            << "  Global Exit Normal = " << globalNormal
-            << " || = " << globalNormal.mag() << G4endl;
-        edN << "  Calculated         = " << fCalculatedExitNormal << G4endl;
-        G4Exception("G4Navigator::GetGlobalExitNormal()", "GeomNav0002",
-                    JustWarning, edN,
-                    "Value obtained from new local *solid* is incorrect.");
-#endif
-        localNormal = localNormal.unit(); // Should we correct it ??
+       edN << "G4Navigator::GetGlobalExitNormal: "
+           << "  Using Local Normal - from call to GetLocalExitNormalAndCheck. "
+           << G4endl
+           << "  Local  Exit Normal = " << localNormal  << " || = "
+           << std::sqrt(localMag2) << G4endl
+           << "  Global Exit Normal = " << globalNormal << " || = "
+           << globalNormal.mag() << G4endl;
+       edN << "  Calculated It      = " << fCalculatedExitNormal << G4endl;
+
+       G4Exception("G4Navigator::GetGlobalExitNormal()",
+                   "GeomNav0003",JustWarning, edN,
+                   "Value obtained from new local *solid* is incorrect.");
+       localNormal = localNormal.unit(); // Should we correct it ??
      }
-
      G4AffineTransform localToGlobal = GetLocalToGlobalTransform();
-     globalNormal = localToGlobal.TransformAxis( localNormal );     
+     globalNormal = localToGlobal.TransformAxis( localNormal );
   }
 
 #ifdef G4DEBUG_NAVIGATION
   // Temporary extra checks
-
   if( fLastTriedStepComputation && fExiting)
   {
-     localNormal = GetLocalExitNormalAndCheck( IntersectPointGlobal,
-                                               &validNormal);
-     *pNormalCalculated = fCalculatedExitNormal;
+    localNormal = GetLocalExitNormalAndCheck( IntersectPointGlobal, &validNormal);
+    *pNormalCalculated = fCalculatedExitNormal;
 
-     G4AffineTransform localToGlobal = GetLocalToGlobalTransform();
-     globalNormal = localToGlobal.TransformAxis( localNormal );
+    G4AffineTransform localToGlobal = GetLocalToGlobalTransform();
+    globalNormal = localToGlobal.TransformAxis( localNormal );
     
-     // Check the value computed against fExitNormalGlobalFrame
-     //
-     G4ThreeVector diffNorm = globalNormal - fExitNormalGlobalFrame;
-     if( diffNorm.mag2() > perMillion*CLHEP::perMillion)
-     {
-        G4cerr << "Found difference in normals in case of exiting mother "
-               << "- when Get is called after ComputingStep " << G4endl;
-        G4cerr << "  Magnitude of diff =      " << diffNorm.mag() << G4endl;
-        G4cerr << "  Normal stored (Global)     = " << fExitNormalGlobalFrame
-               << G4endl;
-        G4cerr << "  Global Computed from Local = " << globalNormal << G4endl;
-     }
-  }
-  else
-  {
-     G4cout << " Agreement at check n5. " << G4endl;
+    // Check the value computed against fExitNormalGlobalFrame
+    G4ThreeVector diffNorm = globalNormal - fExitNormalGlobalFrame;
+    if( diffNorm.mag2() > perMillion*CLHEP::perMillion)
+    {
+      G4ExceptionDescription edDfn;
+      edDfn << "Found difference in normals in case of exiting mother "
+            << "- when Get is called after ComputingStep " << G4endl;
+      edDfn << "  Magnitude of diff =      " << diffNorm.mag() << G4endl;
+      edDfn << "  Normal stored (Global)     = " << fExitNormalGlobalFrame
+            << G4endl;
+      edDfn << "  Global Computed from Local = " << globalNormal << G4endl;
+      G4Exception("G4Navigator::GetGlobalExitNormal()", "GeomNav0003",
+                  JustWarning, edDfn);
+    }
   }
 #endif
    
   return globalNormal;
 }
 
+// To make the new Voxel Safety the default, uncomment the next line
+// #define  G4NEW_SAFETY  1
+
 // ********************************************************************
 // ComputeSafety
 //
@@ -1571,7 +1625,6 @@ G4double G4Navigator::ComputeSafety( const G4ThreeVector &pGlobalpoint,
 #endif
 
   if (keepState)  { SetSavedState(); }
-  //  fLastTriedStepComputation= true;   -- this method is NOT computing the Step size
 
   G4double distEndpointSq = (pGlobalpoint-fStepEndPoint).mag2(); 
   G4bool   stayedOnEndpoint  = distEndpointSq < kCarTolerance*kCarTolerance; 
@@ -1581,8 +1634,8 @@ G4double G4Navigator::ComputeSafety( const G4ThreeVector &pGlobalpoint,
   {
     // Pseudo-relocate to this point (updates voxel information only)
     //
-    LocateGlobalPointWithinVolume( pGlobalpoint );
-      // --->> Danger: Side effects on sub-navigator voxel information <<---
+    LocateGlobalPointWithinVolume( pGlobalpoint ); 
+      // --->> DANGER: Side effects on sub-navigator voxel information <<---
       //       Could be replaced again by 'granular' calls to sub-navigator
       //       locates (similar side-effects, but faster.  
       //       Solutions:
@@ -1609,7 +1662,62 @@ G4double G4Navigator::ComputeSafety( const G4ThreeVector &pGlobalpoint,
         case kNormal:
           if ( pVoxelHeader )
           {
-            newSafety=fvoxelNav.ComputeSafety(localPoint,fHistory,pMaxLength);
+#ifdef G4NEW_SAFETY
+            static G4VoxelSafety sfVoxelSafety;
+            G4double safetyTwo = sfVoxelSafety.ComputeSafety(localPoint,
+                                           *motherPhysical, pMaxLength);
+#ifdef G4DEBUG_NAVIGATION
+            G4double safetyNormal=
+               fnormalNav.ComputeSafety(localPoint, fHistory, pMaxLength);
+
+            G4double diffSafety= (safetyTwo - safetyNormal);
+            if( std::fabs(diffSafety) > CLHEP::perMillion
+                                      * std::fabs(safetyNormal) )
+            {
+              G4ExceptionDescription exd;
+              exd << " ERROR in G4Navigator::ComputeStep " << G4endl;
+              exd << "  Error>  DIFFERENCE in Safety from G4VoxelSafety "
+                  << " - compared to value from Normal.  Diff = " << diffSafety << G4endl;
+              exd << "  New Voxel Safety= " << safetyTwo
+                  << "  Value from Normal= " << safetyNormal << G4endl;
+              exd << "  Location:  Local coordinates = " << localPoint
+                  << "  mother Volume= " << *motherPhysical->GetName()
+                  << "  Copy# = " << motherPhysical->GetCopyNo() << G4endl;
+              exd << "          : Global coordinates = " << pGlobalpoint
+                  << G4endl;
+              G4Exception("G4Navigator::ComputeSafety()",
+                          "GeomNav0003", JustWarning, exd);
+            }
+            G4double safetyOldVoxel;
+            safetyOldVoxel =
+              fvoxelNav.ComputeSafety(localPoint,fHistory,pMaxLength);
+
+            G4double diffBetterToApprox= safetyTwo - safetyOldVoxel;
+            if( diffBetterToApprox < 0.0 )
+            {
+              G4ExceptionDescription exd;
+              exd << "SMALLER Safety from call G4VoxelSafety compared to value "
+                  << " from Normal.  Diff = " << diffSafety << G4endl;
+              exd << " New Voxel Safety= " << safetyTwo
+                  << "  Old value from Normal= " << newSafety << G4endl;
+              exd << "  Location:  Local coordinates = " << localPoint
+                  << "  mother Volume= " << *motherPhysical->GetName()
+                  << "  Copy# = " << motherPhysical->GetCopyNo() << G4endl;
+              exd << "          : Global coordinates = " << pGlobalpoint
+                  << G4endl;
+              G4Exception("G4Navigator::ComputeSafety()",
+                          "GeomNav0003", JustWarning, exd);
+            }
+#endif
+
+            // newSafety= safetyOldVoxel;
+            newSafety= safetyTwo;   // Faster and best available
+#else
+            G4double safetyOldVoxel;
+            safetyOldVoxel =
+              fvoxelNav.ComputeSafety(localPoint,fHistory,pMaxLength);
+            newSafety= safetyOldVoxel;
+#endif
           }
           else
           {
@@ -1619,15 +1727,15 @@ G4double G4Navigator::ComputeSafety( const G4ThreeVector &pGlobalpoint,
         case kParameterised:
           if( GetDaughtersRegularStructureId(motherLogical) != 1 )
           {
-            newSafety = fparamNav.ComputeSafety(localPoint,fHistory,pMaxLength);
+            newSafety=fparamNav.ComputeSafety(localPoint,fHistory,pMaxLength);
           }
           else  // Regular structure
           {
-            newSafety = fregularNav.ComputeSafety(localPoint,fHistory,pMaxLength);
+            newSafety=fregularNav.ComputeSafety(localPoint,fHistory,pMaxLength);
           }
           break;
         case kReplica:
-          G4Exception("G4Navigator::ComputeSafety()", "NotApplicable",
+          G4Exception("G4Navigator::ComputeSafety()", "GeomNav0001",
                       FatalException, "Not applicable for replicated volumes.");
           break;
       }
@@ -1709,7 +1817,8 @@ void  G4Navigator::PrintState() const
   }
   if( ( 1 < fVerbose) && (fVerbose < 4) )
   {
-    G4cout << std::setw(30) << " ExitNormal "  << " "     
+    G4cout << G4endl; // Make sure to line up
+    G4cout << std::setw(30) << " ExitNormal "  << " "
            << std::setw( 5) << " Valid "       << " "     
            << std::setw( 9) << " Exiting "     << " "      
            << std::setw( 9) << " Entering"     << " " 
@@ -1850,6 +1959,67 @@ void G4Navigator::ComputeStepLog(const G4ThreeVector& pGlobalpoint,
 //
 std::ostream& operator << (std::ostream &os,const G4Navigator &n)
 {
-  os << "Current History: " << G4endl << n.fHistory;
+  //  Old version did only the following:
+  // os << "Current History: " << G4endl << n.fHistory;
+  //  Old behaviour is recovered for fVerbose = 0
+  
+  // Adapted from G4Navigator::PrintState() const
+
+  G4int oldcoutPrec = os.precision(4);
+  if( n.fVerbose >= 4 )
+  {
+    os << "The current state of G4Navigator is: " << G4endl;
+    os << "  ValidExitNormal= " << n.fValidExitNormal << G4endl
+    << "  ExitNormal     = " << n.fExitNormal      << G4endl
+    << "  Exiting        = " << n.fExiting         << G4endl
+    << "  Entering       = " << n.fEntering        << G4endl
+    << "  BlockedPhysicalVolume= " ;
+    if (n.fBlockedPhysicalVolume==0)
+      os << "None";
+    else
+      os << n.fBlockedPhysicalVolume->GetName();
+    os << G4endl
+    << "  BlockedReplicaNo     = " <<  n.fBlockedReplicaNo       << G4endl
+    << "  LastStepWasZero      = " <<   n.fLastStepWasZero       << G4endl
+    << G4endl;
+  }
+  if( ( 1 < n.fVerbose) && (n.fVerbose < 4) )
+  {
+    os << G4endl; // Make sure to line up
+    os << std::setw(30) << " ExitNormal "  << " "
+    << std::setw( 5) << " Valid "       << " "
+    << std::setw( 9) << " Exiting "     << " "
+    << std::setw( 9) << " Entering"     << " "
+    << std::setw(15) << " Blocked:Volume "  << " "
+    << std::setw( 9) << " ReplicaNo"        << " "
+    << std::setw( 8) << " LastStepZero  "   << " "
+    << G4endl;
+    os << "( " << std::setw(7) << n.fExitNormal.x()
+    << ", " << std::setw(7) << n.fExitNormal.y()
+    << ", " << std::setw(7) << n.fExitNormal.z() << " ) "
+    << std::setw( 5)  << n.fValidExitNormal  << " "
+    << std::setw( 9)  << n.fExiting          << " "
+    << std::setw( 9)  << n.fEntering         << " ";
+    if ( n.fBlockedPhysicalVolume==0 )
+      { os << std::setw(15) << "None"; }
+    else
+      { os << std::setw(15)<< n.fBlockedPhysicalVolume->GetName(); }
+    os << std::setw( 9)  << n.fBlockedReplicaNo  << " "
+    << std::setw( 8)  << n.fLastStepWasZero   << " "
+    << G4endl;
+  }
+  if( n.fVerbose > 2 )
+  {
+    os.precision(8);
+    os << " Current Localpoint = " << n.fLastLocatedPointLocal << G4endl;
+    os << " PreviousSftOrigin  = " << n.fPreviousSftOrigin << G4endl;
+    os << " PreviousSafety     = " << n.fPreviousSafety << G4endl;
+  }
+  if( n.fVerbose > 3 || n.fVerbose == 0 )
+  {
+    os << "Current History: " << G4endl << n.fHistory;
+  }
+    
+  os.precision(oldcoutPrec);
   return os;
 }
