@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4ConicalSurface.cc,v 1.12 2010-07-07 14:45:31 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // ----------------------------------------------------------------------
 // GEANT 4 class source file
@@ -35,6 +34,7 @@
 // ----------------------------------------------------------------------
 
 #include "G4ConicalSurface.hh"
+#include "G4PhysicalConstants.hh"
 #include "G4Sort.hh"
 #include "G4Globals.hh"
 
