@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4SphericalSurface.cc,v 1.11 2010-07-07 14:45:31 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // ----------------------------------------------------------------------
 // GEANT 4 class source file
@@ -35,6 +34,7 @@
 // ----------------------------------------------------------------------
 
 #include "G4SphericalSurface.hh"
+#include "G4PhysicalConstants.hh"
 
 G4SphericalSurface::G4SphericalSurface()
   : G4Surface(), radius(1.0), phi_1(0.0), phi_2(2*pi),
