@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4SubtractionSolid.cc,v 1.35 2010-10-20 07:31:39 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // Implementation of methods for the class G4IntersectionSolid
 //
@@ -40,8 +39,11 @@
 //
 // --------------------------------------------------------------------
 
+#include <sstream>
+
 #include "G4SubtractionSolid.hh"
 
+#include "G4SystemOfUnits.hh"
 #include "G4VoxelLimits.hh"
 #include "G4VPVParameterisation.hh"
 #include "G4GeometryTolerance.hh"
@@ -52,8 +54,6 @@
 #include "G4NURBS.hh"
 // #include "G4NURBSbox.hh"
 
-#include <sstream>
-
 ///////////////////////////////////////////////////////////////////
 //
 // Transfer all data members to G4BooleanSolid which is responsible
