@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4Box.cc,v 1.53 2010-10-19 15:42:09 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4Box.cc 79541 2014-03-06 14:19:53Z gcosmo $
 //
 // 
 //
@@ -42,6 +41,7 @@
 
 #include "G4Box.hh"
 
+#include "G4SystemOfUnits.hh"
 #include "G4VoxelLimits.hh"
 #include "G4AffineTransform.hh"
 #include "Randomize.hh"
@@ -65,8 +65,8 @@ G4Box::G4Box(const G4String& pName,
   : G4CSGSolid(pName), fDx(pX), fDy(pY), fDz(pZ)
 {
   if ( (pX < 2*kCarTolerance)
-    && (pY < 2*kCarTolerance)
-    && (pZ < 2*kCarTolerance) )  // limit to thickness of surfaces
+    || (pY < 2*kCarTolerance)
+    || (pZ < 2*kCarTolerance) )  // limit to thickness of surfaces
   {
     std::ostringstream message;
     message << "Dimensions too small for Solid: " << GetName() << "!" << G4endl
