@@ -24,14 +24,14 @@
 // ********************************************************************
 //
 //
-// $Id: G4Torus.cc,v 1.71 2010-10-19 15:42:10 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4Torus.cc 69788 2013-05-15 12:06:57Z gcosmo $
 //
 // 
 // class G4Torus
 //
 // Implementation
 //
+// 05.04.12 M.Kelsey:   Use sqrt(r) in GetPointOnSurface() for uniform points
 // 02.10.07 T.Nikitina: Bug fixed in SolveNumericJT(), b.969:segmentation fault.
 //                      rootsrefined is used only if the number of refined roots
 //                      is the same as for primary roots. 
@@ -1763,13 +1763,13 @@ G4ThreeVector G4Torus::GetPointOnSurface() const
   }
   else if( (chose >= aOut + aIn) && (chose < aOut + aIn + aSide) )
   {
-    rRand = RandFlat::shoot(fRmin,fRmax);
+    rRand = GetRadiusInRing(fRmin,fRmax);
     return G4ThreeVector ((fRtor+rRand*cosv)*std::cos(fSPhi),
                           (fRtor+rRand*cosv)*std::sin(fSPhi), rRand*sinv);
   }
   else
   {   
-    rRand = RandFlat::shoot(fRmin,fRmax);
+    rRand = GetRadiusInRing(fRmin,fRmax);
     return G4ThreeVector ((fRtor+rRand*cosv)*std::cos(fSPhi+fDPhi),
                           (fRtor+rRand*cosv)*std::sin(fSPhi+fDPhi), 
                           rRand*sinv);
