@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4ExtrudedSolid.cc,v 1.22 2010-10-20 08:54:18 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4ExtrudedSolid.cc 87943 2015-01-22 09:16:36Z gcosmo $
 //
 //
 // --------------------------------------------------------------------
@@ -42,6 +41,9 @@
 #include <iomanip>
 
 #include "G4ExtrudedSolid.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
+#include "G4VFacet.hh"
 #include "G4TriangularFacet.hh"
 #include "G4QuadrangularFacet.hh"
 
@@ -360,10 +362,23 @@ G4bool G4ExtrudedSolid::IsSameLine(G4TwoVector p,
   {
     return std::fabs(p.x() - l1.x()) < kCarTolerance * 0.5; 
   }
+   G4double  slope= ((l2.y() - l1.y())/(l2.x() - l1.x())); 
+   G4double predy= l1.y() +  slope *(p.x() - l1.x()); 
+   G4double dy= p.y() - predy; 
 
-  return std::fabs (p.y() - l1.y() - ((l2.y() - l1.y())/(l2.x() - l1.x()))
-                                    *(p.x() - l1.x())) < kCarTolerance * 0.5;
- }
+   // Calculate perpendicular distance
+   //
+   // G4double perpD= std::fabs(dy) / std::sqrt( 1 + slope * slope ); 
+   // G4bool   simpleComp= (perpD<0.5*kCarTolerance); 
+
+   // Check perpendicular distance vs tolerance 'directly'
+   //
+   const G4double tol= 0.5 * kCarTolerance ; 
+   G4bool    squareComp=  (dy*dy < (1+slope*slope) * tol * tol); 
+
+   // return  simpleComp; 
+   return squareComp;
+}                    
 
 //_____________________________________________________________________________
 
@@ -543,7 +558,7 @@ G4bool G4ExtrudedSolid::AddGeneralPolygonFacets()
     //G4cout << "angle " << angle  << G4endl;
 
     G4int counter = 0;
-    while ( angle > pi )
+    while ( angle >= pi )
     {
       // G4cout << "Skipping concave vertex " << c2->second << G4endl;
 
