@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4TwistBoxSide.cc,v 1.8 2010-07-16 15:58:59 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4TwistBoxSide.cc 67011 2013-01-29 16:17:41Z gcosmo $
 //
 // 
 // --------------------------------------------------------------------
@@ -43,6 +42,7 @@
 #include <cmath>
 
 #include "G4TwistBoxSide.hh"
+#include "G4PhysicalConstants.hh"
 #include "G4JTPolynomialSolver.hh"
 
 //=====================================================================
@@ -314,7 +314,7 @@ G4int G4TwistBoxSide::DistanceToSurface(const G4ThreeVector &gp,
 
   else {
 
-    G4double c[8],sr[7],si[7] ;  
+    G4double c[8],srd[7],si[7] ;  
 
     c[7] = -14400*(-2*phixz + 2*fTAlph*phiyz + fDx4plus2*fPhiTwist*v.z()) ;
     c[6] = 28800*(phiyz + 2*fDz*v.x() - (fdeltaX + fDx4minus2)*v.z() + fTAlph*(phixz - 2*fDz*v.y() + fdeltaY*v.z())) ;
@@ -338,15 +338,15 @@ G4int G4TwistBoxSide::DistanceToSurface(const G4ThreeVector &gp,
 #endif    
 
     G4JTPolynomialSolver trapEq ;
-    G4int num = trapEq.FindRoots(c,7,sr,si);
+    G4int num = trapEq.FindRoots(c,7,srd,si);
   
 
     for (G4int i = 0 ; i<num ; i++ ) {  // loop over all mathematical solutions
       if ( (si[i]==0.0) && fPhiTwist ) {  // only real solutions
 #ifdef G4TWISTDEBUG
-        G4cout << "Solution " << i << " : " << sr[i] << G4endl ;
+        G4cout << "Solution " << i << " : " << srd[i] << G4endl ;
 #endif
-        phi = std::fmod(sr[i] , pihalf)  ;
+        phi = std::fmod(srd[i] , pihalf)  ;
 
         u   = (2*phiyz + 4*fDz*phi*v.y() - 2*fdeltaY*phi*v.z()
              - fDx4plus2*fPhiTwist*v.z()*std::sin(phi)
@@ -1014,7 +1014,7 @@ G4ThreeVector G4TwistBoxSide::ProjectPoint(const G4ThreeVector &p,
   }
 }
 
-void G4TwistBoxSide::GetFacets( G4int m, G4int n,  G4double xyz[][3], G4int faces[][4], G4int iside ) 
+void G4TwistBoxSide::GetFacets( G4int k, G4int n,  G4double xyz[][3], G4int faces[][4], G4int iside ) 
 {
 
   G4double phi ;
@@ -1026,7 +1026,7 @@ void G4TwistBoxSide::GetFacets( G4int m, G4int n,  G4double xyz[][3], G4int face
   G4int nnode ;
   G4int nface ;
 
-  // calculate the (n-1)*(m-1) vertices
+  // calculate the (n-1)*(k-1) vertices
 
   G4int i,j ;
 
@@ -1036,23 +1036,23 @@ void G4TwistBoxSide::GetFacets( G4int m, G4int n,  G4double xyz[][3], G4int face
     phi = z*fPhiTwist/(2*fDz) ;
     b = GetValueB(phi) ;
 
-    for ( j = 0 ; j<m ; j++ ) {
+    for ( j = 0 ; j<k ; j++ ) {
 
-      nnode = GetNode(i,j,m,n,iside) ;
-      u = -b/2 +j*b/(m-1) ;
+      nnode = GetNode(i,j,k,n,iside) ;
+      u = -b/2 +j*b/(k-1) ;
       p = SurfacePoint(phi,u,true) ;  // surface point in global coordinate system
 
       xyz[nnode][0] = p.x() ;
       xyz[nnode][1] = p.y() ;
       xyz[nnode][2] = p.z() ;
 
-      if ( i<n-1 && j<m-1 ) {   // conterclock wise filling
+      if ( i<n-1 && j<k-1 ) {   // conterclock wise filling
         
-        nface = GetFace(i,j,m,n,iside) ;
-        faces[nface][0] = GetEdgeVisibility(i,j,m,n,0,-1) * (GetNode(i  ,j  ,m,n,iside)+1) ;  // fortran numbering
-        faces[nface][1] = GetEdgeVisibility(i,j,m,n,1,-1) * (GetNode(i  ,j+1,m,n,iside)+1) ;
-        faces[nface][2] = GetEdgeVisibility(i,j,m,n,2,-1) * (GetNode(i+1,j+1,m,n,iside)+1) ;
-        faces[nface][3] = GetEdgeVisibility(i,j,m,n,3,-1) * (GetNode(i+1,j  ,m,n,iside)+1) ;
+        nface = GetFace(i,j,k,n,iside) ;
+        faces[nface][0] = GetEdgeVisibility(i,j,k,n,0,-1) * (GetNode(i  ,j  ,k,n,iside)+1) ;  // fortran numbering
+        faces[nface][1] = GetEdgeVisibility(i,j,k,n,1,-1) * (GetNode(i  ,j+1,k,n,iside)+1) ;
+        faces[nface][2] = GetEdgeVisibility(i,j,k,n,2,-1) * (GetNode(i+1,j+1,k,n,iside)+1) ;
+        faces[nface][3] = GetEdgeVisibility(i,j,k,n,3,-1) * (GetNode(i+1,j  ,k,n,iside)+1) ;
 
       }
     }
