@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4VTwistedFaceted.cc,v 1.22 2010-09-23 10:27:38 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4VTwistedFaceted.cc 67011 2013-01-29 16:17:41Z gcosmo $
 //
 // 
 // --------------------------------------------------------------------
@@ -41,6 +40,8 @@
 
 #include "G4VTwistedFaceted.hh"
 
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4VoxelLimits.hh"
 #include "G4AffineTransform.hh"
 #include "G4SolidExtentList.hh"
@@ -1333,12 +1334,12 @@ G4ThreeVector G4VTwistedFaceted::GetPointOnSurface() const
 G4Polyhedron* G4VTwistedFaceted::CreatePolyhedron () const 
 {
   // number of meshes
-  const G4int m =
+  const G4int k =
     G4int(G4Polyhedron::GetNumberOfRotationSteps() * fPhiTwist / twopi) + 2;
-  const G4int n = m;
+  const G4int n = k;
 
-  const G4int nnodes = 4*(m-1)*(n-2) + 2*m*m ;
-  const G4int nfaces = 4*(m-1)*(n-1) + 2*(m-1)*(m-1) ;
+  const G4int nnodes = 4*(k-1)*(n-2) + 2*k*k ;
+  const G4int nfaces = 4*(k-1)*(n-1) + 2*(k-1)*(k-1) ;
 
   G4Polyhedron *ph=new G4Polyhedron;
   typedef G4double G4double3[3];
@@ -1346,12 +1347,12 @@ G4Polyhedron* G4VTwistedFaceted::CreatePolyhedron () const
   G4double3* xyz = new G4double3[nnodes];  // number of nodes 
   G4int4*  faces = new G4int4[nfaces] ;    // number of faces
 
-  fLowerEndcap->GetFacets(m,m,xyz,faces,0) ;
-  fUpperEndcap->GetFacets(m,m,xyz,faces,1) ;
-  fSide270->GetFacets(m,n,xyz,faces,2) ;
-  fSide0->GetFacets(m,n,xyz,faces,3) ;
-  fSide90->GetFacets(m,n,xyz,faces,4) ;
-  fSide180->GetFacets(m,n,xyz,faces,5) ;
+  fLowerEndcap->GetFacets(k,k,xyz,faces,0) ;
+  fUpperEndcap->GetFacets(k,k,xyz,faces,1) ;
+  fSide270->GetFacets(k,n,xyz,faces,2) ;
+  fSide0->GetFacets(k,n,xyz,faces,3) ;
+  fSide90->GetFacets(k,n,xyz,faces,4) ;
+  fSide180->GetFacets(k,n,xyz,faces,5) ;
 
   ph->createPolyhedron(nnodes,nfaces,xyz,faces);
 
