@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4UIWin32.cc,v 1.13 2006-06-29 19:09:45 gunter Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // G.Barrand
 
@@ -288,7 +287,7 @@ G4UIsession* G4UIWin32::SessionStart (
 }
 /***************************************************************************/
 void G4UIWin32::Prompt (
- G4String a_prompt
+ const G4String& a_prompt
 )
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
@@ -303,7 +302,7 @@ void G4UIWin32::SessionTerminate (
 }
 /***************************************************************************/
 void G4UIWin32::PauseSessionStart (
- G4String a_state
+ const G4String& a_state
 )
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
@@ -319,7 +318,7 @@ void G4UIWin32::PauseSessionStart (
 }
 /***************************************************************************/
 void G4UIWin32::SecondaryLoop (
- G4String a_prompt
+ const G4String& a_prompt
 )
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
@@ -336,7 +335,7 @@ void G4UIWin32::SecondaryLoop (
 }
 /***************************************************************************/
 G4int G4UIWin32::ReceiveG4cout (
- G4String a_string
+ const G4String& a_string
 )
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
@@ -346,7 +345,7 @@ G4int G4UIWin32::ReceiveG4cout (
 }
 /***************************************************************************/
 G4int G4UIWin32::ReceiveG4cerr (
- G4String a_string
+ const G4String& a_string
 )
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
@@ -380,7 +379,7 @@ G4bool G4UIWin32::GetHelpChoice(
 }
 /***************************************************************************/
 void G4UIWin32::ExitHelp(
-)
+) const
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
 {
