@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4UIXm.cc,v 1.15 2008-11-14 16:21:42 lgarnier Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // G.Barrand
 
@@ -217,7 +216,7 @@ void G4UIXm::SessionTerminate (
 }
 /***************************************************************************/
 void G4UIXm::PauseSessionStart (
- G4String a_state
+ const G4String& a_state
 )
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
@@ -250,7 +249,7 @@ void G4UIXm::SecondaryLoop (
 }
 /***************************************************************************/
 G4int G4UIXm::ReceiveG4cout (
- G4String a_string
+ const G4String& a_string
 )
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
@@ -260,7 +259,7 @@ G4int G4UIXm::ReceiveG4cout (
 }
 /***************************************************************************/
 G4int G4UIXm::ReceiveG4cerr (
- G4String a_string
+ const G4String& a_string
 )
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
@@ -294,7 +293,7 @@ G4bool G4UIXm::GetHelpChoice(
 }
 /***************************************************************************/
 void G4UIXm::ExitHelp(
-)
+) const
 /***************************************************************************/
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*/
 {
