@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4Qt.cc,v 1.17 2010-05-20 07:01:03 lgarnier Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // L. Garnier
 
@@ -149,6 +148,22 @@ G4Qt::G4Qt (
   }
 #endif
   //  AddDispatcher     ((G4DispatchFunction)XtDispatchEvent);
+
+  /*
+   * On some non-English locale, comma is used for the decimal separator instead of dot
+   * bringing to weird behavior of strtod (string to double) function in user application.
+   * This is "by design" from Qt, see https://bugreports.qt-project.org/browse/QTBUG-10994
+   *
+   *      $ LC_NUMERIC=fr_FR.UTF-8 ./qtstrtod
+   *      strtod(0.1) = 0
+   *      $ LC_NUMERIC=C ./qtstrtod
+   *      strtod(0.1) = 0.1
+   *
+   * Jerome Suhard, jerome@suhard.fr
+   */
+
+  // explicitly set the LC_NUMBERIC locale to "C"
+  setlocale (LC_NUMERIC, "C");
 }
 /***************************************************************************/
 G4Qt::~G4Qt (
