@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4DensityEffectData.cc,v 1.12 2010-05-15 15:37:33 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4DensityEffectData.cc 67044 2013-01-30 08:50:06Z gcosmo $
 
 //---------------------------------------------------------------------------
 //
@@ -44,9 +43,11 @@
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-#include "G4DensityEffectData.hh"
 #include <iomanip>
 
+#include "G4DensityEffectData.hh"
+#include "G4SystemOfUnits.hh"
+
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 G4DensityEffectData::G4DensityEffectData():index(0) 
