@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4NistMessenger.cc,v 1.10 2010-10-25 13:22:51 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4NistMessenger.cc 67044 2013-01-30 08:50:06Z gcosmo $
 //
 //
 // File name:     G4NistMessenger
@@ -85,6 +84,7 @@ G4NistMessenger::G4NistMessenger(G4NistManager* man)
   lisMatCmd->SetGuidance("simple - simple NIST materials.");
   lisMatCmd->SetGuidance("compound - compound NIST materials.");
   lisMatCmd->SetGuidance("hep - HEP materials.");
+  lisMatCmd->SetGuidance("biomedical - biomedical materials.");
   lisMatCmd->SetGuidance("all - list of all Geant4 materials.");
   lisMatCmd->SetParameterName("list", true);
   lisMatCmd->SetCandidates("simple compound hep all");
