@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4AntiLambdab.cc,v 1.17 2010-10-01 02:41:43 kurasige Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // 
 // ----------------------------------------------------------------------
@@ -39,6 +38,7 @@
 // 
 
 #include "G4AntiLambdab.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleTable.hh"
 
 #include "G4PhaseSpaceDecayChannel.hh"
@@ -73,9 +73,9 @@ G4AntiLambdab* G4AntiLambdab::Definition()
                  name,      5.6202*GeV,  0.462e-9*MeV,          0.,
                     1,              +1,             0,
                     0,               0,             0,
-             "baryon",               0,            +1,       -5122,
+             "baryon",               0,            -1,       -5122,
                 false,      1.425e-3*ns,          NULL,
-                false,       "lambda_b");
+                false,   "anti_lambda_b");
   }
   theInstance = reinterpret_cast<G4AntiLambdab*>(anInstance);
   return theInstance;
