@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4XibMinus.cc,v 1.16 2010-10-01 02:41:43 kurasige Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // 
 // ----------------------------------------------------------------------
@@ -39,6 +38,7 @@
 //
 
 #include "G4XibMinus.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleTable.hh"
 
 #include "G4PhaseSpaceDecayChannel.hh"
