@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4MuonPlus.cc,v 1.16 2010-10-01 02:41:44 kurasige Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // 
 // ----------------------------------------------------------------------
@@ -38,6 +37,8 @@
 // ----------------------------------------------------------------------
 
 #include "G4MuonPlus.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleTable.hh"
 
 #include "G4MuonDecayChannel.hh"
