@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4NucleiProperties.cc,v 1.23 2010-08-10 15:47:42 kurasige Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // 
 // ------------------------------------------------------------
@@ -41,7 +40,8 @@
 // 090331 Migrate to AME03 by Koi, Tatsumi 
 
 #include "G4NucleiProperties.hh"
-
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 G4double G4NucleiProperties::mass_proton = -1.;
 G4double G4NucleiProperties::mass_neutron = -1.;
