@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4ParticleDefinition.cc,v 1.39 2010-12-22 07:07:59 kurasige Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // 
 // --------------------------------------------------------------
@@ -52,6 +51,8 @@
 
 
 #include "G4ParticleDefinition.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleTable.hh"
 #include "G4IonTable.hh"
 #include "G4DecayTable.hh"
@@ -180,6 +181,26 @@ G4ParticleDefinition::G4ParticleDefinition()
 
 G4ParticleDefinition::~G4ParticleDefinition() 
 {
+  if (G4ParticleTable::GetParticleTable()->GetReadiness()) {
+    G4StateManager* pStateManager = G4StateManager::GetStateManager();
+    G4ApplicationState currentState = pStateManager->GetCurrentState();
+    if (currentState != G4State_PreInit) {
+      G4String msg = "Request of deletion for ";
+      msg += GetParticleName();  
+      msg += " has No effects because readyToUse is true.";
+      G4Exception("G4ParticleDefinition::~G4ParticleDefinition()",
+		  "PART117", JustWarning, msg);
+      return ;
+    } else {
+#ifdef G4VERBOSE
+      if (verboseLevel>0){
+	G4cout << GetParticleName()
+	       << " will be deleted " << G4endl;
+      }
+#endif
+    }
+  }
+
   if (theDecayTable!= 0) delete theDecayTable;
 }
 
