@@ -24,7 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4tgbGeometryDumper.cc,v 1.15 2010-11-02 11:13:05 gcosmo Exp $
+// $Id: G4tgbGeometryDumper.cc 87947 2015-01-22 10:10:59Z gcosmo $
 // GEANT4 tag $Name: $
 //
 //
@@ -38,6 +38,7 @@
 
 #include "G4tgrMessenger.hh"
 
+#include "G4SystemOfUnits.hh"
 #include "G4UIcommand.hh"
 #include "G4Material.hh"
 #include "G4Element.hh"
@@ -785,11 +786,9 @@ std::vector<G4double> G4tgbGeometryDumper::GetSolidParams( const G4VSolid * so)
     const G4Trap * trp = dynamic_cast < const G4Trap * > (so);
     if (trp) {
       G4ThreeVector symAxis(trp->GetSymAxis());
-      G4double theta = symAxis.theta()/deg;
-      G4double phi = symAxis.phi()/deg;
       params.push_back( trp->GetZHalfLength() );
-      params.push_back( theta ); 
-      params.push_back( phi);
+      params.push_back( symAxis.theta()/deg);
+      params.push_back( symAxis.phi()/deg);
       params.push_back( trp->GetYHalfLength1() );
       params.push_back( trp->GetXHalfLength1() );
       params.push_back( trp->GetXHalfLength2() );    
@@ -811,15 +810,13 @@ std::vector<G4double> G4tgbGeometryDumper::GetSolidParams( const G4VSolid * so)
   } else if (solidType == "PARA") {
     const G4Para * para = dynamic_cast < const G4Para * > (so);
     if (para) {
-      G4double phi = 0.;
-      if(para->GetSymAxis().z()!=1.0)
-        { phi = std::atan(para->GetSymAxis().y()/para->GetSymAxis().x()); }
+      G4ThreeVector symAxis(para->GetSymAxis());
       params.push_back( para->GetXHalfLength());
       params.push_back(  para->GetYHalfLength());
       params.push_back( para->GetZHalfLength());
       params.push_back( std::atan(para->GetTanAlpha())/deg);
-      params.push_back( std::acos(para->GetSymAxis().z())/deg);
-      params.push_back( phi/deg);
+      params.push_back( symAxis.theta()/deg);
+      params.push_back( symAxis.phi()/deg);
     }
   } else if (solidType == "CONS") {
     const G4Cons * cn = dynamic_cast < const G4Cons * > (so);
@@ -859,19 +856,19 @@ std::vector<G4double> G4tgbGeometryDumper::GetSolidParams( const G4VSolid * so)
   } else if (solidType == "POLYCONE") {
     //--- Dump RZ corners, as original parameters will not be present
     //    if it was build from RZ corners
-    const G4Polycone * pc = dynamic_cast < const G4Polycone * > (so);
-    if (pc) {
-      G4double angphi = pc->GetStartPhi()/deg;
+    const G4Polycone * plc = dynamic_cast < const G4Polycone * > (so);
+    if (plc) {
+      G4double angphi = plc->GetStartPhi()/deg;
       if( angphi > 180*deg )  { angphi -= 360*deg; }
-      G4int ncor = pc->GetNumRZCorner();
+      G4int ncor = plc->GetNumRZCorner();
       params.push_back( angphi );
-      params.push_back( pc->GetOriginalParameters()->Opening_angle/deg ); 
+      params.push_back( plc->GetOriginalParameters()->Opening_angle/deg ); 
       params.push_back( ncor );
     
       for( G4int ii = 0; ii < ncor; ii++ )
       {
-        params.push_back( pc->GetCorner(ii).r ); 
-        params.push_back( pc->GetCorner(ii).z );
+        params.push_back( plc->GetCorner(ii).r ); 
+        params.push_back( plc->GetCorner(ii).z );
       }
     }
   } else if (solidType == "POLYHEDRA") {
