@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4tgbVolume.cc,v 1.23 2010-11-05 08:58:36 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4tgbVolume.cc 69803 2013-05-15 15:24:50Z gcosmo $
 //
 //
 // class G4tgbVolume
@@ -35,6 +34,9 @@
 // -------------------------------------------------------------------------
 
 #include "G4tgbVolume.hh"
+
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4tgbVolumeMgr.hh"
 #include "G4tgbMaterialMgr.hh"
 #include "G4tgbRotationMatrixMgr.hh"
@@ -159,10 +161,6 @@ void G4tgbVolume::ConstructG4Volumes( const G4tgrPlace* place,
 	g4vmgr->RegisterMe( logvol );
 	g4vmgr->RegisterChildParentLVs( logvol, parentLV ); 
       }
-      else
-      {
-        return;
-      }
     }
     else
     {
