@@ -23,7 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4FTFBinaryKaonBuilder.cc 54715 2011-11-11 16:16:06Z gcosmo $
+// $Id: G4FTFBinaryKaonBuilder.cc 65043 2012-11-12 17:11:00Z gcosmo $
 // GEANT4 tag $Name: not supported by cvs2svn $
 //
 //---------------------------------------------------------------------------
@@ -40,15 +40,19 @@
 //----------------------------------------------------------------------------
 //
 #include "G4FTFBinaryKaonBuilder.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleDefinition.hh"
 #include "G4ParticleTable.hh"
 #include "G4ProcessManager.hh"
-#include "G4QHadronInelasticDataSet.hh"
+
+#include "G4ChipsKaonMinusInelasticXS.hh"
+#include "G4ChipsKaonPlusInelasticXS.hh"
+#include "G4ChipsKaonZeroInelasticXS.hh"
+#include "G4CrossSectionDataSetRegistry.hh"
 
 G4FTFBinaryKaonBuilder::
 G4FTFBinaryKaonBuilder(G4bool quasiElastic)
-{
-  theKaonData = new  G4QHadronInelasticDataSet();
+{    
   theMin = 4*GeV;
   theModel = new G4TheoFSGenerator("FTFB");
 
@@ -79,7 +83,6 @@ G4FTFBinaryKaonBuilder:: ~G4FTFBinaryKaonBuilder()
   delete theStringDecay;
   delete theStringModel;
   delete theModel;
-  delete theKaonData;
   if ( theQuasiElastic ) delete theQuasiElastic;
 }
 
@@ -90,7 +93,7 @@ void G4FTFBinaryKaonBuilder::
 Build(G4KaonPlusInelasticProcess * aP)
 {
   theModel->SetMinEnergy(theMin);
-  aP->AddDataSet(theKaonData);
+  aP->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonPlusInelasticXS::Default_Name()));
   aP->RegisterMe(theModel);
 }
 
@@ -98,7 +101,7 @@ void G4FTFBinaryKaonBuilder::
 Build(G4KaonMinusInelasticProcess * aP)
 {
   theModel->SetMinEnergy(theMin);
-  aP->AddDataSet(theKaonData);
+  aP->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonMinusInelasticXS::Default_Name()));
   aP->RegisterMe(theModel);
 }
 
@@ -106,7 +109,7 @@ void G4FTFBinaryKaonBuilder::
 Build(G4KaonZeroLInelasticProcess * aP)
 {
   theModel->SetMinEnergy(theMin);
-  aP->AddDataSet(theKaonData);
+  aP->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonZeroInelasticXS::Default_Name()));
   aP->RegisterMe(theModel);
 }
 
@@ -114,6 +117,7 @@ void G4FTFBinaryKaonBuilder::
 Build(G4KaonZeroSInelasticProcess * aP)
 {
   theModel->SetMinEnergy(theMin);
-  aP->AddDataSet(theKaonData);
+    
+  aP->AddDataSet(G4CrossSectionDataSetRegistry::Instance()->GetCrossSectionDataSet(G4ChipsKaonZeroInelasticXS::Default_Name()));
   aP->RegisterMe(theModel);
 }
