@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4ProductionCutsTable.cc,v 1.28 2010-12-23 06:00:42 kurasige Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 //
 // --------------------------------------------------------------
@@ -52,7 +51,7 @@
 #include "G4UnitsTable.hh"
 
 #include "G4Timer.hh"
-
+#include "G4SystemOfUnits.hh"
 #include "G4ios.hh"
 #include <iomanip>                
 #include <fstream>       
