@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4VRangeToEnergyConverter.cc,v 1.16 2010-12-23 06:00:42 kurasige Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 //
 // --------------------------------------------------------------
@@ -40,6 +39,7 @@
 #include "G4PhysicsLogVector.hh"
 
 #include "G4ios.hh"
+#include "G4SystemOfUnits.hh"
 
 // energy range
 G4double  G4VRangeToEnergyConverter::LowestEnergy = 0.99e-3*MeV;
