@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4ee2KChargedModel.cc,v 1.2 2009-02-20 16:38:33 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4ee2KChargedModel.cc 66996 2013-01-29 14:50:52Z gcosmo $
 //
 // -------------------------------------------------------------------
 //
@@ -49,6 +48,8 @@
 
 #include "G4ee2KChargedModel.hh"
 #include "Randomize.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4KaonPlus.hh"
 #include "G4KaonMinus.hh"
 #include "G4DynamicParticle.hh"
