@@ -49,14 +49,15 @@
 //
 // =========================================================================== 
 
+#include <iomanip>
 
 #include "G4IonDEDXHandler.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4VIonDEDXTable.hh"
 #include "G4VIonDEDXScalingAlgorithm.hh"
 #include "G4ParticleDefinition.hh"
 #include "G4Material.hh"
 #include "G4LPhysicsFreeVector.hh"
-#include <iomanip>
 
 //#define PRINT_DEBUG
 
@@ -388,18 +389,18 @@ G4CacheValue G4IonDEDXHandler::GetCacheValue(
       entry.key = key;
       cacheEntries.push_front(entry);
 
-      CacheEntryList::iterator* pointerIter = 
+      CacheEntryList::iterator* pointerIter1 = 
                                    new CacheEntryList::iterator();
-      *pointerIter = cacheEntries.begin();
-      cacheKeyPointers[key] = pointerIter;
+      *pointerIter1 = cacheEntries.begin();
+      cacheKeyPointers[key] = pointerIter1;
 
       if(G4int(cacheEntries.size()) > maxCacheEntries) {
 
   	 G4CacheEntry lastEntry = cacheEntries.back();
 	          
-         void* pointerIter = cacheKeyPointers[lastEntry.key];
+         void* pointerIter2 = cacheKeyPointers[lastEntry.key];
          CacheEntryList::iterator* listPointerIter = 
-                      	  (CacheEntryList::iterator*) pointerIter;
+                      	  (CacheEntryList::iterator*) pointerIter2;
 
          cacheEntries.erase(*listPointerIter);
 
