@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4LivermoreBremsstrahlungModel.cc,v 1.9 2010-12-03 16:03:35 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // Author: Luciano Pandola
 //         on base of G4LowEnergyBremsstrahlung developed by A.Forti and V.Ivanchenko
@@ -45,6 +44,8 @@
 //
 
 #include "G4LivermoreBremsstrahlungModel.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleDefinition.hh"
 #include "G4MaterialCutsCouple.hh"
 
@@ -54,10 +55,10 @@
 #include "G4Electron.hh"
 #include "G4SemiLogInterpolation.hh"
 //
-#include "G4VBremAngularDistribution.hh"
+#include "G4VEmAngularDistribution.hh"
 #include "G4ModifiedTsai.hh"
 #include "G4Generator2BS.hh"
-#include "G4Generator2BN.hh"
+//#include "G4Generator2BN.hh"
 //
 #include "G4BremsstrahlungCrossSectionHandler.hh"
 //
@@ -80,11 +81,12 @@ G4LivermoreBremsstrahlungModel::G4LivermoreBremsstrahlungModel(const G4ParticleD
   SetHighEnergyLimit(fIntrinsicHighEnergyLimit);
   //
   verboseLevel = 0;
+  SetAngularDistribution(new G4Generator2BS());
   //
-  generatorName = "tsai";
-  angularDistribution = new G4ModifiedTsai("TsaiGenerator"); //default generator
+  //generatorName = "tsai";
+  //angularDistribution = new G4ModifiedTsai("TsaiGenerator"); //default generator
   //
-  TsaiAngularDistribution = new G4ModifiedTsai("TsaiGenerator");
+  //TsaiAngularDistribution = new G4ModifiedTsai("TsaiGenerator");
   //
 }
 
@@ -95,8 +97,8 @@ G4LivermoreBremsstrahlungModel::~G4LivermoreBremsstrahlungModel()
   if (crossSectionHandler) delete crossSectionHandler;
   if (energySpectrum) delete energySpectrum;
   energyBins.clear();
-  delete angularDistribution;
-  delete TsaiAngularDistribution;
+  //delete angularDistribution;
+  //delete TsaiAngularDistribution;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
@@ -270,37 +272,22 @@ void G4LivermoreBremsstrahlungModel::SampleSecondaries(std::vector<G4DynamicPart
 
   //Sample gamma energy
   G4double tGamma = energySpectrum->SampleEnergy(Z, energyCut, kineticEnergy, kineticEnergy);
+  //nothing happens
+  if (tGamma == 0.) { return; }
+
   G4double totalEnergy = kineticEnergy + electron_mass_c2;
   G4double finalEnergy = kineticEnergy - tGamma; // electron final energy  
-  G4double theta = 0;
-
-  if (tGamma == 0.) //nothing happens
-    return;
 
   //Sample gamma direction
-  //Use alternative algorithms, if it is the case.
-  if((kineticEnergy < MeV && kineticEnergy > keV))
-    { 
-      theta = angularDistribution->PolarAngle(kineticEnergy,finalEnergy,Z);
-    }
-  else
-    //Otherwise, use tsai
-    {
-      theta = TsaiAngularDistribution->PolarAngle(kineticEnergy,finalEnergy,Z);
-    }  
+  G4ThreeVector gammaDirection = 
+    GetAngularDistribution()->SampleDirection(aDynamicParticle, 
+					      totalEnergy-tGamma,
+					      Z, 
+					      couple->GetMaterial());
 
-  G4double phi   = twopi * G4UniformRand();
-  G4double dirZ  = std::cos(theta);
-  G4double sinTheta  = std::sqrt(1. - dirZ*dirZ);
-  G4double dirX  = sinTheta*std::cos(phi);
-  G4double dirY  = sinTheta*std::sin(phi);
-
-  G4ThreeVector gammaDirection (dirX, dirY, dirZ);
   G4ThreeVector electronDirection = aDynamicParticle->GetMomentumDirection();
 
-  //Update the incident particle
-  gammaDirection.rotateUz(electronDirection);   
-    
+  //Update the incident particle    
   if (finalEnergy < 0.) 
     {
       // Kinematic problem
@@ -347,7 +334,7 @@ void G4LivermoreBremsstrahlungModel::SampleSecondaries(std::vector<G4DynamicPart
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
-
+/*
 void 
 G4LivermoreBremsstrahlungModel::SetAngularGenerator(G4VBremAngularDistribution* distribution)
 {
@@ -356,37 +343,38 @@ G4LivermoreBremsstrahlungModel::SetAngularGenerator(G4VBremAngularDistribution*
   angularDistribution = distribution;
   angularDistribution->PrintGeneratorInformation();
 }
-
+*/
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
-
-void G4LivermoreBremsstrahlungModel::SetAngularGenerator(const G4String& name)
+ /*
+void G4LivermoreBremsstrahlungModel::SetAngularGenerator(const G4String& theGenName)
 {
-  if(name == generatorName) return;
-  if (name == "tsai") 
+  if(theGenName == generatorName) return;
+  if (theGenName == "tsai") 
     {
       delete angularDistribution;
       angularDistribution = new G4ModifiedTsai("TsaiGenerator");
-      generatorName = name;
+      generatorName = theGenName;
     }
-  else if (name == "2bn")
+  else if (theGenName == "2bn")
     {
       delete angularDistribution;
       angularDistribution = new G4Generator2BN("2BNGenerator");
-      generatorName = name;
+      generatorName = theGenName;
     }
-  else if (name == "2bs")
+  else if (theGenName == "2bs")
     {
       delete angularDistribution;
       angularDistribution = new G4Generator2BS("2BSGenerator");
-      generatorName = name;
+      generatorName = theGenName;
     }
   else
     {
       G4cout << "### G4LivermoreBremsstrahlungModel::SetAngularGenerator WARNING:"
-	     << " generator <" << name << "> is not known" << G4endl;
+	     << " generator <" << theGenName << "> is not known" << G4endl;
       return; 
 
     }
 
   angularDistribution->PrintGeneratorInformation();
 }
+ */
