@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4UAtomicDeexcitation.cc,v 1.11 
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // -------------------------------------------------------------------
 //
@@ -41,6 +40,7 @@
 //                   out thei ranges with Analytical one.
 // 07 Nov 2011  Alf  Restored original ioniation XS for alphas, 
 //                   letting scaled ones for other ions.   
+// 20 Mar 2012  LP   Register G4PenelopeIonisationCrossSection
 //
 // -------------------------------------------------------------------
 //
@@ -50,9 +50,10 @@
 // -------------------------------------------------------------------
 
 #include "G4UAtomicDeexcitation.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "Randomize.hh"
 #include "G4Gamma.hh"
-#include "G4Electron.hh"
 #include "G4AtomicTransitionManager.hh"
 #include "G4FluoTransition.hh"
 #include "G4Electron.hh"
@@ -62,6 +63,7 @@
 
 #include "G4teoCrossSection.hh"
 #include "G4empCrossSection.hh"
+#include "G4PenelopeIonisationCrossSection.hh"
 #include "G4LivermoreIonisationCrossSection.hh"
 #include "G4EmCorrections.hh"
 #include "G4LossTableManager.hh"
@@ -94,7 +96,6 @@ G4UAtomicDeexcitation::~G4UAtomicDeexcitation()
 
 void G4UAtomicDeexcitation::InitialiseForNewRun()
 {
- 
   if(!IsFluoActive()) { return; }
   transitionManager = G4AtomicTransitionManager::Instance();
   if(IsPIXEActive()) {
@@ -102,7 +103,7 @@ void G4UAtomicDeexcitation::InitialiseForNewRun()
     G4cout << "### === G4UAtomicDeexcitation::InitialiseForNewRun()" << G4endl;
     anaPIXEshellCS = new G4teoCrossSection("Analytical");
  
- }
+  }
   else  {return;}
   // initializing PIXE x-section name
   // 
@@ -176,6 +177,8 @@ void G4UAtomicDeexcitation::InitialiseForNewRun()
     {
       SetPIXEElectronCrossSectionModel("ProtonEmpirical");
     }
+  else if (PIXEElectronCrossSectionModel() == "Penelope")
+    SetPIXEElectronCrossSectionModel("Penelope");
   else 
     {
       G4cout << "### G4UAtomicDeexcitation::InitialiseForNewRun WARNING "
@@ -212,6 +215,10 @@ void G4UAtomicDeexcitation::InitialiseForNewRun()
 	{
 	  ePIXEshellCS = new G4LivermoreIonisationCrossSection();
 	}
+      else if (PIXEElectronCrossSectionModel() == "Penelope")
+	{
+	  ePIXEshellCS = new G4PenelopeIonisationCrossSection();
+	}
     } 
 }
 
@@ -233,12 +240,12 @@ void G4UAtomicDeexcitation::GenerateParticles(
 
   // Defined initial conditions
   G4int givenShellId = atomicShell->ShellId();
-  //  G4cout << "generating particles for vacancy in shellId: " << givenShellId << G4endl;
+  //G4cout << "generating particles for vacancy in shellId: " << givenShellId << G4endl; // debug
   minGammaEnergy = gammaCut;
   minElectronEnergy = eCut;
 
   // V.I. short-cut
-  if(!IsAugerActive()) {  minElectronEnergy = DBL_MAX; }
+  //  if(!IsAugerActive()) {  minElectronEnergy = DBL_MAX; }
 
   // generation secondaries
   G4DynamicParticle* aParticle=0;
@@ -262,12 +269,13 @@ void G4UAtomicDeexcitation::GenerateParticles(
 	    if  ( provShellId >0) 
 	      {
 		aParticle = GenerateFluorescence(Z,givenShellId,provShellId);
-		//if (aParticle != 0) { G4cout << "****FLUO!****" << G4endl;} //debug  
+		//if (aParticle != 0) { G4cout << "****FLUO!_1**** " << aParticle->GetParticleDefinition()->GetParticleType() << " " << aParticle->GetKineticEnergy()/keV << G4endl ;} //debug  
 	      }
 	    else if ( provShellId == -1)
 	      {
+		//		G4cout << "Try to generate Auger 1" << G4endl; //debug
 		aParticle = GenerateAuger(Z, givenShellId);
-		//if (aParticle != 0) { G4cout << "****AUGER!****" << G4endl;} //debug
+		//		if (aParticle != 0) { G4cout << "****AUGER!****" << G4endl;} //debug
 	      }
 	    else
 	      {
@@ -282,12 +290,13 @@ void G4UAtomicDeexcitation::GenerateParticles(
 	    if  (provShellId >0)
 	      {
 		aParticle = GenerateFluorescence(Z,newShellId,provShellId);
-		//if (aParticle != 0) { G4cout << "****FLUO!****" << G4endl;} //debug
+		//if (aParticle != 0) { G4cout << "****FLUO!_2****" << aParticle->GetParticleDefinition()->GetParticleType() << " " << aParticle->GetKineticEnergy()/keV << G4endl;} //debug
 	      }
 	    else if ( provShellId == -1)
 	      {
+		//		G4cout << "Try to generate Auger 2" << G4endl; //debug
 		aParticle = GenerateAuger(Z, newShellId);
-		//if (aParticle != 0) { G4cout << "****AUGER!****" << G4endl;} //debug
+		//		if (aParticle != 0) { G4cout << "****AUGER!****" << G4endl;} //debug
 	      }
 	    else
 	      {
@@ -309,7 +318,7 @@ void G4UAtomicDeexcitation::GenerateParticles(
       G4Exception("G4UAtomicDeexcitation::GenerateParticles()","de0001",JustWarning, "Energy deposited locally");
     }
   
-  //  G4cout << "---------FATTO!---------" << G4endl; //debug 
+  //G4cout << "---------FATTO!---------" << G4endl; //debug 
 
 }
 
@@ -333,7 +342,7 @@ G4UAtomicDeexcitation::GetShellIonisationCrossSectionPerAtom(
 
   // 
   if(pdef == theElectron || pdef == thePositron) {
-    xsec = ePIXEshellCS->CrossSection(Z,shellEnum,kineticEnergy,0.0);
+    xsec = ePIXEshellCS->CrossSection(Z,shellEnum,kineticEnergy,0.0,mat);
     return xsec;
   }
 
@@ -355,10 +364,10 @@ G4UAtomicDeexcitation::GetShellIonisationCrossSectionPerAtom(
     }
   }
   
-  if(PIXEshellCS) { xsec = PIXEshellCS->CrossSection(Z,shellEnum,escaled,mass); }
+  if(PIXEshellCS) { xsec = PIXEshellCS->CrossSection(Z,shellEnum,escaled,mass,mat); }
   if(xsec < 1e-100) { 
     
-    xsec = anaPIXEshellCS->CrossSection(Z,shellEnum,escaled,mass); 
+    xsec = anaPIXEshellCS->CrossSection(Z,shellEnum,escaled,mass,mat); 
     
   }
 
@@ -532,16 +541,20 @@ G4UAtomicDeexcitation::GenerateFluorescence(G4int Z, G4int shellId,
 
 G4DynamicParticle* G4UAtomicDeexcitation::GenerateAuger(G4int Z, G4int shellId)
 {
-  if(!IsAugerActive()) { return 0; }
-
+  if(!IsAugerActive()) { 
+    //    G4cout << "auger inactive!" << G4endl; //debug
+    return 0; 
+  }
+  
   if (shellId <=0 ) {
-    {
+    
 
       G4Exception("G4UAtomicDeexcitation::GenerateAuger()","de0002",JustWarning, "Energy deposited locally");
 
       return 0;
-    }
+    
   }
+
   // G4int provShellId = -1;
   G4int maxNumOfShells = transitionManager->NumberOfReachableAugerShells(Z);  
   
@@ -564,7 +577,7 @@ G4DynamicParticle* G4UAtomicDeexcitation::GenerateAuger(G4int Z, G4int shellId)
 	  shellNum++;
  	  if(shellNum == maxNumOfShells)
  	    {
- 	      //G4Exception("G4UAtomicDeexcitation: No Auger transition found");
+	      // 	      G4cout << "No Auger transition found" << G4endl; //debug
 	      return 0;
  	    }
 	}
@@ -686,7 +699,11 @@ G4DynamicParticle* G4UAtomicDeexcitation::GenerateAuger(G4int Z, G4int shellId)
       // and the id of the shell, from which the transition e- come (transitionRandomShellid)
       // If no Transition has been found, 0 is returned.  
 
-      if (!foundFlag) {return 0;} 
+      if (!foundFlag) {
+	//	G4cout << "Auger not found (foundflag = false) " << G4endl; //debug
+	return 0;
+
+} 
       
       // Isotropic angular distribution for the outcoming e-
       G4double newcosTh = 1.-2.*G4UniformRand();
@@ -710,7 +727,9 @@ G4DynamicParticle* G4UAtomicDeexcitation::GenerateAuger(G4int Z, G4int shellId)
       */
       
       if (transitionEnergy < minElectronEnergy) {
-	//G4cout << "Problem!" << G4endl; // debug
+	// G4cout << "Problem!  (transitionEnergy < minElectronEnergy)" << G4endl; // debug
+	// G4cout << "minElectronEnergy(KeV): " << minElectronEnergy/keV << G4endl; // debug
+	// G4cout << "transitionEnergy(KeV): " << transitionEnergy/keV << G4endl; // debug
 	return 0;
       }
 
@@ -724,7 +743,8 @@ G4DynamicParticle* G4UAtomicDeexcitation::GenerateAuger(G4int Z, G4int shellId)
     }
   else 
     {
-      //G4Exception("G4UAtomicDeexcitation: no auger transition found");
+      //      G4cout << "G4UAtomicDeexcitation: no auger transition found" << G4endl ;
+      //      G4cout << "( shellId <= refAugerTransition->FinalShellId() )" << G4endl;
       return 0;
     }
 }
