@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4PolarizedBremsstrahlungCrossSection.cc,v 1.4 2007-11-01 17:32:34 schaelic Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4PolarizedBremsstrahlungCrossSection.cc 69847 2013-05-16 09:36:18Z gcosmo $
 //
 // -------------------------------------------------------------------
 //
@@ -39,8 +38,7 @@
 //
 
 #include "G4PolarizedBremsstrahlungCrossSection.hh"
-//#include "G4ePolarizedBremsstrahlungModel.hh"
-//#include "G4Element.hh"
+#include "G4PhysicalConstants.hh"
 
 G4bool G4PolarizedBremsstrahlungCrossSection::scrnInitialized=false;
 G4double G4PolarizedBremsstrahlungCrossSection::SCRN [3][20];  
