@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4PolarizedComptonCrossSection.cc,v 1.5 2010-11-12 10:38:56 schaelic Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4PolarizedComptonCrossSection.cc 69847 2013-05-16 09:36:18Z gcosmo $
 //
 // GEANT4 Class file
 //
@@ -45,13 +44,13 @@
 //   recalculated by P.Starovoitov
 //
 #include "G4PolarizedComptonCrossSection.hh"
+#include "G4PhysicalConstants.hh"
 #include "Randomize.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
-G4PolarizedComptonCrossSection::G4PolarizedComptonCrossSection() :
-  gammaPol0(false), electronPol1(false), gammaPol2(false), electronPol3(false),
-  epsilon(0.)
-  {
+G4PolarizedComptonCrossSection::G4PolarizedComptonCrossSection() 
+  : gammaPol2(false), electronPol3(false)
+{
   SetYmin(0.);
 
   //  G4cout<<"G4PolarizedComptonCrossSection() init\n";
