@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4PolarizedComptonModel.cc,v 1.4 2007-05-23 08:52:20 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4PolarizedComptonModel.cc 69847 2013-05-16 09:36:18Z gcosmo $
 //
 // -------------------------------------------------------------------
 //
@@ -50,6 +49,7 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 #include "G4PolarizedComptonModel.hh"
+#include "G4PhysicalConstants.hh"
 #include "G4Electron.hh"
 #include "G4Gamma.hh"
 #include "Randomize.hh"
@@ -173,9 +173,9 @@ void G4PolarizedComptonModel::SampleSecondaries(std::vector<G4DynamicParticle*>*
 
   G4double epsilon, epsilonsq, onecost, sint2, greject ;
 
-  G4double epsilon0   = 1./(1. + 2.*E0_m);
-  G4double epsilon0sq = epsilon0*epsilon0;
-  G4double alpha1     = - std::log(epsilon0);
+  G4double eps0       = 1./(1. + 2.*E0_m);
+  G4double epsilon0sq = eps0*eps0;
+  G4double alpha1     = - std::log(eps0);
   G4double alpha2     = 0.5*(1.- epsilon0sq);
 
   G4double polarization = theBeamPolarization.p3()*theTargetPolarization.p3();
