@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4PolarizedPEEffectCrossSection.cc,v 1.1 2007-11-01 17:29:09 schaelic Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4PolarizedPEEffectCrossSection.cc 69847 2013-05-16 09:36:18Z gcosmo $
 //
 // GEANT4 Class file
 //
@@ -41,7 +40,7 @@
 // Class Description:
 //
 #include "G4PolarizedPEEffectCrossSection.hh"
-//#include "Randomize.hh"
+#include "G4PhysicalConstants.hh"
 
 using namespace std;
 
