@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4ePolarizedBremsstrahlung.cc,v 1.3 2007-05-23 08:52:20 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4ePolarizedBremsstrahlung.cc 69847 2013-05-16 09:36:18Z gcosmo $
 //
 // -------------------------------------------------------------------
 //
@@ -46,6 +45,7 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 #include "G4ePolarizedBremsstrahlung.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4Gamma.hh"
 #include "G4ePolarizedBremsstrahlungModel.hh"
 #include "G4UniversalFluctuation.hh"
