@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4SeltzerBergerModel.cc,v 1.18 2010-11-04 17:30:32 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // -------------------------------------------------------------------
 //
@@ -33,28 +32,22 @@
 //
 // File name:     G4SeltzerBergerModel
 //
-// Author:        Andreas Schaelicke 
+// Author:        Vladimir Ivanchenko use inheritance from Andreas Schaelicke
+//                base class implementing ultra relativistic bremsstrahlung
+//                model 
 //
-// Creation date: 12.08.2008
+// Creation date: 04.10.2011
 //
 // Modifications:
 //
-// 13.11.08    add SetLPMflag and SetLPMconstant methods
-// 13.11.08    change default LPMconstant value
-// 13.10.10    add angular distributon interface (VI)
-//
-// Main References:
-//  Y.-S.Tsai, Rev. Mod. Phys. 46 (1974) 815; Rev. Mod. Phys. 49 (1977) 421. 
-//  S.Klein,  Rev. Mod. Phys. 71 (1999) 1501.
-//  T.Stanev et.al., Phys. Rev. D25 (1982) 1291.
-//  M.L.Ter-Mikaelian, High-energy Electromagnetic Processes in Condensed Media, Wiley, 1972.
-//
 // -------------------------------------------------------------------
 //
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 #include "G4SeltzerBergerModel.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4Electron.hh"
 #include "G4Positron.hh"
 #include "G4Gamma.hh"
@@ -78,20 +71,29 @@
 
 using namespace std;
 
+G4Physics2DVector* G4SeltzerBergerModel::dataSB[101] = {0};
+G4double G4SeltzerBergerModel::ylimit[101] = {0.0};
+G4double G4SeltzerBergerModel::expnumlim = -12.;
+
 G4SeltzerBergerModel::G4SeltzerBergerModel(const G4ParticleDefinition* p,
-					   const G4String& name)
-  : G4eBremsstrahlungRelModel(p,name)
+					   const G4String& nam)
+  : G4eBremsstrahlungRelModel(p,nam),useBicubicInterpolation(false)
 {
   SetLowEnergyLimit(0.0);
   SetLPMFlag(false);
-  dataSB.resize(101,0);
+  nwarn = 0;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 G4SeltzerBergerModel::~G4SeltzerBergerModel()
 {
-  for(size_t i=0; i<101; ++i) { delete dataSB[i]; }
+  for(size_t i=0; i<101; ++i) { 
+    if(dataSB[i]) {
+      delete dataSB[i]; 
+      dataSB[i] = 0;
+    } 
+  }
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
@@ -152,8 +154,12 @@ void G4SeltzerBergerModel::ReadData(size_t Z, const char* path)
   //G4cout << "G4SeltzerBergerModel read from <" << ost.str().c_str() 
   //	 << ">" << G4endl;
   G4Physics2DVector* v = new G4Physics2DVector();
-  if(v->Retrieve(fin)) { dataSB[Z] = v; }
-  else {
+  const G4double emaxlog = 4*log(10.);
+  if(v->Retrieve(fin)) { 
+    if(useBicubicInterpolation) { v->SetBicubicInterpolation(true); }
+    dataSB[Z] = v; 
+    ylimit[Z] = v->Value(0.97, emaxlog);
+  } else {
     G4ExceptionDescription ed;
     ed << "Bremsstrahlung data file <" << ost.str().c_str()
        << "> is not retrieved!" << G4endl;
@@ -180,12 +186,15 @@ G4double G4SeltzerBergerModel::ComputeDXSectionPerAtom(G4double gammaEnergy)
   G4double cross = dataSB[Z]->Value(x,y)*invb2*millibarn/bremFactor;
   
   if(!isElectron) {
-    if(1 - x < 1.e-20) { cross = 0.0; }
-    else {
-      G4double invbeta1 = sqrt(invb2);
-      G4double e2 = kinEnergy - gammaEnergy;
-      G4double invbeta2 = (e2 + particleMass)/sqrt(e2*(e2 + 2*particleMass)); 
-      cross *= exp(twopi*fine_structure_const*currentZ*(invbeta1 - invbeta2)); 
+    G4double invbeta1 = sqrt(invb2);
+    G4double e2 = kinEnergy - gammaEnergy;
+    if(e2 > 0.0) {
+      G4double invbeta2 = (e2 + particleMass)/sqrt(e2*(e2 + 2*particleMass));
+      G4double xxx = twopi*fine_structure_const*currentZ*(invbeta1 - invbeta2);
+      if(xxx < expnumlim) { cross = 0.0; }
+      else { cross *= exp(xxx); }
+    } else {
+      cross = 0.0;
     }
   }
   
@@ -216,7 +225,6 @@ G4SeltzerBergerModel::SampleSecondaries(std::vector<G4DynamicParticle*>* vdp,
   totalEnergy = kineticEnergy + particleMass;
   densityCorr = densityFactor*totalEnergy*totalEnergy;
   G4double totMomentum = sqrt(kineticEnergy*(totalEnergy + electron_mass_c2));
-  G4ThreeVector direction = dp->GetMomentumDirection();
   /*
   G4cout << "G4SeltzerBergerModel::SampleSecondaries E(MeV)= " 
 	 << kineticEnergy/MeV
@@ -230,68 +238,84 @@ G4SeltzerBergerModel::SampleSecondaries(std::vector<G4DynamicParticle*>* vdp,
   G4double gammaEnergy, v; 
 
   // majoranta
-  G4double vmax = dataSB[Z]->Value(cut/kineticEnergy, y);
-  if(isElectron && Z > 12 && kineticEnergy < 100*keV) {
-    if((Z < 41 && kineticEnergy < 10*keV) ||
-       (Z >= 41 && Z < 61 && kineticEnergy < 50*keV) ||
-       (Z >= 61) )
-      {
-	v = 1.05*dataSB[Z]->Value(emax/kineticEnergy, y);
-	if(v > vmax) { vmax = v; }
-      }
+  G4double x0 = cut/kineticEnergy;
+  G4double vmax = dataSB[Z]->Value(x0, y)*1.02;
+  //  G4double invbeta1 = 0;
+
+  const G4double epeaklimit= 300*MeV; 
+  const G4double elowlimit = 10*keV; 
+
+  // majoranta corrected for e-
+  if(isElectron && x0 < 0.97 && 
+     ((kineticEnergy > epeaklimit) || (kineticEnergy < elowlimit))) {
+    G4double ylim = std::min(ylimit[Z],1.1*dataSB[Z]->Value(0.97, y)); 
+    if(ylim > vmax) { vmax = ylim; }
   }
+  if(x0 < 0.05) { vmax *= 1.2; }
 
   //G4cout<<"y= "<<y<<" xmin= "<<xmin<<" xmax= "<<xmax<<" vmax= "<<vmax<<G4endl;
-
+  //  G4int ncount = 0;
   do {
+    //++ncount;
     G4double x = exp(xmin + G4UniformRand()*(xmax - xmin)) - densityCorr;
     if(x < 0.0) { x = 0.0; }
     gammaEnergy = sqrt(x);
     G4double x1 = gammaEnergy/kineticEnergy;
     v = dataSB[Z]->Value(x1, y);
-        
+
+    // correction for positrons        
     if(!isElectron) {
-      if(1 - x1 < 1.e-20) { v = 0.0; }
-      else {
-	G4double e1 = kineticEnergy - cut;
-	G4double invbeta1 = (e1 + particleMass)/sqrt(e1*(e1 + 2*particleMass));
-	G4double e2 = kineticEnergy - gammaEnergy;
-	G4double invbeta2 = (e2 + particleMass)/sqrt(e2*(e2 + 2*particleMass));
-	v *= exp(twopi*fine_structure_const*currentZ*(invbeta1 - invbeta2));
-      } 
+      G4double e1 = kineticEnergy - cut;
+      G4double invbeta1 = (e1 + particleMass)/sqrt(e1*(e1 + 2*particleMass));
+      G4double e2 = kineticEnergy - gammaEnergy;
+      G4double invbeta2 = (e2 + particleMass)/sqrt(e2*(e2 + 2*particleMass));
+      G4double xxx = twopi*fine_structure_const*currentZ*(invbeta1 - invbeta2); 
+
+      if(xxx < expnumlim) { v = 0.0; }
+      else { v *= exp(xxx); }
     }
    
-    if ( v > 1.5*vmax ) {
+    if (v > 1.05*vmax && nwarn < 20) {
+      ++nwarn;
       G4cout << "### G4SeltzerBergerModel Warning: Majoranta exceeded! "
-	     << v << " > " << vmax
+	     << v << " > " << vmax << " by " << v/vmax
 	     << " Egamma(MeV)= " << gammaEnergy
 	     << " Ee(MeV)= " << kineticEnergy
 	     << " Z= " << Z << "  " << particle->GetParticleName()
+	//<< " ncount= " << ncount
 	     << G4endl;
+     
+      if ( 20 == nwarn ) {
+	G4cout << "### G4SeltzerBergerModel Warnings will not be printed anymore"
+	       << G4endl;
+      }
     }
-
   } while (v < vmax*G4UniformRand());
 
   //
   // angles of the emitted gamma. ( Z - axis along the parent particle)
   // use general interface
   //
-  G4double theta = 
-    GetAngularDistribution()->PolarAngle(totalEnergy,totalEnergy-gammaEnergy,Z);
 
-  G4double sint = sin(theta);
-  G4double phi = twopi * G4UniformRand();
-  G4ThreeVector gammaDirection(sint*cos(phi),sint*sin(phi), cos(theta));
-  gammaDirection.rotateUz(direction);
+  G4ThreeVector gammaDirection = 
+    GetAngularDistribution()->SampleDirection(dp, totalEnergy-gammaEnergy,
+					      Z, couple->GetMaterial());
 
   // create G4DynamicParticle object for the Gamma
-  G4DynamicParticle* g = 
+  G4DynamicParticle* gamma = 
     new G4DynamicParticle(theGamma,gammaDirection,gammaEnergy);
-  vdp->push_back(g);
+  vdp->push_back(gamma);
   
-  G4ThreeVector dir = totMomentum*direction - gammaEnergy*gammaDirection;
-  direction = dir.unit();
+  G4ThreeVector direction = (totMomentum*dp->GetMomentumDirection()
+			     - gammaEnergy*gammaDirection).unit();
 
+  /*
+  G4cout << "### G4SBModel: v= "
+	 << " Eg(MeV)= " << gammaEnergy
+	 << " Ee(MeV)= " << kineticEnergy
+	 << " DirE " << direction << " DirG " << gammaDirection
+	 << G4endl;
+  */
   // energy of primary
   G4double finalE = kineticEnergy - gammaEnergy;
 
