@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4UrbanMscModel93.cc,v 1.11 2010-12-23 18:31:17 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4UrbanMscModel93.cc 69120 2013-04-18 13:41:13Z vnivanch $
 //
 // -------------------------------------------------------------------
 //   
@@ -103,6 +102,8 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 #include "G4UrbanMscModel93.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "Randomize.hh"
 #include "G4Electron.hh"
 #include "G4LossTableManager.hh"
@@ -116,13 +117,11 @@
 using namespace std;
 
 G4UrbanMscModel93::G4UrbanMscModel93(const G4String& nam)
-  : G4VMscModel(nam),
-    isInitialized(false)
+  : G4VMscModel(nam)
 {
   masslimite    = 0.6*MeV;
   lambdalimit   = 1.*mm;
   fr            = 0.02;
-  //facsafety     = 0.3;
   taubig        = 8.0;
   tausmall      = 1.e-16;
   taulim        = 1.e-6;
@@ -162,9 +161,15 @@ G4UrbanMscModel93::G4UrbanMscModel93(const G4String& nam)
   third         = 1./3.;
   particle      = 0;
   theManager    = G4LossTableManager::Instance(); 
+  firstStep     = true; 
   inside        = false;  
   insideskin    = false;
 
+  numlim        = 0.01;
+  xsi           = 3.;
+  ea            = exp(-xsi);
+  eaa           = 1.-ea ;
+
   skindepth = skin*stepmin;
 
   mass = proton_mass_c2;
@@ -174,8 +179,8 @@ G4UrbanMscModel93::G4UrbanMscModel93(const G4String& nam)
 
   currentMaterialIndex = -1;
   fParticleChange = 0;
-  theLambdaTable = 0;
   couple = 0;
+  SetSampleZ(false);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -190,7 +195,6 @@ void G4UrbanMscModel93::Initialise(const G4ParticleDefinition* p,
 {
   skindepth = skin*stepmin;
 
-  if(isInitialized) { return; }
   // set values of some data members
   SetParticle(p);
 
@@ -201,9 +205,7 @@ void G4UrbanMscModel93::Initialise(const G4ParticleDefinition* p,
 	   << G4endl;
   }
 
-  fParticleChange = GetParticleChangeForMSC();
-
-  isInitialized = true;
+  fParticleChange = GetParticleChangeForMSC(p);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -214,23 +216,24 @@ G4double G4UrbanMscModel93::ComputeCrossSectionPerAtom(
                                    G4double AtomicNumber,G4double,
 				   G4double, G4double)
 {
-  const G4double sigmafactor = twopi*classic_electr_radius*classic_electr_radius;
-  const G4double epsfactor = 2.*electron_mass_c2*electron_mass_c2*
+  static const G4double sigmafactor = 
+    twopi*classic_electr_radius*classic_electr_radius;
+  static const G4double epsfactor = 2.*electron_mass_c2*electron_mass_c2*
                             Bohr_radius*Bohr_radius/(hbarc*hbarc);
-  const G4double epsmin = 1.e-4 , epsmax = 1.e10;
+  static const G4double epsmin = 1.e-4 , epsmax = 1.e10;
 
-  const G4double Zdat[15] = { 4.,  6., 13., 20., 26., 29., 32., 38., 47.,
-                             50., 56., 64., 74., 79., 82. };
+  static const G4double Zdat[15] = { 4.,  6., 13., 20., 26., 29., 32., 38., 47.,
+				     50., 56., 64., 74., 79., 82. };
 
-  const G4double Tdat[22] = { 100*eV,  200*eV,  400*eV,  700*eV,
-                               1*keV,   2*keV,   4*keV,   7*keV,
-			      10*keV,  20*keV,  40*keV,  70*keV,
-                             100*keV, 200*keV, 400*keV, 700*keV,
-                               1*MeV,   2*MeV,   4*MeV,   7*MeV,
-			      10*MeV,  20*MeV};
+  static const G4double Tdat[22] = { 100*eV,  200*eV,  400*eV,  700*eV,
+				     1*keV,   2*keV,   4*keV,   7*keV,
+				     10*keV,  20*keV,  40*keV,  70*keV,
+				     100*keV, 200*keV, 400*keV, 700*keV,
+				     1*MeV,   2*MeV,   4*MeV,   7*MeV,
+				     10*MeV,  20*MeV};
 
   // corr. factors for e-/e+ lambda for T <= Tlim
-          G4double celectron[15][22] =
+  static const G4double celectron[15][22] =
           {{1.125,1.072,1.051,1.047,1.047,1.050,1.052,1.054,
             1.054,1.057,1.062,1.069,1.075,1.090,1.105,1.111,
             1.112,1.108,1.100,1.093,1.089,1.087            },
@@ -277,7 +280,7 @@ G4double G4UrbanMscModel93::ComputeCrossSectionPerAtom(
             1.985,1.609,1.343,1.188,1.113,1.013,0.960,0.939,
             0.933,0.930,0.933,0.936,0.939,0.949            }};
 	    
-           G4double cpositron[15][22] = {
+  static const G4double cpositron[15][22] = {
            {2.589,2.044,1.658,1.446,1.347,1.217,1.144,1.110,
             1.097,1.083,1.080,1.086,1.092,1.108,1.123,1.131,
             1.131,1.126,1.117,1.108,1.103,1.100            },
@@ -325,25 +328,27 @@ G4double G4UrbanMscModel93::ComputeCrossSectionPerAtom(
             1.456,1.412,1.364,1.328,1.307,1.282            }};
 
   //data/corrections for T > Tlim  
-  G4double Tlim = 10.*MeV;
-  G4double beta2lim = Tlim*(Tlim+2.*electron_mass_c2)/
+  static const G4double Tlim = 10.*MeV;
+  static const G4double beta2lim = Tlim*(Tlim+2.*electron_mass_c2)/
                       ((Tlim+electron_mass_c2)*(Tlim+electron_mass_c2));
-  G4double bg2lim   = Tlim*(Tlim+2.*electron_mass_c2)/
+  static const G4double bg2lim   = Tlim*(Tlim+2.*electron_mass_c2)/
                       (electron_mass_c2*electron_mass_c2);
 
-  G4double sig0[15] = {0.2672*barn,  0.5922*barn, 2.653*barn,  6.235*barn,
+  static const G4double sig0[15] = {
+                     0.2672*barn,  0.5922*barn, 2.653*barn,  6.235*barn,
                       11.69*barn  , 13.24*barn  , 16.12*barn, 23.00*barn ,
 		      35.13*barn  , 39.95*barn  , 50.85*barn, 67.19*barn ,
                       91.15*barn  , 104.4*barn  , 113.1*barn};
 		      		       
-  G4double hecorr[15] = {120.70, 117.50, 105.00, 92.92, 79.23,  74.510,  68.29,
+  static const G4double hecorr[15] = {
+                         120.70, 117.50, 105.00, 92.92, 79.23,  74.510,  68.29,
                           57.39,  41.97,  36.14, 24.53, 10.21,  -7.855, -16.84,
 			 -22.30};
 
   G4double sigma;
   SetParticle(part);
 
-  G4double Z23 = 2.*log(AtomicNumber)/3.; Z23 = exp(Z23);
+  Z23 = pow(AtomicNumber,2./3.); 
 
   // correction if particle .ne. e-/e+
   // compute equivalent kinetic energy
@@ -383,10 +388,10 @@ G4double G4UrbanMscModel93::ComputeCrossSectionPerAtom(
   if (iZ==14)                               iZ = 13;
   if (iZ==-1)                               iZ = 0 ;
 
-  G4double Z1 = Zdat[iZ];
-  G4double Z2 = Zdat[iZ+1];
-  G4double ratZ = (AtomicNumber-Z1)*(AtomicNumber+Z1)/
-                  ((Z2-Z1)*(Z2+Z1));
+  G4double ZZ1 = Zdat[iZ];
+  G4double ZZ2 = Zdat[iZ+1];
+  G4double ratZ = (AtomicNumber-ZZ1)*(AtomicNumber+ZZ1)/
+                  ((ZZ2-ZZ1)*(ZZ2+ZZ1));
 
   if(eKineticEnergy <= Tlim) 
   {
@@ -437,12 +442,12 @@ G4double G4UrbanMscModel93::ComputeCrossSectionPerAtom(
   {
     c1 = bg2lim*sig0[iZ]*(1.+hecorr[iZ]*(beta2-beta2lim))/bg2;
     c2 = bg2lim*sig0[iZ+1]*(1.+hecorr[iZ+1]*(beta2-beta2lim))/bg2;
-    if((AtomicNumber >= Z1) && (AtomicNumber <= Z2))
+    if((AtomicNumber >= ZZ1) && (AtomicNumber <= ZZ2))
       sigma = c1+ratZ*(c2-c1) ;
-    else if(AtomicNumber < Z1)
-      sigma = AtomicNumber*AtomicNumber*c1/(Z1*Z1);
-    else if(AtomicNumber > Z2)
-      sigma = AtomicNumber*AtomicNumber*c2/(Z2*Z2);
+    else if(AtomicNumber < ZZ1)
+      sigma = AtomicNumber*AtomicNumber*c1/(ZZ1*ZZ1);
+    else if(AtomicNumber > ZZ2)
+      sigma = AtomicNumber*AtomicNumber*c2/(ZZ2*ZZ2);
   }
   return sigma;
 
@@ -450,33 +455,38 @@ G4double G4UrbanMscModel93::ComputeCrossSectionPerAtom(
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
+void G4UrbanMscModel93::StartTracking(G4Track* track)
+{
+  SetParticle(track->GetDynamicParticle()->GetDefinition());
+  firstStep = true; 
+  inside = false;
+  insideskin = false;
+  tlimit = geombig;
+  stepmin = tlimitminfix ;
+  tlimitmin = 10.*stepmin ;
+}
+
+//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
+
 G4double G4UrbanMscModel93::ComputeTruePathLengthLimit(
                              const G4Track& track,
-			     G4PhysicsTable* theTable,
-			     G4double currentMinimalStep)
+			     G4double& currentMinimalStep)
 {
   tPathLength = currentMinimalStep;
+  const G4DynamicParticle* dp = track.GetDynamicParticle();
   G4StepPoint* sp = track.GetStep()->GetPreStepPoint();
   G4StepStatus stepStatus = sp->GetStepStatus();
-
-  const G4DynamicParticle* dp = track.GetDynamicParticle();
-
-  if(stepStatus == fUndefined) {
-    inside = false;
-    insideskin = false;
-    tlimit = geombig;
-    SetParticle( dp->GetDefinition() );
-  }
-
-  theLambdaTable = theTable;
   couple = track.GetMaterialCutsCouple();
+  SetCurrentCouple(couple); 
   currentMaterialIndex = couple->GetIndex();
   currentKinEnergy = dp->GetKineticEnergy();
   currentRange = GetRange(particle,currentKinEnergy,couple);
-  lambda0 = GetLambda(currentKinEnergy);
+  lambda0 = GetTransportMeanFreePath(particle,currentKinEnergy);
 
   // stop here if small range particle
-  if(inside) { return tPathLength; }            
+  if(inside || tPathLength < tlimitminfix) { 
+    return ConvertTrueToGeom(tPathLength, currentMinimalStep); 
+  } 
   
   if(tPathLength > currentRange) { tPathLength = currentRange; }
 
@@ -491,7 +501,7 @@ G4double G4UrbanMscModel93::ComputeTruePathLengthLimit(
   if(currentRange < presafety)
     {
       inside = true;
-      return tPathLength;  
+      return ConvertTrueToGeom(tPathLength, currentMinimalStep);  
     }
 
   // standard  version
@@ -499,22 +509,22 @@ G4double G4UrbanMscModel93::ComputeTruePathLengthLimit(
   if (steppingAlgorithm == fUseDistanceToBoundary)
     {
       //compute geomlimit and presafety 
-      G4double geomlimit = ComputeGeomLimit(track, presafety, currentRange);
+      geomlimit = ComputeGeomLimit(track, presafety, currentRange);
 
       // is it far from boundary ?
       if(currentRange < presafety)
 	{
 	  inside = true;
-	  return tPathLength;   
+	  return ConvertTrueToGeom(tPathLength, currentMinimalStep);   
 	}
 
       smallstep += 1.;
       insideskin = false;
 
-      if((stepStatus == fGeomBoundary) || (stepStatus == fUndefined))
+      if(firstStep || stepStatus == fGeomBoundary)
         {
           rangeinit = currentRange;
-          if(stepStatus == fUndefined) smallstep = 1.e10;
+          if(firstStep) smallstep = 1.e10;
           else  smallstep = 1.;
 
           //define stepmin here (it depends on lambda!)
@@ -563,7 +573,7 @@ G4double G4UrbanMscModel93::ComputeTruePathLengthLimit(
       // shortcut
       if((tPathLength < tlimit) && (tPathLength < presafety) &&
          (smallstep >= skin) && (tPathLength < geomlimit-0.999*skindepth))
-	return tPathLength;   
+	return ConvertTrueToGeom(tPathLength, currentMinimalStep);   
 
       // step reduction near to boundary
       if(smallstep < skin)
@@ -588,8 +598,7 @@ G4double G4UrbanMscModel93::ComputeTruePathLengthLimit(
       if(tlimit < stepmin) tlimit = stepmin;
 
       // randomize 1st step or 1st 'normal' step in volume
-      if((stepStatus == fUndefined) ||
-         ((smallstep == skin) && !insideskin)) 
+      if(firstStep || ((smallstep == skin) && !insideskin)) 
         { 
           G4double temptlimit = tlimit;
           if(temptlimit > tlimitmin)
@@ -622,10 +631,10 @@ G4double G4UrbanMscModel93::ComputeTruePathLengthLimit(
       if(currentRange < presafety)
         {
           inside = true;
-          return tPathLength;  
+          return ConvertTrueToGeom(tPathLength, currentMinimalStep);  
         }
 
-      if((stepStatus == fGeomBoundary) || (stepStatus == fUndefined))
+      if(firstStep || stepStatus == fGeomBoundary)
       {
         rangeinit = currentRange;
         fr = facrange;
@@ -671,13 +680,14 @@ G4double G4UrbanMscModel93::ComputeTruePathLengthLimit(
     }
   //G4cout << "tPathLength= " << tPathLength 
   //	 << " currentMinimalStep= " << currentMinimalStep << G4endl;
-  return tPathLength ;
+  return ConvertTrueToGeom(tPathLength, currentMinimalStep);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 G4double G4UrbanMscModel93::ComputeGeomPathLength(G4double)
 {
+  firstStep = false; 
   lambdaeff = lambda0;
   par1 = -1. ;  
   par2 = par3 = 0. ;  
@@ -715,7 +725,7 @@ G4double G4UrbanMscModel93::ComputeGeomPathLength(G4double)
       zmean = 1./(par1*par3) ;
   } else {
     G4double T1 = GetEnergy(particle,currentRange-tPathLength,couple);
-    G4double lambda1 = GetLambda(T1);
+    G4double lambda1 = GetTransportMeanFreePath(particle,T1);
 
     par1 = (lambda0-lambda1)/(lambda0*tPathLength) ;
     par2 = 1./(par1*lambda0) ;
@@ -786,6 +796,7 @@ G4double G4UrbanMscModel93::ComputeTrueStepLength(G4double geomStepLength)
     }  
   }
   if(tPathLength < geomStepLength) tPathLength = geomStepLength;
+
   //G4cout << "tPathLength= " << tPathLength << " step= " << geomStepLength << G4endl;
 
   return tPathLength;
@@ -799,7 +810,7 @@ G4double G4UrbanMscModel93::ComputeTheta0(G4double trueStepLength,
   // for all particles take the width of the central part
   //  from a  parametrization similar to the Highland formula
   // ( Highland formula: Particle Physics Booklet, July 2002, eq. 26.10)
-  const G4double c_highland = 13.6*MeV ;
+  static const G4double c_highland = 13.6*MeV ;
   G4double betacp = sqrt(currentKinEnergy*(currentKinEnergy+2.*mass)*
                          KineticEnergy*(KineticEnergy+2.*mass)/
                       ((currentKinEnergy+mass)*(KineticEnergy+mass)));
@@ -816,47 +827,53 @@ G4double G4UrbanMscModel93::ComputeTheta0(G4double trueStepLength,
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-void G4UrbanMscModel93::SampleScattering(const G4DynamicParticle* dynParticle,
-					 G4double safety)
+G4ThreeVector& 
+G4UrbanMscModel93::SampleScattering(const G4ThreeVector& oldDirection,
+				    G4double safety)
 {
-  G4double kineticEnergy = dynParticle->GetKineticEnergy();
-
-  if((kineticEnergy <= 0.0) || (tPathLength <= tlimitminfix) ||
-     (tPathLength/tausmall < lambda0)) return;
+  fDisplacement.set(0.0,0.0,0.0);
+  G4double kineticEnergy = currentKinEnergy;
+  if (tPathLength > currentRange*dtrl) {
+    kineticEnergy = GetEnergy(particle,currentRange-tPathLength,couple);
+  } else {
+    kineticEnergy -= tPathLength*GetDEDX(particle,currentKinEnergy,couple);
+  }
+  if((kineticEnergy <= eV) || (tPathLength <= tlimitminfix) ||
+     (tPathLength/tausmall < lambda0)) { return  fDisplacement; }
 
   G4double cth  = SampleCosineTheta(tPathLength,kineticEnergy);
 
   // protection against 'bad' cth values
-  if(std::fabs(cth) > 1.) return;
+  if(std::fabs(cth) > 1.) { return  fDisplacement; }
 
   // extra protection agaist high energy particles backscattered 
-  if(cth < 1.0 - 1000*tPathLength/lambda0 && kineticEnergy > 20*MeV) { 
+  //  if(cth < 1.0 - 1000*tPathLength/lambda0 && kineticEnergy > 20*MeV) { 
     //G4cout << "Warning: large scattering E(MeV)= " << kineticEnergy 
     //	   << " s(mm)= " << tPathLength/mm
     //	   << " 1-cosTheta= " << 1.0 - cth << G4endl;
     // do Gaussian central scattering
-    if(kineticEnergy > GeV && cth < 0.0) {
-      G4ExceptionDescription ed;
-      ed << dynParticle->GetDefinition()->GetParticleName()
-	 << " E(MeV)= " << kineticEnergy/MeV
-	 << " Step(mm)= " << tPathLength/mm
-	 << " in " << CurrentCouple()->GetMaterial()->GetName()
-	 << " CosTheta= " << cth 
-	 << " is too big - the angle is resampled" << G4endl;
-      G4Exception("G4UrbanMscModel93::SampleScattering","em0004",
-		  JustWarning, ed,"");
-    }
-    do {
-      cth = 1.0 + 2*log(G4UniformRand())*tPathLength/lambda0;
-    } while(cth < -1.0);
+  //  if(kineticEnergy > 0.5*GeV && cth < 0.9) {
+  /*
+  if(cth < 1.0 - 1000*tPathLength/lambda0 && 
+     cth < 0.9 && kineticEnergy > 500*MeV) { 
+    G4ExceptionDescription ed;
+    ed << particle->GetParticleName()
+       << " E(MeV)= " << kineticEnergy/MeV
+       << " Step(mm)= " << tPathLength/mm
+       << " tau= " << tPathLength/lambda0
+       << " in " << CurrentCouple()->GetMaterial()->GetName()
+       << " CosTheta= " << cth 
+       << " is too big";
+    G4Exception("G4UrbanMscModel93::SampleScattering","em0004",
+		JustWarning, ed,"");
   }
+  */
 
   G4double sth  = sqrt((1.0 - cth)*(1.0 + cth));
   G4double phi  = twopi*G4UniformRand();
   G4double dirx = sth*cos(phi);
   G4double diry = sth*sin(phi);
 
-  G4ThreeVector oldDirection = dynParticle->GetMomentumDirection();
   G4ThreeVector newDirection(dirx,diry,cth);
   newDirection.rotateUz(oldDirection);
   fParticleChange->ProposeMomentumDirection(newDirection);
@@ -890,15 +907,14 @@ void G4UrbanMscModel93::SampleScattering(const G4DynamicParticle* dynParticle,
             Phi = phi-psi;
         }
 
-        dirx = std::cos(Phi);
-        diry = std::sin(Phi);
+        dirx = r*std::cos(Phi);
+        diry = r*std::sin(Phi);
 
-        G4ThreeVector latDirection(dirx,diry,0.0);
-        latDirection.rotateUz(oldDirection);
-
-	ComputeDisplacement(fParticleChange, latDirection, r, safety);
+	fDisplacement.set(dirx,diry,0.0);
+	fDisplacement.rotateUz(oldDirection);
       }
   }
+  return fDisplacement;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -967,72 +983,131 @@ G4double G4UrbanMscModel93::SampleCosineTheta(G4double trueStepLength,
     if (tau >= taubig) cth = -1.+2.*G4UniformRand();
     else if (tau >= tausmall)
     {
-      G4double xsi = 3.;
-      G4double x0 = 1.;
-      G4double a = 1., ea = 0., eaa = 1.;
-      G4double b=2.,b1=3.,bx=1.,eb1=3.,ebx=1.;
-      G4double prob = 1. , qprob = 1. ;
-      G4double xmean1 = 1., xmean2 = 0.;
-      G4double xmeanth = exp(-tau);
-      G4double x2meanth = (1.+2.*exp(-2.5*tau))/3.;
-
+      G4double xmeanth, x2meanth;
+      if(tau < numlim) {
+	xmeanth = 1.0 - tau*(1.0 - 0.5*tau);
+        x2meanth= 1.0 - tau*(5.0 - 6.25*tau)/3.;
+      } else {
+	xmeanth = exp(-tau);
+	x2meanth = (1.+2.*exp(-2.5*tau))/3.;
+      }
       G4double relloss = 1.-KineticEnergy/currentKinEnergy;
+
       if(relloss > rellossmax) 
         return SimpleScattering(xmeanth,x2meanth);
 
       G4double theta0 = ComputeTheta0(trueStepLength,KineticEnergy);
 
+      //G4cout << "Theta0= " << theta0 << " theta0max= " << theta0max 
+      //	     << "  sqrt(tausmall)= " << sqrt(tausmall) << G4endl;
+
       // protection for very small angles
-      if(theta0*theta0 < tausmall) return cth;
+      G4double theta2 = theta0*theta0;
+
+      if(theta2 < tausmall) { return cth; }
     
-      if(theta0 > theta0max)
+      if(theta0 > theta0max) {
         return SimpleScattering(xmeanth,x2meanth);
-      G4double sth = sin(0.5*theta0);
-      a = 0.25/(sth*sth);
+      }
 
-      ea = exp(-xsi);
-      eaa = 1.-ea ;
-      xmean1 = 1.-(1.-(1.+xsi)*ea)/(a*eaa);
-      x0 = 1.-xsi/a;
+      G4double x = theta2*(1.0 - theta2/12.);
+      if(theta2 > numlim) {
+	G4double sth = 2.*sin(0.5*theta0);
+	x = sth*sth;
+      }
 
-      if(xmean1 <= 0.999*xmeanth)
+      G4double xmean1 = 1.-(1.-(1.+xsi)*ea)*x/eaa;
+      G4double x0 = 1. - xsi*x;
+
+      // G4cout << " xmean1= " << xmean1 << "  xmeanth= " << xmeanth << G4endl;
+
+      if(xmean1 <= 0.999*xmeanth) {
         return SimpleScattering(xmeanth,x2meanth);
-
+      }
       // from e- and muon scattering data                    
-      G4double c = coeffc1+coeffc2*y; ;                         
+      G4double c = coeffc1+coeffc2*y; 
 
-      if(abs(c-3.) < 0.001)  c = 3.001;      
-      if(abs(c-2.) < 0.001)  c = 2.001;      
-      if(abs(c-1.) < 0.001)  c = 1.001;      
+      // tail should not be too big
+      if(c < 1.9) { 
+	/*
+	if(KineticEnergy > 200*MeV && c < 1.6) {
+	  G4cout << "G4UrbanMscModel93::SampleCosineTheta: E(GeV)= " 
+		 << KineticEnergy/GeV 
+		 << " !!** c= " << c
+		 << " **!! length(mm)= " << trueStepLength << " Zeff= " << Zeff 
+		 << " " << couple->GetMaterial()->GetName()
+		 << " tau= " << tau << G4endl;
+	}
+	*/
+	c = 1.9; 
+      }
+
+      if(fabs(c-3.) < 0.001)      { c = 3.001; }
+      else if(fabs(c-2.) < 0.001) { c = 2.001; }
 
       G4double c1 = c-1.;
 
       //from continuity of derivatives
-      b = 1.+(c-xsi)/a;
+      G4double b = 1.+(c-xsi)*x;
 
-      b1 = b+1.;
-      bx = c/a;
-      eb1 = exp(c1*log(b1));
-      ebx = exp(c1*log(bx));
+      G4double b1 = b+1.;
+      G4double bx = c*x;
 
-      xmean2 = (x0*eb1+ebx-(eb1*bx-b1*ebx)/(c-2.))/(eb1-ebx);
+      G4double eb1 = pow(b1,c1);
+      G4double ebx = pow(bx,c1);
+      G4double d = ebx/eb1;
+
+      // G4double xmean2 = (x0*eb1+ebx-(eb1*bx-b1*ebx)/(c-2.))/(eb1-ebx);
+      G4double xmean2 = (x0 + d - (bx - b1*d)/(c-2.))/(1. - d);
       
-      G4double f1x0 = a*ea/eaa;
-      G4double f2x0 = c1*eb1/(bx*(eb1-ebx));
-      prob = f2x0/(f1x0+f2x0);
+      G4double f1x0 = ea/eaa;
+      G4double f2x0 = c1/(c*(1. - d));
+      G4double prob = f2x0/(f1x0+f2x0);
 
-      qprob = xmeanth/(prob*xmean1+(1.-prob)*xmean2);
+      G4double qprob = xmeanth/(prob*xmean1+(1.-prob)*xmean2);
 
       // sampling of costheta
+      //G4cout << "c= " << c << " qprob= " << qprob << " eb1= " << eb1
+      // << " c1= " << c1 << " b1= " << b1 << " bx= " << bx << " eb1= " << eb1
+      //	     << G4endl;
       if(G4UniformRand() < qprob)
       {
-        if(G4UniformRand() < prob)
-          cth = 1.+log(ea+G4UniformRand()*eaa)/a ;
-        else
-          cth = b-b1*bx/exp(log(ebx+(eb1-ebx)*G4UniformRand())/c1) ;
+        G4double var = 0;
+        if(G4UniformRand() < prob) {
+          cth = 1.+log(ea+G4UniformRand()*eaa)*x;
+        } else {
+          var = (1.0 - d)*G4UniformRand();
+          if(var < numlim*d) {
+            var /= (d*c1); 
+            cth = -1.0 + var*(1.0 - 0.5*var*c)*(2. + (c - xsi)*x);
+	  } else {
+	    cth = 1. + x*(c - xsi - c*pow(var + d, -1.0/c1));
+	    //b-b1*bx/exp(log(ebx+(eb1-ebx)*G4UniformRand())/c1) ;
+	  }
+	}
+	if(KineticEnergy > 5*GeV && cth < 0.9) {
+	  G4cout << "G4UrbanMscModel93::SampleCosineTheta: E(GeV)= " 
+		 << KineticEnergy/GeV 
+		 << " 1-cosT= " << 1 - cth
+		 << " length(mm)= " << trueStepLength << " Zeff= " << Zeff 
+		 << " tau= " << tau
+		 << " prob= " << prob << " var= " << var << G4endl;
+	  G4cout << "  c= " << c << " qprob= " << qprob << " eb1= " << eb1
+		 << " ebx= " << ebx
+		 << " c1= " << c1 << " b= " << b << " b1= " << b1 
+		 << " bx= " << bx << " d= " << d
+		 << " ea= " << ea << " eaa= " << eaa << G4endl;
+	}
       }
-      else
+      else {
         cth = -1.+2.*G4UniformRand();
+	if(KineticEnergy > 5*GeV) {
+	  G4cout << "G4UrbanMscModel93::SampleCosineTheta: E(GeV)= " 
+		 << KineticEnergy/GeV 
+		 << " length(mm)= " << trueStepLength << " Zeff= " << Zeff 
+		 << " qprob= " << qprob << G4endl;
+	}
+      }
     }
   }  
   return cth ;
