@@ -46,6 +46,9 @@
 // facsafety optimization is back for UseSafety
 // 10-10-2011 L.Urban 
 //  facsafety=0.5 instead of 0.3  
+// 12-04-2012 L.Urban
+// correction of tail for high energy/small step
+//
 //
 // Class Description:
 //
@@ -62,6 +65,8 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 #include "G4UrbanMscModel95.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "Randomize.hh"
 #include "G4Electron.hh"
 #include "G4LossTableManager.hh"
@@ -69,14 +74,14 @@
 
 #include "G4Poisson.hh"
 #include "globals.hh"
+#include "G4Pow.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 using namespace std;
 
 G4UrbanMscModel95::G4UrbanMscModel95(const G4String& nam)
-  : G4VMscModel(nam),
-    isInitialized(false)
+  : G4VMscModel(nam)
 {
   masslimite    = 0.6*MeV;
   lambdalimit   = 1.*mm;
@@ -123,6 +128,7 @@ G4UrbanMscModel95::G4UrbanMscModel95(const G4String& nam)
   third         = 1./3.;
   particle      = 0;
   theManager    = G4LossTableManager::Instance(); 
+  firstStep     = true; 
   inside        = false;  
   insideskin    = false;
 
@@ -135,9 +141,8 @@ G4UrbanMscModel95::G4UrbanMscModel95(const G4String& nam)
 
   currentMaterialIndex = -1;
   fParticleChange = 0;
-  theLambdaTable = 0;
   couple = 0;
-  samplez = true;
+  SetSampleZ(false);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -151,23 +156,22 @@ void G4UrbanMscModel95::Initialise(const G4ParticleDefinition* p,
 				   const G4DataVector&)
 {
   skindepth = skin*stepmin;
+  //  trackID = -1;
 
-  if(isInitialized) { return; }
   // set values of some data members
   SetParticle(p);
-
+  /*
   if(p->GetPDGMass() > MeV) {
     G4cout << "### WARNING: G4UrbanMscModel95 model is used for " 
 	   << p->GetParticleName() << " !!! " << G4endl;
     G4cout << "###          This model should be used only for e+-" 
 	   << G4endl;
   }
-
-  fParticleChange = GetParticleChangeForMSC();
+  */
+  fParticleChange = GetParticleChangeForMSC(p);
 
   //samplez = true;
-
-  isInitialized = true;
+  //G4cout << "### G4UrbanMscModel95::Initialise done!" << G4endl;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -178,23 +182,24 @@ G4double G4UrbanMscModel95::ComputeCrossSectionPerAtom(
                                    G4double AtomicNumber,G4double,
 				   G4double, G4double)
 {
-  const G4double sigmafactor = twopi*classic_electr_radius*classic_electr_radius;
-  const G4double epsfactor = 2.*electron_mass_c2*electron_mass_c2*
+  static const G4double sigmafactor = 
+    twopi*classic_electr_radius*classic_electr_radius;
+  static const G4double epsfactor = 2.*electron_mass_c2*electron_mass_c2*
                             Bohr_radius*Bohr_radius/(hbarc*hbarc);
-  const G4double epsmin = 1.e-4 , epsmax = 1.e10;
+  static const G4double epsmin = 1.e-4 , epsmax = 1.e10;
 
-  const G4double Zdat[15] = { 4.,  6., 13., 20., 26., 29., 32., 38., 47.,
-                             50., 56., 64., 74., 79., 82. };
+  static const G4double Zdat[15] = { 4.,  6., 13., 20., 26., 29., 32., 38., 47.,
+				     50., 56., 64., 74., 79., 82. };
 
-  const G4double Tdat[22] = { 100*eV,  200*eV,  400*eV,  700*eV,
-                               1*keV,   2*keV,   4*keV,   7*keV,
-			      10*keV,  20*keV,  40*keV,  70*keV,
-                             100*keV, 200*keV, 400*keV, 700*keV,
-                               1*MeV,   2*MeV,   4*MeV,   7*MeV,
-			      10*MeV,  20*MeV};
+  static const G4double Tdat[22] = { 100*eV,  200*eV,  400*eV,  700*eV,
+				     1*keV,   2*keV,   4*keV,   7*keV,
+				     10*keV,  20*keV,  40*keV,  70*keV,
+				     100*keV, 200*keV, 400*keV, 700*keV,
+				     1*MeV,   2*MeV,   4*MeV,   7*MeV,
+				     10*MeV,  20*MeV};
 
   // corr. factors for e-/e+ lambda for T <= Tlim
-          G4double celectron[15][22] =
+  static const G4double celectron[15][22] =
           {{1.125,1.072,1.051,1.047,1.047,1.050,1.052,1.054,
             1.054,1.057,1.062,1.069,1.075,1.090,1.105,1.111,
             1.112,1.108,1.100,1.093,1.089,1.087            },
@@ -241,7 +246,7 @@ G4double G4UrbanMscModel95::ComputeCrossSectionPerAtom(
             1.985,1.609,1.343,1.188,1.113,1.013,0.960,0.939,
             0.933,0.930,0.933,0.936,0.939,0.949            }};
 	    
-           G4double cpositron[15][22] = {
+  static const G4double cpositron[15][22] = {
            {2.589,2.044,1.658,1.446,1.347,1.217,1.144,1.110,
             1.097,1.083,1.080,1.086,1.092,1.108,1.123,1.131,
             1.131,1.126,1.117,1.108,1.103,1.100            },
@@ -289,25 +294,27 @@ G4double G4UrbanMscModel95::ComputeCrossSectionPerAtom(
             1.456,1.412,1.364,1.328,1.307,1.282            }};
 
   //data/corrections for T > Tlim  
-  G4double Tlim = 10.*MeV;
-  G4double beta2lim = Tlim*(Tlim+2.*electron_mass_c2)/
+  static const G4double Tlim = 10.*MeV;
+  static const G4double beta2lim = Tlim*(Tlim+2.*electron_mass_c2)/
                       ((Tlim+electron_mass_c2)*(Tlim+electron_mass_c2));
-  G4double bg2lim   = Tlim*(Tlim+2.*electron_mass_c2)/
+  static const G4double bg2lim   = Tlim*(Tlim+2.*electron_mass_c2)/
                       (electron_mass_c2*electron_mass_c2);
 
-  G4double sig0[15] = {0.2672*barn,  0.5922*barn, 2.653*barn,  6.235*barn,
+  static const G4double sig0[15] = {
+                     0.2672*barn,  0.5922*barn, 2.653*barn,  6.235*barn,
                       11.69*barn  , 13.24*barn  , 16.12*barn, 23.00*barn ,
 		      35.13*barn  , 39.95*barn  , 50.85*barn, 67.19*barn ,
                       91.15*barn  , 104.4*barn  , 113.1*barn};
 		      		       
-  G4double hecorr[15] = {120.70, 117.50, 105.00, 92.92, 79.23,  74.510,  68.29,
+  static const G4double hecorr[15] = {
+                         120.70, 117.50, 105.00, 92.92, 79.23,  74.510,  68.29,
                           57.39,  41.97,  36.14, 24.53, 10.21,  -7.855, -16.84,
 			 -22.30};
 
   G4double sigma;
   SetParticle(part);
 
-  G4double Z23 = 2.*log(AtomicNumber)/3.; Z23 = exp(Z23);
+  Z23 = G4Pow::GetInstance()->Z23(G4lrint(AtomicNumber));
 
   // correction if particle .ne. e-/e+
   // compute equivalent kinetic energy
@@ -347,10 +354,10 @@ G4double G4UrbanMscModel95::ComputeCrossSectionPerAtom(
   if (iZ==14)                               iZ = 13;
   if (iZ==-1)                               iZ = 0 ;
 
-  G4double Z1 = Zdat[iZ];
-  G4double Z2 = Zdat[iZ+1];
-  G4double ratZ = (AtomicNumber-Z1)*(AtomicNumber+Z1)/
-                  ((Z2-Z1)*(Z2+Z1));
+  G4double ZZ1 = Zdat[iZ];
+  G4double ZZ2 = Zdat[iZ+1];
+  G4double ratZ = (AtomicNumber-ZZ1)*(AtomicNumber+ZZ1)/
+                  ((ZZ2-ZZ1)*(ZZ2+ZZ1));
 
   if(eKineticEnergy <= Tlim) 
   {
@@ -401,12 +408,12 @@ G4double G4UrbanMscModel95::ComputeCrossSectionPerAtom(
   {
     c1 = bg2lim*sig0[iZ]*(1.+hecorr[iZ]*(beta2-beta2lim))/bg2;
     c2 = bg2lim*sig0[iZ+1]*(1.+hecorr[iZ+1]*(beta2-beta2lim))/bg2;
-    if((AtomicNumber >= Z1) && (AtomicNumber <= Z2))
+    if((AtomicNumber >= ZZ1) && (AtomicNumber <= ZZ2))
       sigma = c1+ratZ*(c2-c1) ;
-    else if(AtomicNumber < Z1)
-      sigma = AtomicNumber*AtomicNumber*c1/(Z1*Z1);
-    else if(AtomicNumber > Z2)
-      sigma = AtomicNumber*AtomicNumber*c2/(Z2*Z2);
+    else if(AtomicNumber < ZZ1)
+      sigma = AtomicNumber*AtomicNumber*c1/(ZZ1*ZZ1);
+    else if(AtomicNumber > ZZ2)
+      sigma = AtomicNumber*AtomicNumber*c2/(ZZ2*ZZ2);
   }
   return sigma;
 
@@ -414,48 +421,53 @@ G4double G4UrbanMscModel95::ComputeCrossSectionPerAtom(
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
+void G4UrbanMscModel95::StartTracking(G4Track* track)
+{
+  SetParticle(track->GetDynamicParticle()->GetDefinition());
+  firstStep = true; 
+  inside = false;
+  insideskin = false;
+  tlimit = geombig;
+  stepmin = tlimitminfix ;
+  tlimitmin = 10.*stepmin ;
+}
+
+//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
+
 G4double G4UrbanMscModel95::ComputeTruePathLengthLimit(
                              const G4Track& track,
-			     G4PhysicsTable* theTable,
-			     G4double currentMinimalStep)
+			     G4double& currentMinimalStep)
 {
   tPathLength = currentMinimalStep;
+  const G4DynamicParticle* dp = track.GetDynamicParticle();
+  
   G4StepPoint* sp = track.GetStep()->GetPreStepPoint();
   G4StepStatus stepStatus = sp->GetStepStatus();
-
-  const G4DynamicParticle* dp = track.GetDynamicParticle();
-
-  if(stepStatus == fUndefined) {
-    inside = false;
-    insideskin = false;
-    tlimit = geombig;
-    SetParticle( dp->GetDefinition() );
-  }
-
-  theLambdaTable = theTable;
   couple = track.GetMaterialCutsCouple();
+  SetCurrentCouple(couple); 
   currentMaterialIndex = couple->GetIndex();
   currentKinEnergy = dp->GetKineticEnergy();
   currentRange = GetRange(particle,currentKinEnergy,couple);
-  lambda0 = GetLambda(currentKinEnergy);
-
-  // stop here if small range particle
-  if(inside) { return tPathLength; }            
-  
+  lambda0 = GetTransportMeanFreePath(particle,currentKinEnergy);
   if(tPathLength > currentRange) { tPathLength = currentRange; }
 
+  // stop here if small range particle
+  if(inside || tPathLength < tlimitminfix) { 
+    return ConvertTrueToGeom(tPathLength, currentMinimalStep); 
+  }
+  
   presafety = sp->GetSafety();
-
-  // G4cout << "G4Urban2::StepLimit tPathLength= " 
-  // 	 <<tPathLength<<" safety= " << presafety
-  //        << " range= " <<currentRange<< " lambda= "<<lambda0
-  // 	 << " Alg: " << steppingAlgorithm <<G4endl;
-
+  /*
+  G4cout << "G4Urban95::StepLimit tPathLength= " 
+   	 <<tPathLength<<" safety= " << presafety
+          << " range= " <<currentRange<< " lambda= "<<lambda0
+   	 << " Alg: " << steppingAlgorithm <<G4endl;
+  */
   // far from geometry boundary
   if(currentRange < presafety)
     {
       inside = true;
-      return tPathLength;  
+      return ConvertTrueToGeom(tPathLength, currentMinimalStep);  
     }
 
   // standard  version
@@ -463,22 +475,22 @@ G4double G4UrbanMscModel95::ComputeTruePathLengthLimit(
   if (steppingAlgorithm == fUseDistanceToBoundary)
     {
       //compute geomlimit and presafety 
-      G4double geomlimit = ComputeGeomLimit(track, presafety, currentRange);
+      geomlimit = ComputeGeomLimit(track, presafety, currentRange);
 
       // is it far from boundary ?
       if(currentRange < presafety)
 	{
 	  inside = true;
-	  return tPathLength;   
+	  return ConvertTrueToGeom(tPathLength, currentMinimalStep);   
 	}
 
       smallstep += 1.;
       insideskin = false;
 
-      if((stepStatus == fGeomBoundary) || (stepStatus == fUndefined))
+      if(firstStep || (stepStatus == fGeomBoundary))
         {
           rangeinit = currentRange;
-          if(stepStatus == fUndefined) smallstep = 1.e10;
+          if(firstStep) smallstep = 1.e10;
           else  smallstep = 1.;
 
           //define stepmin here (it depends on lambda!)
@@ -524,11 +536,11 @@ G4double G4UrbanMscModel95::ComputeTruePathLengthLimit(
 
       // shortcut
       if((tPathLength < tlimit) && (tPathLength < presafety) &&
-         (smallstep >= skin) && (tPathLength < geomlimit-0.999*skindepth))
-	return tPathLength;   
+         (smallstep > skin) && (tPathLength < geomlimit-0.999*skindepth))
+	return ConvertTrueToGeom(tPathLength, currentMinimalStep);   
 
       // step reduction near to boundary
-      if(smallstep < skin)
+      if(smallstep <= skin)
 	{
 	  tlimit = stepmin;
 	  insideskin = true;
@@ -550,8 +562,7 @@ G4double G4UrbanMscModel95::ComputeTruePathLengthLimit(
       if(tlimit < stepmin) tlimit = stepmin;
 
       // randomize 1st step or 1st 'normal' step in volume
-      if((stepStatus == fUndefined) ||
-         ((smallstep == skin) && !insideskin)) 
+      if(firstStep || ((smallstep == skin) && !insideskin)) 
         { 
           G4double temptlimit = tlimit;
           if(temptlimit > tlimitmin)
@@ -579,15 +590,20 @@ G4double G4UrbanMscModel95::ComputeTruePathLengthLimit(
       // i.e. when it is needed for optimization purposes
       if((stepStatus != fGeomBoundary) && (presafety < tlimitminfix)) 
 	presafety = ComputeSafety(sp->GetPosition(),tPathLength); 
-
+      /*
+      G4cout << "presafety= " << presafety
+	     << " firstStep= " << firstStep
+	     << " stepStatus= " << stepStatus 
+	     << G4endl;
+      */
       // is far from boundary
       if(currentRange < presafety)
         {
           inside = true;
-          return tPathLength;  
+          return ConvertTrueToGeom(tPathLength, currentMinimalStep);  
         }
 
-      if((stepStatus == fGeomBoundary) || (stepStatus == fUndefined))
+      if(firstStep || stepStatus == fGeomBoundary)
       {
         rangeinit = currentRange;
         fr = facrange;
@@ -633,13 +649,14 @@ G4double G4UrbanMscModel95::ComputeTruePathLengthLimit(
     }
   //G4cout << "tPathLength= " << tPathLength 
   //	 << " currentMinimalStep= " << currentMinimalStep << G4endl;
-  return tPathLength ;
+  return ConvertTrueToGeom(tPathLength, currentMinimalStep);
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 G4double G4UrbanMscModel95::ComputeGeomPathLength(G4double)
 {
+  firstStep = false; 
   lambdaeff = lambda0;
   par1 = -1. ;  
   par2 = par3 = 0. ;  
@@ -652,8 +669,9 @@ G4double G4UrbanMscModel95::ComputeGeomPathLength(G4double)
 
   // this correction needed to run MSC with eIoni and eBrem inactivated
   // and makes no harm for a normal run
-  if(tPathLength > currentRange)
-    tPathLength = currentRange ;
+  // It is already checked
+  // if(tPathLength > currentRange)
+  //  tPathLength = currentRange ;
 
   G4double tau   = tPathLength/lambda0 ;
 
@@ -684,15 +702,15 @@ G4double G4UrbanMscModel95::ComputeGeomPathLength(G4double)
 
   } else {
     G4double T1 = GetEnergy(particle,currentRange-tPathLength,couple);
-    G4double lambda1 = GetLambda(T1);
+    G4double lambda1 = GetTransportMeanFreePath(particle,T1);
 
-    par1 = (lambda0-lambda1)/(lambda0*tPathLength) ;
-    par2 = 1./(par1*lambda0) ;
+    par1 = (lambda0-lambda1)/(lambda0*tPathLength);
+    par2 = 1./(par1*lambda0);
     par3 = 1.+par2 ;
-    zmean = (1.-exp(par3*log(lambda1/lambda0)))/(par1*par3) ;
+    zmean = (1.-exp(par3*log(lambda1/lambda0)))/(par1*par3);
   }
 
-  zPathLength = zmean ;
+  zPathLength = zmean;
 
   //  sample z
   if(samplez)
@@ -723,7 +741,7 @@ G4double G4UrbanMscModel95::ComputeGeomPathLength(G4double)
   }
 
   if(zPathLength > lambda0) { zPathLength = lambda0; }
-  //G4cout << "zPathLength= " << zPathLength << " lambda1= " << lambda0 << G4endl;
+  //G4cout<< "zPathLength= "<< zPathLength<< " lambda1= " << lambda0 << G4endl;
   return zPathLength;
 }
 
@@ -732,29 +750,37 @@ G4double G4UrbanMscModel95::ComputeGeomPathLength(G4double)
 G4double G4UrbanMscModel95::ComputeTrueStepLength(G4double geomStepLength)
 {
   // step defined other than transportation 
-  if(geomStepLength == zPathLength && tPathLength <= currentRange)
+  if(geomStepLength == zPathLength)
     { return tPathLength; }
 
-  // t = z for very small step
   zPathLength = geomStepLength;
-  tPathLength = geomStepLength;
-  if(geomStepLength < tlimitminfix) { return tPathLength; }
+
+  // t = z for very small step
+  if(geomStepLength < tlimitminfix) { 
+    tPathLength = geomStepLength; 
   
   // recalculation
-  if((geomStepLength > lambda0*tausmall) && !insideskin)
-  {
-    if(par1 <  0.)
-      tPathLength = -lambda0*log(1.-geomStepLength/lambda0) ;
-    else 
-    {
-      if(par1*par3*geomStepLength < 1.)
-        tPathLength = (1.-exp(log(1.-par1*par3*geomStepLength)/par3))/par1 ;
-      else 
-        tPathLength = currentRange;
+  } else {
+
+    G4double tlength = geomStepLength;
+    if((geomStepLength > lambda0*tausmall) && !insideskin) {
+
+      if(par1 <  0.) {
+	tlength = -lambda0*log(1.-geomStepLength/lambda0) ;
+      } else {
+	if(par1*par3*geomStepLength < 1.) {
+	  tlength = (1.-exp(log(1.-par1*par3*geomStepLength)/par3))/par1 ;
+	} else {
+	  tlength = currentRange;
+	}
+      }
+      if(tlength < geomStepLength)   { tlength = geomStepLength; }
+      else if(tlength > tPathLength) { tlength = tPathLength; }
     }  
+    tPathLength = tlength; 
   }
-  if(tPathLength < geomStepLength) tPathLength = geomStepLength;
-  //G4cout << "tPathLength= " << tPathLength << " step= " << geomStepLength << G4endl;
+  //G4cout << "Urban95::ComputeTrueLength: tPathLength= " << tPathLength 
+  //	 << " step= " << geomStepLength << G4endl;
 
   return tPathLength;
 }
@@ -767,7 +793,7 @@ G4double G4UrbanMscModel95::ComputeTheta0(G4double trueStepLength,
   // for all particles take the width of the central part
   //  from a  parametrization similar to the Highland formula
   // ( Highland formula: Particle Physics Booklet, July 2002, eq. 26.10)
-  const G4double c_highland = 13.6*MeV ;
+  static const G4double c_highland = 13.6*MeV ;
   G4double betacp = sqrt(currentKinEnergy*(currentKinEnergy+2.*mass)*
                          KineticEnergy*(KineticEnergy+2.*mass)/
                       ((currentKinEnergy+mass)*(KineticEnergy+mass)));
@@ -784,51 +810,62 @@ G4double G4UrbanMscModel95::ComputeTheta0(G4double trueStepLength,
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-void G4UrbanMscModel95::SampleScattering(const G4DynamicParticle* dynParticle,
-					 G4double safety)
+G4ThreeVector& 
+G4UrbanMscModel95::SampleScattering(const G4ThreeVector& oldDirection,
+				    G4double safety)
 {
-  G4double kineticEnergy = dynParticle->GetKineticEnergy();
+  fDisplacement.set(0.0,0.0,0.0);
+  G4double kineticEnergy = currentKinEnergy;
+  if (tPathLength > currentRange*dtrl) {
+    kineticEnergy = GetEnergy(particle,currentRange-tPathLength,couple);
+  } else {
+    kineticEnergy -= tPathLength*GetDEDX(particle,currentKinEnergy,couple);
+  }
 
-  if((kineticEnergy <= 0.0) || (tPathLength <= tlimitminfix) ||
-     (tPathLength/tausmall < lambda0)) return;
+  if((kineticEnergy <= eV) || (tPathLength <= tlimitminfix) ||
+     (tPathLength/tausmall < lambda0)) { return fDisplacement; }
 
   G4double cth  = SampleCosineTheta(tPathLength,kineticEnergy);
 
   // protection against 'bad' cth values
-  if(std::fabs(cth) > 1.) return;
+  if(std::fabs(cth) > 1.) { return fDisplacement; }
 
   // extra protection agaist high energy particles backscattered 
-  if(cth < 1.0 - 1000*tPathLength/lambda0 && kineticEnergy > 20*MeV) { 
     //G4cout << "Warning: large scattering E(MeV)= " << kineticEnergy 
     //	   << " s(mm)= " << tPathLength/mm
     //	   << " 1-cosTheta= " << 1.0 - cth << G4endl;
     // do Gaussian central scattering
-    if(kineticEnergy > GeV && cth < 0.0) {
-      G4ExceptionDescription ed;
-      ed << dynParticle->GetDefinition()->GetParticleName()
-	 << " E(MeV)= " << kineticEnergy/MeV
-	 << " Step(mm)= " << tPathLength/mm
-	 << " in " << CurrentCouple()->GetMaterial()->GetName()
-	 << " CosTheta= " << cth 
-	 << " is too big - the angle is resampled" << G4endl;
-      G4Exception("G4UrbanMscModel95::SampleScattering","em0004",
-		  JustWarning, ed,"");
-    }
-    do {
-      cth = 1.0 + 2*log(G4UniformRand())*tPathLength/lambda0;
-    } while(cth < -1.0);
-  }
+  //if(kineticEnergy > 5*GeV && cth < 0.9) {
+  /*
+  if(cth < 1.0 - 1000*tPathLength/lambda0 
+     && cth < 0.8 && kineticEnergy > 20*MeV) { 
+    G4ExceptionDescription ed;
+    ed << particle->GetParticleName()
+       << " E(MeV)= " << kineticEnergy/MeV
+       << " Step(mm)= " << tPathLength/mm
+       << " in " << CurrentCouple()->GetMaterial()->GetName()
+       << " CosTheta= " << cth 
+       << " is too big";
+    G4Exception("G4UrbanMscModel95::SampleScattering","em0004",
+		JustWarning, ed,"");
+		}
+  */
 
   G4double sth  = sqrt((1.0 - cth)*(1.0 + cth));
   G4double phi  = twopi*G4UniformRand();
   G4double dirx = sth*cos(phi);
   G4double diry = sth*sin(phi);
 
-  G4ThreeVector oldDirection = dynParticle->GetMomentumDirection();
   G4ThreeVector newDirection(dirx,diry,cth);
   newDirection.rotateUz(oldDirection);
   fParticleChange->ProposeMomentumDirection(newDirection);
-
+  /*
+  G4cout << "G4UrbanMscModel95::SampleSecondaries: e(MeV)= " << kineticEnergy
+	 << " sinTheta= " << sth << " safety(mm)= " << safety
+	 << " trueStep(mm)= " << tPathLength
+	 << " geomStep(mm)= " << zPathLength
+	 << G4endl;
+  */
   if (latDisplasment && safety > tlimitminfix) {
 
     G4double r = SampleDisplacement();
@@ -861,12 +898,11 @@ void G4UrbanMscModel95::SampleScattering(const G4DynamicParticle* dynParticle,
         dirx = std::cos(Phi);
         diry = std::sin(Phi);
 
-        G4ThreeVector latDirection(dirx,diry,0.0);
-        latDirection.rotateUz(oldDirection);
-
-	ComputeDisplacement(fParticleChange, latDirection, r, safety);
+        fDisplacement.set(r*dirx,r*diry,0.0);
+        fDisplacement.rotateUz(oldDirection);
       }
   }
+  return fDisplacement;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -875,7 +911,9 @@ G4double G4UrbanMscModel95::SampleCosineTheta(G4double trueStepLength,
 					      G4double KineticEnergy)
 {
   G4double cth = 1. ;
-  G4double tau = trueStepLength/lambda0 ;
+  G4double tau = trueStepLength/lambda0;
+  currentTau   = tau;
+  lambdaeff    = lambda0;
 
   Zeff = couple->GetMaterial()->GetTotNbOfElectPerVolume()/
          couple->GetMaterial()->GetTotNbOfAtomsPerVolume() ;
@@ -919,7 +957,7 @@ G4double G4UrbanMscModel95::SampleCosineTheta(G4double trueStepLength,
   }
   else
   {
-    G4double lambda1 = GetLambda(KineticEnergy);
+    G4double lambda1 = GetTransportMeanFreePath(particle,KineticEnergy);
     if(std::fabs(lambda1/lambda0 - 1) > 0.01 && lambda1 > 0.)
     {
       // mean tau value
@@ -933,70 +971,143 @@ G4double G4UrbanMscModel95::SampleCosineTheta(G4double trueStepLength,
     if (tau >= taubig) cth = -1.+2.*G4UniformRand();
     else if (tau >= tausmall)
     {
-      G4double x0 = 1.;
-      G4double a = 1., ea = 0., eaa = 1.;
-      G4double b=1.,b1=2.,bx=1.,eb1=3.,ebx=1.;
-      G4double prob = 1. ;
-      G4double xmean1 = 1., xmean2 = 0.;
-      G4double xmeanth = exp(-tau);
-      G4double x2meanth = (1.+2.*exp(-2.5*tau))/3.;
-
+      static const G4double numlim = 0.01;
+      G4double xmeanth, x2meanth;
+      if(tau < numlim) {
+	xmeanth = 1.0 - tau*(1.0 - 0.5*tau);
+        x2meanth= 1.0 - tau*(5.0 - 6.25*tau)/3.;
+      } else {
+	xmeanth = exp(-tau);
+	x2meanth = (1.+2.*exp(-2.5*tau))/3.;
+      }
       G4double relloss = 1.-KineticEnergy/currentKinEnergy;
+
       if(relloss > rellossmax) 
         return SimpleScattering(xmeanth,x2meanth);
 
       G4double theta0 = ComputeTheta0(trueStepLength,KineticEnergy);
 
+      //G4cout << "Theta0= " << theta0 << " theta0max= " << theta0max 
+      //	     << "  sqrt(tausmall)= " << sqrt(tausmall) << G4endl;
+
       // protection for very small angles
-      if(theta0*theta0 < tausmall) return cth;
+      G4double theta2 = theta0*theta0;
+
+      if(theta2 < tausmall) { return cth; }
     
-      if(theta0 > theta0max)
+      if(theta0 > theta0max) {
         return SimpleScattering(xmeanth,x2meanth);
-      G4double sth = sin(0.5*theta0);
-      a = 0.25/(sth*sth);
+      }
+
+      G4double x = theta2*(1.0 - theta2/12.);
+      if(theta2 > numlim) {
+	G4double sth = 2*sin(0.5*theta0);
+	x = sth*sth;
+      }
 
       // parameter for tail
-      G4double u = exp(log(tau)/6.);
-      G4double x = log(lambdaeff/currentRadLength);
-      G4double c = coeffc1+u*(coeffc2+coeffc3*u)+coeffc4*x;
+      G4double ltau= log(tau);
+      G4double u   = exp(ltau/6.);
+      G4double xx  = log(lambdaeff/currentRadLength);
+      G4double xsi = coeffc1+u*(coeffc2+coeffc3*u)+coeffc4*xx;
+      G4double   c = xsi;
 
-      if(abs(c-3.) < 0.001)  c = 3.001;      
-      if(abs(c-2.) < 0.001)  c = 2.001;      
-      if(abs(c-1.) < 0.001)  c = 1.001;      
+      //correction of tail for high energy/small step
+      if(ltau < -10.63)
+        { c *= (0.016*ltau+1.17008); }
 
-      ea = exp(-c);
-      eaa = 1.-ea ;
-      xmean1 = 1.-(1.-(1.+c)*ea)/(a*eaa);
-      x0 = 1.-c/a;
+      // tail should not be too big
+      if(c < 1.9) { 
+	/*
+	if(KineticEnergy > 20*MeV && c < 1.6) {
+	  G4cout << "G4UrbanMscModel95::SampleCosineTheta: E(GeV)= " 
+		 << KineticEnergy/GeV 
+		 << " !!** c= " << c
+		 << " **!! length(mm)= " << trueStepLength << " Zeff= " << Zeff 
+		 << " " << couple->GetMaterial()->GetName()
+		 << " tau= " << tau << G4endl;
+	}
+	*/
+	c = 1.9; 
+      }
 
-      if(xmean1 <= 0.999*xmeanth)
-        return SimpleScattering(xmeanth,x2meanth);
+      if(fabs(c-3.) < 0.001)      { c = 3.001; }
+      else if(fabs(c-2.) < 0.001) { c = 2.001; }
 
       G4double c1 = c-1.;
 
-      bx = c/a;
-      eb1 = exp(c1*log(b1));
-      ebx = exp(c1*log(bx));
+      G4double ea = exp(-xsi);
+      G4double eaa = 1.-ea ;
+      G4double xmean1 = 1.-(1.-(1.+xsi)*ea)*x/eaa;
+      G4double x0 = 1. - xsi*x;
 
-      xmean2 = (x0*eb1+ebx-(eb1*bx-b1*ebx)/(c-2.))/(eb1-ebx);
-      
-      G4double f1x0 = a*ea/eaa;
-      G4double f2x0 = c1*eb1/(bx*(eb1-ebx));
-      prob = f2x0/(f1x0+f2x0);
+      // G4cout << " xmean1= " << xmean1 << "  xmeanth= " << xmeanth << G4endl;
+
+      if(xmean1 <= 0.999*xmeanth) {
+        return SimpleScattering(xmeanth,x2meanth);
+      }
+      //from continuity of derivatives
+      G4double b = 1.+(c-xsi)*x;
+
+      G4double b1 = b+1.;
+      G4double bx = c*x;
+
+      G4double eb1 = pow(b1,c1);
+      G4double ebx = pow(bx,c1);
+      G4double d = ebx/eb1;
+
+      G4double xmean2 = (x0 + d - (bx - b1*d)/(c-2.))/(1. - d);
+
+      G4double f1x0 = ea/eaa;
+      G4double f2x0 = c1/(c*(1. - d));
+      G4double prob = f2x0/(f1x0+f2x0);
+
+      G4double qprob = xmeanth/(prob*xmean1+(1.-prob)*xmean2);
 
       // sampling of costheta
-     G4double qprob = xmeanth/(prob*xmean1+(1.-prob)*xmean2);
-     if(G4UniformRand() < qprob)
-     {
-       if(G4UniformRand() < prob)
-         cth = 1.+log(ea+G4UniformRand()*eaa)/a ;
-       else
-         cth = b-b1*bx/exp(log(ebx+(eb1-ebx)*G4UniformRand())/c1) ;
-     }
-     else
-       cth = 2.*G4UniformRand()-1.;
+      //G4cout << "c= " << c << " qprob= " << qprob << " eb1= " << eb1
+      // << " c1= " << c1 << " b1= " << b1 << " bx= " << bx << " eb1= " << eb1
+      //	     << G4endl;
+      if(G4UniformRand() < qprob)
+      {
+        G4double var = 0;
+        if(G4UniformRand() < prob) {
+          cth = 1.+log(ea+G4UniformRand()*eaa)*x;
+        } else {
+          var = (1.0 - d)*G4UniformRand();
+          if(var < numlim*d) {
+            var /= (d*c1); 
+            cth = -1.0 + var*(1.0 - 0.5*var*c)*(2. + (c - xsi)*x);
+	  } else {
+	    cth = 1. + x*(c - xsi - c*pow(var + d, -1.0/c1));
+	    //b-b1*bx/exp(log(ebx+(eb1-ebx)*G4UniformRand())/c1) ;
+	  }
+	}
+	if(KineticEnergy > 5*GeV && cth < 0.9) {
+	  G4cout << "G4UrbanMscModel95::SampleCosineTheta: E(GeV)= " 
+		 << KineticEnergy/GeV 
+		 << " 1-cosT= " << 1 - cth
+		 << " length(mm)= " << trueStepLength << " Zeff= " << Zeff 
+		 << " tau= " << tau
+		 << " prob= " << prob << " var= " << var << G4endl;
+	  G4cout << "  c= " << c << " qprob= " << qprob << " eb1= " << eb1
+		 << " ebx= " << ebx
+		 << " c1= " << c1 << " b= " << b << " b1= " << b1 
+		 << " bx= " << bx << " d= " << d
+		 << " ea= " << ea << " eaa= " << eaa << G4endl;
+	}
+      }
+      else {
+        cth = -1.+2.*G4UniformRand();
+	if(KineticEnergy > 5*GeV) {
+	  G4cout << "G4UrbanMscModel95::SampleCosineTheta: E(GeV)= " 
+		 << KineticEnergy/GeV 
+		 << " length(mm)= " << trueStepLength << " Zeff= " << Zeff 
+		 << " qprob= " << qprob << G4endl;
+	}
+      }
     }
-  }  
+  }
   return cth ;
 }
 
@@ -1034,8 +1145,8 @@ G4double G4UrbanMscModel95::SampleDisplacement()
 
 G4double G4UrbanMscModel95::LatCorrelation()
 {
-  const G4double kappa = 2.5;
-  const G4double kappami1 = kappa-1.;
+  static const G4double kappa = 2.5;
+  static const G4double kappami1 = kappa-1.;
 
   G4double latcorr = 0.;
   if((currentTau >= tausmall) && !insideskin)
