@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4WentzelOKandVIxSection.cc,v 1.14 2010-11-13 19:08:27 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4WentzelOKandVIxSection.cc 69141 2013-04-19 09:36:47Z vnivanch $
 //
 // -------------------------------------------------------------------
 //
@@ -48,6 +47,8 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 #include "G4WentzelOKandVIxSection.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "Randomize.hh"
 #include "G4Electron.hh"
 #include "G4Positron.hh"
@@ -56,8 +57,9 @@
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
-G4double G4WentzelOKandVIxSection::ScreenRSquare[] = {0.0};
-G4double G4WentzelOKandVIxSection::FormFactor[]    = {0.0};
+G4double G4WentzelOKandVIxSection::ScreenRSquareElec[] = {0.0};
+G4double G4WentzelOKandVIxSection::ScreenRSquare[]     = {0.0};
+G4double G4WentzelOKandVIxSection::FormFactor[]        = {0.0};
 
 using namespace std;
 
@@ -85,10 +87,14 @@ G4WentzelOKandVIxSection::G4WentzelOKandVIxSection() :
     G4double constn = 6.937e-6/(MeV*MeV);
 
     ScreenRSquare[0] = alpha2*a0*a0;
+    ScreenRSquareElec[0] = ScreenRSquare[0];
     for(G4int j=1; j<100; ++j) {
       G4double x = a0*fG4pow->Z13(j);
-      ScreenRSquare[j] = 0.5*(1 + exp(-j*j*0.001))*alpha2*x*x;
-      //ScreenRSquare[j] = alpha2*x*x;
+      if(1 == j) { ScreenRSquare[j] = 0.5*alpha2*a0*a0; }
+      else {
+	ScreenRSquare[j] = 0.5*(1 + exp(-j*j*0.001))*alpha2*x*x;
+	ScreenRSquareElec[j] = 0.5*alpha2*x*x;
+      }
       x = fNistManager->GetA27(j);
       FormFactor[j] = constn*x*x;
     } 
@@ -99,8 +105,12 @@ G4WentzelOKandVIxSection::G4WentzelOKandVIxSection() :
 
   factB1= 0.5*CLHEP::pi*fine_structure_const;
 
-  Initialise(theElectron, 1.0);
+  tkin = mom2 = momCM2 = factorA2 = mass = spin = chargeSquare = charge3 = 0.0;
+  ecut = etag = DBL_MAX;
+  targetZ = 0;
+  cosThetaMax = 1.0;
   targetMass = proton_mass_c2;
+  particle = 0;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -118,10 +128,14 @@ void G4WentzelOKandVIxSection::Initialise(const G4ParticleDefinition* p,
   ecut = etag = DBL_MAX;
   targetZ = 0;
   cosThetaMax = CosThetaLim;
-  G4double a = 
-    G4LossTableManager::Instance()->FactorForAngleLimit()*CLHEP::hbarc/CLHEP::fermi;
+  G4double a = G4LossTableManager::Instance()->FactorForAngleLimit()
+    *CLHEP::hbarc/CLHEP::fermi;
   factorA2 = 0.5*a*a;
   currentMaterial = 0;
+  
+  //G4cout << "G4WentzelOKandVIxSection::Initialise  mass= " << mass
+  //	 << "  " << p->GetParticleName() << G4endl; 
+  
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
@@ -158,18 +172,18 @@ G4WentzelOKandVIxSection::SetupTarget(G4int Z, G4double cut)
     //gam0pcmp = (etot + targetMass)*targetMass/invmass2;
     //pcmp2    = tmass2/invmass2;
 
-    kinFactor = coeff*targetZ*chargeSquare*invbeta2/mom2;
+    kinFactor = coeff*Z*chargeSquare*invbeta2/mom2;
 
-    screenZ = ScreenRSquare[targetZ]/mom2;
-    if(Z > 1) {
-      if(mass > MeV) {
-	screenZ *= std::min(Z*1.13,1.13 +3.76*Z*Z*invbeta2*alpha2*chargeSquare);
-      } else {
-	G4double tau = tkin/mass;
-	//	screenZ *= std::min(Z*invbeta2,
-	screenZ *= std::min(Z*1.13,
-        (1.13 +3.76*Z*Z*invbeta2*alpha2*std::sqrt(tau/(tau + fG4pow->Z23(Z)))));
-      }
+    if(1 == Z) {
+      screenZ = ScreenRSquare[targetZ]/mom2;
+    } else if(mass > MeV) {
+      screenZ = std::min(Z*1.13,1.13 +3.76*Z*Z*invbeta2*alpha2*chargeSquare)*
+	ScreenRSquare[targetZ]/mom2;
+    } else {
+      G4double tau = tkin/mass;
+      screenZ = std::min(Z*1.13,(1.13 +3.76*Z*Z
+	  *invbeta2*alpha2*std::sqrt(tau/(tau + fG4pow->Z23(targetZ)))))*
+	ScreenRSquareElec[targetZ]/mom2;
     }
     if(targetZ == 1 && cosTetMaxNuc2 < 0.0 && particle == theProton) {
       cosTetMaxNuc2 = 0.0;
