@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4eplusAnnihilation.cc,v 1.30 2009-02-20 12:06:37 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // -------------------------------------------------------------------
 //
@@ -105,10 +104,10 @@ void G4eplusAnnihilation::InitialiseProcess(const G4ParticleDefinition*)
 {
   if(!isInitialised) {
     isInitialised = true;
-    if(!Model(1)) { SetModel(new G4eeToTwoGammaModel(),1); }
-    Model(1)->SetLowEnergyLimit(MinKinEnergy());
-    Model(1)->SetHighEnergyLimit(MaxKinEnergy());
-    AddEmModel(1, Model(1));
+    if(!EmModel(1)) { SetEmModel(new G4eeToTwoGammaModel(),1); }
+    EmModel(1)->SetLowEnergyLimit(MinKinEnergy());
+    EmModel(1)->SetHighEnergyLimit(MaxKinEnergy());
+    AddEmModel(1, EmModel(1));
   }
 }
 
