@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4hMultipleScattering.cc,v 1.18 2010-04-16 09:01:24 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // -----------------------------------------------------------------------------
 //
@@ -46,7 +45,7 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 #include "G4hMultipleScattering.hh"
-#include "G4UrbanMscModel90.hh"
+#include "G4UrbanMscModel95.hh"
 #include "G4MscStepLimitType.hh"
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -77,8 +76,8 @@ G4bool G4hMultipleScattering::IsApplicable (const G4ParticleDefinition& p)
 void G4hMultipleScattering::InitialiseProcess(const G4ParticleDefinition*)
 {
   if(isInitialized) { return; }
-  G4VMscModel* mscUrban = new G4UrbanMscModel90();
-  AddEmModel(1,mscUrban);
+  if(!EmModel(1)) { SetEmModel(new G4UrbanMscModel95(), 1); }
+  AddEmModel(1, EmModel(1));
   isInitialized = true;
 }
 
