@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4VEnergyLoss.cc,v 1.46 2006-06-29 19:55:21 gunter Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
 // --------------------------------------------------------------
@@ -52,6 +51,8 @@
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
 
 #include "G4VEnergyLoss.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4EnergyLossMessenger.hh"
 #include "G4ProductionCutsTable.hh"
 
@@ -83,7 +84,11 @@ G4VEnergyLoss::G4VEnergyLoss(const G4String& aName , G4ProcessType aType)
      nmaxCont1(4),
      nmaxCont2(16)
 {
-  if(!ELossMessenger) { ELossMessenger = new G4EnergyLossMessenger(); }
+  if(!ELossMessenger) { 
+    G4cout << "### G4VEnergyLoss class is obsolete "
+	   << "and will be removed for the next release." << G4endl;
+    ELossMessenger = new G4EnergyLossMessenger(); 
+  }
 
   imat = 0;
   f1Fluct = f2Fluct = e1Fluct = e2Fluct = rateFluct = ipotFluct = e1LogFluct 
