@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4Scintillation.cc,v 1.38 2010-12-15 07:39:26 gunter Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 ////////////////////////////////////////////////////////////////////////
 // Scintillation Light Class Implementation
@@ -71,6 +70,8 @@
 
 #include "G4ios.hh"
 #include "globals.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleTypes.hh"
 #include "G4EmProcessSubType.hh"
 
@@ -596,12 +597,12 @@ void G4Scintillation::BuildThePhysicsTable()
                          // loop over all (photon energy, intensity)
                          // pairs stored for this material  
 
-                         for (size_t i = 1;
-                              i < theFastLightVector->GetVectorLength();
-                              i++)
+                         for (size_t ii = 1;
+                              ii < theFastLightVector->GetVectorLength();
+                              ++ii)
                          {
-                                currentPM = theFastLightVector->Energy(i);
-                                currentIN = (*theFastLightVector)[i];
+                                currentPM = theFastLightVector->Energy(ii);
+                                currentIN = (*theFastLightVector)[ii];
 
                                 currentCII = 0.5 * (prevIN + currentIN);
 
@@ -650,12 +651,12 @@ void G4Scintillation::BuildThePhysicsTable()
                          // loop over all (photon energy, intensity)
                          // pairs stored for this material
 
-                         for (size_t i = 1;
-                              i < theSlowLightVector->GetVectorLength();
-                              i++)
+                         for (size_t ii = 1;
+                              ii < theSlowLightVector->GetVectorLength();
+                              ++ii)
                          {
-                                currentPM = theSlowLightVector->Energy(i);
-                                currentIN = (*theSlowLightVector)[i];
+                                currentPM = theSlowLightVector->Energy(ii);
+                                currentIN = (*theSlowLightVector)[ii];
 
                                 currentCII = 0.5 * (prevIN + currentIN);
 
@@ -739,8 +740,8 @@ G4double G4Scintillation::sample_time(G4double tau1, G4double tau2)
           // make sure the envelope function is 
           // always larger than the bi-exponential
           G4double t = -1.0*tau2*std::log(1-ran1);
-          G4double g = d*single_exp(t,tau2);
-          if (ran2 <= bi_exp(t,tau1,tau2)/g) return t;
+          G4double gg = d*single_exp(t,tau2);
+          if (ran2 <= bi_exp(t,tau1,tau2)/gg) return t;
         }
         return -1.0;
 }
