@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4BGGPionInelasticXS.cc,v 1.12 2011-01-09 02:37:48 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // -------------------------------------------------------------------
 //
@@ -42,10 +41,12 @@
 //
 
 #include "G4BGGPionInelasticXS.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4GlauberGribovCrossSection.hh"
 #include "G4UPiNuclearCrossSection.hh"
 #include "G4HadronNucleonXsc.hh"
-#include "G4HadronInelasticDataSet.hh"
+//#include "G4HadronInelasticDataSet.hh"
+#include "G4ComponentSAIDTotalXS.hh"
 
 #include "G4Proton.hh"
 #include "G4PionPlus.hh"
@@ -59,6 +60,7 @@ G4BGGPionInelasticXS::G4BGGPionInelasticXS(const G4ParticleDefinition* p)
   verboseLevel = 0;
   fGlauberEnergy = 91.*GeV;
   fLowEnergy = 20.*MeV;
+  fSAIDHighEnergyLimit = 2.6*GeV;
   SetMinKinEnergy(0.0);
   SetMaxKinEnergy(100*TeV);
 
@@ -70,8 +72,8 @@ G4BGGPionInelasticXS::G4BGGPionInelasticXS(const G4ParticleDefinition* p)
   fPion = 0;
   fGlauber = 0;
   fHadron  = 0;
-  fGHEISHA = 0;
-
+  //  fGHEISHA = 0;
+  fSAID    = 0;
   particle = p;
   theProton= G4Proton::Proton();
   isPiplus = false;
@@ -84,15 +86,16 @@ G4BGGPionInelasticXS::~G4BGGPionInelasticXS()
   delete fGlauber;
   delete fPion;
   delete fHadron;
+  delete fSAID;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
 
 G4bool 
-G4BGGPionInelasticXS::IsElementApplicable(const G4DynamicParticle*, G4int Z,
+G4BGGPionInelasticXS::IsElementApplicable(const G4DynamicParticle*, G4int,
 					  const G4Material*)
 {
-  return (1 < Z);
+  return true;
 }
 
 //....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
@@ -109,25 +112,27 @@ G4bool G4BGGPionInelasticXS::IsIsoApplicable(const G4DynamicParticle*,
 
 G4double
 G4BGGPionInelasticXS::GetElementCrossSection(const G4DynamicParticle* dp,
-					     G4int zElement, 
-					     const G4Material*)
+					     G4int ZZ, const G4Material*)
 {
   // this method should be called only for Z > 1
 
   G4double cross = 0.0;
   G4double ekin = dp->GetKineticEnergy();
-  G4int Z = zElement; 
-  if(Z > 92) { Z = 92; }
-  else if(Z < 2) { Z = 2; }
-
-  if(ekin <= fLowEnergy && !isPiplus) {
-    cross = theCoulombFac[Z];
-  } else if(ekin <= 2*MeV && isPiplus) {
-    cross = theCoulombFac[Z]*CoulombFactor(ekin, Z);  
-  } else if(ekin > fGlauberEnergy) {
-    cross = theGlauberFac[Z]*fGlauber->GetInelasticGlauberGribov(dp, Z, theA[Z]);
+  G4int Z = ZZ;
+  if(1 == Z) {
+    cross = 1.0115*GetIsoCrossSection(dp,1,1);
   } else {
-    cross = fPion->GetInelasticCrossSection(dp, Z, theA[Z]);
+    if(Z > 92) { Z = 92; }
+
+    if(ekin <= fLowEnergy && !isPiplus) {
+      cross = theCoulombFac[Z];
+    } else if(ekin <= 2*MeV && isPiplus) {
+      cross = theCoulombFac[Z]*CoulombFactor(ekin, Z);  
+    } else if(ekin > fGlauberEnergy) {
+      cross = theGlauberFac[Z]*fGlauber->GetInelasticGlauberGribov(dp, Z, theA[Z]);
+    } else {
+      cross = fPion->GetInelasticCrossSection(dp, Z, theA[Z]);
+    }
   }
   if(verboseLevel > 1) {
     G4cout << "G4BGGPionInelasticXS::GetCrossSection  for "
@@ -147,13 +152,20 @@ G4BGGPionInelasticXS::GetIsoCrossSection(const G4DynamicParticle* dp,
 					 G4int Z, G4int A, 
 					 const G4Isotope*,
 					 const G4Element*,
-					 const G4Material* mat)
+					 const G4Material*)
 {
   // this method should be called only for Z = 1
 
   G4double cross = 0.0;
   G4double ekin = dp->GetKineticEnergy();
 
+  if(ekin <= fSAIDHighEnergyLimit) {
+    cross = fSAID->GetInelasticIsotopeCrossSection(particle, ekin, 1, 1);
+  } else {
+    fHadron->GetHadronNucleonXscPDG(dp, theProton);
+    cross = (theCoulombFac[1]/ekin + 1)*fHadron->GetInelasticHadronNucleonXsc();
+  } 
+  /*
   if(isPiplus) { 
     if(ekin <= 20*GeV) {
       cross = theCoulombFac[1]*fGHEISHA->GetElementCrossSection(dp, 1, mat);
@@ -172,6 +184,7 @@ G4BGGPionInelasticXS::GetIsoCrossSection(const G4DynamicParticle* dp,
       cross = fHadron->GetInelasticHadronNucleonXsc();
     }
   }
+  */
   cross *= A;
 
   if(verboseLevel > 1) {
@@ -206,7 +219,8 @@ void G4BGGPionInelasticXS::BuildPhysicsTable(const G4ParticleDefinition& p)
   fPion    = new G4UPiNuclearCrossSection();
   fGlauber = new G4GlauberGribovCrossSection();
   fHadron  = new G4HadronNucleonXsc();
-  fGHEISHA = new G4HadronInelasticDataSet();
+  //  fGHEISHA = new G4HadronInelasticDataSet();
+  fSAID    = new G4ComponentSAIDTotalXS();
 
   fPion->BuildPhysicsTable(*particle);
   fGlauber->BuildPhysicsTable(*particle);
@@ -242,6 +256,13 @@ void G4BGGPionInelasticXS::BuildPhysicsTable(const G4ParticleDefinition& p)
 	     << " factor= " << theGlauberFac[iz] << G4endl; 
     }
   }
+  dp.SetKineticEnergy(fSAIDHighEnergyLimit);
+  fHadron->GetHadronNucleonXscPDG(&dp, theProton);
+  theCoulombFac[1] = fSAIDHighEnergyLimit*
+    (fSAID->GetInelasticIsotopeCrossSection(particle,fSAIDHighEnergyLimit,1,1)
+     /fHadron->GetInelasticHadronNucleonXsc() - 1);
+
+  /*
   dp.SetKineticEnergy(20*GeV);
   const G4Material* mat = 0;
   if(isPiplus) { 
@@ -254,7 +275,7 @@ void G4BGGPionInelasticXS::BuildPhysicsTable(const G4ParticleDefinition& p)
     fHadron->GetHadronNucleonXscNS(&dp, theProton);
     theGlauberFac[1] /= fHadron->GetInelasticHadronNucleonXsc();
   }
-     
+  */ 
   if(isPiplus) { 
     dp.SetKineticEnergy(2*MeV);
     for(G4int iz=2; iz<93; iz++) {
@@ -264,8 +285,8 @@ void G4BGGPionInelasticXS::BuildPhysicsTable(const G4ParticleDefinition& p)
 
   } else {
     dp.SetKineticEnergy(fLowEnergy);
-    fHadron->GetHadronNucleonXscNS(&dp, theProton);
-    theCoulombFac[1] = theGlauberFac[1]*fHadron->GetInelasticHadronNucleonXsc();
+    //fHadron->GetHadronNucleonXscNS(&dp, theProton);
+    //theCoulombFac[1] = theGlauberFac[1]*fHadron->GetInelasticHadronNucleonXsc();
     for(G4int iz=2; iz<93; iz++) {
       theCoulombFac[iz] = fPion->GetInelasticCrossSection(&dp, iz, theA[iz]);
     }
