@@ -24,18 +24,27 @@
 // ********************************************************************
 //
 // 24.11.08 V. Grichine - first implementation
+// 25.10.12 W.Pokorski - following Vladimir's advice, I removed Z>1 condition
 //
 
 #include "G4GGNuclNuclCrossSection.hh"
 
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleTable.hh"
 #include "G4IonTable.hh"
 #include "G4ParticleDefinition.hh"
 #include "G4HadTmpUtil.hh"
+#include "G4HadronNucleonXsc.hh"
+
+// factory
+#include "G4CrossSectionFactory.hh"
+//
+G4_DECLARE_XS_FACTORY(G4GGNuclNuclCrossSection);
 
 
 G4GGNuclNuclCrossSection::G4GGNuclNuclCrossSection() 
- : G4VCrossSectionDataSet("Glauber-Gribov nucleus nucleus"),
+ : G4VCrossSectionDataSet(Default_Name()),
    fUpperLimit(100000*GeV), fLowerLimit(0.1*MeV),
    fRadiusConst(1.08*fermi),  // 1.1, 1.3 ?
    fTotalXsc(0.0), fElasticXsc(0.0), fInelasticXsc(0.0), fProductionXsc(0.0),
@@ -43,11 +52,14 @@ G4GGNuclNuclCrossSection::G4GGNuclNuclCrossSection()
 {
   theProton   = G4Proton::Proton();
   theNeutron  = G4Neutron::Neutron();
+  hnXsc = new G4HadronNucleonXsc();
 }
 
 
 G4GGNuclNuclCrossSection::~G4GGNuclNuclCrossSection()
-{}
+{
+  delete hnXsc;
+}
 
 void
 G4GGNuclNuclCrossSection::CrossSectionDescription(std::ostream& outFile) const
@@ -59,13 +71,13 @@ G4GGNuclNuclCrossSection::CrossSectionDescription(std::ostream& outFile) const
 }
 
 G4bool 
-G4GGNuclNuclCrossSection::IsElementApplicable(const G4DynamicParticle* aDP, 
-					      G4int Z, const G4Material*)
+G4GGNuclNuclCrossSection::IsElementApplicable(const G4DynamicParticle*, 
+					      G4int, const G4Material*)
 {
-  G4bool applicable = false;
-  G4double kineticEnergy = aDP->GetKineticEnergy();
+  G4bool applicable = true;
+//  G4double kineticEnergy = aDP->GetKineticEnergy();
 
-  if (kineticEnergy >= fLowerLimit && Z > 1) applicable = true;
+//  if (kineticEnergy >= fLowerLimit) applicable = true;
   return applicable;
 }
 
@@ -118,20 +130,41 @@ GetZandACrossSection(const G4DynamicParticle* aParticle,
   G4double tN = tA - tZ;
   if( tN < 0. ) tN = 0.;
 
-  G4double tR = GetNucleusRadius(tA);  
-  G4double pR = GetNucleusRadius(pA); 
+  G4double tR = GetNucleusRadius( G4double(tZ),G4double(tA) );  
+  G4double pR = GetNucleusRadius(pZ,pA); 
 
   cB = GetCoulombBarier(aParticle, G4double(tZ), G4double(tA), pR, tR);
-  if (cB > 0.) {
 
-    sigma = (pZ*tZ+pN*tN)*GetHadronNucleonXscNS(theProton, pTkin, theProton) +
-          (pZ*tN+pN*tZ)*GetHadronNucleonXscNS(theProton, pTkin, theNeutron);
+  if ( cB > 0. ) 
+  {
+    G4DynamicParticle* dProton = new G4DynamicParticle(theProton,
+                                              G4ParticleMomentum(1.,0.,0.), 
+                                              pTkin);
+
+    G4DynamicParticle* dNeutron = new G4DynamicParticle(theNeutron,
+                                              G4ParticleMomentum(1.,0.,0.), 
+                                              pTkin);
+
+    sigma = (pZ*tZ+pN*tN)*hnXsc->GetHadronNucleonXscNS(dProton, theProton);
+
+    G4double ppInXsc = hnXsc->GetInelasticHadronNucleonXsc();
+
+    sigma += (pZ*tN+pN*tZ)*hnXsc->GetHadronNucleonXscNS(dNeutron, theProton);
+
+    G4double npInXsc = hnXsc->GetInelasticHadronNucleonXsc();
+
+      delete dProton;
+      delete dNeutron;
+      
+    // G4cout<<"ppInXsc = "<<ppInXsc/millibarn<<"; npInXsc = "<<npInXsc/millibarn<<G4endl;
+    // G4cout<<"npTotXsc = "<<hnXsc->GetTotalHadronNucleonXsc()/millibarn<<"; npElXsc = "
+    //                      <<hnXsc->GetElasticHadronNucleonXsc()/millibarn<<G4endl;
 
     nucleusSquare = cofTotal*pi*( pR*pR + tR*tR );   // basically 2piRR
 
-    ratio = sigma/nucleusSquare;
-    xsection =  nucleusSquare*std::log( 1. + ratio );
-    fTotalXsc = xsection;
+    ratio      = sigma/nucleusSquare;
+    xsection   = nucleusSquare*std::log( 1. + ratio );
+    fTotalXsc  = xsection;
     fTotalXsc *= cB;
 
     fInelasticXsc = nucleusSquare*std::log( 1. + cofInelastic*ratio )/cofInelastic;
@@ -150,8 +183,7 @@ GetZandACrossSection(const G4DynamicParticle* aParticle,
     //sigma = (pZ*tZ+pN*tN)*GetHadronNucleonXscMK(theProton, pTkin, theProton) +
     //      (pZ*tN+pN*tZ)*GetHadronNucleonXscMK(theProton, pTkin, theNeutron);
 
-    sigma = (pZ*tZ+pN*tN)*GetHadronNucleonXscNS(theProton, pTkin, theProton) +
-          (pZ*tN+pN*tZ)*GetHadronNucleonXscNS(theProton, pTkin, theNeutron);
+    sigma = (pZ*tZ+pN*tN)*ppInXsc + (pZ*tN+pN*tZ)*npInXsc;
  
     ratio = sigma/nucleusSquare;
     fProductionXsc = nucleusSquare*std::log( 1. + cofInelastic*ratio )/cofInelastic;
@@ -165,6 +197,7 @@ GetZandACrossSection(const G4DynamicParticle* aParticle,
     fElasticXsc    = 0.;
     fProductionXsc = 0.;
   }
+    
   return fInelasticXsc;   // xsection; 
 }
 
@@ -229,8 +262,8 @@ GetRatioSD(const G4DynamicParticle* aParticle, G4double tA, G4double tZ)
   G4double tN = tA - tZ;
   if( tN < 0. ) tN = 0.;
 
-  G4double tR = GetNucleusRadius(tA);  
-  G4double pR = GetNucleusRadius(pA); 
+  G4double tR = GetNucleusRadius(tZ,tA);  
+  G4double pR = GetNucleusRadius(pZ,pA); 
 
   sigma = (pZ*tZ+pN*tN)*GetHadronNucleonXscNS(theProton, pTkin, theProton) +
           (pZ*tN+pN*tZ)*GetHadronNucleonXscNS(theProton, pTkin, theNeutron);
@@ -269,8 +302,8 @@ GetRatioQE(const G4DynamicParticle* aParticle, G4double tA, G4double tZ)
   G4double tN = tA - tZ;
   if( tN < 0. ) tN = 0.;
 
-  G4double tR = GetNucleusRadius(tA);  
-  G4double pR = GetNucleusRadius(pA); 
+  G4double tR = GetNucleusRadius(tZ,tA);  
+  G4double pR = GetNucleusRadius(pZ,pA); 
 
   sigma = (pZ*tZ+pN*tN)*GetHadronNucleonXscNS(theProton, pTkin, theProton) +
           (pZ*tN+pN*tZ)*GetHadronNucleonXscNS(theProton, pTkin, theNeutron);
@@ -420,8 +453,8 @@ G4GGNuclNuclCrossSection::GetHadronNucleonXscNS(G4ParticleDefinition* pParticle,
   G4double xsection(0);
   // G4double Delta;   DHW 19 May 2011: variable set but not used
   G4double A0, B0;
-  G4double hpXsc(0);
-  G4double hnXsc(0);
+  G4double hpXscv(0);
+  G4double hnXscv(0);
 
   G4double targ_mass = tParticle->GetPDGMass();
   G4double proj_mass = pParticle->GetPDGMass(); 
@@ -468,37 +501,37 @@ G4GGNuclNuclCrossSection::GetHadronNucleonXscNS(G4ParticleDefinition* pParticle,
       {
         if( proj_momentum < 0.73 )
         {
-          hnXsc = 23 + 50*( std::pow( std::log(0.73/proj_momentum), 3.5 ) );
+          hnXscv = 23 + 50*( std::pow( std::log(0.73/proj_momentum), 3.5 ) );
         }
         else if( proj_momentum < 1.05  )
         {
-          hnXsc = 23 + 40*(std::log(proj_momentum/0.73))*
+          hnXscv = 23 + 40*(std::log(proj_momentum/0.73))*
                          (std::log(proj_momentum/0.73));
         }
         else  // if( proj_momentum < 10.  )
         {
-          hnXsc = 39.0 + 
+          hnXscv = 39.0 + 
               75*(proj_momentum - 1.2)/(std::pow(proj_momentum,3.0) + 0.15);
         }
-        xsection = hnXsc;
+        xsection = hnXscv;
       }
       else  // pn to be np
       {
         if( proj_momentum < 0.8 )
         {
-          hpXsc = 33+30*std::pow(std::log(proj_momentum/1.3),4.0);
+          hpXscv = 33+30*std::pow(std::log(proj_momentum/1.3),4.0);
         }      
         else if( proj_momentum < 1.4 )
         {
-          hpXsc = 33+30*std::pow(std::log(proj_momentum/0.95),2.0);
+          hpXscv = 33+30*std::pow(std::log(proj_momentum/0.95),2.0);
         }
         else    // if( proj_momentum < 10.  )
         {
-          hpXsc = 33.3+
+          hpXscv = 33.3+
               20.8*(std::pow(proj_momentum,2.0)-1.35)/
                  (std::pow(proj_momentum,2.50)+0.95);
         }
-        xsection = hpXsc;
+        xsection = hpXscv;
       }
   }
   xsection *= millibarn; // parametrised in mb
@@ -610,10 +643,11 @@ G4GGNuclNuclCrossSection::GetNucleusRadius(const G4DynamicParticle* ,
 //
 
 G4double 
-G4GGNuclNuclCrossSection::GetNucleusRadius(G4double At)
+G4GGNuclNuclCrossSection::GetNucleusRadius(G4double Zt, G4double At)
 {
   G4double R;
-  R = GetNucleusRadiusDE(At);
+  R = GetNucleusRadiusDE(Zt,At);
+  // R = GetNucleusRadiusRMS(Zt,At);
 
   return R;
 }
@@ -644,9 +678,12 @@ G4GGNuclNuclCrossSection::GetNucleusRadiusGG(G4double At)
   return R;
 }
 
+/////////////////////////////////////////////////////////////////////////////
+//
+//
 
 G4double 
-G4GGNuclNuclCrossSection::GetNucleusRadiusDE(G4double A)
+G4GGNuclNuclCrossSection::GetNucleusRadiusDE(G4double Z, G4double A)
 {
   // algorithm from diffuse-elastic
 
@@ -658,13 +695,24 @@ G4GGNuclNuclCrossSection::GetNucleusRadiusDE(G4double A)
   a2 = 1.1;
   a3 = 1.;
 
+  // Special rms radii for light nucleii
 
   if (A < 50.)
   {
-    if( 10  < A && A <= 15. )     r0  = a11*( 1 - std::pow(A, -2./3.) )*fermi;   // 1.08*fermi;
-    else if( 15  < A && A <= 20 ) r0  = a12*( 1 - std::pow(A, -2./3.) )*fermi;
-    else if( 20  < A && A <= 30 ) r0  = a13*( 1 - std::pow(A, -2./3.) )*fermi;
-    else                          r0  = a2*fermi;
+    if     (std::abs(A-1.) < 0.5)                         return 0.89*fermi; // p
+    else if(std::abs(A-2.) < 0.5)                         return 2.13*fermi; // d
+    else if(std::abs(Z-1.) < 0.5 && std::abs(A-3.) < 0.5) return 1.80*fermi; // t
+
+    else if(std::abs(Z-2.) < 0.5 && std::abs(A-3.) < 0.5) return 1.96*fermi; // He3
+    else if(std::abs(Z-2.) < 0.5 && std::abs(A-4.) < 0.5) return 1.68*fermi; // He4
+
+    else if(std::abs(Z-3.) < 0.5)                         return 2.40*fermi; // Li7
+    else if(std::abs(Z-4.) < 0.5)                         return 2.51*fermi; // Be9
+
+    else if( 10.  < A && A <= 16. ) r0  = a11*( 1 - std::pow(A, -2./3.) )*fermi;   // 1.08*fermi;
+    else if( 15.  < A && A <= 20. ) r0  = a12*( 1 - std::pow(A, -2./3.) )*fermi;
+    else if( 20.  < A && A <= 30. ) r0  = a13*( 1 - std::pow(A, -2./3.) )*fermi;
+    else                            r0  = a2*fermi;
 
     R = r0*std::pow( A, 1./3. );
   }
@@ -678,6 +726,28 @@ G4GGNuclNuclCrossSection::GetNucleusRadiusDE(G4double A)
 }
 
 
+/////////////////////////////////////////////////////////////////////////////
+//
+// RMS radii from e-A scattering data
+
+G4double 
+G4GGNuclNuclCrossSection::GetNucleusRadiusRMS(G4double Z, G4double A)
+{
+
+  if     (std::abs(A-1.) < 0.5)                         return 0.89*fermi; // p
+  else if(std::abs(A-2.) < 0.5)                         return 2.13*fermi; // d
+  else if(std::abs(Z-1.) < 0.5 && std::abs(A-3.) < 0.5) return 1.80*fermi; // t
+
+  else if(std::abs(Z-2.) < 0.5 && std::abs(A-3.) < 0.5) return 1.96*fermi; // He3
+  else if(std::abs(Z-2.) < 0.5 && std::abs(A-4.) < 0.5) return 1.68*fermi; // He4
+
+  else if(std::abs(Z-3.) < 0.5)                         return 2.40*fermi; // Li7
+  else if(std::abs(Z-4.) < 0.5)                         return 2.51*fermi; // Be9
+
+  else                               return 1.24*std::pow(A, 0.28 )*fermi; // A > 9
+}
+
+
 ///////////////////////////////////////////////////////////////////////////////
 //
 //
