@@ -33,11 +33,18 @@
 
 #include "G4GlauberGribovCrossSection.hh"
 
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleTable.hh"
 #include "G4IonTable.hh"
 #include "G4ParticleDefinition.hh"
 #include "G4HadronNucleonXsc.hh"
 
+// factory
+#include "G4CrossSectionFactory.hh"
+//
+G4_DECLARE_XS_FACTORY(G4GlauberGribovCrossSection);
+
 ///////////////////////////////////////////////////////////////////////////////
 
 const G4double G4GlauberGribovCrossSection::fNeutronBarCorrectionTot[93] = {
@@ -221,7 +228,7 @@ const G4double G4GlauberGribovCrossSection::fPionMinusBarCorrectionIn[93] = {
 //
 
 G4GlauberGribovCrossSection::G4GlauberGribovCrossSection() 
- : G4VCrossSectionDataSet("Glauber-Gribov"),
+ : G4VCrossSectionDataSet(Default_Name()),
    fUpperLimit(100000*GeV), fLowerLimit(10.*MeV),// fLowerLimit(3*GeV),
    fRadiusConst(1.08*fermi),  // 1.1, 1.3 ?
    fTotalXsc(0.0), fElasticXsc(0.0), fInelasticXsc(0.0), fProductionXsc(0.0),
@@ -316,8 +323,12 @@ G4GlauberGribovCrossSection::GetIsoCrossSection(const G4DynamicParticle* aPartic
 						const G4Material*)
 {
   G4double xsection, sigma, cofInelastic, cofTotal, nucleusSquare, ratio;
+  G4double hpInXsc(0.), hnInXsc(0.);
   G4double R             = GetNucleusRadius(A); 
 
+  G4int N = A - Z;              // number of neutrons
+  if (N < 0) N = 0;
+
   const G4ParticleDefinition* theParticle = aParticle->GetDefinition();
 
   if( theParticle == theProton  || 
@@ -325,7 +336,16 @@ G4GlauberGribovCrossSection::GetIsoCrossSection(const G4DynamicParticle* aPartic
       theParticle == thePiPlus  || 
       theParticle == thePiMinus      )
   {
-    sigma        = GetHadronNucleonXscNS(aParticle, A, Z);
+    // sigma        = GetHadronNucleonXscNS(aParticle, A, Z);
+
+    sigma = Z*hnXsc->GetHadronNucleonXscNS(aParticle, theProton);
+
+    hpInXsc = hnXsc->GetInelasticHadronNucleonXsc();
+
+    sigma += N*hnXsc->GetHadronNucleonXscNS(aParticle, theNeutron);
+
+    hnInXsc = hnXsc->GetInelasticHadronNucleonXsc();
+
     cofInelastic = 2.4;
     cofTotal     = 2.0;
   }
@@ -367,13 +387,17 @@ G4GlauberGribovCrossSection::GetIsoCrossSection(const G4DynamicParticle* aPartic
 
     fElasticXsc   = fTotalXsc - fInelasticXsc;
 
+    if(fElasticXsc < 0.) fElasticXsc = 0.;
     
     G4double difratio = ratio/(1.+ratio);
 
     fDiffractionXsc = 0.5*nucleusSquare*( difratio - std::log( 1. + difratio ) );
 
 
-    sigma = GetHNinelasticXsc(aParticle, A, Z);
+    // sigma = GetHNinelasticXsc(aParticle, A, Z);
+
+    sigma = Z*hpInXsc + N*hnInXsc;
+
     ratio = sigma/nucleusSquare;
 
     fProductionXsc = nucleusSquare*std::log( 1. + cofInelastic*ratio )/cofInelastic;
@@ -740,8 +764,8 @@ G4GlauberGribovCrossSection::GetHadronNucleonXscNS(const G4DynamicParticle* aPar
   G4double xsection(0);
   // G4double Delta;   DHW 19 May 2011: variable set but not used
   G4double A0, B0;
-  G4double hpXsc(0);
-  G4double hnXsc(0);
+  G4double hpXscv(0);
+  G4double hnXscv(0);
 
   G4int Nt = At-Zt;              // number of neutrons
   if (Nt < 0) Nt = 0;  
@@ -806,35 +830,35 @@ G4GlauberGribovCrossSection::GetHadronNucleonXscNS(const G4DynamicParticle* aPar
 
       if( proj_momentum < 0.73 )
       {
-        hnXsc = 23 + 50*( std::pow( std::log(0.73/proj_momentum), 3.5 ) );
+        hnXscv = 23 + 50*( std::pow( std::log(0.73/proj_momentum), 3.5 ) );
       }
       else if( proj_momentum < 1.05  )
       {
-       hnXsc = 23 + 40*(std::log(proj_momentum/0.73))*
+       hnXscv = 23 + 40*(std::log(proj_momentum/0.73))*
                          (std::log(proj_momentum/0.73));
       }
       else  // if( proj_momentum < 10.  )
       {
-         hnXsc = 39.0+
+         hnXscv = 39.0+
               75*(proj_momentum - 1.2)/(std::pow(proj_momentum,3.0) + 0.15);
       }
       // pn to be np
 
       if( proj_momentum < 0.8 )
       {
-        hpXsc = 33+30*std::pow(std::log(proj_momentum/1.3),4.0);
+        hpXscv = 33+30*std::pow(std::log(proj_momentum/1.3),4.0);
       }      
       else if( proj_momentum < 1.4 )
       {
-        hpXsc = 33+30*std::pow(std::log(proj_momentum/0.95),2.0);
+        hpXscv = 33+30*std::pow(std::log(proj_momentum/0.95),2.0);
       }
       else    // if( proj_momentum < 10.  )
       {
-        hpXsc = 33.3+
+        hpXscv = 33.3+
               20.8*(std::pow(proj_momentum,2.0)-1.35)/
                  (std::pow(proj_momentum,2.50)+0.95);
       }
-      xsection = hpXsc*zz + hnXsc*nn;
+      xsection = hpXscv*zz + hnXscv*nn;
     }
   } 
   else if(theParticle == theProton) 
@@ -866,37 +890,37 @@ G4GlauberGribovCrossSection::GetHadronNucleonXscNS(const G4DynamicParticle* aPar
 
       if( proj_momentum < 0.73 )
       {
-        hpXsc = 23 + 50*( std::pow( std::log(0.73/proj_momentum), 3.5 ) );
+        hpXscv = 23 + 50*( std::pow( std::log(0.73/proj_momentum), 3.5 ) );
       }
       else if( proj_momentum < 1.05  )
       {
-       hpXsc = 23 + 40*(std::log(proj_momentum/0.73))*
+       hpXscv = 23 + 40*(std::log(proj_momentum/0.73))*
                          (std::log(proj_momentum/0.73));
       }
       else    // if( proj_momentum < 10.  )
       {
-         hpXsc = 39.0+
+         hpXscv = 39.0+
               75*(proj_momentum - 1.2)/(std::pow(proj_momentum,3.0) + 0.15);
       }
       // pn to be np
 
       if( proj_momentum < 0.8 )
       {
-        hnXsc = 33+30*std::pow(std::log(proj_momentum/1.3),4.0);
+        hnXscv = 33+30*std::pow(std::log(proj_momentum/1.3),4.0);
       }      
       else if( proj_momentum < 1.4 )
       {
-        hnXsc = 33+30*std::pow(std::log(proj_momentum/0.95),2.0);
+        hnXscv = 33+30*std::pow(std::log(proj_momentum/0.95),2.0);
       }
       else   // if( proj_momentum < 10.  )
       {
-        hnXsc = 33.3+
+        hnXscv = 33.3+
               20.8*(std::pow(proj_momentum,2.0)-1.35)/
                  (std::pow(proj_momentum,2.50)+0.95);
       }
-      xsection = hpXsc*zz + hnXsc*nn;
-      // xsection = hpXsc*(Zt + Nt);
-      // xsection = hnXsc*(Zt + Nt);
+      xsection = hpXscv*zz + hnXscv*nn;
+      // xsection = hpXscv*(Zt + Nt);
+      // xsection = hnXscv*(Zt + Nt);
     }    
     // xsection *= 0.95;
   } 
@@ -935,50 +959,50 @@ G4GlauberGribovCrossSection::GetHadronNucleonXscNS(const G4DynamicParticle* aPar
     if(proj_momentum < 0.4)
     {
       G4double Ex3 = 180*std::exp(-(proj_momentum-0.29)*(proj_momentum-0.29)/0.085/0.085);
-      hpXsc      = Ex3+20.0;
+      hpXscv      = Ex3+20.0;
     }
     else if( proj_momentum < 1.15 )
     {
       G4double Ex4 = 88*(std::log(proj_momentum/0.75))*(std::log(proj_momentum/0.75));
-      hpXsc = Ex4+14.0;
+      hpXscv = Ex4+14.0;
     }
     else if(proj_momentum < 3.5)
     {
       G4double Ex1 = 3.2*std::exp(-(proj_momentum-2.55)*(proj_momentum-2.55)/0.55/0.55);
       G4double Ex2 = 12*std::exp(-(proj_momentum-1.47)*(proj_momentum-1.47)/0.225/0.225);
-      hpXsc = Ex1+Ex2+27.5;
+      hpXscv = Ex1+Ex2+27.5;
     }
     else //  if(proj_momentum > 3.5) // mb
     {
-      hpXsc = 10.6+2.*std::log(proj_energy)+25*std::pow(proj_energy,-0.43);
+      hpXscv = 10.6+2.*std::log(proj_energy)+25*std::pow(proj_energy,-0.43);
     }
     // pi+n = pi-p??
 
     if(proj_momentum < 0.37)
     {
-      hnXsc = 28.0 + 40*std::exp(-(proj_momentum-0.29)*(proj_momentum-0.29)/0.07/0.07);
+      hnXscv = 28.0 + 40*std::exp(-(proj_momentum-0.29)*(proj_momentum-0.29)/0.07/0.07);
     }
     else if(proj_momentum<0.65)
     {
-       hnXsc = 26+110*(std::log(proj_momentum/0.48))*(std::log(proj_momentum/0.48));
+       hnXscv = 26+110*(std::log(proj_momentum/0.48))*(std::log(proj_momentum/0.48));
     }
     else if(proj_momentum<1.3)
     {
-      hnXsc = 36.1+
+      hnXscv = 36.1+
                 10*std::exp(-(proj_momentum-0.72)*(proj_momentum-0.72)/0.06/0.06)+
                 24*std::exp(-(proj_momentum-1.015)*(proj_momentum-1.015)/0.075/0.075);
     }
     else if(proj_momentum<3.0)
     {
-      hnXsc = 36.1+0.079-4.313*std::log(proj_momentum)+
+      hnXscv = 36.1+0.079-4.313*std::log(proj_momentum)+
                 3*std::exp(-(proj_momentum-2.1)*(proj_momentum-2.1)/0.4/0.4)+
                 1.5*std::exp(-(proj_momentum-1.4)*(proj_momentum-1.4)/0.12/0.12);
     }
     else   // mb
     {
-      hnXsc = 10.6+2*std::log(proj_energy)+30*std::pow(proj_energy,-0.43); 
+      hnXscv = 10.6+2*std::log(proj_energy)+30*std::pow(proj_energy,-0.43); 
     }
-    xsection = hpXsc*zz + hnXsc*nn;
+    xsection = hpXscv*zz + hnXscv*nn;
   } 
   else if(theParticle == thePiMinus) 
   {
@@ -987,50 +1011,50 @@ G4GlauberGribovCrossSection::GetHadronNucleonXscNS(const G4DynamicParticle* aPar
     if(proj_momentum < 0.4)
     {
       G4double Ex3 = 180*std::exp(-(proj_momentum-0.29)*(proj_momentum-0.29)/0.085/0.085);
-      hnXsc      = Ex3+20.0;
+      hnXscv      = Ex3+20.0;
     }
     else if(proj_momentum < 1.15)
     {
       G4double Ex4 = 88*(std::log(proj_momentum/0.75))*(std::log(proj_momentum/0.75));
-      hnXsc = Ex4+14.0;
+      hnXscv = Ex4+14.0;
     }
     else if(proj_momentum < 3.5)
     {
       G4double Ex1 = 3.2*std::exp(-(proj_momentum-2.55)*(proj_momentum-2.55)/0.55/0.55);
       G4double Ex2 = 12*std::exp(-(proj_momentum-1.47)*(proj_momentum-1.47)/0.225/0.225);
-      hnXsc = Ex1+Ex2+27.5;
+      hnXscv = Ex1+Ex2+27.5;
     }
     else //  if(proj_momentum > 3.5) // mb
     {
-      hnXsc = 10.6+2.*std::log(proj_energy)+25*std::pow(proj_energy,-0.43);
+      hnXscv = 10.6+2.*std::log(proj_energy)+25*std::pow(proj_energy,-0.43);
     }
     // pi-p
 
     if(proj_momentum < 0.37)
     {
-      hpXsc = 28.0 + 40*std::exp(-(proj_momentum-0.29)*(proj_momentum-0.29)/0.07/0.07);
+      hpXscv = 28.0 + 40*std::exp(-(proj_momentum-0.29)*(proj_momentum-0.29)/0.07/0.07);
     }
     else if(proj_momentum<0.65)
     {
-       hpXsc = 26+110*(std::log(proj_momentum/0.48))*(std::log(proj_momentum/0.48));
+       hpXscv = 26+110*(std::log(proj_momentum/0.48))*(std::log(proj_momentum/0.48));
     }
     else if(proj_momentum<1.3)
     {
-      hpXsc = 36.1+
+      hpXscv = 36.1+
                 10*std::exp(-(proj_momentum-0.72)*(proj_momentum-0.72)/0.06/0.06)+
                 24*std::exp(-(proj_momentum-1.015)*(proj_momentum-1.015)/0.075/0.075);
     }
     else if(proj_momentum<3.0)
     {
-      hpXsc = 36.1+0.079-4.313*std::log(proj_momentum)+
+      hpXscv = 36.1+0.079-4.313*std::log(proj_momentum)+
                 3*std::exp(-(proj_momentum-2.1)*(proj_momentum-2.1)/0.4/0.4)+
                 1.5*std::exp(-(proj_momentum-1.4)*(proj_momentum-1.4)/0.12/0.12);
     }
     else   // mb
     {
-      hpXsc = 10.6+2*std::log(proj_energy)+30*std::pow(proj_energy,-0.43); 
+      hpXscv = 10.6+2*std::log(proj_energy)+30*std::pow(proj_energy,-0.43); 
     }
-    xsection = hpXsc*zz + hnXsc*nn;
+    xsection = hpXscv*zz + hnXscv*nn;
   } 
   else if(theParticle == theKPlus) 
   {
