@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4ElementaryParticleCollider.cc,v 1.75 2010-10-19 19:48:35 mkelsey Exp $
-// Geant4 tag: $Name: not supported by cvs2svn $
+// $Id$
 //
 // 20100114  M. Kelsey -- Remove G4CascadeMomentum, use G4LorentzVector directly
 // 20100316  D. Wright (restored by M. Kelsey) -- Replace original (incorrect)
@@ -81,6 +80,12 @@
 // 20111007  M. Kelsey -- Add gamma-N final-state tables to printFinalState
 // 20111107  M. Kelsey -- In sampleCMmomentumFor2to2(), hide message about
 //		unrecognized gamma-N initial state behind verbosity.
+// 20111216  M. Kelsey -- Add diagnostics to generateMomModulesFor2toMany(),
+//		defer allocation of buffer in generateSCMfinalState() so that
+//		multiplicity failures return zero output, and can be trapped.
+// 20120308  M. Kelsey -- Allow photons to interact with dibaryons (see
+//		changes in G4NucleiModel).
+// 20120608  M. Kelsey -- Fix variable-name "shadowing" compiler warnings.
 
 #include "G4ElementaryParticleCollider.hh"
 #include "G4CascadeChannel.hh"
@@ -173,8 +178,15 @@ G4ElementaryParticleCollider::collide(G4InuclParticle* bullet,
 
     generateSCMfinalState(ekin, etot_scm, pscm, particle1, particle2,
 			  &convertToSCM);
-    
-    if(!particles.empty()) { // convert back to Lab
+
+    if (particles.empty()) {	// No final state possible, pass bullet through
+      if (verboseLevel) {
+	G4cerr << " ElementaryParticleCollider -> failed to collide " 
+	       << particle1->getMomModule() << " GeV/c " 
+	       << particle1->getDefinition()->GetParticleName() << " with "
+	       << particle2->getDefinition()->GetParticleName() << G4endl;
+      }
+    } else {			 // convert back to Lab
       G4LorentzVector mom;		// Buffer to avoid memory churn
       particleIterator ipart;
       for(ipart = particles.begin(); ipart != particles.end(); ipart++) {	
@@ -196,12 +208,13 @@ G4ElementaryParticleCollider::collide(G4InuclParticle* bullet,
 
       std::sort(particles.begin(), particles.end(), G4ParticleLargerEkin());
       output.addOutgoingParticles(particles);
-    };
-  } else {
-    if(particle1->quasi_deutron() || particle2->quasi_deutron()) {
-      if(particle1->pion() || particle2->pion()) {
+    }
+  } else {	// neither particle is nucleon: pion on quasideuteron
+    if (particle1->quasi_deutron() || particle2->quasi_deutron()) {
+      if (particle1->pion() || particle2->pion() ||
+	  particle1->isPhoton() || particle2->isPhoton()) {
 	G4LorentzConvertor convertToSCM;
-	if(particle1->pion()) {
+	if(particle2->quasi_deutron()) {	// Quasideuteron is target
 	  convertToSCM.setBullet(particle1);
 	  convertToSCM.setTarget(particle2);
 	} else {
@@ -213,7 +226,14 @@ G4ElementaryParticleCollider::collide(G4InuclParticle* bullet,
 	
 	generateSCMpionAbsorption(etot_scm, particle1, particle2);
 
-	if(!particles.empty()) { // convert back to Lab
+	if (particles.empty()) {	// Failed to generate final state
+	  if (verboseLevel) {
+	    G4cerr << " ElementaryParticleCollider -> failed to collide " 
+		   << particle1->getMomModule() << " GeV/c " 
+		   << particle1->getDefinition()->GetParticleName() << " with "
+		   << particle2->getDefinition()->GetParticleName() << G4endl;
+	  }
+	} else {			// convert back to Lab
 	  G4LorentzVector mom;	// Buffer to avoid memory churn
 	  particleIterator ipart;
 	  for(ipart = particles.begin(); ipart != particles.end(); ipart++) {
@@ -226,13 +246,12 @@ G4ElementaryParticleCollider::collide(G4InuclParticle* bullet,
 	  std::sort(particles.begin(), particles.end(), G4ParticleLargerEkin());
 	  output.addOutgoingParticles(particles);
 	};
-	
       } else {
-	G4cerr << " ElementaryParticleCollider -> can only collide pions with deuterons " 
+	G4cerr << " ElementaryParticleCollider -> can only collide pions with dibaryons " 
 	       << G4endl;
       };
     } else {
-      G4cerr << " ElementaryParticleCollider -> can only collide something with nucleon or deuteron " 
+      G4cerr << " ElementaryParticleCollider -> can only collide something with nucleon or dibaryon " 
 	     << G4endl;
     };
   };  
@@ -299,9 +318,13 @@ G4ElementaryParticleCollider::generateSCMfinalState(G4double ekin,
     multiplicity = generateMultiplicity(is, ekin);
 
     generateOutgoingPartTypes(is, multiplicity, ekin);
-    if (particle_kinds.empty()) continue;
-
-    particles.resize(multiplicity);	// Preallocate buffer
+    if (particle_kinds.empty()) {
+      if (verboseLevel > 3) {
+	G4cout << " generateOutgoingPartTypes failed mult " << multiplicity
+	       << G4endl;
+      }
+      continue;
+    }
 
     if (multiplicity == 2) {
       // Identify charge or strangeness exchange (non-elastic scatter)
@@ -311,21 +334,22 @@ G4ElementaryParticleCollider::generateSCMfinalState(G4double ekin,
       G4double pmod = pscm;	// Elastic scattering preserves CM momentum
 
       if (kw == 2) {		// Non-elastic needs new CM momentum value
-	G4double m1 = dummy.getParticleMass(particle_kinds[0]);
-	G4double m2 = dummy.getParticleMass(particle_kinds[1]);
+	G4double mone = dummy.getParticleMass(particle_kinds[0]);
+	G4double mtwo = dummy.getParticleMass(particle_kinds[1]);
 
-	if (etot_scm < m1+m2) {		// Can't produce final state
+	if (etot_scm < mone+mtwo) {		// Can't produce final state
 	  if (verboseLevel > 2) {
 	    G4cerr << " bad final state " << particle_kinds[0]
 		   << " , " << particle_kinds[1] << " etot_scm " << etot_scm
-		   << " < m1+m2 " << m1+m2 << " , but ekin " << ekin << G4endl;
+		   << " < mone+mtwo " << mone+mtwo << " , but ekin " << ekin
+		   << G4endl;
 	  }
 	  continue;
 	}
 
 	G4double ecm_sq = etot_scm*etot_scm;
-	G4double msumsq = m1+m2; msumsq *= msumsq;
-	G4double mdifsq = m1-m2; mdifsq *= mdifsq;
+	G4double msumsq = mone+mtwo; msumsq *= msumsq;
+	G4double mdifsq = mone-mtwo; mdifsq *= mdifsq;
 
 	G4double a = (ecm_sq - msumsq) * (ecm_sq - mdifsq);
 
@@ -350,10 +374,10 @@ G4ElementaryParticleCollider::generateSCMfinalState(G4double ekin,
       }
       G4LorentzVector mom1(-mom.vect(), mom.e());
 
+      particles.resize(multiplicity);		// Preallocate buffer
       particles[0].fill(mom, particle_kinds[0], G4InuclParticle::EPCollider);
       particles[1].fill(mom1, particle_kinds[1], G4InuclParticle::EPCollider);
       generate = false;
-
     } else {			 // 2 -> many
       G4int itry = 0;
       G4bool bad = true;
@@ -368,11 +392,17 @@ G4ElementaryParticleCollider::generateSCMfinalState(G4double ekin,
 	itry++;
 
 	if (verboseLevel > 3){
-	  G4cout << " itry in while " << itry << G4endl;
+	  G4cout << " itry in generateSCMfinalState " << itry << G4endl;
 	}
 
 	generateMomModules(multiplicity, is, ekin, etot_scm);
-	if (G4int(modules.size()) != multiplicity) continue;
+	if (G4int(modules.size()) != multiplicity) {
+	  if (verboseLevel > 3) {
+	    G4cerr << " generateMomModule failed at mult " << multiplicity
+		   << " ekin " << ekin << " etot_scm " << etot_scm << G4endl;
+	  }
+	  continue;
+	}
 
 	if (multiplicity == 3) { 
 	  G4LorentzVector mom3 = 
@@ -401,7 +431,9 @@ G4ElementaryParticleCollider::generateSCMfinalState(G4double ekin,
 	    
 	    bad = false;
 	    generate = false;
-	    
+
+	    particles.resize(multiplicity);		// Preallocate buffer
+   
 	    particles[0].fill(mom1, particle_kinds[0], G4InuclParticle::EPCollider);
 	    particles[1].fill(mom2, particle_kinds[1], G4InuclParticle::EPCollider);
 	    particles[2].fill(mom3, particle_kinds[2], G4InuclParticle::EPCollider);
@@ -430,8 +462,7 @@ G4ElementaryParticleCollider::generateSCMfinalState(G4double ekin,
 	      }
 	      
 	      if(s1 * alf * std::exp(-s1 / p0) > s2) st = s1 / modules[i];
-	      
-	    }; 
+	    };
 	    
 	    if(verboseLevel > 3){
 	      G4cout << " itry1 " << itry1 << " i " << i << " st " << st
@@ -469,7 +500,6 @@ G4ElementaryParticleCollider::generateSCMfinalState(G4double ekin,
 	  }            
 	  
 	  if (std::fabs(ct) < ang_cut) {
-	    
 	    G4int i(0);
 	    for (i = 0; i < multiplicity - 2; i++) 
 	      scm_momentums[i] = toSCM->rotate(scm_momentums[i]);
@@ -493,23 +523,25 @@ G4ElementaryParticleCollider::generateSCMfinalState(G4double ekin,
 	    if (verboseLevel > 2){
 	      G4cout << " ok for mult " << multiplicity << G4endl;
 	    }
-	    
+
+	    particles.resize(multiplicity);		// Preallocate buffer
 	    for (i = 0; i < multiplicity; i++) {
 	      particles[i].fill(scm_momentums[i], particle_kinds[i],
 				G4InuclParticle::EPCollider);
-	    };
-	  };
-	}; 
-      };
+	    }
+	  }	// |ct| < ang_cut
+	}	// multiplicity > 3
+      }		// while (bad && itry < itry_max)
 
       if (itry == itry_max) {
-	if (verboseLevel > 2){
+	if (verboseLevel > 2) {
 	  G4cout << " cannot generate the distr. for mult " << multiplicity
-		 << "\n and set it to " << multiplicity - 1 << G4endl;
+		 << G4endl;
 	}
-      };
-    };
-  }; 
+	break;
+      }
+    }	// multiplicity > 2
+  }	// while (generate) 
 
   if (verboseLevel > 3) {
     G4cout << " <<< G4ElementaryParticleCollider::generateSCMfinalState"
@@ -553,7 +585,7 @@ G4ElementaryParticleCollider::generateMomModules(G4int mult,
   G4double mass_last = std::sqrt(masses2[mult - 1]);
 
   if (verboseLevel > 3){
-    G4cout << " knd_last " << particle_kinds[mult - 1] << " mlast " 
+    G4cout << " knd_last " << particle_kinds[mult - 1] << " mass_last " 
            << mass_last << G4endl;
   }
 
@@ -567,7 +599,6 @@ G4ElementaryParticleCollider::generateMomModules(G4int mult,
     G4double eleft = etot_cm;
 
     for (G4int i = 0; i < mult - 1; i++) {
-
       G4double pmod = 
 	getMomModuleFor2toMany(is, mult, particle_kinds[i], ekin);
 
@@ -575,9 +606,9 @@ G4ElementaryParticleCollider::generateMomModules(G4int mult,
       eleft -= std::sqrt(pmod * pmod + masses2[i]);
 
       if (verboseLevel > 3){
-	G4cout << " kp " << particle_kinds[i] << " pmod " << pmod << " mass2 " 
-               << masses2[i] << G4endl;
-	G4cout << " x1 " << eleft - mass_last << G4endl;
+	G4cout << " kp " << particle_kinds[i] << " pmod " << pmod
+	       << " mass2 " << masses2[i] << " eleft " << eleft
+	       << "\n x1 " << eleft - mass_last << G4endl;
       }
 
       if (eleft <= mass_last) break;
@@ -600,7 +631,10 @@ G4ElementaryParticleCollider::generateMomModules(G4int mult,
 	} else return;
       }
     }
-  }
+  }	// while (itry < itry_max)
+
+  if (verboseLevel > 2)
+    G4cerr << " Unable to generate momenta for multiplicity " << mult << G4endl;
 
   modules.clear();		// Something went wrong, throw away partial
   return;    
@@ -609,20 +643,20 @@ G4ElementaryParticleCollider::generateMomModules(G4int mult,
 
 G4bool 
 G4ElementaryParticleCollider::satisfyTriangle(
-			const std::vector<G4double>& modules) const 
+			const std::vector<G4double>& pmod) const 
 {
   if (verboseLevel > 3) {
     G4cout << " >>> G4ElementaryParticleCollider::satisfyTriangle" 
            << G4endl;
   }
 
-  G4bool good = ( (modules.size() != 3) ||
-		  !(std::fabs(modules[1] - modules[2]) > modules[0] || 
-		    modules[0] > modules[1] + modules[2] ||
-		    std::fabs(modules[0] - modules[2]) > modules[1] ||
-		    modules[1] > modules[0] + modules[2] ||
-		    std::fabs(modules[0] - modules[1]) > modules[2] ||
-		    modules[2] > modules[1] + modules[0]));
+  G4bool good = ( (pmod.size() != 3) ||
+		  !(std::fabs(pmod[1] - pmod[2]) > pmod[0] || 
+		    pmod[0] > pmod[1] + pmod[2] ||
+		    std::fabs(pmod[0] - pmod[2]) > pmod[1] ||
+		    pmod[1] > pmod[0] + pmod[2] ||
+		    std::fabs(pmod[0] - pmod[1]) > pmod[2] ||
+		    pmod[2] > pmod[1] + pmod[0]));
 
   return good;
 }
@@ -652,9 +686,9 @@ G4ElementaryParticleCollider::getMomModuleFor2toMany(G4int is, G4int /*mult*/,
 					             G4int knd, 
 					     	     G4double ekin) const 
 {
-  if (verboseLevel > 3) {
-    G4cout << " >>> G4ElementaryParticleCollider::getMomModuleFor2toMany" 
-           << G4endl;
+  if (verboseLevel > 2) {
+    G4cout << " >>> G4ElementaryParticleCollider::getMomModuleFor2toMany "
+	   << " is " << is << " knd " << knd << " ekin " << ekin << G4endl;
   }
 
   G4double S = inuclRndm();
@@ -667,20 +701,55 @@ G4ElementaryParticleCollider::getMomModuleFor2toMany(G4int is, G4int /*mult*/,
   G4int JM = 2;
   G4int IM = 3;
 
-  if(is == 1 || is == 2 || is == 4) KM = 1;
-  if(knd == 1 || knd == 2) JK = 0;
+  if (is == 1 || is == 2 || is == 4) KM = 1;
+  if (knd == 1 || knd == 2) JK = 0;
+
+  if (verboseLevel > 3) {
+    G4cout << " S " << S << " KM " << KM << " IL " << IL << " JK " << JK
+	   << " JM " << JM << " IM " << IM << G4endl;
+  }
 
   for(G4int i = 0; i < 4; i++) {
     G4double V = 0.0;
-    for(G4int k = 0; k < 4; k++) V += rmn[k + JK][i + IL][KM - 1] * std::pow(ekin, k);
+    for(G4int k = 0; k < 4; k++) {
+      if (verboseLevel > 3) {
+	G4cout << " k " << k << " : rmn[k+JK][i+IL][KM-1] "
+	       << rmn[k+JK][i+IL][KM-1] << " ekin^k " << std::pow(ekin, k)
+	       << G4endl;
+      }
+
+      V += rmn[k + JK][i + IL][KM - 1] * std::pow(ekin, k);
+    }
+
+    if (verboseLevel > 3) {
+      G4cout << " i " << i << " : V " << V << " S^i " << std::pow(S, i)
+	     << G4endl;
+    }
+
     PR += V * std::pow(S, i);
     PQ += V;
   }
 
-  if(knd == 1 || knd == 2) JM = 1;
-  for(G4int m = 0; m < 3; m++) PS += rmn[8 + IM + m][7 + JM][KM - 1] * std::pow(ekin, m);
+  if (verboseLevel > 3) G4cout << " PR " << PR << " PQ " << PQ << G4endl;
+
+  if (knd == 1 || knd == 2) JM = 1;
+  if (verboseLevel > 3) G4cout << " JM " << JM << G4endl;
+
+  for(G4int im = 0; im < 3; im++) {
+    if (verboseLevel >3) {
+      G4cout << " im " << im << " : rmn[8+IM+im][7+JM][KM-1] "
+	     << rmn[8+IM+im][7+JM][KM-1] << " ekin^im " << std::pow(ekin, im)
+	     << G4endl;
+    }
+    PS += rmn[8 + IM + im][7 + JM][KM - 1] * std::pow(ekin, im);
+  }
+  
   G4double PRA = PS * std::sqrt(S) * (PR + (1 - PQ) * (S*S*S*S));
 
+  if (verboseLevel > 3) 
+    G4cout << " PS " << PS << " PRA = PS*sqrt(S)*(PR+(1-PQ)*S^4) " << PRA
+	   << G4endl;
+
   return std::fabs(PRA);
 }
 
@@ -717,8 +786,8 @@ G4ElementaryParticleCollider::particleSCMmomentumFor2to3(
     for(G4int l = 0; l < 4; l++) {
       G4double V = 0.0;
 
-      for(G4int m = 0; m < 4; m++) {
-	V += abn[m][l][K + J - 1] * std::pow(ekin, m);
+      for(G4int im = 0; im < 4; im++) {
+	V += abn[im][l][K+J-1] * std::pow(ekin, im);
       };
 
       U += V;
@@ -772,9 +841,31 @@ G4ElementaryParticleCollider::sampleCMmomentumFor2to2(G4int is, G4int kw,
     pC = interp.interpolate(ekin, nnC);
     pCos = interp.interpolate(ekin, nnCos);
     pFrac = interp.interpolate(ekin, nnFrac);
+
+  } else if (kw == 2 && (is == 9 || is == 18)) {
+    // gamma p -> pi+ n, gamma p -> pi0 p, gamma p -> K Y (and isospin variants)
+    // for now and due to lack of better data, use the gamma p -> pi+ n angular
+    // distribution for all of these channels
+    if (verboseLevel > 3)
+      G4cout << " gamma-nucleon inelastic with 2-body final state" << G4endl;
+
+    static const G4double gnke[10] =   {0.0,   0.11,  0.22,   0.26,  0.30,  0.34,  0.42,   0.59,   0.79,  10.0};
+    static const G4double gnA[10] =    {0.0,   0.0,   5.16,   5.55,  5.33,  7.40, 13.55,  13.44,  13.31,   7.3};
+    static const G4double gnC[10] =    {0.0, -10.33, -5.44,  -5.92, -4.27, -0.66,  1.37,   1.07,   0.52,   7.3};
+    static const G4double gnCos[10] =  {1.0,   1.0,   0.906,  0.940, 0.940, 0.906, 0.906,  0.91,   0.91,   0.94};
+    static const G4double gnFrac[10] = {0.0,   0.0,   0.028,  0.012, 0.014, 0.044, 0.087,  0.122,  0.16,   1.0};
+
+    static G4CascadeInterpolator<10> interp(gnke);
+    pA = interp.interpolate(ekin, gnA);
+    pC = interp.interpolate(ekin, gnC);
+    pCos = interp.interpolate(ekin, gnCos);
+    pFrac = interp.interpolate(ekin, gnFrac);
+
   } else if (kw == 2) {
-    // pion charge exchange (pi-p -> pi0n, pi+n -> pi0p, pi0p -> pi+n, pi0n -> pi-p
-    if (verboseLevel > 3) G4cout << " pion-nucleon charge exchange " << G4endl;
+    // pi- p -> pi0 n, pi0 p -> pi+ n, pi- p -> K Y, pi0 p -> K Y (and isospin variants)
+    // includes charge and strangeness exchange  
+    if (verboseLevel > 3)
+      G4cout << " pion-nucleon inelastic with 2-body final state " << G4endl;
 
     static const G4double qxke[10] =   {0.0,   0.062,  0.12,   0.217,  0.533,  0.873,  1.34,   2.86,   5.86,  10.0};
     static const G4double qxA[10] =    {0.0,   0.0,    2.48,   7.93,  10.0,    9.78,   5.08,   8.13,   8.13,   8.13};
@@ -787,9 +878,10 @@ G4ElementaryParticleCollider::sampleCMmomentumFor2to2(G4int is, G4int kw,
     pC = interp.interpolate(ekin, qxC);
     pCos = interp.interpolate(ekin, qxCos);
     pFrac = interp.interpolate(ekin, qxFrac);
-  } else if (is == 3 || is == 7 || is == 14 || is == 10 || is == 11 ||
-	     is == 30 || is == 17 || is == 26) {
-    // pi+p, pi0p, pi0n, pi-n, k+p, k0n, k0bp, or k-n
+
+  } else if (is == 3 || is == 7 || is == 9 || is == 11 || is == 17 ||
+             is == 10 || is == 14 || is == 18 || is == 26 || is == 30) {
+    // pi+p, pi0p, gammap, k+p, k0bp, pi-n, pi0n, gamman, k-n, or k0n
     if (verboseLevel > 3) G4cout << " meson-nucleon elastic (1)" << G4endl;
 
     static const G4double hn1ke[10] =   {0.0,  0.062,  0.12,   0.217,  0.533,  0.873,  1.34,   2.86,   5.86,  10.0};
@@ -803,6 +895,7 @@ G4ElementaryParticleCollider::sampleCMmomentumFor2to2(G4int is, G4int kw,
     pC = interp.interpolate(ekin, hn1C);
     pCos = interp.interpolate(ekin, hn1Cos);
     pFrac = interp.interpolate(ekin, hn1Frac);
+
   } else if (is == 5 || is == 6 || is == 13 || is == 34 || is == 22 ||
 	     is == 15) {
     // pi-p, pi+n, k-p, k0bn, k+n, or k0p
@@ -819,13 +912,14 @@ G4ElementaryParticleCollider::sampleCMmomentumFor2to2(G4int is, G4int kw,
     pC = interp.interpolate(ekin, hn2C);
     pCos = interp.interpolate(ekin, hn2Cos);
     pFrac = interp.interpolate(ekin, hn2Frac);
+
   } else {
     if (verboseLevel)
       G4cerr << " G4ElementaryParticleCollider::sampleCMmomentumFor2to2:"
 	     << " interaction is=" << is << " not recognized " << G4endl;
   } 
 
-  // Bound parameters to their physical ranges
+  // Bound parameters by their physical ranges
   pCos = std::max(-1.,std::min(pCos,1.));
   pFrac = std::max(0.,std::min(pFrac,1.));
 
@@ -875,14 +969,13 @@ void
 G4ElementaryParticleCollider::generateSCMpionAbsorption(G4double etot_scm,
 			             G4InuclElementaryParticle* particle1,
 			             G4InuclElementaryParticle* particle2) {
-  if (verboseLevel > 3) G4cout << " >>> G4ElementaryParticleCollider::generateSCMpionAbsorption" 
-                               << G4endl;
+  if (verboseLevel > 3)
+    G4cout << " >>> G4ElementaryParticleCollider::generateSCMpionAbsorption" 
+	   << G4endl;
 
-  // generate nucleons momenta for pion absorption
+  // generate nucleons momenta for pion or photon absorption
   // the nucleon distribution assumed to be isotropic in SCM
 
-  G4InuclElementaryParticle dummy;
-
   particles.clear();		// Initialize buffers for this event
   particles.resize(2);
 
@@ -893,66 +986,55 @@ G4ElementaryParticleCollider::generateSCMpionAbsorption(G4double etot_scm,
 
   // generate kinds
 
-  if (type1 == 3) {
-
-    if (type2 == 111) { // pi+ + PP -> ? 
-
-      G4cout << " pion absorption: pi+ + PP -> ? " << G4endl;
-
+  if (type1 == pionPlus) {
+    if (type2 == diproton) {		// pi+ + PP -> ? 
+      G4cerr << " pion absorption: pi+ + PP -> ? " << G4endl;
+      return;
+    } else if (type2 == unboundPN) { 	// pi+ + PN -> PP
+      particle_kinds.push_back(proton);
+      particle_kinds.push_back(proton);
+    } else if (type2 == dineutron) { 	// pi+ + NN -> PN
+      particle_kinds.push_back(proton);
+      particle_kinds.push_back(neutron);
+    }
+  } else if (type1 == pionMinus) { 
+    if (type2 == diproton) {		// pi- + PP -> PN 
+      particle_kinds.push_back(proton);
+      particle_kinds.push_back(neutron);
+    } else if (type2 == unboundPN) {	 // pi- + PN -> NN
+      particle_kinds.push_back(neutron);
+      particle_kinds.push_back(neutron);
+    } else if (type2 == dineutron) {	// pi- + NN -> ?
+      G4cerr << " pion absorption: pi- + NN -> ? " << G4endl;
       return;
     }
-    else if(type2 == 112) { // pi+ + PN -> PP
-      particle_kinds.push_back(1);
-      particle_kinds.push_back(1);
+  } else if (type1 == pionZero || type1 == photon) {
+    if (type2 == diproton) {		// pi0/gamma + PP -> PP 
+      particle_kinds.push_back(proton);
+      particle_kinds.push_back(proton);
+    } else if (type2 == unboundPN) {	// pi0/gamma + PN -> PN
+      particle_kinds.push_back(proton);
+      particle_kinds.push_back(neutron);
+    } else if (type2 == dineutron) {	// pi0/gamma + NN -> ?
+      particle_kinds.push_back(neutron);
+      particle_kinds.push_back(neutron);
     }
-    else if(type2 == 122) { // pi+ + NN -> PN
-      particle_kinds.push_back(1);
-      particle_kinds.push_back(2);
-    };     
   }
-  else if(type1 == 5) { 
-    if(type2 == 111) { // pi- + PP -> PN 
-      particle_kinds.push_back(1);
-      particle_kinds.push_back(2);
-    }
-    else if(type2 == 112) { // pi- + PN -> NN
-      particle_kinds.push_back(2);
-      particle_kinds.push_back(2);
-    }
-    else if(type2 == 122) { // pi- + NN -> ?
-
-      G4cout << " pion absorption: pi- + NN -> ? " << G4endl;
-
-      return;
-    };     
-  }
-  else if(type1 == 7) {
-    if(type2 == 111) { // pi0 + PP -> PP 
-      particle_kinds.push_back(1);
-      particle_kinds.push_back(1);
-    }
-    else if(type2 == 112) { // pi0 + PN -> PN
-      particle_kinds.push_back(1);
-      particle_kinds.push_back(2);
-    }
-    else if(type2 == 122) { // pi0 + NN -> ?
-      particle_kinds.push_back(2);
-      particle_kinds.push_back(2);
-    };     
-  };
     
-  G4double m1 = dummy.getParticleMass(particle_kinds[0]);
-  G4double m1sq = m1*m1;
+  G4InuclElementaryParticle dummy;
 
-  G4double m2 = dummy.getParticleMass(particle_kinds[1]);
-  G4double m2sq = m2*m2;
+  G4double mone = dummy.getParticleMass(particle_kinds[0]);
+  G4double m1sq = mone*mone;
+
+  G4double mtwo = dummy.getParticleMass(particle_kinds[1]);
+  G4double m2sq = mtwo*mtwo;
 
   G4double a = 0.5 * (etot_scm * etot_scm - m1sq - m2sq);
 
   G4double pmod = std::sqrt((a * a - m1sq * m2sq) / (m1sq + m2sq + 2.0 * a));
-  G4LorentzVector mom1 = generateWithRandomAngles(pmod, m1);
+  G4LorentzVector mom1 = generateWithRandomAngles(pmod, mone);
   G4LorentzVector mom2;
-  mom2.setVectM(-mom1.vect(), m2);
+  mom2.setVectM(-mom1.vect(), mtwo);
 
   particles[0].fill(mom1, particle_kinds[0], G4InuclParticle::EPCollider);
   particles[1].fill(mom2, particle_kinds[1], G4InuclParticle::EPCollider);
