@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4QKaonMinusElasticCrossSection.cc,v 1.2 2010-06-14 15:55:18 mkossov Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 //
 // G4 Physics class: G4QKaonMinusElasticCrossSection for pA elastic cross sections
@@ -44,6 +43,7 @@
 //#define sdebug
 
 #include "G4QKaonMinusElasticCrossSection.hh"
+#include "G4SystemOfUnits.hh"
 
 // Initialization of the static parameters
 const G4int G4QKaonMinusElasticCrossSection::nPoints=128;//#ofPt in AMDB table(>anyPar)/D
@@ -1094,8 +1094,8 @@ G4double G4QKaonMinusElasticCrossSection::GetQ2max(G4int PDG, G4int tgZ, G4int t
   {
     G4double mt=G4QPDGCode(90000000+tgZ*1000+tgN).GetMass()*.001; // Target mass in GeV
     G4double dmt=mt+mt;
-    G4double s=dmt*std::sqrt(pP2+mK2)+mK2+mt*mt;    // Mondelstam s
-    return dmt*dmt*pP2/s;
+    G4double s_value=dmt*std::sqrt(pP2+mK2)+mK2+mt*mt;    // Mondelstam s
+    return dmt*dmt*pP2/s_value;
   }
   else
   {
