@@ -45,6 +45,7 @@
 //#define debugs
 
 #include "G4QKaonMinusNuclearCrossSection.hh"
+#include "G4SystemOfUnits.hh"
 
 // Initialization of the
 G4double* G4QKaonMinusNuclearCrossSection::lastLEN=0; // Pointer to lastArray of LowEn CS
@@ -80,7 +81,7 @@ G4QKaonMinusNuclearCrossSection::~G4QKaonMinusNuclearCrossSection()
 G4double G4QKaonMinusNuclearCrossSection::GetCrossSection(G4bool fCS, G4double pMom,
                                                        G4int tgZ, G4int tgN, G4int PDG)
 {
-  static G4double tolerance=0.001;     // Tolerance (0.1%) to consider as "the same mom"
+  //A.R.23-Oct-2012 Shadowed variable  static G4double tolerance=0.001;     // Tolerance (0.1%) to consider as "the same mom"
   static G4int j;                      // A#0f Z/N-records already tested in AMDB
   static std::vector <G4int>    colN;  // Vector of N for calculated nuclei (isotops)
   static std::vector <G4int>    colZ;  // Vector of Z for calculated nuclei (isotops)
@@ -266,9 +267,9 @@ G4double G4QKaonMinusNuclearCrossSection::CalculateCrossSection(G4bool, G4int F,
       lastHEN = new G4double[nH];      // Allocate memory for the new HEN cross sections
       // --- Instead of making a separate function ---
       G4double P=THmiG;                // Table threshold in GeV/c
-      for(G4int m=0; m<nL; m++)
+      for(G4int n=0; n<nL; n++)
       {
-        lastLEN[m] = CrossSectionLin(targZ, targN, P);
+        lastLEN[n] = CrossSectionLin(targZ, targN, P);
         P+=dPG;
       }
       G4double lP=milPG;
@@ -381,14 +382,14 @@ G4double G4QKaonMinusNuclearCrossSection::CrossSectionFormula(G4int tZ, G4int tN
     G4double al=std::log(a);
     G4double a2=a*a;
     G4double c=52.*std::exp(al*0.6)*(1.+97./a2)/(1.+9.8/a)/(1.+47./a2);
-    G4double g=-.2-.003*a;
+    G4double g_value=-.2-.003*a;
     G4double h=.5+.07*a;
     G4double v=P-1.;
     G4double f=.6*a*sa/(1.+.00002*a2);
     G4double u=.125+.127*al;
-    sigma=(c+d*d)/(1.+g/sp+h/p2/p2)+f/(v*v+u*u)+20.*sa/P/sp;
+    sigma=(c+d*d)/(1.+g_value/sp+h/p2/p2)+f/(v*v+u*u)+20.*sa/P/sp;
 #ifdef pdebug
-    G4cout<<"G4QKMinNucCS::CSForm: A="<<a<<",P="<<P<<",CS="<<sigma<<",c="<<c<<",g="<<g
+    G4cout<<"G4QKMinNucCS::CSForm: A="<<a<<",P="<<P<<",CS="<<sigma<<",c="<<c<<",g="<<g_value
           <<",d="<<d<<",r="<<r<<",e="<<e<<",h="<<h<<G4endl;
 #endif
   }
