@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4QCaptureAtRest.cc,v 1.2 2010-06-25 09:46:05 gunter Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 //      ---------------- G4QCaptureAtRest class -----------------
 //                 by Mikhail Kossov, December 2003.
@@ -47,10 +46,17 @@
 //#define tdebug
 
 #include "G4QCaptureAtRest.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
+#include "G4HadronicDeprecate.hh"
+
 
 G4QCaptureAtRest::G4QCaptureAtRest(const G4String& processName)
   : G4VRestProcess(processName, fHadronic), Time(0.), EnergyDeposition(0.)
 {
+
+  G4HadronicDeprecate("G4QCaptureAtRest");
+
 #ifdef debug
   G4cout<<"G4QCaptureAtRest::Constructor is called"<<G4endl;
 #endif
@@ -66,11 +72,12 @@ G4bool   G4QCaptureAtRest::manualFlag=false; // If false then standard parameter
 G4double G4QCaptureAtRest::Temperature=180.; // Critical Temperature (sensitive at High En)
 G4double G4QCaptureAtRest::SSin2Gluons=0.3;  // Supression of s-quarks (in respect to u&d)
 G4double G4QCaptureAtRest::EtaEtaprime=0.3;  // Supression of eta mesons (gg->qq/3g->qq)
-G4double G4QCaptureAtRest::freeNuc=0.5;      // Percentage of free nucleons on the surface
-G4double G4QCaptureAtRest::freeDib=0.05;     // Percentage of free diBaryons on the surface
-G4double G4QCaptureAtRest::clustProb=5.;     // Nuclear clusterization parameter
+G4double G4QCaptureAtRest::freeNuc=0.04;     // Percentage of free nucleons on the surface
+G4double G4QCaptureAtRest::freeDib=0.08;     // Percentage of free diBaryons on the surface
+G4double G4QCaptureAtRest::clustProb=4.;     // Nuclear clusterization parameter
 G4double G4QCaptureAtRest::mediRatio=10.;    // medium/vacuum hadronization ratio
-G4int    G4QCaptureAtRest::nPartCWorld=152;  // The#of particles initialized in CHIPS World
+//G4int    G4QCaptureAtRest::nPartCWorld=152;// The#of particles initialized in CHIPS World
+G4int    G4QCaptureAtRest::nPartCWorld=85;  // The#of parts initialized in CHIPS World RED
 G4double G4QCaptureAtRest::SolidAngle=0.5;   // Part of Solid Angle to capture (@@A-dep.)
 G4bool   G4QCaptureAtRest::EnergyFlux=false; // Flag for Energy Flux use (not MultyQuasmon)
 G4double G4QCaptureAtRest::PiPrThresh=141.4; // Pion Production Threshold for gammas
@@ -85,7 +92,7 @@ void G4QCaptureAtRest::SetParameters(G4double temper, G4double ssin2g, G4double
                                      G4double fN, G4double fD, G4double cP, G4double mR,
                                      G4int nParCW, G4double solAn, G4bool efFlag,
                                      G4double piThresh, G4double mpisq, G4double dinum)
-{//  =============================================================================
+{
   Temperature=temper;
   SSin2Gluons=ssin2g;
   EtaEtaprime=etaetap;
@@ -286,8 +293,8 @@ G4VParticleChange* G4QCaptureAtRest::AtRestDoIt(const G4Track& track, const G4St
   nOfNeutrons=N;                                       // Remember it for energy-mom. check
   G4double dd=0.025;
   G4double am=Z+N;
-  G4double sr=std::sqrt(am);
-  G4double dsr=0.01*(sr+sr);
+  G4double value_sr=std::sqrt(am);
+  G4double dsr=0.01*(value_sr+value_sr);
   if(dsr<dd)dsr=dd;
   if(manualFlag) G4QNucleus::SetParameters(freeNuc,freeDib,clustProb,mediRatio); // ManualP
   else if(projPDG==-2212) G4QNucleus::SetParameters(1.-dsr-dsr,dd+dd,5.,10.);//aP ClustPars
@@ -704,7 +711,7 @@ G4VParticleChange* G4QCaptureAtRest::AtRestDoIt(const G4Track& track, const G4St
         G4LorentzVector s4Mom(0.,0.,0.,mqq);     // Quark-Antiquark
         if(!G4QHadron(projLV).DecayIn2(f4Mom,s4Mom))
         {
-          G4cerr<<"---Worning---G4QCaptureAtRest::AtRestDoIt: (mu-)=>q+aq+nu, M#1"<<G4endl;
+          G4cerr<<"---Warning---G4QCaptureAtRest::AtRestDoIt: (mu-)=>q+aq+nu, M#1"<<G4endl;
           return 0;
         }
         neutr = new G4QHadron(nuPDG,f4Mom);      // Create Neutrino
@@ -717,7 +724,7 @@ G4VParticleChange* G4QCaptureAtRest::AtRestDoIt(const G4Track& track, const G4St
     EnMomConservation=G4LorentzVector(0.,0.,0.,tM);         // Total 4-mom of the reaction
 
 #ifdef tdebug
-    G4cout<<"====>G4QCapAR:E/MCons, p="<<mp<<","<<projPDG<<",t="<<tM<<","<<targPDG<<",t4M="
+    G4cout<<"=--=>G4QCapAR:E/MCons, p="<<mp<<","<<projPDG<<",t="<<tM<<","<<targPDG<<",t4M="
           <<EnMomConservation<<G4endl;
 #endif
     G4QHadron* pH = new G4QHadron(projPDG,projLV);          // ---> DELETED---->---->----+
@@ -739,7 +746,8 @@ G4VParticleChange* G4QCaptureAtRest::AtRestDoIt(const G4Track& track, const G4St
       //#ifdef pdebug
       G4cerr<<"***G4QCaptureAtRest::AtRestDoIt: Exception is catched"<<G4endl; //    |
       //#endif
-      G4Exception("G4QCaptureAtRest::AtRestDoIt:","27",FatalException,"Gen.CHIPS Except.");
+      G4Exception("G4QCaptureAtRest::AtRestDoIt()","HAD_CHPS_0027",
+                  FatalException," General CHIPS Exception");
     }                                                             //                 |
     delete pan;                              // Delete the Nuclear Environment <--<--+
 #ifdef debug
