@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4QElastic.cc,v 1.9 2010-06-08 11:25:09 mkossov Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 //      ---------------- G4QElastic class -----------------
 //                 by Mikhail Kossov, December 2003.
@@ -40,6 +39,9 @@
 //#define ppdebug
 
 #include "G4QElastic.hh"
+#include "G4SystemOfUnits.hh"
+#include "G4HadronicDeprecate.hh"
+
 
 // Initialization of static vectors
 //G4int    G4QElastic::nPartCWorld=152;      // The#of particles initialized in CHIPS World
@@ -54,6 +56,8 @@ std::vector<std::vector<G4double>*>G4QElastic::IsoProbInEl;//SumProbabIsotopes i
 G4QElastic::G4QElastic(const G4String& processName): 
  G4VDiscreteProcess(processName, fHadronic)
 {
+  G4HadronicDeprecate("G4QElastic");
+
 #ifdef debug
   G4cout<<"G4QElastic::Constructor is called processName="<<processName<<G4endl;
 #endif
