@@ -30,6 +30,10 @@
 //
 // 
 
+#include "G4AntiNuclElastic.hh"
+
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4ParticleTable.hh"
 #include "G4ParticleDefinition.hh"
 #include "G4IonTable.hh"
@@ -45,7 +49,6 @@
 #include "G4Deuteron.hh"
 #include "G4Alpha.hh"
 #include "G4Pow.hh"
-#include "G4AntiNuclElastic.hh"
 
 #include "G4NucleiProperties.hh"       
 
