@@ -36,13 +36,16 @@
 // JMQ (14 february 2009) bug fixed in emission width: hbarc instead of hbar_Planck in the denominator
 //
 #include <iostream>
-using namespace std;
 
 #include "G4EvaporationProbability.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4PairingCorrection.hh"
 #include "G4ParticleTable.hh"
 #include "G4IonTable.hh"
 
+using namespace std;
+
 G4EvaporationProbability::G4EvaporationProbability(G4int anA, G4int aZ, 
 						   G4double aGamma,
 						   G4VCoulombBarrier * aCoulombBarrier) 
@@ -63,16 +66,16 @@ G4EvaporationProbability::~G4EvaporationProbability()
 {}
   
 G4double 
-G4EvaporationProbability::EmissionProbability(const G4Fragment & fragment, G4double anEnergy)
+G4EvaporationProbability::EmissionProbability(const G4Fragment & fragment, 
+					      G4double anEnergy)
 {
-  G4double EmissionProbability = 0.0;
-  G4double MaximalKineticEnergy = anEnergy;
+  G4double probability = 0.0;
 
-  if (MaximalKineticEnergy > 0.0 && fragment.GetExcitationEnergy() > 0.0) {
-    EmissionProbability = CalculateProbability(fragment, MaximalKineticEnergy);
+  if (anEnergy > 0.0 && fragment.GetExcitationEnergy() > 0.0) {
+    probability = CalculateProbability(fragment, anEnergy);
 
   }
-  return EmissionProbability;
+  return probability;
 }
 
 ////////////////////////////////////
