@@ -23,8 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4He3EvaporationProbability.cc,v 1.18 2010-11-17 11:06:03 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // J.M. Quesada (August2008). Based on:
 //
@@ -36,6 +35,7 @@
 // 17-11-2010 V.Ivanchenko integer Z and A
 
 #include "G4He3EvaporationProbability.hh"
+#include "G4SystemOfUnits.hh"
 
 G4He3EvaporationProbability::G4He3EvaporationProbability() :
    G4EvaporationProbability(3,2,2,&theCoulombBarrier) // A,Z,Gamma,&theCoulombBarrier
@@ -136,7 +136,7 @@ G4double G4He3EvaporationProbability::GetOpt12(const  G4double K)
   G4double     p2 = -1389.;
   G4double     landa0 = -0.00535;
   G4double     landa1 = -11.16;
-  G4double     mu0 = 555.5;
+  G4double     mum0 = 555.5;
   G4double     mu1 = 0.40;
   G4double     nu0 = 687.4;
   G4double     nu1 = -476.3;
@@ -148,7 +148,7 @@ G4double G4He3EvaporationProbability::GetOpt12(const  G4double K)
   landa = landa0*ResidualA + landa1;
 
   G4double resmu1 = fG4pow->powZ(ResidualA,mu1); 
-  mu = mu0*resmu1;
+  mu = mum0*resmu1;
   nu = resmu1*(nu0 + nu1*Ec + nu2*(Ec*Ec));
   q = landa - nu/(Ec*Ec) - 2*p*Ec;
   r = mu + 2*nu/Ec + p*(Ec*Ec);
@@ -179,7 +179,7 @@ G4double G4He3EvaporationProbability::GetOpt34(const  G4double K)
   G4double     p2 = -1487.;
   G4double     landa0 = 0.00459;
   G4double     landa1 = -8.93;
-  G4double     mu0 = 611.2;
+  G4double     mum0 = 611.2;
   G4double     mu1 = 0.35;
   G4double     nu0 = 473.8;
   G4double     nu1 = -468.2;
@@ -194,7 +194,7 @@ G4double G4He3EvaporationProbability::GetOpt34(const  G4double K)
   p = p0 + p1/ec + p2/ecsq;
   landa = landa0*ResidualA + landa1;
   a = fG4pow->powZ(ResidualA,mu1);
-  mu = mu0 * a;
+  mu = mum0 * a;
   nu = a* (nu0+nu1*ec+nu2*ecsq);  
   xnulam = nu / landa;
   if (xnulam > spill) { xnulam=0.; }
