@@ -44,6 +44,8 @@
 // 04.05.2011 J. M. Quesada: added detailed printout for testing
 
 #include "G4FermiFragmentsPool.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4StableFermiFragment.hh"
 #include "G4B9FermiFragment.hh"
 #include "G4Be8FermiFragment.hh"
@@ -608,7 +610,7 @@ G4FermiFragmentsPool::GetConfigurationList(G4int Z, G4int A, G4double mass)
     v->push_back(conf);
     ++nconf;
     if(verbose > 0) { 
-      G4cout<<"Total number of configurations = "<<nconf<<G4cout;
+      G4cout<<"Total number of configurations = "<<nconf<<G4endl;
       G4double ExEn= mass -G4NucleiProperties::GetNuclearMass(A,Z);
       G4cout<<"Total number of configurations = "<<nconf<<" for A= "
 	    <<A<<"   Z= "<<Z<<"   E*= "<< ExEn<<" MeV"<<G4endl;
