@@ -23,11 +23,14 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4EvaporationGEMFactory.cc,v 1.10 2010-04-27 11:43:16 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // Hadronic Process: Nuclear De-excitations
 // by V. Lara
+//
+// Modifications:
+//
+// 23 January 2012 V.Ivanchenko added pointer of G4VPhotonEvaporation 
 
 #include "G4EvaporationGEMFactory.hh"
 
@@ -99,21 +102,21 @@
 #include "G4Mg28GEMChannel.hh"
 
 #include "G4CompetitiveFission.hh"
-#include "G4PhotonEvaporation.hh"
 
-G4EvaporationGEMFactory::G4EvaporationGEMFactory()
+G4EvaporationGEMFactory::G4EvaporationGEMFactory(G4VEvaporationChannel* ptr)
+  : G4VEvaporationFactory(ptr)
 {} 
   
 G4EvaporationGEMFactory::~G4EvaporationGEMFactory() 
 {}
                  
-std::vector<G4VEvaporationChannel*> * G4EvaporationGEMFactory::CreateChannel()
+std::vector<G4VEvaporationChannel*> * G4EvaporationGEMFactory::GetChannel()
 {
   std::vector<G4VEvaporationChannel*> * theChannel = 
     new std::vector<G4VEvaporationChannel*>;
   theChannel->reserve(68);
 
-  theChannel->push_back( new G4PhotonEvaporation() );  // Photon Channel
+  theChannel->push_back( thePhotonEvaporation );  // Photon Channel
   theChannel->push_back( new G4CompetitiveFission() ); // Fission Channel
 
   theChannel->push_back( new G4NeutronGEMChannel() );  // n
