@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4StatMFMacroTemperature.cc,v 1.9 2010-10-29 17:35:04 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // Hadronic Process: Nuclear De-excitations
 // by V. Lara
@@ -41,6 +40,8 @@
 // 28.10.10 V.Ivanchenko defined members in constructor and cleaned up
 
 #include "G4StatMFMacroTemperature.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 G4StatMFMacroTemperature::G4StatMFMacroTemperature(const G4double anA, const G4double aZ, 
   const G4double ExEnergy, const G4double FreeE0, const G4double kappa, 
@@ -172,9 +173,7 @@ G4double G4StatMFMacroTemperature::FragsExcitEnergy(const G4double T)
       }
 
     // Excitation energy per nucleon
-    G4double FragsExcitEnergy = AverageEnergy - _FreeInternalE0;
-
-    return FragsExcitEnergy;
+    return AverageEnergy - _FreeInternalE0;
 
 }
 
