@@ -23,14 +23,13 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4PairingCorrection.cc,v 1.8 2010-11-15 12:41:58 vnivanch Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // Hadronic Process: Nuclear De-excitations
 // by V. Lara
 
-
 #include "G4PairingCorrection.hh"
+#include "G4SystemOfUnits.hh"
 
 G4PairingCorrection* G4PairingCorrection::theInstance = 0;
 
