@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEAntiKaonZeroInelastic.cc,v 1.18 2010-11-27 00:06:50 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
-#include "globals.hh"
-#include "G4ios.hh"
-
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
 // and the low energy two-body model. Not included is the low energy stuff like
@@ -40,8 +36,10 @@
 //
  
 #include "G4HEAntiKaonZeroInelastic.hh"
-#include <iostream>
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 G4HEAntiKaonZeroInelastic::G4HEAntiKaonZeroInelastic(const G4String& name)
  : G4HEInelastic(name)
@@ -51,6 +49,8 @@ G4HEAntiKaonZeroInelastic::G4HEAntiKaonZeroInelastic(const G4String& name)
   theMaxEnergy = 10*TeV;
   MAXPART      = 2048;
   verboseLevel = 0;
+  G4cout << "WARNING: model G4HEAntiKaonZeroInelastic is being deprecated and will\n"
+         << "disappear in Geant4 version 10.0"  << G4endl;  
 }
 
 
@@ -214,8 +214,8 @@ G4HEAntiKaonZeroInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;      // upper bound for arg. of exp
+  static const G4double expxl = -expxu;   // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;
@@ -238,120 +238,87 @@ G4HEAntiKaonZeroInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
   static G4double neutmul[numMul], neutnorm[numSec];  // neutron constants
 
   // misc. local variables
-  // np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  // npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
-   if( first ) 
-     {                   // compute normalization constants, this will only be done once
-       first = false;
-       for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
-       for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
-          {
-            for( nm=std::max(0,np-2); nm<=np; nm++ ) 
-               {
-                 for( nz=0; nz<numSec/3; nz++ ) 
-                    {
-                      if( ++counter < numMul ) 
-                        {
-                          nt = np+nm+nz;
-                          if( (nt>0) && (nt<=numSec) ) 
-                            {
-                              protmul[counter] =
-                                    pmltpc(np,nm,nz,nt,protb,c) ;
-                              protnorm[nt-1] += protmul[counter];
-                            }
-                        }
-                    }
-               }
+  if (first) {  // Computation of normalization constants will only be done once
+    first = false;
+    for (i = 0; i < numMul; i++) protmul[i]  = 0.0;
+    for (i = 0; i < numSec; i++) protnorm[i] = 0.0;
+    counter = -1;
+    for (npos = 0; npos < (numSec/3); npos++) {
+      for (nneg = std::max(0,npos-2); nneg <= npos; nneg++) {
+        for (nzero = 0; nzero < numSec/3; nzero++) {
+          if (++counter < numMul) {
+            nt = npos+nneg+nzero;
+            if ((nt > 0) && (nt <= numSec) ) {
+              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
+              protnorm[nt-1] += protmul[counter];
+            }
           }
-       for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
-       for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
-          {
-            for( nm=std::max(0,np-1); nm<=(np+1); nm++ ) 
-               {
-                 for( nz=0; nz<numSec/3; nz++ ) 
-                    {
-                      if( ++counter < numMul ) 
-                        {
-                          nt = np+nm+nz;
-                          if( (nt>0) && (nt<=numSec) ) 
-                            {
-                               neutmul[counter] =
-                                      pmltpc(np,nm,nz,nt,neutb,c);
-                               neutnorm[nt-1] += neutmul[counter];
-                            }
-                        }
-                    }
-               }
+        }
+      }
+    }
+
+    for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
+    for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
+    counter = -1;
+    for (npos = 0; npos < numSec/3; npos++) {
+      for (nneg = std::max(0,npos-1); nneg <= (npos+1); nneg++) {
+        for (nzero = 0; nzero < numSec/3; nzero++) {
+          if (++counter < numMul) {
+            nt = npos+nneg+nzero;
+            if ((nt > 0) && (nt <= numSec) ) {
+              neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
+              neutnorm[nt-1] += neutmul[counter];
+            }
           }
-       for( i=0; i<numSec; i++ ) 
-          {
-            if( protnorm[i] > 0.0 )protnorm[i] = 1.0/protnorm[i];
-            if( neutnorm[i] > 0.0 )neutnorm[i] = 1.0/neutnorm[i];
-          }
-     }                                          // end of initialization
+        }
+      }
+    }
+    for (i = 0; i < numSec; i++) {
+      if (protnorm[i] > 0.0) protnorm[i] = 1.0/protnorm[i];
+      if (neutnorm[i] > 0.0) neutnorm[i] = 1.0/neutnorm[i];
+    }
+  }  // end of initialization
 
-         
-                                              // initialize the first two places
-                                              // the same as beam and target                                    
-   pv[0] = incidentParticle;
-   pv[1] = targetParticle;
-   vecLen = 2;
+  pv[0] = incidentParticle;    // initialize the first two places
+  pv[1] = targetParticle;      // the same as beam and target
+  vecLen = 2;
 
-   if (!inElastic || (availableEnergy <= PionPlus.getMass())) 
-      return;
+  if (!inElastic || (availableEnergy <= PionPlus.getMass())) return;
 
-                                        
-//                                            inelastic scattering
+  // inelastic scattering
+  npos = 0, nneg = 0, nzero = 0;
+  G4double cech[] = { 1., 1., 1., 0.70, 0.60, 0.55, 0.35, 0.25, 0.18, 0.15};
+  G4int iplab = G4int( incidentTotalMomentum*5.);
+  if ( (iplab < 10) && (G4UniformRand() < cech[iplab]) ) {
+    G4int ipl = std::min(19, G4int( incidentTotalMomentum*5.));
+    G4double cnk0[] = {0.17, 0.18, 0.17, 0.24, 0.26, 0.20, 0.22, 0.21, 0.34, 0.45,
+                       0.58, 0.55, 0.36, 0.29, 0.29, 0.32, 0.32, 0.33, 0.33, 0.33};
+    if (G4UniformRand() < cnk0[ipl] ) {
+      if (targetCode == protonCode) {
+        return;
+      } else {
+        pv[0] = KaonMinus;
+        pv[1] = Proton;
+        return;
+      }
+    }
 
-   np = 0, nm = 0, nz = 0;
-   G4double cech[] = { 1., 1., 1., 0.70, 0.60, 0.55, 0.35, 0.25, 0.18, 0.15};
-   G4int iplab = G4int( incidentTotalMomentum*5.);
-   if( (iplab < 10) && (G4UniformRand() < cech[iplab]) ) 
-     {
-       G4int     iplab = std::min(19, G4int( incidentTotalMomentum*5.));
-       G4double cnk0[] = {0.17, 0.18, 0.17, 0.24, 0.26, 0.20, 0.22, 0.21, 0.34, 0.45,
-                          0.58, 0.55, 0.36, 0.29, 0.29, 0.32, 0.32, 0.33, 0.33, 0.33};
-       if( G4UniformRand() < cnk0[iplab] )
-         {
-           if( targetCode == protonCode )
-             {
-               return;
-             }
-           else
-             {
-               pv[0] = KaonMinus;
-               pv[1] = Proton;
-               return;
-             }
-         }
-       G4double ran = G4UniformRand();
-       if( targetCode == protonCode )                    // target is a proton 
-         {
-           if( ran < 0.25 )
-             { 
-             } 
-           else if (ran < 0.50)
-             {
-               pv[0] = PionPlus;
-               pv[1] = SigmaZero;
-             }
-           else if (ran < 0.75)
-             {
-             }
-           else
-             {
-               pv[0] = PionPlus;
-               pv[1] = Lambda;
-             }
-         } 
-       else 
-         {                                               // target is a neutron
+    G4double ran = G4UniformRand();
+    if (targetCode == protonCode) {  // target is a proton 
+      if (ran < 0.25) { 
+      } else if (ran < 0.50) {
+        pv[0] = PionPlus;
+        pv[1] = SigmaZero;
+      } else if (ran < 0.75) {
+      } else {
+        pv[0] = PionPlus;
+        pv[1] = Lambda;
+      }
+    } else {   // target is a neutron
            if( ran < 0.25 )
              { 
                pv[0] = PionMinus;
@@ -372,67 +339,65 @@ G4HEAntiKaonZeroInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
                pv[0] = PionZero;
                pv[1] = Lambda;
              }
-         }
-       return;
-     }
-   else
-     {
-//                    number of total particles vs. centre of mass Energy - 2*proton mass
-   
-       G4double aleab = std::log(availableEnergy);
-       G4double n     = 3.62567+aleab*(0.665843+aleab*(0.336514
-                    + aleab*(0.117712+0.0136912*aleab))) - 2.0;
-   
-//                    normalization constant for kno-distribution.
-//                    calculate first the sum of all constants, check for numerical problems.   
-       G4double test, dum, anpn = 0.0;
+    }
+    return;
 
-       for (nt=1; nt<=numSec; nt++) {
-         test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
-         dum = pi*nt/(2.0*n*n);
-         if (std::fabs(dum) < 1.0) { 
-           if( test >= 1.0e-10 )anpn += dum*test;
-         } else { 
-           anpn += dum*test;
-         }
-       }
+  } else {
+    // number of total particles vs. centre of mass Energy - 2*proton mass
+    G4double aleab = std::log(availableEnergy);
+    G4double n = 3.62567+aleab*(0.665843+aleab*(0.336514
+                 + aleab*(0.117712+0.0136912*aleab))) - 2.0;
    
-       G4double ran = G4UniformRand();
-       G4double excs = 0.0;
-       if (targetCode == protonCode) {
-         counter = -1;
-         for (np=0; np<numSec/3; np++) {
-           for (nm=std::max(0,np-2); nm<=np; nm++) {
-             for (nz=0; nz<numSec/3; nz++) {
-               if (++counter < numMul) {
-                 nt = np+nm+nz;
-                 if( (nt>0) && (nt<=numSec) ) {
-                   test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
-                   dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
+    // normalization constant for kno-distribution.
+    // calculate first the sum of all constants, check for numerical problems.   
+    G4double test, dum, anpn = 0.0;
 
-                   if (std::fabs(dum) < 1.0) { 
-                     if( test >= 1.0e-10 )excs += dum*test;
-                   } else { 
-                     excs += dum*test;
-		   }
+    for (nt=1; nt<=numSec; nt++) {
+      test = std::exp(std::min(expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
+      dum = pi*nt/(2.0*n*n);
+      if (std::fabs(dum) < 1.0) { 
+        if( test >= 1.0e-10 )anpn += dum*test;
+      } else { 
+        anpn += dum*test;
+      }
+    }
+   
+    G4double ran = G4UniformRand();
+    G4double excs = 0.0;
+    if (targetCode == protonCode) {
+      counter = -1;
+      for (npos=0; npos<numSec/3; npos++) {
+        for (nneg=std::max(0,npos-2); nneg<=npos; nneg++) {
+          for (nzero=0; nzero<numSec/3; nzero++) {
+            if (++counter < numMul) {
+              nt = npos+nneg+nzero;
+              if ((nt>0) && (nt<=numSec) ) {
+                test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
+                dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
 
-                   if (ran < excs) goto outOfLoop;      //----------------------->
-		 }
-	       }
-             }
-           }
-	 }
+                if (std::fabs(dum) < 1.0) { 
+                  if( test >= 1.0e-10 )excs += dum*test;
+                } else { 
+                  excs += dum*test;
+                }
+
+                if (ran < excs) goto outOfLoop;      //----------------------->
+              }
+            }
+          }
+        }
+      }
                                             // 3 previous loops continued to the end
-         inElastic = false;                 // quasi-elastic scattering   
-         return;
+      inElastic = false;                 // quasi-elastic scattering   
+      return;
 
-       } else {         // target must be a neutron
+    } else {         // target must be a neutron
          counter = -1;
-         for (np=0; np<numSec/3; np++) {
-           for (nm=std::max(0,np-1); nm<=(np+1); nm++) {
-             for (nz=0; nz<numSec/3; nz++) {
+         for (npos=0; npos<numSec/3; npos++) {
+           for (nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++) {
+             for (nzero=0; nzero<numSec/3; nzero++) {
                if (++counter < numMul) {
-                 nt = np+nm+nz;
+                 nt = npos+nneg+nzero;
                  if( (nt>=1) && (nt<=numSec) ) {
                    test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                    dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -452,35 +417,27 @@ G4HEAntiKaonZeroInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
                                                   // 3 previous loops continued to the end
          inElastic = false;                     // quasi-elastic scattering.
          return;
-       }
-     } 
-   outOfLoop:           //  <------------------------------------------------------------------------   
+    }
+  }  // if (iplab < 10 .... )
+ 
+  outOfLoop:           //  <------------------------------------------------------------------------   
     
-   if( targetCode == protonCode)
-     {
-       if( np == nm)
-         {
-         }
-       else if (np == (1+nm))
-         {
-           if( G4UniformRand() < 0.5)
-             {
-               pv[0] = KaonMinus;
-             }
-           else
-             {
-               pv[1] = Neutron;
-             }
-         }
-       else      
-         {
-           pv[0] = KaonMinus;
-           pv[1] = Neutron;
-         } 
-     }  
-   else
-     {
-       if( np == nm)
+  if (targetCode == protonCode) {
+    if (npos == nneg) {
+
+    } else if (npos == (1+nneg)) {
+      if (G4UniformRand() < 0.5) {
+        pv[0] = KaonMinus;
+      } else {
+        pv[1] = Neutron;
+      }
+    } else {
+      pv[0] = KaonMinus;
+      pv[1] = Neutron;
+    }
+
+  } else {
+      if( npos == nneg)
          {
            if( G4UniformRand() < 0.75)
              {
@@ -491,7 +448,7 @@ G4HEAntiKaonZeroInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
                pv[1] = Proton;
              }
          } 
-       else if ( np == (1+nm))
+       else if ( npos == (1+nneg))
          {
            pv[0] = KaonMinus;
          }
@@ -499,39 +456,29 @@ G4HEAntiKaonZeroInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
          {
            pv[1] = Proton;
          }
-     }      
+  }      
 
+  if (G4UniformRand() < 0.5) {
+    if (((pv[0].getCode() == kaonMinusCode)
+          && (pv[1].getCode() == neutronCode) )
+        || ((pv[0].getCode() == kaonZeroCode)
+             && (pv[1].getCode() == protonCode) )
+        || ((pv[0].getCode() == antiKaonZeroCode)
+               && (pv[1].getCode() == protonCode) ) ) {
 
-   if( G4UniformRand() < 0.5 )   
-     {
-       if(    (    (pv[0].getCode() == kaonMinusCode)
-                && (pv[1].getCode() == neutronCode)  )
-           || (    (pv[0].getCode() == kaonZeroCode)
-                && (pv[1].getCode() == protonCode)   )
-           || (    (pv[0].getCode() == antiKaonZeroCode)
-                && (pv[1].getCode() == protonCode)   )   )
-         {
-           G4double ran = G4UniformRand();
-           if( pv[1].getCode() == protonCode)
-             { 
-               if(ran < 0.68)
-                 {
-                   pv[0] = PionPlus;
-                   pv[1] = Lambda;
-                 }
-               else if (ran < 0.84)
-                 {
-                   pv[0] = PionZero;
-                   pv[1] = SigmaPlus;
-                 }
-               else
-                 {
-                   pv[0] = PionPlus;
-                   pv[1] = SigmaZero;
-                 }
-             }
-           else
-             {
+      G4double ran = G4UniformRand();
+      if (pv[1].getCode() == protonCode) { 
+        if (ran < 0.68) {
+          pv[0] = PionPlus;
+          pv[1] = Lambda;
+        } else if (ran < 0.84) {
+          pv[0] = PionZero;
+          pv[1] = SigmaPlus;
+        } else {
+          pv[0] = PionPlus;
+          pv[1] = SigmaZero;
+        }
+      } else {
                if(ran < 0.68)
                  {
                    pv[0] = PionMinus;
@@ -547,10 +494,8 @@ G4HEAntiKaonZeroInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
                    pv[0] = PionZero;
                    pv[1] = SigmaMinus;
                  }
-             }
-         } 
-       else
-         {
+      }
+    } else {
            G4double ran = G4UniformRand();
            if (ran < 0.67)
               {
@@ -572,56 +517,41 @@ G4HEAntiKaonZeroInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
                 pv[0] = PionPlus;
                 pv[1] = SigmaMinus;
               }
-         }
-     }
+    }
+  }  // if rand < 0.5
                
-
-   nt = np + nm + nz;
-   while ( nt > 0)
-       {
-         G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
-            { 
-              if( np > 0 ) 
-                { pv[vecLen++] = PionPlus;
-                  np--;
-                }
-            }
-         else if ( ran < (G4double)(np+nm)/nt)
-            {   
-              if( nm > 0 )
-                { 
-                  pv[vecLen++] = PionMinus;
-                  nm--;
-                }
-            }
-         else
-            {
-              if( nz > 0 )
-                { 
-                  pv[vecLen++] = PionZero;
-                  nz--;
-                }
-            }
-         nt = np + nm + nz;
-       } 
-   if (verboseLevel > 1)
-      {
-        G4cout << "Particles produced: " ;
-        G4cout << pv[0].getName() << " " ;
-        G4cout << pv[1].getName() << " " ;
-        for (i=2; i < vecLen; i++)   
-            { 
-              G4cout << pv[i].getName() << " " ;
-            }
-         G4cout << G4endl;
+  nt = npos + nneg + nzero;
+  while (nt > 0) {
+    G4double ran = G4UniformRand();
+    if (ran < (G4double)npos/nt) { 
+      if (npos > 0) {
+        pv[vecLen++] = PionPlus;
+        npos--;
       }
-   return;
+    } else if (ran < (G4double)(npos+nneg)/nt) {   
+      if (nneg > 0) { 
+        pv[vecLen++] = PionMinus;
+        nneg--;
+      }
+    } else {
+      if (nzero > 0) { 
+        pv[vecLen++] = PionZero;
+        nzero--;
+      }
+    }
+    nt = npos + nneg + nzero;
+  }
+ 
+  if (verboseLevel > 1) {
+    G4cout << "Particles produced: " ;
+    G4cout << pv[0].getName() << " " ;
+    G4cout << pv[1].getName() << " " ;
+    for (i=2; i < vecLen; i++) { 
+      G4cout << pv[i].getName() << " " ;
+    }
+    G4cout << G4endl;
+  }
+
+  return;
  }
 
-
-
-
-
-
-
