@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEAntiProtonInelastic.cc,v 1.16 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
-#include "globals.hh"
-#include "G4ios.hh"
-
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
 // and the low energy two-body model. Not included are the low energy stuff
@@ -39,7 +35,10 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HEAntiProtonInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 void G4HEAntiProtonInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -202,8 +201,8 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82;      // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;
@@ -226,9 +225,9 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
   static G4double neutmulAn[numMulAn],neutnormAn[numSec];
 
   //  misc. local variables
-  //  np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  //  npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
    if( first ) 
      {             // compute normalization constants, this will only be done once
@@ -236,18 +235,18 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
        for( i=0; i<numMul  ; i++ ) protmul[i]  = 0.0;
        for( i=0; i<numSec  ; i++ ) protnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
+       for( npos=0; npos<(numSec/3); npos++ ) 
           {
-            for( nm=Imax(0,np-1); nm<=(np+1); nm++ ) 
+            for( nneg=Imax(0,npos-1); nneg<=(npos+1); nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c);
+                              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
                               protnorm[nt-1] += protmul[counter];
                             }
                         }
@@ -258,18 +257,18 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
 
        for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
+       for( npos=0; npos<numSec/3; npos++ ) 
           {
-            for( nm=np; nm<=(np+2); nm++ ) 
+            for( nneg=npos; nneg<=(npos+2); nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                               neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+                               neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
                                neutnorm[nt-1] += neutmul[counter];
                             }
                         }
@@ -285,17 +284,17 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
        for( i=0; i<numMulAn  ; i++ ) protmulAn[i]  = 0.0;
        for( i=0; i<numSec    ; i++ ) protnormAn[i] = 0.0;
        counter = -1;
-       for( np=1; np<(numSec/3); np++ ) 
+       for( npos=1; npos<(numSec/3); npos++ ) 
           {
-            nm = np; 
-            for( nz=0; nz<numSec/3; nz++ ) 
+            nneg = npos; 
+            for( nzero=0; nzero<numSec/3; nzero++ ) 
                {
                  if( ++counter < numMulAn ) 
                    {
-                     nt = np+nm+nz;
+                     nt = npos+nneg+nzero;
                      if( (nt>0) && (nt<=numSec) ) 
                        {
-                         protmulAn[counter] = pmltpc(np,nm,nz,nt,protb,c);
+                         protmulAn[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
                          protnormAn[nt-1] += protmulAn[counter];
                        }
                    }
@@ -304,17 +303,17 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
        for( i=0; i<numMulAn; i++ ) neutmulAn[i]  = 0.0;
        for( i=0; i<numSec;   i++ ) neutnormAn[i] = 0.0;
        counter = -1;
-       for( np=1; np<numSec/3; np++ ) 
+       for( npos=1; npos<numSec/3; npos++ ) 
           {
-            nm = np+1; 
-            for( nz=0; nz<numSec/3; nz++ ) 
+            nneg = npos+1; 
+            for( nzero=0; nzero<numSec/3; nzero++ ) 
                {
                  if( ++counter < numMulAn ) 
                    {
-                     nt = np+nm+nz;
+                     nt = npos+nneg+nzero;
                      if( (nt>0) && (nt<=numSec) ) 
                        {
-                          neutmulAn[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+                          neutmulAn[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
                           neutnormAn[nt-1] += neutmulAn[counter];
                        }
                    }
@@ -356,7 +355,7 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
 
                                                   //   inelastic scattering
 
-   np = 0; nm = 0; nz = 0;
+   npos = 0; nneg = 0; nzero = 0;
    G4double anhl[] = {1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 0.90,
                       0.60, 0.52, 0.47, 0.44, 0.41, 0.39, 0.37, 0.35, 0.34, 0.24,
                       0.19, 0.15, 0.12, 0.10, 0.09, 0.07, 0.06, 0.05, 0.00};
@@ -384,9 +383,9 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
                wm = - sqr(-1.+neutb)/(2.*c*c);  
                wm = std::exp(wm);
                if( G4UniformRand() < w0/(w0+wm) )  
-                 { np = 0; nm = 0; nz = 1; }
+                 { npos = 0; nneg = 0; nzero = 1; }
                else 
-                 { np = 0; nm = 1; nz = 0; }       
+                 { npos = 0; nneg = 1; nzero = 0; }       
              } 
            else 
              {                                               // target is a proton
@@ -399,11 +398,11 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
                wp = w0+wp;
                ran = G4UniformRand();
                if( ran < w0/wt)
-                 { np = 0; nm = 0; nz = 1; }       
+                 { npos = 0; nneg = 0; nzero = 1; }       
                else if( ran < wp/wt)
-                 { np = 1; nm = 0; nz = 0; }       
+                 { npos = 1; nneg = 0; nzero = 0; }       
                else
-                 { np = 0; nm = 1; nz = 0; }       
+                 { npos = 0; nneg = 1; nzero = 0; }       
              }
          }
        else
@@ -433,15 +432,15 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
            if( targetCode == protonCode ) 
              {
                counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+               for( npos=0; npos<numSec/3; npos++ ) 
                   {
-                    for( nm=Imax(0,np-1); nm<=(np+1); nm++ ) 
+                    for( nneg=Imax(0,npos-1); nneg<=(npos+1); nneg++ ) 
                        {
-                         for( nz=0; nz<numSec/3; nz++ ) 
+                         for( nzero=0; nzero<numSec/3; nzero++ ) 
                             {
                               if( ++counter < numMul ) 
                                 {
-                                  nt = np+nm+nz;
+                                  nt = npos+nneg+nzero;
                                   if ( (nt>0) && (nt<=numSec) ) {
                                     test = std::exp( Amin( expxu, Amax( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                                     dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -465,15 +464,15 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
            else   
              {                                         // target must be a neutron
                counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+               for( npos=0; npos<numSec/3; npos++ ) 
                   {
-                    for( nm=np; nm<=(np+2); nm++ ) 
+                    for( nneg=npos; nneg<=(npos+2); nneg++ ) 
                        {
-                         for( nz=0; nz<numSec/3; nz++ ) 
+                         for( nzero=0; nzero<numSec/3; nzero++ ) 
                             {
                               if( ++counter < numMul ) 
                                 {
-                                  nt = np+nm+nz;
+                                  nt = npos+nneg+nzero;
                                   if ( (nt>=1) && (nt<=numSec) ) {
                                     test = std::exp( Amin( expxu, Amax( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                                     dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -498,10 +497,10 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
     
        if( targetCode == neutronCode)
          {
-           if( np == nm)
+           if( npos == nneg)
              {
              }
-           else if (np == (nm-1))
+           else if (npos == (nneg-1))
              {
                if( G4UniformRand() < 0.5)
                  {
@@ -520,7 +519,7 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
          }  
        else
          {
-           if( np == nm)
+           if( npos == nneg)
              {
                if( G4UniformRand() < 0.25)
                  {
@@ -531,7 +530,7 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
                  {
                  }
              } 
-           else if ( np == (1+nm))
+           else if ( npos == (1+nneg))
              {
                pv[1] = Neutron;
              }
@@ -570,14 +569,14 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
            if( targetCode == protonCode ) 
              {
                counter = -1;
-               for( np=1; np<numSec/3; np++ ) 
+               for( npos=1; npos<numSec/3; npos++ ) 
                   {
-                    nm = np; 
-                    for( nz=0; nz<numSec/3; nz++ ) 
+                    nneg = npos; 
+                    for( nzero=0; nzero<numSec/3; nzero++ ) 
                       {
                         if( ++counter < numMulAn ) 
                           {
-                            nt = np+nm+nz;
+                            nt = npos+nneg+nzero;
                             if ( (nt>0) && (nt<=numSec) ) {
                               test = std::exp( Amin( expxu, Amax( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                               dum = (pi/anpn)*nt*protmulAn[counter]*protnormAn[nt-1]/(2.0*n*n);
@@ -599,14 +598,14 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
            else   
              {                                         // target must be a neutron
                counter = -1;
-               for( np=1; np<numSec/3; np++ ) 
+               for( npos=1; npos<numSec/3; npos++ ) 
                  { 
-                   nm = np+1; 
-                   for( nz=0; nz<numSec/3; nz++ ) 
+                   nneg = npos+1; 
+                   for( nzero=0; nzero<numSec/3; nzero++ ) 
                       {
                         if( ++counter < numMulAn ) 
                           {
-                            nt = np+nm+nz;
+                            nt = npos+nneg+nzero;
                             if ( (nt>=1) && (nt<=numSec) ) {
                               test = std::exp( Amin( expxu, Amax( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                               dum = (pi/anpn)*nt*neutmulAn[counter]*neutnormAn[nt-1]/(2.0*n*n);
@@ -629,34 +628,34 @@ G4HEAntiProtonInelastic::FirstIntInCasAntiProton(G4bool& inElastic,
          }
      }
 
-   nt = np + nm + nz;
+   nt = npos + nneg + nzero;
    while ( nt > 0)
        {
          G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
+         if ( ran < (G4double)npos/nt)
             { 
-              if( np > 0 ) 
+              if( npos > 0 ) 
                 { pv[vecLen++] = PionPlus;
-                  np--;
+                  npos--;
                 }
             }
-         else if ( ran < (G4double)(np+nm)/nt)
+         else if ( ran < (G4double)(npos+nneg)/nt)
             {   
-              if( nm > 0 )
+              if( nneg > 0 )
                 { 
                   pv[vecLen++] = PionMinus;
-                  nm--;
+                  nneg--;
                 }
             }
          else
             {
-              if( nz > 0 )
+              if( nzero > 0 )
                 { 
                   pv[vecLen++] = PionZero;
-                  nz--;
+                  nzero--;
                 }
             }
-         nt = np + nm + nz;
+         nt = npos + nneg + nzero;
        } 
    if (verboseLevel > 1)
       {
