@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEAntiSigmaMinusInelastic.cc,v 1.17 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
-#include "globals.hh"
-#include "G4ios.hh"
-
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
 // and the low energy two-body model. Not included are the low energy stuff
@@ -39,7 +35,10 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HEAntiSigmaMinusInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 void G4HEAntiSigmaMinusInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -200,8 +199,8 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82;      // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;
@@ -224,9 +223,9 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
   static G4double neutmulAn[numMulAn],neutnormAn[numSec];
 
   //  misc. local variables
-  //  np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  //  npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
    if( first ) 
      {               // compute normalization constants, this will only be done once
@@ -234,18 +233,18 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
        for( i=0; i<numMul  ; i++ ) protmul[i]  = 0.0;
        for( i=0; i<numSec  ; i++ ) protnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
+       for( npos=0; npos<(numSec/3); npos++ ) 
           {
-            for( nm=std::max(0,np-2); nm<=np; nm++ ) 
+            for( nneg=std::max(0,npos-2); nneg<=npos; nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c);
+                              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
                               protnorm[nt-1] += protmul[counter];
                             }
                         }
@@ -255,18 +254,18 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
        for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
        for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
+       for( npos=0; npos<numSec/3; npos++ ) 
           {
-            for( nm=std::max(0,np-1); nm<=(np+1); nm++ ) 
+            for( nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                               neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+                               neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
                                neutnorm[nt-1] += neutmul[counter];
                             }
                         }
@@ -282,17 +281,17 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
        for( i=0; i<numMulAn  ; i++ ) protmulAn[i]  = 0.0;
        for( i=0; i<numSec    ; i++ ) protnormAn[i] = 0.0;
        counter = -1;
-       for( np=1; np<(numSec/3); np++ ) 
+       for( npos=1; npos<(numSec/3); npos++ ) 
           {
-            nm = std::max(0,np-2); 
-            for( nz=0; nz<numSec/3; nz++ ) 
+            nneg = std::max(0,npos-2); 
+            for( nzero=0; nzero<numSec/3; nzero++ ) 
                {
                  if( ++counter < numMulAn ) 
                    {
-                     nt = np+nm+nz;
+                     nt = npos+nneg+nzero;
                      if( (nt>1) && (nt<=numSec) ) 
                        {
-                         protmulAn[counter] = pmltpc(np,nm,nz,nt,protb,c);
+                         protmulAn[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
                          protnormAn[nt-1] += protmulAn[counter];
                        }
                    }
@@ -301,17 +300,17 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
        for( i=0; i<numMulAn; i++ ) neutmulAn[i]  = 0.0;
        for( i=0; i<numSec;   i++ ) neutnormAn[i] = 0.0;
        counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
+       for( npos=0; npos<numSec/3; npos++ ) 
           {
-            nm = np-1; 
-            for( nz=0; nz<numSec/3; nz++ ) 
+            nneg = npos-1; 
+            for( nzero=0; nzero<numSec/3; nzero++ ) 
                {
                  if( ++counter < numMulAn ) 
                    {
-                     nt = np+nm+nz;
+                     nt = npos+nneg+nzero;
                      if( (nt>1) && (nt<=numSec) ) 
                        {
-                          neutmulAn[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+                          neutmulAn[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
                           neutnormAn[nt-1] += neutmulAn[counter];
                        }
                    }
@@ -381,85 +380,75 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
 
                                                   //   inelastic scattering
 
-   np = 0; nm = 0; nz = 0;
-   G4double anhl[] = {1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 0.97, 0.88, 
-                      0.85, 0.81, 0.75, 0.64, 0.64, 0.55, 0.55, 0.45, 0.47, 0.40, 
-                      0.39, 0.36, 0.33, 0.10, 0.01};
-   G4int            iplab =      G4int( incidentTotalMomentum*10.);
-   if ( iplab >  9) iplab = 10 + G4int( (incidentTotalMomentum  -1.)*5. );          
-   if ( iplab > 14) iplab = 15 + G4int(  incidentTotalMomentum  -2.     );
-   if ( iplab > 22) iplab = 23 + G4int( (incidentTotalMomentum -10.)/10.); 
-                    iplab = std::min(24, iplab);
+  npos = 0; nneg = 0; nzero = 0;
+  G4double anhl[] = {1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 0.97, 0.88, 
+                     0.85, 0.81, 0.75, 0.64, 0.64, 0.55, 0.55, 0.45, 0.47, 0.40, 
+                     0.39, 0.36, 0.33, 0.10, 0.01};
+  G4int            iplab =      G4int( incidentTotalMomentum*10.);
+  if ( iplab >  9) iplab = 10 + G4int( (incidentTotalMomentum  -1.)*5. );          
+  if ( iplab > 14) iplab = 15 + G4int(  incidentTotalMomentum  -2.     );
+  if ( iplab > 22) iplab = 23 + G4int( (incidentTotalMomentum -10.)/10.); 
+                   iplab = std::min(24, iplab);
 
-   if ( G4UniformRand() > anhl[iplab] )
-     {                                           // non- annihilation channels
+  if (G4UniformRand() > anhl[iplab]) { // non- annihilation channels
 
-                         //  number of total particles vs. centre of mass Energy - 2*proton mass
+    //  number of total particles vs. centre of mass Energy - 2*proton mass
+    G4double aleab = std::log(availableEnergy);
+    G4double n = 3.62567+aleab*(0.665843+aleab*(0.336514
+                        + aleab*(0.117712+0.0136912*aleab))) - 2.0;
    
-           G4double aleab = std::log(availableEnergy);
-           G4double n     = 3.62567+aleab*(0.665843+aleab*(0.336514
-                            + aleab*(0.117712+0.0136912*aleab))) - 2.0;
-   
-                         // normalization constant for kno-distribution.
-                         // calculate first the sum of all constants, check for numerical problems.   
-           G4double test, dum, anpn = 0.0;
+    // normalization constant for kno-distribution.
+    // calculate first the sum of all constants, check for numerical problems.   
+    G4double test, dum, anpn = 0.0;
 
-           for (nt=1; nt<=numSec; nt++) {
-             test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
-             dum = pi*nt/(2.0*n*n);
-             if (std::fabs(dum) < 1.0) { 
-               if( test >= 1.0e-10 )anpn += dum*test;
-             } else { 
-               anpn += dum*test;
-             }
-           }
+    for (nt=1; nt<=numSec; nt++) {
+      test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
+      dum = pi*nt/(2.0*n*n);
+      if (std::fabs(dum) < 1.0) { 
+        if( test >= 1.0e-10 )anpn += dum*test;
+      } else { 
+        anpn += dum*test;
+      }
+    }
    
-           G4double ran = G4UniformRand();
-           G4double excs = 0.0;
-           if( targetCode == protonCode ) 
-             {
-               counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+    G4double ran = G4UniformRand();
+    G4double excs = 0.0;
+    if (targetCode == protonCode) {
+      counter = -1;
+      for (npos = 0; npos < numSec/3; npos++) {
+        for (nneg = std::max(0,npos-2); nneg <= npos; nneg++) {
+          for (nzero = 0; nzero < numSec/3; nzero++) {
+            if (++counter < numMul) {
+              nt = npos+nneg+nzero;
+              if ((nt > 0) && (nt <= numSec) ) {
+                test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
+                dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
+                if (std::fabs(dum) < 1.0) { 
+                  if( test >= 1.0e-10 )excs += dum*test;
+                } else { 
+                  excs += dum*test;
+                }
+
+                if (ran < excs) goto outOfLoop;      //----------------------->
+              }   
+            }    
+          }     
+        }                                                                                  
+      } 
+                             // 3 previous loops continued to the end
+      inElastic = false;     // quasi-elastic scattering   
+      return;
+    } else {   // target must be a neutron
+      counter = -1;
+               for( npos=0; npos<numSec/3; npos++ ) 
                   {
-                    for( nm=std::max(0,np-2); nm<=np; nm++ ) 
+                    for( nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++ ) 
                        {
-                         for( nz=0; nz<numSec/3; nz++ ) 
+                         for( nzero=0; nzero<numSec/3; nzero++ ) 
                             {
                               if( ++counter < numMul ) 
                                 {
-                                  nt = np+nm+nz;
-                                  if ( (nt>0) && (nt<=numSec) ) {
-                                    test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
-                                    dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
-                                    if (std::fabs(dum) < 1.0) { 
-                                      if( test >= 1.0e-10 )excs += dum*test;
-                                    } else { 
-                                      excs += dum*test;
-			            }
-
-                                    if (ran < excs) goto outOfLoop;      //----------------------->
-                                  }   
-                                }    
-                            }     
-                       }                                                                                  
-                  }
-       
-                                              // 3 previous loops continued to the end
-               inElastic = false;                 // quasi-elastic scattering   
-               return;
-             }
-           else   
-             {                                         // target must be a neutron
-               counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
-                  {
-                    for( nm=std::max(0,np-1); nm<=(np+1); nm++ ) 
-                       {
-                         for( nz=0; nz<numSec/3; nz++ ) 
-                            {
-                              if( ++counter < numMul ) 
-                                {
-                                  nt = np+nm+nz;
+                                  nt = npos+nneg+nzero;
                                   if ( (nt>0) && (nt<=numSec) ) {
                                     test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                                     dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -486,10 +475,10 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
 
        if( targetCode == protonCode)
          {
-           if( np == nm)
+           if( npos == nneg)
              {
              }
-           else if (np == (nm+1))
+           else if (npos == (nneg+1))
              {
                if( ran < 0.50)
                  {
@@ -520,7 +509,7 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
          }  
        else
          {
-           if( np == nm)
+           if( npos == nneg)
              {
                if (ran < 0.5)
                  {
@@ -536,7 +525,7 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
                    pv[1] = Proton;
                  }
              } 
-           else if ( np == (nm+1))
+           else if ( npos == (nneg+1))
              {
                if (ran < 0.5)
                  {
@@ -582,14 +571,14 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
            if( targetCode == protonCode ) 
              {
                counter = -1;
-               for( np=2; np<numSec/3; np++ ) 
+               for( npos=2; npos<numSec/3; npos++ ) 
                   {
-                    nm = np-2; 
-                    for( nz=0; nz<numSec/3; nz++ ) 
+                    nneg = npos-2; 
+                    for( nzero=0; nzero<numSec/3; nzero++ ) 
                       {
                         if( ++counter < numMulAn ) 
                           {
-                            nt = np+nm+nz;
+                            nt = npos+nneg+nzero;
                             if ( (nt>1) && (nt<=numSec) ) {
                               test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                               dum = (pi/anpn)*nt*protmulAn[counter]*protnormAn[nt-1]/(2.0*n*n);
@@ -611,13 +600,13 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
            else   
              {                                         // target must be a neutron
                counter = -1;
-               for( np=1; np<numSec/3; np++ ) 
+               for( npos=1; npos<numSec/3; npos++ ) 
                  { 
-                   nm = np-1; 
-                   for( nz=0; nz<numSec/3; nz++ ) 
+                   nneg = npos-1; 
+                   for( nzero=0; nzero<numSec/3; nzero++ ) 
                       {
                         if (++counter < numMulAn) {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if ( (nt>1) && (nt<=numSec) ) {
                             test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                             dum = (pi/anpn)*nt*neutmulAn[counter]*neutnormAn[nt-1]/(2.0*n*n);
@@ -640,34 +629,34 @@ G4HEAntiSigmaMinusInelastic::FirstIntInCasAntiSigmaMinus(G4bool& inElastic,
          }
      }
 
-   nt = np + nm + nz;
+   nt = npos + nneg + nzero;
    while ( nt > 0)
        {
          G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
+         if ( ran < (G4double)npos/nt)
             { 
-              if( np > 0 ) 
+              if( npos > 0 ) 
                 { pv[vecLen++] = PionPlus;
-                  np--;
+                  npos--;
                 }
             }
-         else if ( ran < (G4double)(np+nm)/nt)
+         else if ( ran < (G4double)(npos+nneg)/nt)
             {   
-              if( nm > 0 )
+              if( nneg > 0 )
                 { 
                   pv[vecLen++] = PionMinus;
-                  nm--;
+                  nneg--;
                 }
             }
          else
             {
-              if( nz > 0 )
+              if( nzero > 0 )
                 { 
                   pv[vecLen++] = PionZero;
-                  nz--;
+                  nzero--;
                 }
             }
-         nt = np + nm + nz;
+         nt = npos + nneg + nzero;
        } 
    if (verboseLevel > 1)
       {
