@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEAntiSigmaPlusInelastic.cc,v 1.17 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
-#include "globals.hh"
-#include "G4ios.hh"
-
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
 // and the low energy two-body model. Not included are the low energy stuff
@@ -39,7 +35,10 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HEAntiSigmaPlusInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 void G4HEAntiSigmaPlusInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -202,8 +201,8 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;
@@ -225,185 +224,151 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
   static G4double neutmulAn[numMulAn],neutnormAn[numSec];
 
   //  misc. local variables
-  //  np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  //  npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
-   if( first ) 
-     {         // compute normalization constants, this will only be done once
-       first = false;
-       for( i=0; i<numMul  ; i++ ) protmul[i]  = 0.0;
-       for( i=0; i<numSec  ; i++ ) protnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
-          {
-            for( nm=std::max(0,np-1); nm<=(np+1); nm++ ) 
-               {
-                 for( nz=0; nz<numSec/3; nz++ ) 
-                    {
-                      if( ++counter < numMul ) 
-                        {
-                          nt = np+nm+nz;
-                          if( (nt>0) && (nt<=numSec) ) 
-                            {
-                              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c);
-                              protnorm[nt-1] += protmul[counter];
-                            }
-                        }
-                    }
-               }
+  if (first) {
+    // compute normalization constants, this will only be done once
+    first = false;
+    for( i=0; i<numMul  ; i++ ) protmul[i]  = 0.0;
+    for( i=0; i<numSec  ; i++ ) protnorm[i] = 0.0;
+    counter = -1;
+    for (npos = 0; npos < (numSec/3); npos++) {
+      for (nneg = std::max(0,npos-1); nneg <= (npos+1); nneg++) {
+        for (nzero = 0; nzero < numSec/3; nzero++) {
+          if (++counter < numMul) {
+            nt = npos+nneg+nzero;
+            if ((nt>0) && (nt<=numSec) ) {
+              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
+              protnorm[nt-1] += protmul[counter];
+            }
           }
-       for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
-       for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
-          {
-            for( nm=np; nm<=(np+2); nm++ ) 
-               {
-                 for( nz=0; nz<numSec/3; nz++ ) 
-                    {
-                      if( ++counter < numMul ) 
-                        {
-                          nt = np+nm+nz;
-                          if( (nt>0) && (nt<=numSec) ) 
-                            {
-                               neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
-                               neutnorm[nt-1] += neutmul[counter];
-                            }
-                        }
-                    }
-               }
+        }
+      }
+    }
+
+    for (i = 0; i < numMul; i++) neutmul[i]  = 0.0;
+    for (i = 0; i < numSec; i++) neutnorm[i] = 0.0;
+    counter = -1;
+    for (npos = 0; npos < numSec/3; npos++) {
+      for (nneg = npos; nneg <= (npos+2); nneg++) {
+        for (nzero = 0; nzero < numSec/3; nzero++) {
+          if (++counter < numMul) {
+            nt = npos+nneg+nzero;
+            if ((nt>0) && (nt<=numSec) ) {
+              neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
+              neutnorm[nt-1] += neutmul[counter];
+            }
           }
-       for( i=0; i<numSec; i++ ) 
-          {
-            if( protnorm[i] > 0.0 )protnorm[i] = 1.0/protnorm[i];
-            if( neutnorm[i] > 0.0 )neutnorm[i] = 1.0/neutnorm[i];
+        }
+      }
+    }
+
+    for (i = 0; i < numSec; i++) {
+      if (protnorm[i] > 0.0 )protnorm[i] = 1.0/protnorm[i];
+      if (neutnorm[i] > 0.0 )neutnorm[i] = 1.0/neutnorm[i];
+    }
+
+    // annihilation
+    for (i = 0; i < numMulAn; i++) protmulAn[i] = 0.0;
+    for (i = 0; i < numSec; i++) protnormAn[i] = 0.0;
+    counter = -1;
+    for (npos = 1; npos < (numSec/3); npos++) {
+      nneg = npos; 
+      for (nzero = 0; nzero < numSec/3; nzero++) {
+        if (++counter < numMulAn) {
+          nt = npos+nneg+nzero;
+          if ((nt>1) && (nt<=numSec) ) {
+            protmulAn[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
+            protnormAn[nt-1] += protmulAn[counter];
           }
-                                                                   // annihilation
-       for( i=0; i<numMulAn  ; i++ ) protmulAn[i]  = 0.0;
-       for( i=0; i<numSec    ; i++ ) protnormAn[i] = 0.0;
-       counter = -1;
-       for( np=1; np<(numSec/3); np++ ) 
-          {
-            nm = np; 
-            for( nz=0; nz<numSec/3; nz++ ) 
-               {
-                 if( ++counter < numMulAn ) 
-                   {
-                     nt = np+nm+nz;
-                     if( (nt>1) && (nt<=numSec) ) 
-                       {
-                         protmulAn[counter] = pmltpc(np,nm,nz,nt,protb,c);
-                         protnormAn[nt-1] += protmulAn[counter];
-                       }
-                   }
-               }
+        }
+      }
+    }
+
+    for (i = 0; i < numMulAn; i++) neutmulAn[i]  = 0.0;
+    for (i = 0; i < numSec; i++) neutnormAn[i] = 0.0;
+    counter = -1;
+    for (npos = 0; npos < numSec/3; npos++) {
+      nneg = npos+1; 
+      for (nzero = 0; nzero < numSec/3; nzero++) {
+        if (++counter < numMulAn) {
+          nt = npos+nneg+nzero;
+          if ((nt>1) && (nt<=numSec) ) {
+            neutmulAn[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
+            neutnormAn[nt-1] += neutmulAn[counter];
           }
-       for( i=0; i<numMulAn; i++ ) neutmulAn[i]  = 0.0;
-       for( i=0; i<numSec;   i++ ) neutnormAn[i] = 0.0;
-       counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
-          {
-            nm = np+1; 
-            for( nz=0; nz<numSec/3; nz++ ) 
-               {
-                 if( ++counter < numMulAn ) 
-                   {
-                     nt = np+nm+nz;
-                     if( (nt>1) && (nt<=numSec) ) 
-                       {
-                          neutmulAn[counter] = pmltpc(np,nm,nz,nt,neutb,c);
-                          neutnormAn[nt-1] += neutmulAn[counter];
-                       }
-                   }
-               }
-          }
-       for( i=0; i<numSec; i++ ) 
-          {
-            if( protnormAn[i] > 0.0 )protnormAn[i] = 1.0/protnormAn[i];
-            if( neutnormAn[i] > 0.0 )neutnormAn[i] = 1.0/neutnormAn[i];
-          }
-     }                                          // end of initialization
+        }
+      }
+    }
+    for (i = 0; i < numSec; i++) {
+      if( protnormAn[i] > 0.0 )protnormAn[i] = 1.0/protnormAn[i];
+      if( neutnormAn[i] > 0.0 )neutnormAn[i] = 1.0/neutnormAn[i];
+    }
+  }  // end of initialization
 
          
-                                              // initialize the first two places
-                                              // the same as beam and target                                    
-   pv[0] = incidentParticle;
-   pv[1] = targetParticle;
-   vecLen = 2;
+  // initialize the first two places the same as beam and target                                    
+  pv[0] = incidentParticle;
+  pv[1] = targetParticle;
+  vecLen = 2;
 
-   if( !inElastic ) 
-     {                                        // some two-body reactions 
-       G4double cech[] = {0.50, 0.45, 0.40, 0.35, 0.30, 0.25, 0.06, 0.04, 0.005, 0.};
+  if (!inElastic) {  // some two-body reactions 
+    G4double cech[] = {0.50, 0.45, 0.40, 0.35, 0.30, 0.25, 0.06, 0.04, 0.005, 0.};
 
-       G4int iplab = std::min(9, G4int( incidentTotalMomentum*2.5));
-       if( G4UniformRand() < cech[iplab]/std::pow(atomicWeight,0.42) ) 
-         {           
-           G4double ran = G4UniformRand();
+    G4int iplab = std::min(9, G4int( incidentTotalMomentum*2.5));
+    if (G4UniformRand() < cech[iplab]/std::pow(atomicWeight,0.42) ) {           
+      G4double ran = G4UniformRand();
 
-           if ( targetCode == protonCode)
-             {
-               if(ran < 0.2)
-                 {
-                   pv[0] = Proton;
-                   pv[1] = AntiSigmaPlus;
-                 }
-               else if (ran < 0.4)
-                 {
-                   pv[0] = AntiLambda;
-                   pv[1] = Neutron;
-                 }
-               else if (ran < 0.6)
-                 {
-                   pv[0] = Neutron;
-                   pv[1] = AntiLambda;
-                 }
-               else if (ran < 0.8)
-                 {
-                   pv[0] = Neutron;
-                   pv[1] = AntiSigmaZero;
-                 }
-               else
-                 {
-                   pv[0] = AntiSigmaZero;
-                   pv[1] = Neutron;
-                 }     
-             }
-           else
-             {
-               pv[0] = Neutron;
-               pv[1] = AntiSigmaPlus;
-             }  
-         }   
-       return;
-     }
-   else if (availableEnergy <= PionPlus.getMass())
-       return;
-
-                                                  //   inelastic scattering
-
-   np = 0; nm = 0; nz = 0;
-   G4double anhl[] = {1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 0.97, 0.88, 
-                      0.85, 0.81, 0.75, 0.64, 0.64, 0.55, 0.55, 0.45, 0.47, 0.40, 
-                      0.39, 0.36, 0.33, 0.10, 0.01};
-   G4int            iplab =      G4int( incidentTotalMomentum*10.);
-   if ( iplab >  9) iplab = 10 + G4int( (incidentTotalMomentum  -1.)*5. );          
-   if ( iplab > 14) iplab = 15 + G4int(  incidentTotalMomentum  -2.     );
-   if ( iplab > 22) iplab = 23 + G4int( (incidentTotalMomentum -10.)/10.); 
-                    iplab = std::min(24, iplab);
-
-   if ( G4UniformRand() > anhl[iplab] )
-     {                                           // non- annihilation channels
-
-                         //  number of total particles vs. centre of mass Energy - 2*proton mass
+      if (targetCode == protonCode) {
+        if (ran < 0.2) {
+          pv[0] = Proton;
+          pv[1] = AntiSigmaPlus;
+        } else if (ran < 0.4) {
+          pv[0] = AntiLambda;
+          pv[1] = Neutron;
+        } else if (ran < 0.6) {
+          pv[0] = Neutron;
+          pv[1] = AntiLambda;
+        } else if (ran < 0.8) {
+          pv[0] = Neutron;
+          pv[1] = AntiSigmaZero;
+        } else {
+          pv[0] = AntiSigmaZero;
+          pv[1] = Neutron;
+        }     
+      } else {
+        pv[0] = Neutron;
+        pv[1] = AntiSigmaPlus;
+      }  
+    }
    
-           G4double aleab = std::log(availableEnergy);
-           G4double n     = 3.62567+aleab*(0.665843+aleab*(0.336514
-                            + aleab*(0.117712+0.0136912*aleab))) - 2.0;
+    return;
+  }
+  else if (availableEnergy <= PionPlus.getMass()) return;
+
+  // inelastic scattering
+  npos = 0; nneg = 0; nzero = 0;
+  G4double anhl[] = {1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 0.97, 0.88, 
+                     0.85, 0.81, 0.75, 0.64, 0.64, 0.55, 0.55, 0.45, 0.47, 0.40, 
+                     0.39, 0.36, 0.33, 0.10, 0.01};
+  G4int iplab = G4int( incidentTotalMomentum*10.);
+  if ( iplab >  9) iplab = 10 + G4int( (incidentTotalMomentum  -1.)*5. );          
+  if ( iplab > 14) iplab = 15 + G4int(  incidentTotalMomentum  -2.     );
+  if ( iplab > 22) iplab = 23 + G4int( (incidentTotalMomentum -10.)/10.); 
+  iplab = std::min(24, iplab);
+
+  if ( G4UniformRand() > anhl[iplab] ) {  // non- annihilation channels
+
+    // number of total particles vs. centre of mass Energy - 2*proton mass
+    G4double aleab = std::log(availableEnergy);
+    G4double n = 3.62567+aleab*(0.665843+aleab*(0.336514
+                 + aleab*(0.117712+0.0136912*aleab))) - 2.0;
    
-                         // normalization constant for kno-distribution.
-                         // calculate first the sum of all constants, check for numerical problems.   
-           G4double test, dum, anpn = 0.0;
+    // normalization constant for kno-distribution.
+    // calculate first the sum of all constants, check for numerical problems.   
+    G4double test, dum, anpn = 0.0;
 
            for (nt=1; nt<=numSec; nt++) {
              test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -420,15 +385,15 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
            if( targetCode == protonCode ) 
              {
                counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+               for( npos=0; npos<numSec/3; npos++ ) 
                   {
-                    for( nm=std::max(0,np-1); nm<=(np+1); nm++ ) 
+                    for( nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++ ) 
                        {
-                         for( nz=0; nz<numSec/3; nz++ ) 
+                         for( nzero=0; nzero<numSec/3; nzero++ ) 
                             {
                               if( ++counter < numMul ) 
                                 {
-                                  nt = np+nm+nz;
+                                  nt = npos+nneg+nzero;
                                   if ( (nt>0) && (nt<=numSec) ) {
                                     test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                                     dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -452,15 +417,15 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
            else   
              {                                         // target must be a neutron
                counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+               for( npos=0; npos<numSec/3; npos++ ) 
                   {
-                    for( nm=np; nm<=(np+2); nm++ ) 
+                    for( nneg=npos; nneg<=(npos+2); nneg++ ) 
                        {
-                         for( nz=0; nz<numSec/3; nz++ ) 
+                         for( nzero=0; nzero<numSec/3; nzero++ ) 
                             {
                               if( ++counter < numMul ) 
                                 {
-                                  nt = np+nm+nz;
+                                  nt = npos+nneg+nzero;
                                   if ( (nt>0) && (nt<=numSec) ) {
                                     test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                                     dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -487,7 +452,7 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
 
        if( targetCode == protonCode)
          {
-           if( np == nm)
+           if( npos == nneg)
              {
                if (ran < 0.50)
                  {
@@ -503,7 +468,7 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
                    pv[1] = Neutron;
                  } 
              }
-           else if (np == (nm-1))
+           else if (npos == (nneg-1))
              {
                if( ran < 0.50)
                  {
@@ -521,10 +486,10 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
          }  
        else
          {
-           if( np == nm)
+           if( npos == nneg)
              {
              } 
-           else if ( np == (nm-1))
+           else if ( npos == (nneg-1))
              {
                if (ran < 0.5)
                  {
@@ -582,14 +547,14 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
            if( targetCode == protonCode ) 
              {
                counter = -1;
-               for( np=1; np<numSec/3; np++ ) 
+               for( npos=1; npos<numSec/3; npos++ ) 
                   {
-                    nm = np; 
-                    for( nz=0; nz<numSec/3; nz++ ) 
+                    nneg = npos; 
+                    for( nzero=0; nzero<numSec/3; nzero++ ) 
                       {
                         if( ++counter < numMulAn ) 
                           {
-                            nt = np+nm+nz;
+                            nt = npos+nneg+nzero;
                             if ( (nt>1) && (nt<=numSec) ) {
                               test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                               dum = (pi/anpn)*nt*protmulAn[counter]*protnormAn[nt-1]/(2.0*n*n);
@@ -611,14 +576,14 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
            else   
              {                                         // target must be a neutron
                counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+               for( npos=0; npos<numSec/3; npos++ ) 
                  { 
-                   nm = np+1; 
-                   for( nz=0; nz<numSec/3; nz++ ) 
+                   nneg = npos+1; 
+                   for( nzero=0; nzero<numSec/3; nzero++ ) 
                       {
                         if( ++counter < numMulAn ) 
                           {
-                            nt = np+nm+nz;
+                            nt = npos+nneg+nzero;
                             if ( (nt>1) && (nt<=numSec) ) {
                               test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                               dum = (pi/anpn)*nt*neutmulAn[counter]*neutnormAn[nt-1]/(2.0*n*n);
@@ -641,34 +606,34 @@ G4HEAntiSigmaPlusInelastic::FirstIntInCasAntiSigmaPlus(G4bool& inElastic,
          }
      }
 
-   nt = np + nm + nz;
+   nt = npos + nneg + nzero;
    while ( nt > 0)
        {
          G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
+         if ( ran < (G4double)npos/nt)
             { 
-              if( np > 0 ) 
+              if( npos > 0 ) 
                 { pv[vecLen++] = PionPlus;
-                  np--;
+                  npos--;
                 }
             }
-         else if ( ran < (G4double)(np+nm)/nt)
+         else if ( ran < (G4double)(npos+nneg)/nt)
             {   
-              if( nm > 0 )
+              if( nneg > 0 )
                 { 
                   pv[vecLen++] = PionMinus;
-                  nm--;
+                  nneg--;
                 }
             }
          else
             {
-              if( nz > 0 )
+              if( nzero > 0 )
                 { 
                   pv[vecLen++] = PionZero;
-                  nz--;
+                  nzero--;
                 }
             }
-         nt = np + nm + nz;
+         nt = npos + nneg + nzero;
        } 
    if (verboseLevel > 1)
       {
