@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEAntiXiZeroInelastic.cc,v 1.17 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
-#include "globals.hh"
-#include "G4ios.hh"
-
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
 // and the low energy two-body model. Not included are the low energy stuff
@@ -39,7 +35,9 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HEAntiXiZeroInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
 
 void G4HEAntiXiZeroInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -201,8 +199,8 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
 // on the whole performance of the program. Take AntiLambda instaed. 
 // ( decay Xi0 -> L Pi > 99 % )
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;
@@ -224,9 +222,9 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
   static G4double neutmulAn[numMulAn],neutnormAn[numSec];
 
   //  misc. local variables
-  //  np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  //  npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
    if( first ) 
      {           // compute normalization constants, this will only be done once
@@ -234,18 +232,18 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
        for( i=0; i<numMul  ; i++ ) protmul[i]  = 0.0;
        for( i=0; i<numSec  ; i++ ) protnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
+       for( npos=0; npos<(numSec/3); npos++ ) 
           {
-            for( nm=std::max(0,np-2); nm<=(np+1); nm++ ) 
+            for( nneg=std::max(0,npos-2); nneg<=(npos+1); nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c);
+                              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
                               protnorm[nt-1] += protmul[counter];
                             }
                         }
@@ -255,18 +253,18 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
        for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
        for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
+       for( npos=0; npos<numSec/3; npos++ ) 
           {
-            for( nm=std::max(0,np-1); nm<=(np+2); nm++ ) 
+            for( nneg=std::max(0,npos-1); nneg<=(npos+2); nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                               neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+                               neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
                                neutnorm[nt-1] += neutmul[counter];
                             }
                         }
@@ -282,17 +280,17 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
        for( i=0; i<numMulAn  ; i++ ) protmulAn[i]  = 0.0;
        for( i=0; i<numSec    ; i++ ) protnormAn[i] = 0.0;
        counter = -1;
-       for( np=1; np<(numSec/3); np++ ) 
+       for( npos=1; npos<(numSec/3); npos++ ) 
           {
-            nm = std::max(0,np-1); 
-            for( nz=0; nz<numSec/3; nz++ ) 
+            nneg = std::max(0,npos-1); 
+            for( nzero=0; nzero<numSec/3; nzero++ ) 
                {
                  if( ++counter < numMulAn ) 
                    {
-                     nt = np+nm+nz;
+                     nt = npos+nneg+nzero;
                      if( (nt>1) && (nt<=numSec) ) 
                        {
-                         protmulAn[counter] = pmltpc(np,nm,nz,nt,protb,c);
+                         protmulAn[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
                          protnormAn[nt-1] += protmulAn[counter];
                        }
                    }
@@ -301,17 +299,17 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
        for( i=0; i<numMulAn; i++ ) neutmulAn[i]  = 0.0;
        for( i=0; i<numSec;   i++ ) neutnormAn[i] = 0.0;
        counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
+       for( npos=0; npos<numSec/3; npos++ ) 
           {
-            nm = np; 
-            for( nz=0; nz<numSec/3; nz++ ) 
+            nneg = npos; 
+            for( nzero=0; nzero<numSec/3; nzero++ ) 
                {
                  if( ++counter < numMulAn ) 
                    {
-                     nt = np+nm+nz;
+                     nt = npos+nneg+nzero;
                      if( (nt>1) && (nt<=numSec) ) 
                        {
-                          neutmulAn[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+                          neutmulAn[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
                           neutnormAn[nt-1] += neutmulAn[counter];
                        }
                    }
@@ -402,7 +400,7 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
 
                                                   //   inelastic scattering
 
-   np = 0; nm = 0; nz = 0;
+   npos = 0; nneg = 0; nzero = 0;
    G4double anhl[] = {1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 1.00, 0.97, 0.88, 
                       0.85, 0.81, 0.75, 0.64, 0.64, 0.55, 0.55, 0.45, 0.47, 0.40, 
                       0.39, 0.36, 0.33, 0.10, 0.01};
@@ -440,15 +438,15 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
            if( targetCode == protonCode ) 
              {
                counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+               for( npos=0; npos<numSec/3; npos++ ) 
                   {
-                    for( nm=std::max(0,np-2); nm<=(np+1); nm++ ) 
+                    for( nneg=std::max(0,npos-2); nneg<=(npos+1); nneg++ ) 
                        {
-                         for( nz=0; nz<numSec/3; nz++ ) 
+                         for( nzero=0; nzero<numSec/3; nzero++ ) 
                             {
                               if( ++counter < numMul ) 
                                 {
-                                  nt = np+nm+nz;
+                                  nt = npos+nneg+nzero;
                                   if ( (nt>0) && (nt<=numSec) ) {
                                     test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                                     dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -472,15 +470,15 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
            else   
              {                                         // target must be a neutron
                counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+               for( npos=0; npos<numSec/3; npos++ ) 
                   {
-                    for( nm=std::max(0,np-1); nm<=(np+2); nm++ ) 
+                    for( nneg=std::max(0,npos-1); nneg<=(npos+2); nneg++ ) 
                        {
-                         for( nz=0; nz<numSec/3; nz++ ) 
+                         for( nzero=0; nzero<numSec/3; nzero++ ) 
                             {
                               if( ++counter < numMul ) 
                                 {
-                                  nt = np+nm+nz;
+                                  nt = npos+nneg+nzero;
                                   if ( (nt>0) && (nt<=numSec) ) {
                                     test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                                     dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -507,7 +505,7 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
 
        if( targetCode == protonCode)
          {
-           if( np == nm)
+           if( npos == nneg)
              {
                if (ran < 0.40)
                  {
@@ -522,7 +520,7 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
                    pv[1] = Neutron;
                  } 
              }
-           else if (np == (nm+1))
+           else if (npos == (nneg+1))
              {
                if( ran < 0.25)
                  {
@@ -538,7 +536,7 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
                    pv[0] = AntiSigmaPlus;
                  }
              }
-           else if (np == (nm-1))
+           else if (npos == (nneg-1))
              {  
                pv[0] = AntiSigmaMinus;
              }
@@ -550,7 +548,7 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
          }  
        else
          {
-           if( np == nm)
+           if( npos == nneg)
              {
                if (ran < 0.4)
                  {
@@ -565,7 +563,7 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
                    pv[1] = Proton;
                  }
              } 
-           else if ( np == (nm-1))
+           else if ( npos == (nneg-1))
              {
                if (ran < 0.5)
                  {
@@ -581,7 +579,7 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
                    pv[1] = Proton;
                  } 
              }
-           else if (np == (nm+1))
+           else if (npos == (nneg+1))
              {
                pv[0] = AntiSigmaPlus;
              }
@@ -621,14 +619,14 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
            if( targetCode == protonCode ) 
              {
                counter = -1;
-               for( np=1; np<numSec/3; np++ ) 
+               for( npos=1; npos<numSec/3; npos++ ) 
                   {
-                    nm = np-1; 
-                    for( nz=0; nz<numSec/3; nz++ ) 
+                    nneg = npos-1; 
+                    for( nzero=0; nzero<numSec/3; nzero++ ) 
                       {
                         if( ++counter < numMulAn ) 
                           {
-                            nt = np+nm+nz;
+                            nt = npos+nneg+nzero;
                             if ( (nt>1) && (nt<=numSec) ) {
                               test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                               dum = (pi/anpn)*nt*protmulAn[counter]*protnormAn[nt-1]/(2.0*n*n);
@@ -650,14 +648,14 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
            else   
              {                                // target must be a neutron
                counter = -1;
-               for( np=0; np<numSec/3; np++ ) 
+               for( npos=0; npos<numSec/3; npos++ ) 
                  { 
-                   nm = np; 
-                   for( nz=0; nz<numSec/3; nz++ ) 
+                   nneg = npos; 
+                   for( nzero=0; nzero<numSec/3; nzero++ ) 
                       {
                         if( ++counter < numMulAn ) 
                           {
-                            nt = np+nm+nz;
+                            nt = npos+nneg+nzero;
                             if ( (nt>1) && (nt<=numSec) ) {
                               test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                               dum = (pi/anpn)*nt*neutmulAn[counter]*neutnormAn[nt-1]/(2.0*n*n);
@@ -679,34 +677,34 @@ G4HEAntiXiZeroInelastic::FirstIntInCasAntiXiZero(G4bool& inElastic,
          }
      }
 
-   nt = np + nm + nz;
+   nt = npos + nneg + nzero;
    while ( nt > 0)
        {
          G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
+         if ( ran < (G4double)npos/nt)
             { 
-              if( np > 0 ) 
+              if( npos > 0 ) 
                 { pv[vecLen++] = PionPlus;
-                  np--;
+                  npos--;
                 }
             }
-         else if ( ran < (G4double)(np+nm)/nt)
+         else if ( ran < (G4double)(npos+nneg)/nt)
             {   
-              if( nm > 0 )
+              if( nneg > 0 )
                 { 
                   pv[vecLen++] = PionMinus;
-                  nm--;
+                  nneg--;
                 }
             }
          else
             {
-              if( nz > 0 )
+              if( nzero > 0 )
                 { 
                   pv[vecLen++] = PionZero;
-                  nz--;
+                  nzero--;
                 }
             }
-         nt = np + nm + nz;
+         nt = npos + nneg + nzero;
        } 
    if (verboseLevel > 1)
       {
