@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEKaonZeroShortInelastic.cc,v 1.13 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
-#include "globals.hh"
-#include "G4ios.hh"
-
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
 // and the low energy two-body model. Not included are the low energy stuff
@@ -39,9 +35,10 @@
 // New version by D.H. Wright (SLAC) to fix seg fault in old version
 // 21 January 2010
 
- 
 #include "G4HEKaonZeroShortInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
 
 void G4HEKaonZeroShortInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -222,15 +219,15 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;
-  static const G4double     c = 1.25;
+  static const G4double c = 1.25;
 
-  static const G4int   numMul = 1200;
-  static const G4int   numSec = 60;
+  static const G4int numMul = 1200;
+  static const G4int numSec = 60;
 
   G4int neutronCode = Neutron.getCode();
   G4int protonCode  = Proton.getCode();
@@ -243,9 +240,9 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
   static G4double neutmul[numMul], neutnorm[numSec];  // neutron constants
 
   // misc. local variables
-  // np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  // npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
   if (first) {
     // compute normalization constants, this will only be done once
@@ -253,13 +250,13 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
     for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
     for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
     counter = -1;
-    for (np=0; np<(numSec/3); np++) {
-      for (nm=std::max(0,np-1); nm<=(np+1); nm++) {
-        for (nz=0; nz<numSec/3; nz++) {
+    for (npos=0; npos<(numSec/3); npos++) {
+      for (nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++) {
+        for (nzero=0; nzero<numSec/3; nzero++) {
           if (++counter < numMul) {
-            nt = np+nm+nz;
+            nt = npos+nneg+nzero;
             if( (nt>0) && (nt<=numSec) ) {
-              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c) ;
+              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c) ;
               protnorm[nt-1] += protmul[counter];
             }
           }
@@ -270,13 +267,13 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
     for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
     for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
     counter = -1;
-    for (np=0; np<numSec/3; np++) {
-      for (nm=np; nm<=(np+2); nm++) {
-        for (nz=0; nz<numSec/3; nz++) {
+    for (npos=0; npos<numSec/3; npos++) {
+      for (nneg=npos; nneg<=(npos+2); nneg++) {
+        for (nzero=0; nzero<numSec/3; nzero++) {
           if (++counter < numMul) {
-            nt = np+nm+nz;
+            nt = npos+nneg+nzero;
             if( (nt>0) && (nt<=numSec) ) {
-              neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+              neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
               neutnorm[nt-1] += neutmul[counter];
             }
           }
@@ -315,7 +312,7 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
 
   // Inelastic scattering
 
-  np = 0, nm = 0, nz = 0;
+  npos = 0, nneg = 0, nzero = 0;
   G4double eab = availableEnergy;
   G4int ieab = G4int( eab*5.0 );
 
@@ -333,13 +330,13 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
       w0 = w0/2.;
       wm = wm*1.5;
       if (G4UniformRand() < w0/(w0+wm) ) {
-        np = 0;
-        nm = 0;
-        nz = 1;
+        npos = 0;
+        nneg = 0;
+        nzero = 1;
       } else {
-        np = 0;
-        nm = 1;
-        nz = 0;
+        npos = 0;
+        nneg = 1;
+        nzero = 0;
       }
 
     } else {
@@ -352,17 +349,17 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
       wp = w0+wp;
       ran = G4UniformRand();
       if ( ran < w0/wt) {
-        np = 0;
-        nm = 0;
-        nz = 1;
+        npos = 0;
+        nneg = 0;
+        nzero = 1;
       } else if (ran < wp/wt) {
-        np = 1;
-        nm = 0;
-        nz = 0;
+        npos = 1;
+        nneg = 0;
+        nzero = 0;
       } else {
-        np = 0;
-        nm = 1;
-        nz = 0;
+        npos = 0;
+        nneg = 1;
+        nzero = 0;
       }
     }
   } else {
@@ -391,13 +388,13 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
        if( targetCode == protonCode )
          {
            counter = -1;
-           for( np=0; np<numSec/3; np++ )
+           for( npos=0; npos<numSec/3; npos++ )
               {
-                for( nm=std::max(0,np-1); nm<=(np+1); nm++ )
+                for( nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++ )
                    {
-                     for (nz=0; nz<numSec/3; nz++) {
+                     for (nzero=0; nzero<numSec/3; nzero++) {
                        if (++counter < numMul) {
-                         nt = np+nm+nz;
+                         nt = npos+nneg+nzero;
                          if ( (nt>0) && (nt<=numSec) ) {
                            test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                            dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -420,13 +417,13 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
        else
          {                                         // target must be a neutron
            counter = -1;
-           for( np=0; np<numSec/3; np++ )
+           for( npos=0; npos<numSec/3; npos++ )
               {
-                for( nm=np; nm<=(np+2); nm++ )
+                for( nneg=npos; nneg<=(npos+2); nneg++ )
                    {
-                     for (nz=0; nz<numSec/3; nz++) {
+                     for (nzero=0; nzero<numSec/3; nzero++) {
                        if (++counter < numMul) {
-                         nt = np+nm+nz;
+                         nt = npos+nneg+nzero;
                          if ( (nt>=1) && (nt<=numSec) ) {
                            test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                            dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -450,10 +447,10 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
 
    if( targetCode == neutronCode)
      {
-       if( np == nm)
+       if( npos == nneg)
          {
          }
-       else if (np == (nm-1))
+       else if (npos == (nneg-1))
          {
            if( G4UniformRand() < 0.5)
              {
@@ -472,7 +469,7 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
      }
    else
      {
-       if( np == nm )
+       if( npos == nneg )
          {
            if( G4UniformRand() < 0.25)
              {
@@ -483,7 +480,7 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
              {
              }
          }
-       else if ( np == (nm+1))
+       else if ( npos == (nneg+1))
          {
            pv[1] = Neutron;
          }
@@ -493,26 +490,26 @@ G4HEKaonZeroShortInelastic::FirstIntInCasKaonZero(G4bool& inElastic,
          }
      }
 
-  nt = np + nm + nz;
+  nt = npos + nneg + nzero;
   while (nt > 0) {
     G4double ran = G4UniformRand();
-    if (ran < (G4double)np/nt) {
-      if (np > 0) {
+    if (ran < (G4double)npos/nt) {
+      if (npos > 0) {
         pv[vecLen++] = PionPlus;
-        np--;
+        npos--;
       }
-    } else if ( ran < (G4double)(np+nm)/nt) {
-      if (nm > 0) {
+    } else if ( ran < (G4double)(npos+nneg)/nt) {
+      if (nneg > 0) {
         pv[vecLen++] = PionMinus;
-        nm--;
+        nneg--;
       }
     } else {
-      if (nz > 0) {
+      if (nzero > 0) {
         pv[vecLen++] = PionZero;
-        nz--;
+        nzero--;
       }
     }
-    nt = np + nm + nz;
+    nt = npos + nneg + nzero;
   }
 
   if (verboseLevel > 1) {
@@ -543,12 +540,12 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;
-  static const G4double     c = 1.25;
+  static const G4double c = 1.25;
 
   static const G4int numMul = 1200;
   static const G4int numSec = 60;
@@ -567,9 +564,9 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
   static G4double neutmul[numMul], neutnorm[numSec];  // neutron constants
 
   // misc. local variables
-  // np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  // npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
   if (first) {
     // compute normalization constants, this will only be done once
@@ -577,13 +574,13 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
     for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
     for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
     counter = -1;
-    for(np=0; np<(numSec/3); np++) {
-      for(nm=std::max(0,np-2); nm<=np; nm++) {
-        for(nz=0; nz<numSec/3; nz++) {
+    for(npos=0; npos<(numSec/3); npos++) {
+      for(nneg=std::max(0,npos-2); nneg<=npos; nneg++) {
+        for(nzero=0; nzero<numSec/3; nzero++) {
           if(++counter < numMul) {
-            nt = np+nm+nz;
+            nt = npos+nneg+nzero;
             if( (nt>0) && (nt<=numSec) ) {
-              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c) ;
+              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c) ;
               protnorm[nt-1] += protmul[counter];
             }
           }
@@ -594,13 +591,13 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
     for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
     for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
     counter = -1;
-    for(np=0; np<numSec/3; np++) {
-      for(nm=std::max(0,np-1); nm<=(np+1); nm++) {
-        for(nz=0; nz<numSec/3; nz++) {
+    for(npos=0; npos<numSec/3; npos++) {
+      for(nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++) {
+        for(nzero=0; nzero<numSec/3; nzero++) {
           if(++counter < numMul) {
-            nt = np+nm+nz;
+            nt = npos+nneg+nzero;
             if( (nt>0) && (nt<=numSec) ) {
-              neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+              neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
               neutnorm[nt-1] += neutmul[counter];
             }
           }
@@ -625,14 +622,14 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
                                         
   // Inelastic scattering
 
-  np = 0, nm = 0, nz = 0;
+  npos = 0, nneg = 0, nzero = 0;
   G4double cech[] = { 1., 1., 1., 0.70, 0.60, 0.55, 0.35, 0.25, 0.18, 0.15};
   G4int iplab = G4int( incidentTotalMomentum*5.);
   if( (iplab < 10) && (G4UniformRand() < cech[iplab]) ) {
-    G4int     iplab = std::min(19, G4int( incidentTotalMomentum*5.));
+    G4int ipl = std::min(19, G4int( incidentTotalMomentum*5.));
     G4double cnk0[] = {0.17, 0.18, 0.17, 0.24, 0.26, 0.20, 0.22, 0.21, 0.34, 0.45,
                        0.58, 0.55, 0.36, 0.29, 0.29, 0.32, 0.32, 0.33, 0.33, 0.33};
-    if(G4UniformRand() < cnk0[iplab]) {
+    if(G4UniformRand() < cnk0[ipl]) {
       if(targetCode == protonCode) {
         return;
       } else {
@@ -701,11 +698,11 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
     G4double excs = 0.0;
     if (targetCode == protonCode) {
       counter = -1;
-      for (np=0; np<numSec/3; np++) {
-        for (nm=std::max(0,np-2); nm<=np; nm++) {
-          for (nz=0; nz<numSec/3; nz++) {
+      for (npos=0; npos<numSec/3; npos++) {
+        for (nneg=std::max(0,npos-2); nneg<=npos; nneg++) {
+          for (nzero=0; nzero<numSec/3; nzero++) {
             if (++counter < numMul) {
-              nt = np+nm+nz;
+              nt = npos+nneg+nzero;
               if( (nt>0) && (nt<=numSec) ) {
                 test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                 dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -728,11 +725,11 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
 
     } else {         // target must be a neutron
       counter = -1;
-      for (np=0; np<numSec/3; np++) {
-        for (nm=std::max(0,np-1); nm<=(np+1); nm++) {
-          for (nz=0; nz<numSec/3; nz++) {
+      for (npos=0; npos<numSec/3; npos++) {
+        for (nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++) {
+          for (nzero=0; nzero<numSec/3; nzero++) {
             if (++counter < numMul) {
-              nt = np+nm+nz;
+              nt = npos+nneg+nzero;
               if( (nt>=1) && (nt<=numSec) ) {
                 test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                 dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -758,10 +755,10 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
     
   if( targetCode == protonCode)
      {
-       if( np == nm)
+       if( npos == nneg)
          {
          }
-       else if (np == (1+nm))
+       else if (npos == (1+nneg))
          {
            if( G4UniformRand() < 0.5)
              {
@@ -780,7 +777,7 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
      }  
   else
      {
-       if( np == nm)
+       if( npos == nneg)
          {
            if( G4UniformRand() < 0.75)
              {
@@ -791,7 +788,7 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
                pv[1] = Proton;
              }
          } 
-       else if ( np == (1+nm))
+       else if ( npos == (1+nneg))
          {
            pv[0] = KaonMinus;
          }
@@ -875,26 +872,26 @@ G4HEKaonZeroShortInelastic::FirstIntInCasAntiKaonZero(G4bool& inElastic,
          }
     }
 
-  nt = np + nm + nz;
+  nt = npos + nneg + nzero;
   while ( nt > 0) {
     G4double ran = G4UniformRand();
-    if ( ran < (G4double)np/nt) { 
-      if( np > 0 ) {
+    if ( ran < (G4double)npos/nt) { 
+      if( npos > 0 ) {
         pv[vecLen++] = PionPlus;
-        np--;
+        npos--;
       }
-    } else if (ran < (G4double)(np+nm)/nt) {   
-      if( nm > 0 ) { 
+    } else if (ran < (G4double)(npos+nneg)/nt) {   
+      if( nneg > 0 ) { 
         pv[vecLen++] = PionMinus;
-        nm--;
+        nneg--;
       }
     } else {
-      if( nz > 0 ) { 
+      if( nzero > 0 ) { 
         pv[vecLen++] = PionZero;
-        nz--;
+        nzero--;
       }
     }
-    nt = np + nm + nz;
+    nt = npos + nneg + nzero;
   }
  
   if (verboseLevel > 1) {
