@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEPionPlusInelastic.cc,v 1.17 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
-#include "globals.hh"
-#include "G4ios.hh"
-
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
 // and the low energy two-body model. Not included are the low energy stuff
@@ -39,7 +35,9 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HEPionPlusInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
 
 void G4HEPionPlusInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -206,8 +204,8 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;
@@ -228,9 +226,9 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
   static G4double neutmul[numMul], neutnorm[numSec];  // neutron constants
 
   // misc. local variables
-  // np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  // npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
    if( first ) 
      {   // compute normalization constants, this will only be done once
@@ -238,19 +236,19 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
        for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
        for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
+       for( npos=0; npos<(numSec/3); npos++ ) 
           {
-            for( nm=Imax(0,np-2); nm<=np; nm++ ) 
+            for( nneg=Imax(0,npos-2); nneg<=npos; nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
                               protmul[counter] =
-                                    pmltpc(np,nm,nz,nt,protb,c) ;
+                                    pmltpc(npos,nneg,nzero,nt,protb,c) ;
                               protnorm[nt-1] += protmul[counter];
                             }
                         }
@@ -260,19 +258,19 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
        for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
        for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
+       for( npos=0; npos<numSec/3; npos++ ) 
           {
-            for( nm=Imax(0,np-1); nm<=(np+1); nm++ ) 
+            for( nneg=Imax(0,npos-1); nneg<=(npos+1); nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
                                neutmul[counter] =
-                                      pmltpc(np,nm,nz,nt,neutb,c);
+                                      pmltpc(npos,nneg,nzero,nt,neutb,c);
                                neutnorm[nt-1] += neutmul[counter];
                             }
                         }
@@ -312,7 +310,7 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
 
 //                                            inelastic scattering
 
-   np = 0, nm = 0, nz = 0;
+   npos = 0, nneg = 0, nzero = 0;
    G4double eab = availableEnergy;
    G4int ieab = G4int( eab*5.0 );
    
@@ -327,9 +325,9 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
            w0 = - sqr(1.+protb)/(2.*c*c);
            wp = w0 = std::exp(w0);
            if( G4UniformRand() < w0/(w0+wp) )  
-             { np = 0; nm = 0; nz = 1; }
+             { npos = 0; nneg = 0; nzero = 1; }
            else 
-             { np = 1; nm = 0; nz = 0; }       
+             { npos = 1; nneg = 0; nzero = 0; }       
          } 
        else 
          {                                               // target is a neutron
@@ -341,11 +339,11 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
            wp = w0+wp;
            ran = G4UniformRand();
            if( ran < w0/wt)
-             { np = 0; nm = 0; nz = 1; }       
+             { npos = 0; nneg = 0; nzero = 1; }       
            else if( ran < wp/wt)
-             { np = 1; nm = 0; nz = 0; }       
+             { npos = 1; nneg = 0; nzero = 0; }       
            else
-             { np = 0; nm = 1; nz = 0; }       
+             { npos = 0; nneg = 1; nzero = 0; }       
          }
      }
    else
@@ -375,11 +373,11 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
        if( targetCode == protonCode ) 
          {
            counter = -1;
-           for (np=0; np<numSec/3; np++) {
-             for (nm=Imax(0,np-2); nm<=np; nm++) {
-               for (nz=0; nz<numSec/3; nz++) {
+           for (npos=0; npos<numSec/3; npos++) {
+             for (nneg=Imax(0,npos-2); nneg<=npos; nneg++) {
+               for (nzero=0; nzero<numSec/3; nzero++) {
                  if (++counter < numMul) {
-                   nt = np+nm+nz;
+                   nt = npos+nneg+nzero;
                    if ( (nt>0) && (nt<=numSec) ) {
                      test = std::exp( Amin( expxu, Amax( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                      dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -402,11 +400,11 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
        else   
          {                                         // target must be a neutron
            counter = -1;
-           for (np=0; np<numSec/3; np++) {
-             for (nm=Imax(0,np-1); nm<=(np+1); nm++) {
-               for (nz=0; nz<numSec/3; nz++) {
+           for (npos=0; npos<numSec/3; npos++) {
+             for (nneg=Imax(0,npos-1); nneg<=(npos+1); nneg++) {
+               for (nzero=0; nzero<numSec/3; nzero++) {
                  if (++counter < numMul) {
-                   nt = np+nm+nz;
+                   nt = npos+nneg+nzero;
                    if ( (nt>=1) && (nt<=numSec) ) {
                      test = std::exp( Amin( expxu, Amax( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                      dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -430,10 +428,10 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
     
    if( targetCode == protonCode)
      {
-       if( np == nm)
+       if( npos == nneg)
          {
          }
-       else if (np == (1+nm))
+       else if (npos == (1+nneg))
          {
            if( G4UniformRand() < 0.5)
              {
@@ -452,7 +450,7 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
      }  
    else
      {
-       if( np == nm)
+       if( npos == nneg)
          {
            if( G4UniformRand() < 0.25)
              {
@@ -463,7 +461,7 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
              {
              }
          } 
-       else if ( np == (1+nm))
+       else if ( npos == (1+nneg))
          {
            pv[0] = PionZero;
          }
@@ -474,34 +472,34 @@ G4HEPionPlusInelastic::FirstIntInCasPionPlus(G4bool& inElastic,
      }      
 
 
-   nt = np + nm + nz;
+   nt = npos + nneg + nzero;
    while ( nt > 0)
        {
          G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
+         if ( ran < (G4double)npos/nt)
             { 
-              if( np > 0 ) 
+              if( npos > 0 ) 
                 { pv[vecLen++] = PionPlus;
-                  np--;
+                  npos--;
                 }
             }
-         else if ( ran < (G4double)(np+nm)/nt)
+         else if ( ran < (G4double)(npos+nneg)/nt)
             {   
-              if( nm > 0 )
+              if( nneg > 0 )
                 { 
                   pv[vecLen++] = PionMinus;
-                  nm--;
+                  nneg--;
                 }
             }
          else
             {
-              if( nz > 0 )
+              if( nzero > 0 )
                 { 
                   pv[vecLen++] = PionZero;
-                  nz--;
+                  nzero--;
                 }
             }
-         nt = np + nm + nz;
+         nt = npos + nneg + nzero;
        } 
    if (verboseLevel > 1)
       {
