@@ -23,13 +23,9 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEProtonInelastic.cc,v 1.16 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 
-#include "globals.hh"
-#include "G4ios.hh"
-
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
 // and the low energy two-body model. Not included are the low energy stuff 
@@ -39,7 +35,9 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HEProtonInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
 
 void G4HEProtonInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -216,12 +214,12 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.35;
-  static const G4double     c = 1.25;
+  static const G4double c = 1.25;
 
   static const G4int numMul = 1200;
   static const G4int numSec = 60;
@@ -238,9 +236,9 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
   static G4double neutmul[numMul], neutnorm[numSec];  // neutron constants
 
   //  misc. local variables
-  //  np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  //  npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
   if (first) { 
     // compute normalization constants, this will only be done once
@@ -248,14 +246,14 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
     for (i=0; i<numMul; i++) protmul[i] = 0.0;
     for (i=0; i<numSec; i++) protnorm[i] = 0.0;
     counter = -1;
-    for (np=0; np<(numSec/3); np++) {
-      for (nm=Imax(0,np-2); nm<=np; nm++) {
-        for (nz=0; nz<numSec/3; nz++) {
+    for (npos=0; npos<(numSec/3); npos++) {
+      for (nneg=Imax(0,npos-2); nneg<=npos; nneg++) {
+        for (nzero=0; nzero<numSec/3; nzero++) {
           if (++counter < numMul) {
-            nt = np+nm+nz;
+            nt = npos+nneg+nzero;
             if ( (nt>0) && (nt<=numSec) ) {
-              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c)
-                                 /(Factorial(2-np+nm)*Factorial(np-nm)) ;
+              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c)
+                                 /(Factorial(2-npos+nneg)*Factorial(npos-nneg)) ;
               protnorm[nt-1] += protmul[counter];
             }
           }
@@ -266,14 +264,14 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
     for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
     for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
     counter = -1;
-    for (np=0; np<numSec/3; np++) {
-      for (nm=Imax(0,np-1); nm<=(np+1); nm++) {
-        for (nz=0; nz<numSec/3; nz++) {
+    for (npos=0; npos<numSec/3; npos++) {
+      for (nneg=Imax(0,npos-1); nneg<=(npos+1); nneg++) {
+        for (nzero=0; nzero<numSec/3; nzero++) {
           if (++counter < numMul) {
-            nt = np+nm+nz;
+            nt = npos+nneg+nzero;
             if ( (nt>0) && (nt<=numSec) ) {
-              neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c)
-                                 /(Factorial(1-np+nm)*Factorial(1+np-nm));
+              neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c)
+                                 /(Factorial(1-npos+nneg)*Factorial(1+npos-nneg));
               neutnorm[nt-1] += neutmul[counter];
             }
           }
@@ -293,68 +291,61 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
   pv[1] = targetParticle;
   vecLen = 2;
 
-   if( !inElastic ) 
-     {                                     // quasi-elastic scattering, no pions produced
-       if( targetCode == neutronCode ) 
-         {
-           G4double cech[] = {0.50, 0.45, 0.40, 0.35, 0.30, 0.25, 0.06, 0.04, 0.005, 0.};
-           G4int iplab = G4int( Amin( 9.0, incidentTotalMomentum*2.5 ) );
-           if( G4UniformRand() < cech[iplab]/std::pow(atomicWeight,0.42) ) 
-             {                                            // charge exchange  pi+ n -> pi0 p
-               pv[0] = PionZero;
-               pv[1] = Proton;
-             }
-         }
-       return;
-     }
-   else if (availableEnergy <= pionMass)
-       return;
+  if (!inElastic) {    // quasi-elastic scattering, no pions produced
+    if (targetCode == neutronCode) {
+      G4double cech[] = {0.50, 0.45, 0.40, 0.35, 0.30, 0.25, 0.06, 0.04, 0.005, 0.};
+      G4int iplab = G4int( Amin( 9.0, incidentTotalMomentum*2.5 ) );
+      if (G4UniformRand() < cech[iplab]/std::pow(atomicWeight,0.42) ) {
+        // charge exchange  pi+ n -> pi0 p
+        pv[0] = PionZero;
+        pv[1] = Proton;
+      }
+    }
+    return;
+  } else if (availableEnergy <= pionMass) return;
 
-                                                  //   inelastic scattering
-
-   np = 0, nm = 0, nz = 0;
-   G4double eab = availableEnergy;
-   G4int ieab = G4int( eab*5.0 );
+  //   inelastic scattering
+  npos = 0, nneg = 0, nzero = 0;
+  G4double eab = availableEnergy;
+  G4int ieab = G4int( eab*5.0 );
    
-   G4double supp[] = {0., 0.4, 0.55, 0.65, 0.75, 0.82, 0.86, 0.90, 0.94, 0.98};
-   if( (ieab <= 9) && (G4UniformRand() >= supp[ieab]) ) 
-     {
-                                          //   suppress high multiplicity events at low momentum
-                                          //   only one additional pion will be produced
-       G4double w0, wp, wm, wt, ran;
-       if( targetCode == protonCode )                    // target is a proton 
-         {
-           w0 = - sqr(1.+protb)/(2.*c*c);
-           wp = w0 = std::exp(w0);
-           if( G4UniformRand() < w0/(w0+wp) )  
-             { np = 0; nm = 0; nz = 1; }
-           else 
-             { np = 1; nm = 0; nz = 0; }       
-         } 
-       else 
-         {                                               // target is a neutron
-           w0 = -sqr(1.+neutb)/(2.*c*c);
-           w0 = std::exp(w0);
-           wp = w0/2.;
-           wm = -sqr(-1.+neutb)/(2.*c*c);
+  G4double supp[] = {0., 0.4, 0.55, 0.65, 0.75, 0.82, 0.86, 0.90, 0.94, 0.98};
+  if ( (ieab <= 9) && (G4UniformRand() >= supp[ieab]) ) {
+    // suppress high multiplicity events at low momentum
+    //   only one additional pion will be produced
+    G4double w0, wp, wm, wt, ran;
+    if (targetCode == protonCode) {    // target is a proton 
+      w0 = - sqr(1.+protb)/(2.*c*c);
+      wp = w0 = std::exp(w0);
+      if (G4UniformRand() < w0/(w0+wp) ) {
+        npos = 0;
+        nneg = 0;
+        nzero = 1;
+      } else {
+        npos = 1;
+        nneg = 0;
+        nzero = 0; }       
+      } else {     // target is a neutron
+        w0 = -sqr(1.+neutb)/(2.*c*c);
+        w0 = std::exp(w0);
+        wp = w0/2.;
+        wm = -sqr(-1.+neutb)/(2.*c*c);
            wm = std::exp(wm)/2.;
            wt = w0+wp+wm;
            wp = w0+wp;
            ran = G4UniformRand();
            if( ran < w0/wt)
-             { np = 0; nm = 0; nz = 1; }       
+             { npos = 0; nneg = 0; nzero = 1; }       
            else if( ran < wp/wt)
-             { np = 1; nm = 0; nz = 0; }       
+             { npos = 1; nneg = 0; nzero = 0; }       
            else
-             { np = 0; nm = 1; nz = 0; }       
-         }
-     }
-   else
-     {
-       // number of total particles vs. centre of mass Energy - 2*proton mass
+             { npos = 0; nneg = 1; nzero = 0; }       
+      }
+    } else {
+      // number of total particles vs. centre of mass Energy - 2*proton mass
    
-       G4double aleab = std::log(availableEnergy);
-       G4double n     = 3.62567+aleab*(0.665843+aleab*(0.336514
+      G4double aleab = std::log(availableEnergy);
+      G4double n = 3.62567+aleab*(0.665843+aleab*(0.336514
                     + aleab*(0.117712+0.0136912*aleab))) - 2.0;
    
        // normalization constant for kno-distribution.
@@ -376,11 +367,11 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
        if( targetCode == protonCode ) 
          {
            counter = -1;
-           for (np=0; np<numSec/3; np++) {
-             for (nm=Imax(0,np-2); nm<=np; nm++) {
-               for (nz=0; nz<numSec/3; nz++) {
+           for (npos=0; npos<numSec/3; npos++) {
+             for (nneg=Imax(0,npos-2); nneg<=npos; nneg++) {
+               for (nzero=0; nzero<numSec/3; nzero++) {
                  if (++counter < numMul) {
-                   nt = np+nm+nz;
+                   nt = npos+nneg+nzero;
                    if ( (nt>0) && (nt<=numSec) ) {
                      test = std::exp( Amin( expxu, Amax( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                      dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -403,11 +394,11 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
        else   
          {                                         // target must be a neutron
            counter = -1;
-           for (np=0; np<numSec/3; np++) {
-             for (nm=Imax(0,np-1); nm<=(np+1); nm++) {
-               for (nz=0; nz<numSec/3; nz++) {
+           for (npos=0; npos<numSec/3; npos++) {
+             for (nneg=Imax(0,npos-1); nneg<=(npos+1); nneg++) {
+               for (nzero=0; nzero<numSec/3; nzero++) {
                  if (++counter < numMul) {
-                   nt = np+nm+nz;
+                   nt = npos+nneg+nzero;
                    if ( (nt>=1) && (nt<=numSec) ) {
                      test = std::exp( Amin( expxu, Amax( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                      dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -431,10 +422,10 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
     
    if( targetCode == protonCode)
      {
-       if( np == nm)
+       if( npos == nneg)
          {
          }
-       else if (np == (1+nm))
+       else if (npos == (1+nneg))
          {
            if( G4UniformRand() < 0.5)
              {
@@ -453,7 +444,7 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
      }  
    else
      {
-       if( np == nm)
+       if( npos == nneg)
          {
            if( G4UniformRand() < 0.25)
              {
@@ -464,7 +455,7 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
              {
              }
          } 
-       else if ( np == (1+nm))
+       else if ( npos == (1+nneg))
          {
            pv[0] = Neutron;
          }
@@ -475,34 +466,34 @@ G4HEProtonInelastic::FirstIntInCasProton(G4bool& inElastic,
      }      
 
 
-   nt = np + nm + nz;
+   nt = npos + nneg + nzero;
    while ( nt > 0)
        {
          G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
+         if ( ran < (G4double)npos/nt)
             { 
-              if( np > 0 ) 
+              if( npos > 0 ) 
                 { pv[vecLen++] = PionPlus;
-                  np--;
+                  npos--;
                 }
             }
-         else if ( ran < (G4double)(np+nm)/nt)
+         else if ( ran < (G4double)(npos+nneg)/nt)
             {   
-              if( nm > 0 )
+              if( nneg > 0 )
                 { 
                   pv[vecLen++] = PionMinus;
-                  nm--;
+                  nneg--;
                 }
             }
          else
             {
-              if( nz > 0 )
+              if( nzero > 0 )
                 { 
                   pv[vecLen++] = PionZero;
-                  nz--;
+                  nzero--;
                 }
             }
-         nt = np + nm + nz;
+         nt = npos + nneg + nzero;
        } 
    if (verboseLevel > 1)
       {
