@@ -23,12 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HESigmaMinusInelastic.cc,v 1.17 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
-
-#include "globals.hh"
-#include "G4ios.hh"
-#include <iostream>
+// $Id$
 
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
@@ -39,7 +34,10 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HESigmaMinusInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 G4HESigmaMinusInelastic::G4HESigmaMinusInelastic(const G4String& name)
  : G4HEInelastic(name)
@@ -49,6 +47,8 @@ G4HESigmaMinusInelastic::G4HESigmaMinusInelastic(const G4String& name)
   theMaxEnergy = 10*TeV;
   MAXPART      = 2048;
   verboseLevel = 0;
+  G4cout << "WARNING: model G4HESigmaMinusInelastic is being deprecated and will\n"
+         << "disappear in Geant4 version 10.0"  << G4endl;  
 } 
 
 
@@ -215,12 +215,12 @@ G4HESigmaMinusInelastic::FirstIntInCasSigmaMinus(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;              
-  static const G4double     c = 1.25;
+  static const G4double c = 1.25;
 
   static const G4int numMul = 1200;
   static const G4int numSec = 60;
@@ -236,149 +236,117 @@ G4HESigmaMinusInelastic::FirstIntInCasSigmaMinus(G4bool& inElastic,
   static G4double neutmul[numMul], neutnorm[numSec];  // neutron constants
 
   //  misc. local variables
-  //  np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  //  npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
-   if( first ) 
-     {     // compute normalization constants, this will only be done once
-       first = false;
-       for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
-       for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
-          {
-            for( nm=std::max(0,np-1); nm<=(np+1); nm++ ) 
-               {
-                 for( nz=0; nz<numSec/3; nz++ ) 
-                    {
-                      if( ++counter < numMul ) 
-                        {
-                          nt = np+nm+nz;
-                          if( (nt>0) && (nt<=numSec) ) 
-                            {
-                              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c);
-                              protnorm[nt-1] += protmul[counter];
-                            }
-                        }
-                    }
-               }
+  if (first) {  // computation of normalization constants will only be done once
+    first = false;
+    for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
+    for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
+    counter = -1;
+    for (npos = 0; npos < (numSec/3); npos++) {
+      for (nneg = std::max(0,npos-1); nneg <= (npos+1); nneg++) {
+        for (nzero = 0; nzero < numSec/3; nzero++) {
+          if (++counter < numMul) {
+            nt = npos+nneg+nzero;
+            if ((nt > 0) && (nt<=numSec) ) {
+              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
+              protnorm[nt-1] += protmul[counter];
+            }
           }
-       for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
-       for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
-          {
-            for( nm=np; nm<=(np+2); nm++ ) 
-               {
-                 for( nz=0; nz<numSec/3; nz++ ) 
-                    {
-                      if( ++counter < numMul ) 
-                        {
-                          nt = np+nm+nz;
-                          if( (nt>0) && (nt<=numSec) ) 
-                            {
-                               neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
-                               neutnorm[nt-1] += neutmul[counter];
-                            }
-                        }
-                    }
-               }
+        }
+      }
+    }
+
+    for (i = 0; i < numMul; i++) neutmul[i]  = 0.0;
+    for (i = 0; i < numSec; i++) neutnorm[i] = 0.0;
+    counter = -1;
+    for (npos = 0; npos < numSec/3; npos++) {
+      for (nneg = npos; nneg <= (npos+2); nneg++) {
+        for (nzero = 0; nzero < numSec/3; nzero++) {
+          if (++counter < numMul) {
+            nt = npos+nneg+nzero;
+            if ((nt>0) && (nt<=numSec) ) {
+              neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
+              neutnorm[nt-1] += neutmul[counter];
+            }
           }
-       for( i=0; i<numSec; i++ ) 
-          {
-            if( protnorm[i] > 0.0 )protnorm[i] = 1.0/protnorm[i];
-            if( neutnorm[i] > 0.0 )neutnorm[i] = 1.0/neutnorm[i];
-          }
-     }                                          // end of initialization
+        }
+      }
+    }
+    for (i = 0; i < numSec; i++) {
+      if (protnorm[i] > 0.0 )protnorm[i] = 1.0/protnorm[i];
+      if (neutnorm[i] > 0.0 )neutnorm[i] = 1.0/neutnorm[i];
+    }
+  }  // end of initialization
 
-         
-                                              // initialize the first two places
-                                              // the same as beam and target                                    
-   pv[0] = incidentParticle;
-   pv[1] = targetParticle;
-   vecLen = 2;
+  pv[0] = incidentParticle; // initialize the first two places
+  pv[1] = targetParticle;   // the same as beam and target
+  vecLen = 2;
 
-   if( !inElastic ) 
-     {                                     // quasi-elastic scattering, no pions produced
-       G4double cech[] = {0.50, 0.45, 0.40, 0.35, 0.30, 0.25, 0.06, 0.04, 0.005, 0.};
-       G4int iplab = G4int( std::min( 9.0, incidentTotalMomentum*2.5 ) );
-       if( G4UniformRand() < cech[iplab]/std::pow(atomicWeight,0.42) ) 
-         {                                           
-           G4double ran = G4UniformRand();
-           if( targetCode == neutronCode)
-             {
-               pv[0] = Neutron;
-               pv[1] = SigmaMinus;
-             }              
-           else
-             { 
-               if(ran < 0.2)
-                 {
-                   pv[0] = SigmaZero;
-                   pv[1] = Neutron;  
-                 }
-               else if(ran < 0.4)
-                 {
-                   pv[0] = Lambda;
-                   pv[1] = Neutron;
-                 }
-               else if(ran < 0.6)
-                 {
-                   pv[0] = Proton;
-                   pv[1] = SigmaMinus;
-                 } 
-               else if(ran < 0.8)
-                 {
-                   pv[0] = Neutron;
-                   pv[1] = SigmaZero;
-                 }
-               else
-                 {
-                   pv[0] = Neutron;
-                   pv[1] = Lambda;
-                 }  
-             }
-         }
-       return;
-     }
-   else if (availableEnergy <= PionPlus.getMass())
-       return;
+  if (!inElastic) {  // quasi-elastic scattering, no pions produced
+    G4double cech[] = {0.50, 0.45, 0.40, 0.35, 0.30, 0.25, 0.06, 0.04, 0.005, 0.};
+    G4int iplab = G4int( std::min( 9.0, incidentTotalMomentum*2.5 ) );
+    if (G4UniformRand() < cech[iplab]/std::pow(atomicWeight,0.42) ) {
+      G4double ran = G4UniformRand();
+      if (targetCode == neutronCode) {
+        pv[0] = Neutron;
+        pv[1] = SigmaMinus;
+      } else { 
+        if (ran < 0.2) {
+          pv[0] = SigmaZero;
+          pv[1] = Neutron;  
+        } else if (ran < 0.4) {
+          pv[0] = Lambda;
+          pv[1] = Neutron;
+        } else if (ran < 0.6) {
+          pv[0] = Proton;
+          pv[1] = SigmaMinus;
+        } else if (ran < 0.8) {
+          pv[0] = Neutron;
+          pv[1] = SigmaZero;
+        } else {
+          pv[0] = Neutron;
+          pv[1] = Lambda;
+        }  
+      }
+    }
+    return;
 
-                                                  //   inelastic scattering
+  } else if (availableEnergy <= PionPlus.getMass()) return;
 
-   np = 0, nm = 0, nz = 0;
+  //   inelastic scattering
+  npos = 0, nneg = 0, nzero = 0;
 
-   // number of total particles vs. centre of mass Energy - 2*proton mass
-   
-   G4double aleab = std::log(availableEnergy);
-   G4double n     = 3.62567+aleab*(0.665843+aleab*(0.336514
+  // number of total particles vs. centre of mass Energy - 2*proton mass 
+  G4double aleab = std::log(availableEnergy);
+  G4double n = 3.62567+aleab*(0.665843+aleab*(0.336514
                     + aleab*(0.117712+0.0136912*aleab))) - 2.0;
    
-   // normalization constant for kno-distribution.
-   // calculate first the sum of all constants, check for numerical problems.
-   G4double test, dum, anpn = 0.0;
+  // normalization constant for kno-distribution.
+  // calculate first the sum of all constants, check for numerical problems.
+  G4double test, dum, anpn = 0.0;
 
-   for (nt=1; nt<=numSec; nt++) {
-     test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
-     dum = pi*nt/(2.0*n*n);
-     if (std::fabs(dum) < 1.0) {
-       if (test >= 1.0e-10) anpn += dum*test;
-     } else { 
-       anpn += dum*test;
-     }
-   }
+  for (nt = 1; nt <= numSec; nt++) {
+    test = std::exp(std::min(expxu, std::max(expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
+    dum = pi*nt/(2.0*n*n);
+    if (std::fabs(dum) < 1.0) {
+      if (test >= 1.0e-10) anpn += dum*test;
+    } else { 
+      anpn += dum*test;
+    }
+  }
    
-   G4double ran = G4UniformRand();
-   G4double excs = 0.0;
-   if( targetCode == protonCode ) 
-     {
-       counter = -1;
-       for (np=0; np<numSec/3; np++) {
-         for (nm=std::max(0,np-1); nm<=(np+1); nm++) {
-           for (nz=0; nz<numSec/3; nz++) {
+  G4double ran = G4UniformRand();
+  G4double excs = 0.0;
+  if (targetCode == protonCode) {
+    counter = -1;
+    for (npos=0; npos<numSec/3; npos++) {
+         for (nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++) {
+           for (nzero=0; nzero<numSec/3; nzero++) {
              if (++counter < numMul) {
-               nt = np+nm+nz;
+               nt = npos+nneg+nzero;
                if ( (nt>0) && (nt<=numSec) ) {
                  test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                  dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -392,20 +360,19 @@ G4HESigmaMinusInelastic::FirstIntInCasSigmaMinus(G4bool& inElastic,
 	     }
 	   }
 	 }
-       }
+    }
        
-       // 3 previous loops continued to the end
-       inElastic = false;                 // quasi-elastic scattering   
-       return;
-     }
-   else   
-     {                                         // target must be a neutron
+    // 3 previous loops continued to the end
+    inElastic = false;                 // quasi-elastic scattering   
+    return;
+
+  } else {  // target must be a neutron
        counter = -1;
-       for (np=0; np<numSec/3; np++) {
-         for (nm=np; nm<=(np+2); nm++) {
-           for (nz=0; nz<numSec/3; nz++) {
+       for (npos=0; npos<numSec/3; npos++) {
+         for (nneg=npos; nneg<=(npos+2); nneg++) {
+           for (nzero=0; nzero<numSec/3; nzero++) {
              if (++counter < numMul) {
-               nt = np+nm+nz;
+               nt = npos+nneg+nzero;
                if ( (nt>=1) && (nt<=numSec) ) {
                  test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                  dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -420,20 +387,20 @@ G4HESigmaMinusInelastic::FirstIntInCasSigmaMinus(G4bool& inElastic,
 	   }
 	 }
        }
-       // 3 previous loops continued to the end
-       inElastic = false;                         // quasi-elastic scattering.
-       return;
-     }
+    // 3 previous loops continued to the end
+
+    inElastic = false;   // quasi-elastic scattering.
+    return;
+  }
  
-   outOfLoop:           //  <-------------------------------------------   
+  outOfLoop:           //  <-------------------------------------------   
     
-   ran = G4UniformRand();
-   if( targetCode == neutronCode)
-     {
-       if( np == nm)
+  ran = G4UniformRand();
+  if (targetCode == neutronCode) {
+       if( npos == nneg)
          { 
          }
-       else if (np == (nm-1))
+       else if (npos == (nneg-1))
          {
            if( ran < 0.25)
              {
@@ -461,10 +428,8 @@ G4HESigmaMinusInelastic::FirstIntInCasSigmaMinus(G4bool& inElastic,
                pv[1] = Proton;
              }
          }   
-     }  
-   else
-     {
-       if (np == nm)
+  } else {
+       if (npos == nneg)
          {
            if (ran < 0.5) 
              {
@@ -480,7 +445,7 @@ G4HESigmaMinusInelastic::FirstIntInCasSigmaMinus(G4bool& inElastic,
                pv[1] = Neutron;
              }  
          }  
-       else if (np == (nm+1))
+       else if (npos == (nneg+1))
          {  
            pv[1] = Neutron;
          } 
@@ -495,51 +460,40 @@ G4HESigmaMinusInelastic::FirstIntInCasSigmaMinus(G4bool& inElastic,
                pv[0] = Lambda;
              }   
          }
-     }      
+  }      
 
-
-   nt = np + nm + nz;
-   while ( nt > 0)
-       {
-         G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
-            { 
-              if( np > 0 ) 
-                { pv[vecLen++] = PionPlus;
-                  np--;
-                }
-            }
-         else if ( ran < (G4double)(np+nm)/nt)
-            {   
-              if( nm > 0 )
-                { 
-                  pv[vecLen++] = PionMinus;
-                  nm--;
-                }
-            }
-         else
-            {
-              if( nz > 0 )
-                { 
-                  pv[vecLen++] = PionZero;
-                  nz--;
-                }
-            }
-         nt = np + nm + nz;
-       } 
-   if (verboseLevel > 1)
-      {
-        G4cout << "Particles produced: " ;
-        G4cout << pv[0].getCode() << " " ;
-        G4cout << pv[1].getCode() << " " ;
-        for (i=2; i < vecLen; i++)   
-            { 
-              G4cout << pv[i].getCode() << " " ;
-            }
-         G4cout << G4endl;
+  nt = npos + nneg + nzero;
+  while (nt > 0) {
+    G4double rnd = G4UniformRand();
+    if (rnd < (G4double)npos/nt) { 
+      if (npos > 0) {
+        pv[vecLen++] = PionPlus;
+        npos--;
       }
-   return;
- }
+    } else if (rnd < (G4double)(npos+nneg)/nt) {   
+      if (nneg > 0) { 
+        pv[vecLen++] = PionMinus;
+        nneg--;
+      }
+    } else {
+      if (nzero > 0) { 
+        pv[vecLen++] = PionZero;
+        nzero--;
+      }
+    }
+    nt = npos + nneg + nzero;
+  }
+ 
+  if (verboseLevel > 1) {
+    G4cout << "Particles produced: " ;
+    G4cout << pv[0].getCode() << " " ;
+    G4cout << pv[1].getCode() << " " ;
+    for (i = 2; i < vecLen; i++) G4cout << pv[i].getCode() << " " ;
+    G4cout << G4endl;
+  }
+
+  return;
+}
 
 
 
