@@ -23,12 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HESigmaPlusInelastic.cc,v 1.17 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
-
-#include "globals.hh"
-#include "G4ios.hh"
-#include <iostream>
+// $Id$
 
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
@@ -39,8 +34,24 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HESigmaPlusInelastic.hh"
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 
 
+G4HESigmaPlusInelastic::G4HESigmaPlusInelastic(const G4String& name)
+ : G4HEInelastic(name)
+{
+  vecLength = 0;
+  theMinEnergy = 20*GeV;
+  theMaxEnergy = 10*TeV;
+  MAXPART      = 2048;
+  verboseLevel = 0;
+  G4cout << "WARNING: model G4HESigmaPlusInelastic is being deprecated and will\n"
+         << "disappear in Geant4 version 10.0"  << G4endl;
+} 
+
 void G4HESigmaPlusInelastic::ModelDescription(std::ostream& outFile) const
 {
   outFile << "G4HESigmaPlusInelastic is one of the High Energy\n"
@@ -55,18 +66,6 @@ void G4HESigmaPlusInelastic::ModelDescription(std::ostream& outFile) const
 }
 
 
-G4HESigmaPlusInelastic::G4HESigmaPlusInelastic(const G4String& name)
- : G4HEInelastic(name)
-{
-  vecLength = 0;
-  theMinEnergy = 20*GeV;
-  theMaxEnergy = 10*TeV;
-  MAXPART      = 2048;
-  verboseLevel = 0;
-//  Description();
-} 
-
-
 G4HadFinalState*
 G4HESigmaPlusInelastic::ApplyYourself(const G4HadProjectile& aTrack,
                                       G4Nucleus& targetNucleus)
@@ -217,17 +216,17 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;              
-  static const G4double     c = 1.25;
+  static const G4double c = 1.25;
 
   static const G4int numMul = 1200;
   static const G4int numSec = 60;
 
-  G4int protonCode  = Proton.getCode();
+  G4int protonCode = Proton.getCode();
 
   G4int targetCode = targetParticle.getCode();
   G4double incidentTotalMomentum = incidentParticle.getTotalMomentum();
@@ -237,28 +236,28 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
   static G4double neutmul[numMul], neutnorm[numSec];  // neutron constants
 
   //  misc. local variables
-  //  np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  //  npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
-   if( first ) 
-     {   // compute normalization constants, this will only be done once
-       first = false;
-       for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
-       for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
+  if (first) {
+    // compute normalization constants, this will only be done once
+    first = false;
+    for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
+    for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
+    counter = -1;
+       for( npos=0; npos<(numSec/3); npos++ ) 
           {
-            for( nm=std::max(0,np-2); nm<=np; nm++ ) 
+            for( nneg=std::max(0,npos-2); nneg<=npos; nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c);
+                              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
                               protnorm[nt-1] += protmul[counter];
                             }
                         }
@@ -268,18 +267,18 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
        for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
        for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
        counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
+       for( npos=0; npos<numSec/3; npos++ ) 
           {
-            for( nm=std::max(0,np-1); nm<=(np+1); nm++ ) 
+            for( nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                               neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+                               neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
                                neutnorm[nt-1] += neutmul[counter];
                             }
                         }
@@ -348,7 +347,7 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
 
                                                   //   inelastic scattering
 
-   np = 0; nm = 0; nz = 0;
+   npos = 0; nneg = 0; nzero = 0;
 
    // number of total particles vs. centre of mass Energy - 2*proton mass
    
@@ -375,11 +374,11 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
    if( targetCode == protonCode ) 
      {
        counter = -1;
-       for (np=0; np<numSec/3; np++) {
-         for (nm=std::max(0,np-2); nm<=np; nm++) {
-           for (nz=0; nz<numSec/3; nz++) {
+       for (npos=0; npos<numSec/3; npos++) {
+         for (nneg=std::max(0,npos-2); nneg<=npos; nneg++) {
+           for (nzero=0; nzero<numSec/3; nzero++) {
              if (++counter < numMul) {
-               nt = np+nm+nz;
+               nt = npos+nneg+nzero;
                if ( (nt>0) && (nt<=numSec) ) {
                  test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                  dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -402,11 +401,11 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
    else   
      {                                         // target must be a neutron
        counter = -1;
-       for (np=0; np<numSec/3; np++) {
-         for (nm=std::max(0,np-1); nm<=(np+1); nm++) {
-           for (nz=0; nz<numSec/3; nz++) {
+       for (npos=0; npos<numSec/3; npos++) {
+         for (nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++) {
+           for (nzero=0; nzero<numSec/3; nzero++) {
              if (++counter < numMul) {
-               nt = np+nm+nz;
+               nt = npos+nneg+nzero;
                if ( (nt>=1) && (nt<=numSec) ) {
                  test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                  dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -426,15 +425,14 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
        return;
      }
  
-   outOfLoop:           //  <------------------------------------------------
+  outOfLoop:           //  <------------------------------------------------
     
-   ran = G4UniformRand();
-   if( targetCode == protonCode)
-     {
-       if( np == nm)
+  ran = G4UniformRand();
+  if (targetCode == protonCode) {
+       if( npos == nneg)
          { 
          }
-       else if (np == (nm+1))
+       else if (npos == (nneg+1))
          {
            if( ran < 0.25)
              {
@@ -462,10 +460,8 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
                pv[1] = Neutron;
              }
          }   
-     }  
-   else
-     {
-       if (np == nm)
+  } else {
+       if (npos == nneg)
          {
            if (ran < 0.5) 
              {
@@ -481,7 +477,7 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
                pv[1] = Proton;
              }  
          }  
-       else if (np == (nm-1))
+       else if (npos == (nneg-1))
          {  
            pv[1] = Proton;
          } 
@@ -496,58 +492,38 @@ G4HESigmaPlusInelastic::FirstIntInCasSigmaPlus(G4bool& inElastic,
                pv[0] = Lambda;
              }   
          }
-     }      
+  }      
 
-
-   nt = np + nm + nz;
-   while ( nt > 0)
-       {
-         G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
-            { 
-              if( np > 0 ) 
-                { pv[vecLen++] = PionPlus;
-                  np--;
-                }
-            }
-         else if ( ran < (G4double)(np+nm)/nt)
-            {   
-              if( nm > 0 )
-                { 
-                  pv[vecLen++] = PionMinus;
-                  nm--;
-                }
-            }
-         else
-            {
-              if( nz > 0 )
-                { 
-                  pv[vecLen++] = PionZero;
-                  nz--;
-                }
-            }
-         nt = np + nm + nz;
-       } 
-   if (verboseLevel > 1)
-      {
-        G4cout << "Particles produced: " ;
-        G4cout << pv[0].getName() << " " ;
-        G4cout << pv[1].getName() << " " ;
-        for (i=2; i < vecLen; i++)   
-            { 
-              G4cout << pv[i].getName() << " " ;
-            }
-         G4cout << G4endl;
+  nt = npos + nneg + nzero;
+  while (nt > 0) {
+    G4double rnd = G4UniformRand();
+    if (rnd < (G4double)npos/nt) { 
+      if (npos > 0) {
+        pv[vecLen++] = PionPlus;
+        npos--;
       }
-   return;
- }
-
-
-
-
-
-
-
+    } else if (rnd < (G4double)(npos+nneg)/nt) {   
+      if (nneg > 0) { 
+        pv[vecLen++] = PionMinus;
+        nneg--;
+      }
+    } else {
+      if (nzero > 0) { 
+        pv[vecLen++] = PionZero;
+        nzero--;
+      }
+    }
+    nt = npos + nneg + nzero;
+  }
 
+  if (verboseLevel > 1) {
+    G4cout << "Particles produced: " ;
+    G4cout << pv[0].getName() << " " ;
+    G4cout << pv[1].getName() << " " ;
+    for (i = 2; i < vecLen; i++) G4cout << pv[i].getName() << " " ;
+    G4cout << G4endl;
+  }
 
+  return;
+}
 
