@@ -23,11 +23,7 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4HEXiZeroInelastic.cc,v 1.17 2010-11-29 05:44:44 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
-
-#include "globals.hh"
-#include "G4ios.hh"
+// $Id$
 
 // G4 Process: Gheisha High Energy Collision model.
 // This includes the high energy cascading model, the two-body-resonance model
@@ -38,7 +34,9 @@
 // H. Fesefeldt, RWTH-Aachen, 23-October-1996
  
 #include "G4HEXiZeroInelastic.hh"
-
+#include "globals.hh"
+#include "G4ios.hh"
+#include "G4PhysicalConstants.hh"
 
 void G4HEXiZeroInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -204,18 +202,17 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
 // protons/neutrons by kaons or strange baryons according to the average
 // multiplicity per inelastic reaction.
 {
-  static const G4double expxu = std::log(MAXFLOAT); // upper bound for arg. of exp
-  static const G4double expxl = -expxu;             // lower bound for arg. of exp
+  static const G4double expxu = 82.;     // upper bound for arg. of exp
+  static const G4double expxl = -expxu;  // lower bound for arg. of exp
 
   static const G4double protb = 0.7;
   static const G4double neutb = 0.7;              
-  static const G4double     c = 1.25;
+  static const G4double c = 1.25;
 
   static const G4int numMul = 1200;
   static const G4int numSec = 60;
 
   G4int protonCode = Proton.getCode();
-
   G4int targetCode = targetParticle.getCode();
   G4double incidentTotalMomentum = incidentParticle.getTotalMomentum();
 
@@ -224,68 +221,61 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
   static G4double neutmul[numMul], neutnorm[numSec];  // neutron constants
 
   //  misc. local variables
-  //  np = number of pi+,  nm = number of pi-,  nz = number of pi0
+  //  npos = number of pi+,  nneg = number of pi-,  nzero = number of pi0
 
-  G4int i, counter, nt, np, nm, nz;
+  G4int i, counter, nt, npos, nneg, nzero;
 
-   if( first ) 
-     {     // compute normalization constants, this will only be done once
-       first = false;
-       for( i=0; i<numMul; i++ )protmul[i]  = 0.0;
-       for( i=0; i<numSec; i++ )protnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<(numSec/3); np++ ) 
-          {
-            for( nm=std::max(0,np-2); nm<=np; nm++ ) 
-               {
-                 for( nz=0; nz<numSec/3; nz++ ) 
-                    {
-                      if( ++counter < numMul ) 
-                        {
-                          nt = np+nm+nz;
-                          if( (nt>0) && (nt<=numSec) ) 
-                            {
-                              protmul[counter] = pmltpc(np,nm,nz,nt,protb,c);
-                              protnorm[nt-1] += protmul[counter];
-                            }
-                        }
-                    }
-               }
+  if (first) {
+    // compute normalization constants, this will only be done once
+    first = false;
+    for (i = 0; i < numMul; i++) protmul[i] = 0.0;
+    for (i = 0; i < numSec; i++) protnorm[i] = 0.0;
+    counter = -1;
+    for (npos = 0; npos < (numSec/3); npos++) {
+      for (nneg = std::max(0,npos-2); nneg <= npos; nneg++) {
+        for (nzero = 0; nzero < numSec/3; nzero++) {
+          if (++counter < numMul) {
+            nt = npos+nneg+nzero;
+            if ((nt>0) && (nt<=numSec) ) {
+              protmul[counter] = pmltpc(npos,nneg,nzero,nt,protb,c);
+              protnorm[nt-1] += protmul[counter];
+            }
           }
-       for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
-       for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
-       counter = -1;
-       for( np=0; np<numSec/3; np++ ) 
+        }
+      }
+    }
+
+    for( i=0; i<numMul; i++ )neutmul[i]  = 0.0;
+    for( i=0; i<numSec; i++ )neutnorm[i] = 0.0;
+    counter = -1;
+       for( npos=0; npos<numSec/3; npos++ ) 
           {
-            for( nm=std::max(0,np-1); nm<=(np+1); nm++ ) 
+            for( nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++ ) 
                {
-                 for( nz=0; nz<numSec/3; nz++ ) 
+                 for( nzero=0; nzero<numSec/3; nzero++ ) 
                     {
                       if( ++counter < numMul ) 
                         {
-                          nt = np+nm+nz;
+                          nt = npos+nneg+nzero;
                           if( (nt>0) && (nt<=numSec) ) 
                             {
-                               neutmul[counter] = pmltpc(np,nm,nz,nt,neutb,c);
+                               neutmul[counter] = pmltpc(npos,nneg,nzero,nt,neutb,c);
                                neutnorm[nt-1] += neutmul[counter];
                             }
                         }
                     }
                }
           }
-       for( i=0; i<numSec; i++ ) 
-          {
-            if( protnorm[i] > 0.0 )protnorm[i] = 1.0/protnorm[i];
-            if( neutnorm[i] > 0.0 )neutnorm[i] = 1.0/neutnorm[i];
-          }
-     }                                          // end of initialization
-
+    for (i = 0; i < numSec; i++) {
+      if (protnorm[i] > 0.0) protnorm[i] = 1.0/protnorm[i];
+      if (neutnorm[i] > 0.0) neutnorm[i] = 1.0/neutnorm[i];
+    }
+  }  // end of initialization
          
-                                              // initialize the first two places
-                                              // the same as beam and target                                    
-   pv[0] = incidentParticle;
-   pv[1] = targetParticle;
-   vecLen = 2;
+  // initialize the first two places the same as beam and target                                    
+  pv[0] = incidentParticle;
+  pv[1] = targetParticle;
+  vecLen = 2;
 
    if( !inElastic ) 
      {                                     // quasi-elastic scattering, no pions produced
@@ -378,7 +368,7 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
 
                                                   //   inelastic scattering
 
-   np = 0; nm = 0; nz = 0;
+   npos = 0; nneg = 0; nzero = 0;
 
    // number of total particles vs. centre of mass Energy - 2*proton mass
    
@@ -405,11 +395,11 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
    if( targetCode == protonCode ) 
      {
        counter = -1;
-       for (np=0; np<numSec/3; np++) {
-         for (nm=std::max(0,np-2); nm<=np; nm++) {
-           for (nz=0; nz<numSec/3; nz++) {
+       for (npos=0; npos<numSec/3; npos++) {
+         for (nneg=std::max(0,npos-2); nneg<=npos; nneg++) {
+           for (nzero=0; nzero<numSec/3; nzero++) {
              if (++counter < numMul) {
-               nt = np+nm+nz;
+               nt = npos+nneg+nzero;
                if ( (nt>0) && (nt<=numSec) ) {
                  test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                  dum = (pi/anpn)*nt*protmul[counter]*protnorm[nt-1]/(2.0*n*n);
@@ -433,11 +423,11 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
    else   
      {                                         // target must be a neutron
        counter = -1;
-       for (np=0; np<numSec/3; np++) {
-         for (nm=std::max(0,np-1); nm<=(np+1); nm++) {
-           for (nz=0; nz<numSec/3; nz++) {
+       for (npos=0; npos<numSec/3; npos++) {
+         for (nneg=std::max(0,npos-1); nneg<=(npos+1); nneg++) {
+           for (nzero=0; nzero<numSec/3; nzero++) {
              if (++counter < numMul) {
-               nt = np+nm+nz;
+               nt = npos+nneg+nzero;
                if ( (nt>=1) && (nt<=numSec) ) {
                  test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
                  dum = (pi/anpn)*nt*neutmul[counter]*neutnorm[nt-1]/(2.0*n*n);
@@ -458,16 +448,18 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
        return;
      }
  
-   outOfLoop:           //  <----------------------------------------------------   
+  outOfLoop:           //  <----------------------------------------------------   
     
-                                                   // in the following we do not consider
-   ran = G4UniformRand();                          // strangeness transfer in high multiplicity 
-   if( targetCode == protonCode)                   // events. YK combinations are added in 
-     {                                             // StrangeParticlePairProduction
-       if( np == nm)
+  // in the following we do not consider
+  // strangeness transfer in high multiplicity
+  // events. YK combinations are added in
+  // StrangeParticlePairProduction
+  ran = G4UniformRand(); 
+  if (targetCode == protonCode) {
+       if( npos == nneg)
          { 
          }
-       else if (np == (nm+1))
+       else if (npos == (nneg+1))
          {
            if( ran < 0.50)
              {
@@ -483,10 +475,8 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
            pv[0] = XiMinus;
            pv[1] = Neutron;
          }   
-     }  
-   else
-     {
-       if (np == nm)
+  } else {
+       if (npos == nneg)
          {
            if (ran < 0.5) 
              {
@@ -497,7 +487,7 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
                pv[1] = Proton;
              }  
          }  
-       else if (np == (nm-1))
+       else if (npos == (nneg-1))
          {  
            pv[1] = Proton;
          } 
@@ -505,58 +495,38 @@ G4HEXiZeroInelastic::FirstIntInCasXiZero(G4bool& inElastic,
          {
            pv[0] = XiMinus;
          }
-     }      
+  }      
 
-
-   nt = np + nm + nz;
-   while ( nt > 0)
-       {
-         G4double ran = G4UniformRand();
-         if ( ran < (G4double)np/nt)
-            { 
-              if( np > 0 ) 
-                { pv[vecLen++] = PionPlus;
-                  np--;
-                }
-            }
-         else if ( ran < (G4double)(np+nm)/nt)
-            {   
-              if( nm > 0 )
-                { 
-                  pv[vecLen++] = PionMinus;
-                  nm--;
-                }
-            }
-         else
-            {
-              if( nz > 0 )
-                { 
-                  pv[vecLen++] = PionZero;
-                  nz--;
-                }
-            }
-         nt = np + nm + nz;
-       } 
-   if (verboseLevel > 1)
-      {
-        G4cout << "Particles produced: " ;
-        G4cout << pv[0].getCode() << " " ;
-        G4cout << pv[1].getCode() << " " ;
-        for (i=2; i < vecLen; i++)   
-            { 
-              G4cout << pv[i].getCode() << " " ;
-            }
-         G4cout << G4endl;
+  nt = npos + nneg + nzero;
+  while (nt > 0) {
+    G4double rnd = G4UniformRand();
+    if (rnd < (G4double)npos/nt) { 
+      if (npos > 0) {
+        pv[vecLen++] = PionPlus;
+        npos--;
       }
-   return;
- }
-
-
-
-
-
-
-
-
+    } else if (rnd < (G4double)(npos+nneg)/nt) {   
+      if (nneg > 0) { 
+        pv[vecLen++] = PionMinus;
+        nneg--;
+      }
+    } else {
+      if (nzero > 0) { 
+        pv[vecLen++] = PionZero;
+        nzero--;
+      }
+    }
+    nt = npos + nneg + nzero;
+  }
+ 
+  if (verboseLevel > 1) {
+    G4cout << "Particles produced: " ;
+    G4cout << pv[0].getCode() << " " ;
+    G4cout << pv[1].getCode() << " " ;
+    for ( i = 2; i < vecLen; i++) G4cout << pv[i].getCode() << " " ;
+    G4cout << G4endl;
+  }
 
+  return;
+}
 
