@@ -30,8 +30,6 @@
 // Sylvie Leray, CEA
 // Joseph Cugnon, University of Liege
 //
-// INCL++ revision: v5.0_rc3
-//
 #define INCLXX_IN_GEANT4_MODE 1
 
 #include "globals.hh"
@@ -39,8 +37,8 @@
 /*
  * G4INCLNucleus.cc
  *
- *  Created on: Jun 5, 2009
- *      Author: Pekka Kaitaniemi
+ *  \date Jun 5, 2009
+ * \author Pekka Kaitaniemi
  */
 
 #ifndef G4INCLNucleus_hh
@@ -50,17 +48,16 @@
 #include "G4INCLLogger.hh"
 #include "G4INCLParticle.hh"
 #include "G4INCLIAvatar.hh"
-#include "G4INCLRandom.hh"
 #include "G4INCLNucleus.hh"
-#include "G4INCLNuclearDensityFactory.hh"
-#include "G4INCLNuclearPotentialConstant.hh"
-#include "G4INCLNuclearPotentialIsospin.hh"
-#include "G4INCLNuclearPotentialEnergyIsospin.hh"
 #include "G4INCLKinematicsUtils.hh"
 #include "G4INCLDecayAvatar.hh"
-#include "G4INCLRootFinder.hh"
 #include "G4INCLCluster.hh"
 #include "G4INCLClusterDecay.hh"
+#include "G4INCLDeJongSpin.hh"
+#include "G4INCLNuclearPotentialEnergyIsospinSmooth.hh"
+#include "G4INCLNuclearPotentialEnergyIsospin.hh"
+#include "G4INCLNuclearPotentialIsospin.hh"
+#include "G4INCLNuclearPotentialConstant.hh"
 #include <iterator>
 #include <cstdlib>
 #include <sstream>
@@ -68,172 +65,90 @@
 
 namespace G4INCL {
 
-  Nucleus::Nucleus(G4int mass, G4int charge, Config const * const conf)
-    :theZ(charge), theA(mass),
+  Nucleus::Nucleus(G4int mass, G4int charge, Config const * const conf, const G4double universeRadius)
+    : Cluster(charge,mass),
      theInitialZ(charge), theInitialA(mass),
-     forcedTransparent(false),
      theNpInitial(0), theNnInitial(0),
-     theExcitationEnergy(0.),
      initialInternalEnergy(0.),
      incomingAngularMomentum(0.,0.,0.), incomingMomentum(0.,0.,0.),
-     theSpin(0.,0.,0.), theRecoilMomentum(0.,0.,0.),
      initialCenterOfMass(0.,0.,0.),
-     remnant(true)
+     remnant(true),
+     blockedDelta(NULL),
+     initialEnergy(0.),
+     tryCN(false),
+     forceTransparent(false),
+     projectileZ(0),
+     projectileA(0),
+     theUniverseRadius(universeRadius),
+     isNucleusNucleus(false),
+     theProjectileRemnant(NULL),
+     theDensity(NULL),
+     thePotential(NULL)
   {
-    theDensity = NuclearDensityFactory::createDensity(mass, charge);
-
     PotentialType potentialType;
     G4bool pionPotential;
     if(conf) {
       potentialType = conf->getPotentialType();
       pionPotential = conf->getPionPotential();
     } else { // By default we don't use energy dependent
-	     // potential. This is convenient for some tests.
+      // potential. This is convenient for some tests.
       potentialType = IsospinPotential;
       pionPotential = true;
     }
     switch(potentialType) {
+      case IsospinEnergySmoothPotential:
+        thePotential = new NuclearPotential::NuclearPotentialEnergyIsospinSmooth(theA, theZ, pionPotential);
+        break;
       case IsospinEnergyPotential:
-        thePotential = new NuclearPotential::NuclearPotentialEnergyIsospin(theDensity, pionPotential);
+        thePotential = new NuclearPotential::NuclearPotentialEnergyIsospin(theA, theZ, pionPotential);
         break;
       case IsospinPotential:
-        thePotential = new NuclearPotential::NuclearPotentialIsospin(theDensity, pionPotential);
+        thePotential = new NuclearPotential::NuclearPotentialIsospin(theA, theZ, pionPotential);
         break;
       case ConstantPotential:
-        thePotential = new NuclearPotential::NuclearPotentialConstant(theDensity, pionPotential);
+        thePotential = new NuclearPotential::NuclearPotentialConstant(theA, theZ, pionPotential);
         break;
       default:
         FATAL("Unrecognized potential type at Nucleus creation." << std::endl);
-        std::exit(EXIT_FAILURE);
         break;
     }
 
+    ParticleTable::setProtonSeparationEnergy(thePotential->getSeparationEnergy(Proton));
+    ParticleTable::setNeutronSeparationEnergy(thePotential->getSeparationEnergy(Neutron));
+
+    theDensity = NuclearDensityFactory::createDensity(theA, theZ);
+
+    theParticleSampler->setPotential(thePotential);
+    theParticleSampler->setDensity(theDensity);
+
+    if(theUniverseRadius<0)
+      theUniverseRadius = theDensity->getMaximumRadius();
     theStore = new Store(conf);
     toBeUpdated.clear();
-    blockedDelta = NULL;
   }
 
   Nucleus::~Nucleus() {
     delete theStore;
     delete thePotential;
-    delete theDensity;
+    /* We don't delete the density here any more -- the Factory is caching them
+    delete theDensity;*/
   }
 
-  void Nucleus::initializeParticles()
-  {
-    G4INCL::ParticleType type = G4INCL::Proton;
-    for(G4int i = 1; i <= theA; ++i) {
-      // DEBUG("Creating particle " << i << std::endl);
-      if(i == (theZ + 1)) { // Nucleons [Z+1..A] are neutrons
-        type = G4INCL::Neutron;
-      }
+  void Nucleus::initializeParticles() {
+    // Reset the variables connected with the projectile remnant
+    delete theProjectileRemnant;
+    theProjectileRemnant = NULL;
 
-      const G4double pFermi = thePotential->getFermiMomentum(type);
-      ThreeVector momentum = Random::sphereVector(pFermi);
-      G4double P = momentum.mag()/pFermi;
-      ThreeVector position = Random::sphereVector(theDensity->getMaxRFromP(P));
-      Particle *p = new Particle(type, momentum, position);
-      updatePotentialEnergy(p);
-      //    p->makeParticipant(); // Force the particle to become a participant immediately (for testing)
-      theStore->add(p);
+    Cluster::initializeParticles();
+    for(ParticleIter i = particles.begin(); i != particles.end(); ++i) {
+      updatePotentialEnergy(*i);
+      theStore->add(*i);
     }
+    particles.clear();
     initialInternalEnergy = computeTotalEnergy();
-    initialCenterOfMass = computeCenterOfMass();
+    initialCenterOfMass = thePosition;
   }
 
-  G4double Nucleus::getTransmissionProbability(Particle const * const particle) {
-    //        NOUVEAU BARR RELATIVISTE ATTENTION AUX ENTREES SORTIES!
-    //      (06/2005)
-    //
-    //  ATTENTION ICI BARR de version AB different de version TA ...et l'appel est
-    //  probablement version TA!
-    //    BARR=TRANSMISSION PROBABILITY FOR A PARTICLE (Nucleon, cluster or
-    //    pion) of kinetic energy E on the edge of the (attractive) well of
-    //    depth V0 felt by the particle.
-    //          IZ is the isospin of the particle,
-    //          IZN the instantaneous charge of the nucleus and R the radius of
-    //        the well.
-    //          IA is the mass number of the particle, and MRE its mass energy.
-    //
-    //      Modified 9/10/2002 for clusters (d,t,3He,4He) (IZ=isospin,IA=A)
-    //      IZ must be correct so that charge Q=(IA+IZ)/2.
-    //      Modified 4/2004 for relativistic expressions and pions.
-
-    G4double E = particle->getKineticEnergy();
-
-    G4int izn = theZ;
-    G4int iq = particle->getZ();
-
-    G4double v0ia = particle->getPotentialEnergy();
-    /* This isn't really a radius, it's the poG4int where we wish to compute the
-     * value of the barrier. */
-    G4double r = theDensity->getTransmissionRadius(particle);
-
-    G4double barr = 0.0;
-    G4double b = 0.0, px = 0.0, g = 0.0;
-    G4double x = 0.0;
-
-    G4double mre = particle->getMass();
-
-    if (E > v0ia) goto barr12;
-    return 0.0;
-
-barr12:
-    x=std::sqrt((2.*mre*E+E*E)*(2.*mre*(E-v0ia)+std::pow(E-v0ia, 2)));
-    barr=4.*x/(2.*mre*(2.*E-v0ia)+E*E+std::pow(E-v0ia, 2)+2.*x);
-    if (iq > 0 && iq < izn) goto barr22;
-    return barr;
-
-barr22:
-    b=iq*(izn-iq)*1.44/r;
-    px=std::sqrt((E-v0ia)/b);
-
-    if (px < 1.0) goto barr32;
-    return barr;
-
-barr32:
-    g=iq*(izn-iq)/137.03*std::sqrt(2.*mre/(E-v0ia)/(1.+(E-v0ia)/2./mre))
-      *(std::acos(px)-px*std::sqrt(1.-px*px));
-    if (g > 35.) {
-      barr=0.;
-    } else {
-      barr=barr*std::exp(-2.*g);
-    }
-    return barr;
-  }
-
-  /*
-    G4double Nucleus::getTransmissionProbability(Particle *p) {
-    //    const G4double energy = p->getEnergy() - p->getMass();
-    const G4double energy = p->getKineticEnergy();
-    const G4double V0 = 45.0; // FIXME:
-    
-
-    if(energy <= V0) return 0.0;
-
-    const G4double x = std::sqrt(energy * (energy - V0));
-    const G4double barr = (4.0*x/(energy + energy - V0 + x + x));
-
-    if(p->getZ() <= 0) return barr;
-
-    const G4double b = theZ*1.44/(getRadius() * getRadius());
-    const G4double px = std::sqrt((energy - V0)/b);
-    
-    if(px >= 1.0) return barr;
-
-    const G4double g = theZ/137.03 * std::sqrt(2.0*ProtonMass/(energy - V0))
-    * (std::acos(px) - px*std::sqrt(1.0 - px*px));
-
-    if(g > 35.0) {
-    return 0.0;
-    } else {
-    return barr * std::exp(-2.0*g);
-    }
-
-    return 0.0;
-    }
-  */
-
   std::string Nucleus::dump() {
     std::stringstream ss;
     ss <<"(list ;; List of participants " << std::endl;
@@ -257,7 +172,7 @@ barr32:
     FinalStateValidity const validity = finalstate->getValidity();
     if(validity == ValidFS) {
 
-      ParticleList created = finalstate->getCreatedParticles();
+      ParticleList const &created = finalstate->getCreatedParticles();
       for(ParticleIter iter = created.begin(); iter != created.end(); ++iter) {
         theStore->add((*iter));
         if(!(*iter)->isOutOfWell()) {
@@ -266,24 +181,24 @@ barr32:
         }
       }
 
-      ParticleList deleted = finalstate->getDestroyedParticles();
+      ParticleList const &deleted = finalstate->getDestroyedParticles();
       for(ParticleIter iter = deleted.begin(); iter != deleted.end(); ++iter) {
         theStore->particleHasBeenDestroyed((*iter)->getID());
       }
 
-      ParticleList modified = finalstate->getModifiedParticles();
+      ParticleList const &modified = finalstate->getModifiedParticles();
       for(ParticleIter iter = modified.begin(); iter != modified.end(); ++iter) {
         theStore->particleHasBeenUpdated((*iter)->getID());
         totalEnergy += (*iter)->getEnergy() - (*iter)->getPotentialEnergy();
         toBeUpdated.push_back((*iter)); // Particle is modified so we have to create new avatars for it.
       }
 
-      ParticleList out = finalstate->getOutgoingParticles();
+      ParticleList const &out = finalstate->getOutgoingParticles();
       for(ParticleIter iter = out.begin(); iter != out.end(); ++iter) {
         if((*iter)->isCluster()) {
 	  Cluster *clusterOut = dynamic_cast<Cluster*>((*iter));
-          ParticleList const *components = clusterOut->getParticles();
-          for(ParticleIter in = components->begin(); in != components->end(); ++in)
+          ParticleList const components = clusterOut->getParticles();
+          for(ParticleIter in = components.begin(); in != components.end(); ++in)
             theStore->particleHasBeenEjected((*in)->getID());
         } else {
           theStore->particleHasBeenEjected((*iter)->getID());
@@ -295,17 +210,38 @@ barr32:
         (*iter)->setEmissionTime(theStore->getBook()->getCurrentTime());
       }
 
-      if(std::abs(totalEnergy - finalstate->getTotalEnergyBeforeInteraction()) > 0.1) {
-        ERROR("Energy nonconservation! Energy at the beginning of the event = "
-            << finalstate->getTotalEnergyBeforeInteraction()
-            <<" and after G4interaction = "
-            << totalEnergy << std::endl
-            << finalstate->prG4int());
+      ParticleList const &entering = finalstate->getEnteringParticles();
+      for(ParticleIter iter = entering.begin(); iter != entering.end(); ++iter) {
+        insertParticle(*iter);
+        totalEnergy += (*iter)->getEnergy() - (*iter)->getPotentialEnergy();
+        toBeUpdated.push_back((*iter)); // Particle is modified so we have to create new avatars for it.
       }
     } else if(validity == PauliBlockedFS) {
       blockedDelta = finalstate->getBlockedDelta();
+    } else if(validity == ParticleBelowFermiFS) {
+      DEBUG("A Particle is entering below the Fermi sea:" << std::endl << finalstate->print() << std::endl);
+      tryCN = true;
+      ParticleList const &entering = finalstate->getEnteringParticles();
+      for(ParticleIter iter = entering.begin(); iter != entering.end(); ++iter) {
+        insertParticle(*iter);
+      }
+    } else if(validity == ParticleBelowZeroFS) {
+      DEBUG("A Particle is entering below zero energy:" << std::endl << finalstate->print() << std::endl);
+      forceTransparent = true;
+      ParticleList const &entering = finalstate->getEnteringParticles();
+      for(ParticleIter iter = entering.begin(); iter != entering.end(); ++iter) {
+        insertParticle(*iter);
+      }
     }
 
+    if(validity==ValidFS &&
+        std::abs(totalEnergy - finalstate->getTotalEnergyBeforeInteraction()) > 0.1) {
+      ERROR("Energy nonconservation! Energy at the beginning of the event = "
+          << finalstate->getTotalEnergyBeforeInteraction()
+          <<" and after interaction = "
+          << totalEnergy << std::endl
+          << finalstate->print());
+    }
   }
 
   void Nucleus::propagateParticles(G4double /*step*/) {
@@ -316,10 +252,10 @@ barr32:
     G4double totalEnergy = 0.0;
     ParticleList inside = theStore->getParticles();
     for(ParticleIter p=inside.begin(); p!=inside.end(); ++p) {
-      if((*p)->isNucleon()) // Ugly: we should calculate everything using total energies! (FIXME)
+      if((*p)->isNucleon()) // Ugly: we should calculate everything using total energies!
         totalEnergy += (*p)->getKineticEnergy() - (*p)->getPotentialEnergy();
-      else if((*p)->isResonance()) // This is even uglier (why Proton, for instance?!)
-        totalEnergy += (*p)->getEnergy() - (*p)->getPotentialEnergy() - ParticleTable::getMass(Proton);
+      else if((*p)->isResonance())
+        totalEnergy += (*p)->getEnergy() - (*p)->getPotentialEnergy() - ParticleTable::effectiveNucleonMass;
       else
         totalEnergy += (*p)->getEnergy() - (*p)->getPotentialEnergy();
     }
@@ -337,24 +273,22 @@ barr32:
     }
 
     // Compute the recoil momentum and angular momentum
-    theRecoilMomentum = incomingMomentum;
+    theMomentum = incomingMomentum;
     theSpin = incomingAngularMomentum;
 
     ParticleList outgoing = theStore->getOutgoingParticles();
     for(ParticleIter p=outgoing.begin(); p!=outgoing.end(); ++p)
     {
-      theRecoilMomentum -= (*p)->getMomentum();
+      theMomentum -= (*p)->getMomentum();
       theSpin -= (*p)->getAngularMomentum();
     }
 
     // Subtract orbital angular momentum
-    theCenterOfMass = computeCenterOfMass();
-    theSpin -= (theCenterOfMass-initialCenterOfMass).vector(theRecoilMomentum);
+    thePosition = computeCenterOfMass();
+    theSpin -= (thePosition-initialCenterOfMass).vector(theMomentum);
 
-    theExcitationEnergy = computeExcitationEnergy();
-
-    G4double remnantMass = ParticleTable::getMass(theA,theZ) + theExcitationEnergy;
-    theRecoilEnergy = KinematicsUtils::energy(theRecoilMomentum, remnantMass) - remnantMass;
+    setMass(ParticleTable::getTableMass(theA,theZ) + theExcitationEnergy);
+    adjustEnergyFromMomentum();
     remnant=true;
   }
 
@@ -378,7 +312,7 @@ barr32:
     return totalEnergy - initialInternalEnergy - separationEnergies;
   }
 
-  std::string Nucleus::prG4int()
+  std::string Nucleus::print()
   {
     std::stringstream ss;
     ss << "Particles in the nucleus:" << std::endl
@@ -387,58 +321,21 @@ barr32:
     ParticleList participants = theStore->getParticipants();
     for(ParticleIter p = participants.begin(); p != participants.end(); ++p) {
       ss << "index = " << counter << std::endl
-        << (*p)->prG4int();
+        << (*p)->print();
       counter++;
     }
     ss <<"Spectators:" << std::endl;
     ParticleList spectators = theStore->getSpectators();
     for(ParticleIter p = spectators.begin(); p != spectators.end(); ++p)
-      ss << (*p)->prG4int();
+      ss << (*p)->print();
     ss <<"Outgoing:" << std::endl;
     ParticleList outgoing = theStore->getOutgoingParticles();
     for(ParticleIter p = outgoing.begin(); p != outgoing.end(); ++p)
-      ss << (*p)->prG4int();
+      ss << (*p)->print();
 
     return ss.str();
   }
 
-  Particle *Nucleus::particleEnters(Particle *particle) {
-
-    // TODO: this is the place to add refraction
-
-    // Add the nuclear potential to the kinetic energy when entering the
-    // nucleus
-
-    class IncomingEFunctor : public RootFunctor {
-      public:
-        IncomingEFunctor(Particle * const p, NuclearPotential::INuclearPotential const * const np) :
-          theParticle(p), thePotential(np) {
-            theEnergy=theParticle->getEnergy();
-          }
-        ~IncomingEFunctor() {}
-        G4double operator()(const G4double v) const {
-          theParticle->setEnergy(theEnergy + v);
-          theParticle->setPotentialEnergy(v);
-          // Scale the particle momentum
-          theParticle->adjustMomentumFromEnergy();
-          return v - thePotential->computePotentialEnergy(theParticle);
-        }
-        void cleanUp(const G4bool /*success*/) const {}
-      private:
-        Particle *theParticle;
-        NuclearPotential::INuclearPotential const *thePotential;
-        G4double theEnergy;
-    } theIncomingEFunctor(particle,thePotential);
-
-    G4double v = thePotential->computePotentialEnergy(particle);
-    G4bool success = RootFinder::solve(&theIncomingEFunctor, v);
-    if(!success) {
-      WARN("Couldn't compute the potential for incoming particle, root-finding algorithm failed." << std::endl);
-    }
-
-    return particle;
-  }
-
   G4bool Nucleus::decayOutgoingDeltas() {
     ParticleList out = theStore->getOutgoingParticles();
     ParticleList deltas;
@@ -448,16 +345,47 @@ barr32:
     if(deltas.empty()) return false;
 
     for(ParticleIter i = deltas.begin(); i != deltas.end(); ++i) {
+      DEBUG("Decay outgoing delta particle:" << std::endl
+          << (*i)->print() << std::endl);
+      const ThreeVector beta = -(*i)->boostVector();
+      const G4double deltaMass = (*i)->getMass();
+
+      // Set the delta momentum to zero and sample the decay in the CM frame.
+      // This makes life simpler if we are using real particle masses.
+      (*i)->setMomentum(ThreeVector());
+      (*i)->setEnergy((*i)->getMass());
+
+      // Use a DecayAvatar
       IAvatar *decay = new DecayAvatar((*i), 0.0, NULL);
       FinalState *fs = decay->getFinalState();
-      ParticleList created = fs->getCreatedParticles();
-      for(ParticleIter j = created.begin(); j != created.end(); ++j) {
-          theStore->addToOutgoing(*j);
-          (*j)->setEmissionTime(theStore->getBook()->getCurrentTime());
-      }
+      Particle * const pion = fs->getCreatedParticles().front();
+      Particle * const nucleon = fs->getModifiedParticles().front();
+
+      // Adjust the decay momentum if we are using the real masses
+      const G4double decayMomentum = KinematicsUtils::momentumInCM(deltaMass,
+          nucleon->getTableMass(),
+          pion->getTableMass());
+      ThreeVector newMomentum = pion->getMomentum();
+      newMomentum *= decayMomentum / newMomentum.mag();
+
+      pion->setTableMass();
+      pion->setMomentum(newMomentum);
+      pion->adjustEnergyFromMomentum();
+      pion->setEmissionTime(theStore->getBook()->getCurrentTime());
+      pion->boost(beta);
+
+      nucleon->setTableMass();
+      nucleon->setMomentum(-newMomentum);
+      nucleon->adjustEnergyFromMomentum();
+      nucleon->setEmissionTime(theStore->getBook()->getCurrentTime());
+      nucleon->boost(beta);
+
+      theStore->addToOutgoing(pion);
+
       delete fs;
       delete decay;
     }
+
     return true;
   }
 
@@ -481,9 +409,11 @@ barr32:
 
     // Loop over the deltas, make them decay
     for(ParticleIter i = deltas.begin(); i != deltas.end(); ++i) {
-      // Create a forced-decay avatar. Note the last G4boolean parameter. Note
+      DEBUG("Decay inside delta particle:" << std::endl
+          << (*i)->print() << std::endl);
+      // Create a forced-decay avatar. Note the last boolean parameter. Note
       // also that if the remnant is unphysical we more or less explicitly give
-      // up energy conservation and CDPP by passing a NULL poG4inter for the
+      // up energy conservation and CDPP by passing a NULL pointer for the
       // nucleus.
       IAvatar *decay;
       if(unphysicalRemnant)
@@ -522,6 +452,7 @@ barr32:
 
     for(ParticleIter i = clusters.begin(); i != clusters.end(); ++i) {
       Cluster *cluster = dynamic_cast<Cluster*>(*i); // Can't avoid using a cast here
+      cluster->deleteParticles(); // Don't need them
       ParticleList decayProducts = ClusterDecay::decay(cluster);
       for(ParticleIter j = decayProducts.begin(); j!=decayProducts.end(); ++j)
         theStore->addToOutgoing(*j);
@@ -529,10 +460,24 @@ barr32:
     return true;
   }
 
+  G4bool Nucleus::decayMe() {
+    // Do the phase-space decay only if Z=0 or Z=A
+    if(theA<=1 || (theZ!=0 && theA!=theZ))
+      return false;
+
+    ParticleList decayProducts = ClusterDecay::decay(this);
+    for(ParticleIter j = decayProducts.begin(); j!=decayProducts.end(); ++j)
+      theStore->addToOutgoing(*j);
+
+    return true;
+  }
+
   void Nucleus::emitInsidePions() {
-    DEBUG("Forcing emissions of all pions in the nucleus. This probably violates energy"
-        << std::endl << "conservation (although the computation of the recoil kinematics might sweep this"
-        << std::endl << "under the carpet)." << std::endl);
+    /* Forcing emissions of all pions in the nucleus. This probably violates
+     * energy conservation (although the computation of the recoil kinematics
+     * might sweep this under the carpet).
+     */
+    WARN("Forcing emissions of all pions in the nucleus." << std::endl);
 
     // Emit the pions with this kinetic energy
     const G4double tinyPionEnergy = 0.1; // MeV
@@ -541,67 +486,59 @@ barr32:
     ParticleList inside = theStore->getParticles();
     for(ParticleIter i = inside.begin(); i != inside.end(); ++i) {
       if((*i)->isPion()) {
-        theZ -= (*i)->getZ();
         (*i)->setEmissionTime(theStore->getBook()->getCurrentTime());
-        if((*i)->getKineticEnergy() - (*i)->getPotentialEnergy() > 0.0)
-          (*i)->setEnergy((*i)->getEnergy() - (*i)->getPotentialEnergy());
+        // Correction for real masses
+        const G4double theQValueCorrection = (*i)->getEmissionQValueCorrection(theA,theZ);
+        const G4double kineticEnergyOutside = (*i)->getKineticEnergy() - (*i)->getPotentialEnergy() + theQValueCorrection;
+        (*i)->setTableMass();
+        if(kineticEnergyOutside > 0.0)
+          (*i)->setEnergy((*i)->getMass()+kineticEnergyOutside);
         else
           (*i)->setEnergy((*i)->getMass()+tinyPionEnergy);
         (*i)->adjustMomentumFromEnergy();
         (*i)->setPotentialEnergy(0.);
+        theZ -= (*i)->getZ();
         theStore->particleHasBeenEjected((*i)->getID());
         theStore->addToOutgoing(*i);
       }
     }
   }
 
-  Particle *Nucleus::particleLeaves(Particle *particle) {
-
-    // TODO: this is the place to add refraction
-
-    // Subtract the nuclear potential from the kinetic energy when leaving the
-    // nucleus
-    const G4double v = particle->getPotentialEnergy();
-
-    // Scaling factor for the particle momentum
-    const G4double gpsg = std::sqrt((std::pow(particle->getEnergy() - v, 2)
-          - particle->getMass() * particle->getMass())
-        / particle->getMomentum().mag2());
-    particle->setMomentum(particle->getMomentum() * gpsg);
-    particle->setEnergy(particle->getEnergy() - v);
-    particle->setPotentialEnergy(0.);
-
-    return particle;
-
-  }
-
   G4bool Nucleus::isEventTransparent() const {
 
-    if(isForcedTransparent()) return true;
+    // Forced transparent
+    if(forceTransparent)
+      return true;
 
-    ParticleList pL = theStore->getOutgoingParticles();
-    unsigned int nIncoming = theStore->getNumberOfIncomingParticles();
-
-    // If the number of outgoing particles is not equal to the number of
-    // incoming particles, the event is not a transparent.
-    if( pL.size() !=  nIncoming ) return false;
+    ParticleList const &pL = theStore->getOutgoingParticles();
+    G4int outZ = 0, outA = 0;
 
     // If any of the particles has undergone a collision, the event is not a
     // transparent.
     for(ParticleIter p = pL.begin(); p != pL.end(); ++p ) {
       if( (*p)->getNumberOfCollisions() != 0 ) return false;
       if( (*p)->getNumberOfDecays() != 0 ) return false;
+      outZ += (*p)->getZ();
+      outA += (*p)->getA();
     }
 
+    // Add the geometrical spectators to the Z and A count
+    if(theProjectileRemnant) {
+      outZ += theProjectileRemnant->getZ();
+      outA += theProjectileRemnant->getA();
+    }
+
+    if(outZ!=projectileZ || outA!=projectileA) return false;
+
     return true;
 
   }
 
   void Nucleus::computeOneNucleonRecoilKinematics() {
     // We should be here only if the nucleus contains only one nucleon
-    // assert(theStore->getParticles().size()==1);
+// assert(theStore->getParticles().size()==1);
 
-    DEBUG("Computing one-nucleon recoil kinematics" << std::endl);
+    ERROR("Computing one-nucleon recoil kinematics. We should never be here nowadays, cascade should stop earlier than this." << std::endl);
 
     // No excitation energy!
     theExcitationEnergy = 0.0;
@@ -635,9 +572,9 @@ barr32:
       // Can apply exact 2-body kinematics here. Keep the CM emission angle of
       // the first particle.
       Particle *p1 = outgoing.front(), *p2 = outgoing.back();
-      const ThreeVector boostVector = incomingMomentum / initialEnergy;
+      const ThreeVector aBoostVector = incomingMomentum / initialEnergy;
       // Boost to the initial CM
-      p1->boost(boostVector);
+      p1->boost(aBoostVector);
       const G4double sqrts = std::sqrt(initialEnergy*initialEnergy - incomingMomentum.mag2());
       const G4double pcm = KinematicsUtils::momentumInCM(sqrts, p1->getMass(), p2->getMass());
       const G4double scale = pcm/(p1->getMomentum().mag());
@@ -647,8 +584,8 @@ barr32:
       p1->adjustEnergyFromMomentum();
       p2->adjustEnergyFromMomentum();
       // Unboost
-      p1->boost(-boostVector);
-      p2->boost(-boostVector);
+      p1->boost(-aBoostVector);
+      p2->boost(-aBoostVector);
 
     } else {
 
@@ -656,7 +593,7 @@ barr32:
 
       const G4int maxIterations=8;
       G4double totalEnergy, energyScale;
-      G4double val=1.E+6, oldVal=1.E+6, oldOldVal=1.E+6, oldOldOldVal;
+      G4double val=1.E+100, oldVal=1.E+100, oldOldVal=1.E+100, oldOldOldVal;
       ThreeVector totalMomentum, deltaP;
       std::vector<ThreeVector> minMomenta;  // use it to store the particle momenta that minimize the merit function
 
@@ -740,7 +677,7 @@ barr32:
       }
 
       // We should have made at least one successful iteration here
-      // assert(minMomenta.size()==outgoing.size());
+// assert(minMomenta.size()==outgoing.size());
 
       // Apply the optimal momenta
       DEBUG("Applying the solution" << std::endl);
@@ -748,7 +685,7 @@ barr32:
       for(ParticleIter i=outgoing.begin(); i!=outgoing.end(); ++i, ++v) {
         (*i)->setMomentum(*v);
         (*i)->adjustEnergyFromMomentum();
-        DATABLOCK((*i)->prG4int());
+        DATABLOCK((*i)->print());
       }
 
     }
@@ -757,10 +694,83 @@ barr32:
 
   void Nucleus::fillEventInfo(EventInfo *eventInfo) {
     eventInfo->nParticles = 0;
+    G4bool isNucleonAbsorption = false;
+
+    G4bool isPionAbsorption = false;
+    // It is possible to have pion absorption event only if the
+    // projectile is pion.
+    if(eventInfo->projectileType == PiPlus ||
+       eventInfo->projectileType == PiMinus ||
+       eventInfo->projectileType == PiZero) {
+      isPionAbsorption = true;
+    }
+
+    // Forced CN
+    eventInfo->forcedCompoundNucleus = tryCN;
 
     // Outgoing particles
     ParticleList outgoingParticles = getStore()->getOutgoingParticles();
+
+    // Check if we have a nucleon absorption event: nucleon projectile
+    // and no ejected particles.
+    if(outgoingParticles.size() == 0 &&
+       (eventInfo->projectileType == Proton ||
+	eventInfo->projectileType == Neutron)) {
+      isNucleonAbsorption = true;
+    }
+
+    // Reset the remnant counter
+    eventInfo->nRemnants = 0;
+    eventInfo->history.clear();
+
     for( ParticleIter i = outgoingParticles.begin(); i != outgoingParticles.end(); ++i ) {
+      // If the particle is a cluster and has excitation energy, treat it as a cluster
+      if((*i)->isCluster()) {
+        Cluster const * const c = dynamic_cast<Cluster *>(*i);
+// assert(c);
+#ifdef INCLXX_IN_GEANT4_MODE
+        if(!c)
+          continue;
+#endif
+        const G4double eStar = c->getExcitationEnergy();
+        if(std::abs(eStar)>1E-10) {
+          if(eStar<0.) {
+            WARN("Negative excitation energy in outgoing cluster! EStar = " << eStar << std::endl);
+          }
+          eventInfo->ARem[eventInfo->nRemnants] = c->getA();
+          eventInfo->ZRem[eventInfo->nRemnants] = c->getZ();
+          eventInfo->EStarRem[eventInfo->nRemnants] = eStar;
+          ThreeVector remnantSpin = c->getSpin();
+          Float_t remnantSpinMag;
+          if(eventInfo->ARem[eventInfo->nRemnants]%2==0) { // even-A nucleus
+            remnantSpinMag = (G4int) (remnantSpin.mag()/PhysicalConstants::hc + 0.5);
+          } else { // odd-A nucleus
+            remnantSpinMag = ((G4int) (remnantSpin.mag()/PhysicalConstants::hc)) + 0.5;
+          }
+          remnantSpin *= remnantSpinMag/remnantSpin.mag();
+          eventInfo->JRem[eventInfo->nRemnants] = remnantSpinMag;
+          eventInfo->jxRem[eventInfo->nRemnants] = remnantSpin.getX();
+          eventInfo->jyRem[eventInfo->nRemnants] = remnantSpin.getY();
+          eventInfo->jzRem[eventInfo->nRemnants] = remnantSpin.getZ();
+          eventInfo->EKinRem[eventInfo->nRemnants] = c->getKineticEnergy();
+          ThreeVector mom = c->getMomentum();
+          eventInfo->pxRem[eventInfo->nRemnants] = mom.getX();
+          eventInfo->pyRem[eventInfo->nRemnants] = mom.getY();
+          eventInfo->pzRem[eventInfo->nRemnants] = mom.getZ();
+          eventInfo->thetaRem[eventInfo->nRemnants] = Math::toDegrees(mom.theta());
+          eventInfo->phiRem[eventInfo->nRemnants] = Math::toDegrees(mom.phi());
+          eventInfo->nRemnants++;
+          continue; // don't add it as a particle
+        }
+      }
+
+      // We have a pion absorption event only if the projectile is
+      // pion and there are no ejected pions.
+      if(isPionAbsorption) {
+        if((*i)->isPion()) {
+          isPionAbsorption = false;
+        }
+      }
       eventInfo->A[eventInfo->nParticles] = (*i)->getA();
       eventInfo->Z[eventInfo->nParticles] = (*i)->getZ();
       eventInfo->emissionTime[eventInfo->nParticles] = (*i)->getEmissionTime();
@@ -772,35 +782,34 @@ barr32:
       eventInfo->theta[eventInfo->nParticles] = Math::toDegrees(mom.theta());
       eventInfo->phi[eventInfo->nParticles] = Math::toDegrees(mom.phi());
       eventInfo->origin[eventInfo->nParticles] = -1;
-      //      std::strcpy(eventInfo->history[eventInfo->nParticles],"");
+      eventInfo->history.push_back("");
       eventInfo->nParticles++;
     }
-
+    eventInfo->nucleonAbsorption = isNucleonAbsorption;
+    eventInfo->pionAbsorption = isPionAbsorption;
     eventInfo->nCascadeParticles = eventInfo->nParticles;
 
     // Remnant characteristics
     if(hasRemnant()) {
-      eventInfo->nRemnants = 1;
-      eventInfo->ARem[0] = getA();
-      eventInfo->ZRem[0] = getZ();
-      eventInfo->EStarRem[0] = getExcitationEnergy();
-      if(eventInfo->EStarRem[0]<0.) {
-	WARN("Negative excitation energy! EStarRem = " << eventInfo->EStarRem[0] << std::endl);
+      eventInfo->ARem[eventInfo->nRemnants] = getA();
+      eventInfo->ZRem[eventInfo->nRemnants] = getZ();
+      eventInfo->EStarRem[eventInfo->nRemnants] = getExcitationEnergy();
+      if(eventInfo->EStarRem[eventInfo->nRemnants]<0.) {
+	WARN("Negative excitation energy! EStarRem = " << eventInfo->EStarRem[eventInfo->nRemnants] << std::endl);
       }
-      if(eventInfo->ARem[0]%2==0) { // even-A nucleus
-	eventInfo->JRem[0] = (G4int) (getSpin().mag()/hc + 0.5);
+      if(eventInfo->ARem[eventInfo->nRemnants]%2==0) { // even-A nucleus
+	eventInfo->JRem[eventInfo->nRemnants] = (G4int) (getSpin().mag()/PhysicalConstants::hc + 0.5);
       } else { // odd-A nucleus
-	eventInfo->JRem[0] = ((G4int) (getSpin().mag()/hc)) + 0.5;
+	eventInfo->JRem[eventInfo->nRemnants] = ((G4int) (getSpin().mag()/PhysicalConstants::hc)) + 0.5;
       }
-      eventInfo->EKinRem[0] = getRecoilEnergy();
-      ThreeVector mom = getRecoilMomentum();
-      eventInfo->pxRem[0] = mom.getX();
-      eventInfo->pyRem[0] = mom.getY();
-      eventInfo->pzRem[0] = mom.getZ();
-      eventInfo->thetaRem[0] = Math::toDegrees(mom.theta());
-      eventInfo->phiRem[0] = Math::toDegrees(mom.phi());
-    } else {
-      eventInfo->nRemnants = 0;
+      eventInfo->EKinRem[eventInfo->nRemnants] = getKineticEnergy();
+      ThreeVector mom = getMomentum();
+      eventInfo->pxRem[eventInfo->nRemnants] = mom.getX();
+      eventInfo->pyRem[eventInfo->nRemnants] = mom.getY();
+      eventInfo->pzRem[eventInfo->nRemnants] = mom.getZ();
+      eventInfo->thetaRem[eventInfo->nRemnants] = Math::toDegrees(mom.theta());
+      eventInfo->phiRem[eventInfo->nRemnants] = Math::toDegrees(mom.phi());
+      eventInfo->nRemnants++;
     }
 
     // Global counters, flags, etc.
@@ -815,6 +824,83 @@ barr32:
     eventInfo->nDecayAvatars = getStore()->getBook()->getAvatars(DecayAvatarType);
   }
 
+  Nucleus::ConservationBalance Nucleus::getConservationBalance(const EventInfo &theEventInfo, const G4bool afterRecoil) const {
+    ConservationBalance theBalance;
+    // Initialise balance variables with the incoming values
+    theBalance.Z = theEventInfo.Zp + theEventInfo.Zt;
+    theBalance.A = theEventInfo.Ap + theEventInfo.At;
+
+    theBalance.energy = getInitialEnergy();
+    theBalance.momentum = getIncomingMomentum();
+
+    // Process outgoing particles
+    ParticleList outgoingParticles = theStore->getOutgoingParticles();
+    for( ParticleIter i = outgoingParticles.begin(); i != outgoingParticles.end(); ++i ) {
+      theBalance.Z -= (*i)->getZ();
+      theBalance.A -= (*i)->getA();
+      // For outgoing clusters, the total energy automatically includes the
+      // excitation energy
+      theBalance.energy -= (*i)->getEnergy(); // Note that outgoing particles should have the real mass
+      theBalance.momentum -= (*i)->getMomentum();
+    }
+
+    // Remnant contribution, if present
+    if(hasRemnant()) {
+      theBalance.Z -= getZ();
+      theBalance.A -= getA();
+      theBalance.energy -= ParticleTable::getTableMass(getA(),getZ()) +
+        getExcitationEnergy();
+      if(afterRecoil)
+        theBalance.energy -= getKineticEnergy();
+      theBalance.momentum -= getMomentum();
+    }
+
+    return theBalance;
+  }
+
+  void Nucleus::useFusionKinematics() {
+    setEnergy(initialEnergy);
+    setMomentum(incomingMomentum);
+    setSpin(incomingAngularMomentum);
+    theExcitationEnergy = std::sqrt(theEnergy*theEnergy-theMomentum.mag2()) - getTableMass();
+    setMass(getTableMass() + theExcitationEnergy);
+  }
+
+  void Nucleus::finalizeProjectileRemnant(const G4double anEmissionTime) {
+    // Deal with the projectile remnant
+    if(theProjectileRemnant->getA()>1) {
+      // Set the mass
+      const G4double aMass = theProjectileRemnant->getInvariantMass();
+      theProjectileRemnant->setMass(aMass);
+
+      // Compute the excitation energy from the invariant mass
+      const G4double anExcitationEnergy = aMass
+        - ParticleTable::getTableMass(theProjectileRemnant->getA(), theProjectileRemnant->getZ());
+
+      // Set the excitation energy
+      theProjectileRemnant->setExcitationEnergy(anExcitationEnergy);
+
+      // Set the spin
+      theProjectileRemnant->setSpin(DeJongSpin::shoot(theProjectileRemnant->getNumberStoredComponents(), theProjectileRemnant->getA()));
+
+      // Set the emission time
+      theProjectileRemnant->setEmissionTime(anEmissionTime);
+
+      // Put it in the outgoing list
+      theStore->addToOutgoing(theProjectileRemnant);
+
+      // NULL theProjectileRemnant
+      theProjectileRemnant = NULL;
+    } else if(theProjectileRemnant->getA()==1) {
+      // Put the nucleon in the outgoing list
+      Particle *theNucleon = theProjectileRemnant->getParticles().front();
+      theStore->addToOutgoing(theNucleon);
+      // Delete the remnant
+      deleteProjectileRemnant();
+    } else
+      deleteProjectileRemnant();
+  }
+
 }
 
 #endif
