@@ -23,25 +23,28 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4LEKaonMinusInelastic.cc,v 1.15 2006-06-29 20:44:59 gunter Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // Hadronic Process: Low Energy KaonMinus Inelastic Process
 // J.L. Chuma, TRIUMF, 12-Feb-1997
-// J.P.Wellisch 23-Apr-97: bug-hunting (missing initialization of np,nm,nz
+// J.P.Wellisch 23-Apr-97: bug-hunting (missing initialization of npos,nneg,nzero
 //    fixed)
 // Modified by J.L.Chuma 30-Apr-97: added originalTarget for CalculateMomenta
- 
-#include "G4LEKaonMinusInelastic.hh"
-#include "Randomize.hh"
+
 #include <iostream>
 
+#include "G4LEKaonMinusInelastic.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
+#include "Randomize.hh"
 
 G4LEKaonMinusInelastic::G4LEKaonMinusInelastic(const G4String& name)
  :G4InelasticInteraction(name)
 {
   SetMinEnergy(0.0);
   SetMaxEnergy(25.*GeV);
+  G4cout << "WARNING: model G4LEKaonMinusInelastic is being deprecated and will\n"
+         << "disappear in Geant4 version 10.0"  << G4endl;
 }
 
 
@@ -72,8 +75,7 @@ G4LEKaonMinusInelastic::ApplyYourself(const G4HadProjectile& aTrack,
   }
 
   // create the target particle
-    
-  G4DynamicParticle *originalTarget = targetNucleus.ReturnTargetParticle();
+  G4DynamicParticle* originalTarget = targetNucleus.ReturnTargetParticle();
   G4ReactionProduct targetParticle( originalTarget->GetDefinition() );
     
   if (verboseLevel > 1) {
@@ -91,7 +93,6 @@ G4LEKaonMinusInelastic::ApplyYourself(const G4HadProjectile& aTrack,
     
   // Fermi motion and evaporation
   // As of Geant3, the Fermi energy calculation had not been done
-    
   G4double ek = originalIncident->GetKineticEnergy();
   G4double amas = originalIncident->GetDefinition()->GetPDGMass();
     
@@ -107,48 +108,46 @@ G4LEKaonMinusInelastic::ApplyYourself(const G4HadProjectile& aTrack,
   }
     
   // calculate black track energies
-    
-    tkin = targetNucleus.EvaporationEffects( ek );
-    ek -= tkin;
-    currentParticle.SetKineticEnergy( ek );
-    et = ek + amas;
-    p = std::sqrt( std::abs((et-amas)*(et+amas)) );
-    pp = currentParticle.GetMomentum().mag();
-    if( pp > 0.0 )
-    {
-      G4ThreeVector momentum = currentParticle.GetMomentum();
-      currentParticle.SetMomentum( momentum * (p/pp) );
-    }
+  tkin = targetNucleus.EvaporationEffects( ek );
+  ek -= tkin;
+  currentParticle.SetKineticEnergy( ek );
+  et = ek + amas;
+  p = std::sqrt( std::abs((et-amas)*(et+amas)) );
+  pp = currentParticle.GetMomentum().mag();
+  if (pp > 0.0) {
+    G4ThreeVector momentum = currentParticle.GetMomentum();
+    currentParticle.SetMomentum( momentum * (p/pp) );
+  }
 
-    G4ReactionProduct modifiedOriginal = currentParticle;
+  G4ReactionProduct modifiedOriginal = currentParticle;
 
-    currentParticle.SetSide( 1 ); // incident always goes in forward hemisphere
-    targetParticle.SetSide( -1 );  // target always goes in backward hemisphere
-    G4bool incidentHasChanged = false;
-    G4bool targetHasChanged = false;
-    G4bool quasiElastic = false;
-    G4FastVector<G4ReactionProduct,GHADLISTSIZE> vec;  // vec will contain the secondary particles
-    G4int vecLen = 0;
-    vec.Initialize( 0 );
+  currentParticle.SetSide(1); // incident always goes in forward hemisphere
+  targetParticle.SetSide(-1);  // target always goes in backward hemisphere
+  G4bool incidentHasChanged = false;
+  G4bool targetHasChanged = false;
+  G4bool quasiElastic = false;
+  G4FastVector<G4ReactionProduct,GHADLISTSIZE> vec;  // vec will contain the secondary particles
+  G4int vecLen = 0;
+  vec.Initialize(0);
     
-    const G4double cutOff = 0.1*MeV;
-    if( currentParticle.GetKineticEnergy() > cutOff )
-      Cascade( vec, vecLen,
-               originalIncident, currentParticle, targetParticle,
-               incidentHasChanged, targetHasChanged, quasiElastic );
+  const G4double cutOff = 0.1*MeV;
+  if (currentParticle.GetKineticEnergy() > cutOff)
+    Cascade(vec, vecLen, originalIncident, currentParticle, targetParticle,
+            incidentHasChanged, targetHasChanged, quasiElastic);
     
-    CalculateMomenta( vec, vecLen,
-                      originalIncident, originalTarget, modifiedOriginal,
-                      targetNucleus, currentParticle, targetParticle,
-                      incidentHasChanged, targetHasChanged, quasiElastic );
-    
-    SetUpChange( vec, vecLen,
-                 currentParticle, targetParticle,
-                 incidentHasChanged );
+  CalculateMomenta(vec, vecLen, originalIncident, originalTarget,
+                   modifiedOriginal, targetNucleus, currentParticle,
+                   targetParticle, incidentHasChanged, targetHasChanged,
+                   quasiElastic);
     
+  SetUpChange(vec, vecLen, currentParticle, targetParticle, incidentHasChanged);
+
+  if (isotopeProduction) DoIsotopeCounting(originalIncident, targetNucleus);
+
   delete originalTarget;
   return &theParticleChange;    
 }
+
  
 void G4LEKaonMinusInelastic::Cascade(
    G4FastVector<G4ReactionProduct,GHADLISTSIZE> &vec,
@@ -184,8 +183,8 @@ void G4LEKaonMinusInelastic::Cascade(
     const G4int numSec = 60;
     static G4double protmul[numMul], protnorm[numSec]; // proton constants
     static G4double neutmul[numMul], neutnorm[numSec]; // neutron constants
-    // np = number of pi+, nm = number of pi-, nz = number of pi0
-    G4int nt(0), np(0), nm(0), nz(0);
+    // npos = number of pi+, nneg = number of pi-, nzero = number of pi0
+    G4int nt(0), npos(0), nneg(0), nzero(0);
     const G4double c = 1.25;    
     const G4double b[] = { 0.70, 0.70 };
     if( first )       // compute normalization constants, this will only be Done once
@@ -195,18 +194,18 @@ void G4LEKaonMinusInelastic::Cascade(
       for( i=0; i<numMul; ++i )protmul[i] = 0.0;
       for( i=0; i<numSec; ++i )protnorm[i] = 0.0;
       G4int counter = -1;
-      for( np=0; np<(numSec/3); ++np )
+      for( npos=0; npos<(numSec/3); ++npos )
       {
-        for( nm=std::max(0,np-1); nm<=(np+1); ++nm )
+        for( nneg=std::max(0,npos-1); nneg<=(npos+1); ++nneg )
         {
-          for( nz=0; nz<numSec/3; ++nz )
+          for( nzero=0; nzero<numSec/3; ++nzero )
           {
             if( ++counter < numMul )
             {
-              nt = np+nm+nz;
+              nt = npos+nneg+nzero;
               if( (nt>0) && (nt<=numSec) )
               {
-                protmul[counter] = Pmltpc(np,nm,nz,nt,b[0],c);
+                protmul[counter] = Pmltpc(npos,nneg,nzero,nt,b[0],c);
                 protnorm[nt-1] += protmul[counter];
               }
             }
@@ -216,18 +215,18 @@ void G4LEKaonMinusInelastic::Cascade(
       for( i=0; i<numMul; ++i )neutmul[i] = 0.0;
       for( i=0; i<numSec; ++i )neutnorm[i] = 0.0;
       counter = -1;
-      for( np=0; np<numSec/3; ++np )
+      for( npos=0; npos<numSec/3; ++npos )
       {
-        for( nm=np; nm<=(np+2); ++nm )
+        for( nneg=npos; nneg<=(npos+2); ++nneg )
         {
-          for( nz=0; nz<numSec/3; ++nz )
+          for( nzero=0; nzero<numSec/3; ++nzero )
           {
             if( ++counter < numMul )
             {
-              nt = np+nm+nz;
+              nt = npos+nneg+nzero;
               if( (nt>0) && (nt<=numSec) )
               {
-                neutmul[counter] = Pmltpc(np,nm,nz,nt,b[1],c);
+                neutmul[counter] = Pmltpc(npos,nneg,nzero,nt,b[1],c);
                 neutnorm[nt-1] += neutmul[counter];
               }
             }
@@ -259,7 +258,7 @@ void G4LEKaonMinusInelastic::Cascade(
     G4int iplab = G4int(std::min( 9.0, pOriginal/GeV*5.0 ));
     if( (pOriginal <= 2.0*GeV) && (G4UniformRand() < cech[iplab]) )
     {
-      np = nm = nz = nt = 0;
+      npos = nneg = nzero = nt = 0;
       iplab = G4int(std::min( 19.0, pOriginal/GeV*10.0 ));
       const G4double cnk0[] = {0.17,0.18,0.17,0.24,0.26,0.20,0.22,0.21,0.34,0.45,
                                0.58,0.55,0.36,0.29,0.29,0.32,0.32,0.33,0.33,0.33};
@@ -333,15 +332,15 @@ void G4LEKaonMinusInelastic::Cascade(
       if( targetParticle.GetDefinition() == aProton )
       {
         G4int counter = -1;
-        for( np=0; np<numSec/3 && ran>=excs; ++np )
+        for( npos=0; npos<numSec/3 && ran>=excs; ++npos )
         {
-          for( nm=std::max(0,np-1); nm<=(np+1) && ran>=excs; ++nm )
+          for( nneg=std::max(0,npos-1); nneg<=(npos+1) && ran>=excs; ++nneg )
           {
-            for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
+            for( nzero=0; nzero<numSec/3 && ran>=excs; ++nzero )
             {
               if( ++counter < numMul )
               {
-                nt = np+nm+nz;
+                nt = npos+nneg+nzero;
                 if( nt > 0 )
                 {
                   test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -362,8 +361,8 @@ void G4LEKaonMinusInelastic::Cascade(
           quasiElastic = true;
           return;
         }
-        np--; nm--; nz--;
-        if( np == nm )
+        npos--; nneg--; nzero--;
+        if( npos == nneg )
         {
           if( G4UniformRand() >= 0.75 )
           {
@@ -373,7 +372,7 @@ void G4LEKaonMinusInelastic::Cascade(
             targetHasChanged = true;
           }
         }
-        else if( np == nm+1 )
+        else if( npos == nneg+1 )
         {
           targetParticle.SetDefinitionAndUpdateE( aNeutron );
           targetHasChanged = true;
@@ -387,15 +386,15 @@ void G4LEKaonMinusInelastic::Cascade(
       else   // target must be a neutron
       {
         G4int counter = -1;
-        for( np=0; np<numSec/3 && ran>=excs; ++np )
+        for( npos=0; npos<numSec/3 && ran>=excs; ++npos )
         {
-          for( nm=np; nm<=(np+2) && ran>=excs; ++nm )
+          for( nneg=npos; nneg<=(npos+2) && ran>=excs; ++nneg )
           {
-            for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
+            for( nzero=0; nzero<numSec/3 && ran>=excs; ++nzero )
             {
               if( ++counter < numMul )
               {
-                nt = np+nm+nz;
+                nt = npos+nneg+nzero;
                 if( (nt>=1) && (nt<=numSec) )
                 {
                   test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -416,8 +415,8 @@ void G4LEKaonMinusInelastic::Cascade(
           quasiElastic = true;
           return;
         }
-        np--; nm--; nz--;
-        if( np == nm-1 )
+        npos--; nneg--; nzero--;
+        if( npos == nneg-1 )
         {
           if( G4UniformRand() < 0.5 )
           {
@@ -430,7 +429,7 @@ void G4LEKaonMinusInelastic::Cascade(
             incidentHasChanged = true;
           }
         }
-        else if( np != nm )
+        else if( npos != nneg )
         {
           currentParticle.SetDefinitionAndUpdateE( aKaonZL );
           incidentHasChanged = true;
@@ -548,6 +547,6 @@ void G4LEKaonMinusInelastic::Cascade(
       }
     }
 
-  SetUpPions( np, nm, nz, vec, vecLen );
+  SetUpPions( npos, nneg, nzero, vec, vecLen );
   return;
 }
