@@ -26,11 +26,13 @@
 // Hadronic Process: Low Energy Neutron Inelastic Process
 // J.L. Chuma, TRIUMF, 04-Feb-1997
  
-#include "G4LENeutronInelastic.hh"
-#include "Randomize.hh"
-#include "G4Electron.hh"
 #include <iostream>
 
+#include "G4LENeutronInelastic.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
+#include "Randomize.hh"
+#include "G4Electron.hh"
 
 void G4LENeutronInelastic::ModelDescription(std::ostream& outFile) const
 {
@@ -54,95 +56,84 @@ G4LENeutronInelastic::ApplyYourself(const G4HadProjectile& aTrack,
   const G4HadProjectile *originalIncident = &aTrack;
 
   // Create the target particle
-
-  G4DynamicParticle *originalTarget = targetNucleus.ReturnTargetParticle();
+  G4DynamicParticle* originalTarget = targetNucleus.ReturnTargetParticle();
     
   if (verboseLevel > 1) {
-    const G4Material *targetMaterial = aTrack.GetMaterial();
+    const G4Material* targetMaterial = aTrack.GetMaterial();
     G4cout << "G4LENeutronInelastic::ApplyYourself called" << G4endl;
     G4cout << "kinetic energy = " << originalIncident->GetKineticEnergy()/MeV << "MeV, ";
     G4cout << "target material = " << targetMaterial->GetName() << ", ";
     G4cout << "target particle = " << originalTarget->GetDefinition()->GetParticleName()
            << G4endl;
   }
-/* not true, for example for Fe56, etc..
-    if( originalIncident->GetKineticEnergy()/MeV < 0.000001 )
-      throw G4HadronicException(__FILE__, __LINE__, "G4LENeutronInelastic: should be capture process!");
-    if( originalIncident->Get4Momentum().vect().mag()/MeV < 0.000001 )
-      throw G4HadronicException(__FILE__, __LINE__, "G4LENeutronInelastic: should be capture process!");
-*/
-    
+ 
   G4ReactionProduct modifiedOriginal;
   modifiedOriginal = *originalIncident;
   G4ReactionProduct targetParticle;
   targetParticle = *originalTarget;
   if (originalIncident->GetKineticEnergy()/GeV < 0.01 + 2.*G4UniformRand()/9.) {
-    SlowNeutron( originalIncident, modifiedOriginal, targetParticle, targetNucleus );
+    SlowNeutron(originalIncident, modifiedOriginal, targetParticle, targetNucleus);
+    if (isotopeProduction) DoIsotopeCounting(originalIncident, targetNucleus);
     delete originalTarget;
     return &theParticleChange;
   }
 
   // Fermi motion and evaporation
   // As of Geant3, the Fermi energy calculation had not been done
-
   G4double ek = originalIncident->GetKineticEnergy()/MeV;
   G4double amas = originalIncident->GetDefinition()->GetPDGMass()/MeV;
     
-    G4double tkin = targetNucleus.Cinema( ek );
-    ek += tkin;
-    modifiedOriginal.SetKineticEnergy( ek*MeV );
-    G4double et = ek + amas;
-    G4double p = std::sqrt( std::abs((et-amas)*(et+amas)) );
-    G4double pp = modifiedOriginal.GetMomentum().mag()/MeV;
-    if( pp > 0.0 )
-    {
-      G4ThreeVector momentum = modifiedOriginal.GetMomentum();
-      modifiedOriginal.SetMomentum( momentum * (p/pp) );
-    }
-    //
-    // calculate black track energies
-    //
-    tkin = targetNucleus.EvaporationEffects( ek );
-    ek -= tkin;
-    modifiedOriginal.SetKineticEnergy( ek*MeV );
-    et = ek + amas;
-    p = std::sqrt( std::abs((et-amas)*(et+amas)) );
-    pp = modifiedOriginal.GetMomentum().mag()/MeV;
-    if( pp > 0.0 )
-    {
-      G4ThreeVector momentum = modifiedOriginal.GetMomentum();
-      modifiedOriginal.SetMomentum( momentum * (p/pp) );
-    }
-    const G4double cutOff = 0.1;
-    if( modifiedOriginal.GetKineticEnergy()/MeV <= cutOff )
-    {
-      SlowNeutron( originalIncident, modifiedOriginal, targetParticle, targetNucleus );
-      delete originalTarget;
-      return &theParticleChange;
-    }
-    G4ReactionProduct currentParticle = modifiedOriginal;
-    currentParticle.SetSide( 1 ); // incident always goes in forward hemisphere
-    targetParticle.SetSide( -1 );  // target always goes in backward hemisphere
-    G4bool incidentHasChanged = false;
-    G4bool targetHasChanged = false;
-    G4bool quasiElastic = false;
-    G4FastVector<G4ReactionProduct,GHADLISTSIZE> vec;  // vec will contain the secondary particles
-    G4int vecLen = 0;
-    vec.Initialize( 0 );
+  G4double tkin = targetNucleus.Cinema(ek);
+  ek += tkin;
+  modifiedOriginal.SetKineticEnergy( ek*MeV );
+  G4double et = ek + amas;
+  G4double p = std::sqrt( std::abs((et-amas)*(et+amas)) );
+  G4double pp = modifiedOriginal.GetMomentum().mag()/MeV;
+  if (pp > 0.0) {
+    G4ThreeVector momentum = modifiedOriginal.GetMomentum();
+    modifiedOriginal.SetMomentum(momentum * (p/pp) );
+  }
+
+  // calculate black track energies
+  tkin = targetNucleus.EvaporationEffects( ek );
+  ek -= tkin;
+  modifiedOriginal.SetKineticEnergy( ek*MeV );
+  et = ek + amas;
+  p = std::sqrt( std::abs((et-amas)*(et+amas)) );
+  pp = modifiedOriginal.GetMomentum().mag()/MeV;
+  if (pp > 0.0) {
+    G4ThreeVector momentum = modifiedOriginal.GetMomentum();
+    modifiedOriginal.SetMomentum(momentum * (p/pp) );
+  }
+  const G4double cutOff = 0.1;
+  if (modifiedOriginal.GetKineticEnergy()/MeV <= cutOff) {
+    SlowNeutron(originalIncident, modifiedOriginal, targetParticle, targetNucleus);
+    if (isotopeProduction) DoIsotopeCounting(originalIncident, targetNucleus);
+    delete originalTarget;
+    return &theParticleChange;
+  }
+
+  G4ReactionProduct currentParticle = modifiedOriginal;
+  currentParticle.SetSide(1);  // incident always goes in forward hemisphere
+  targetParticle.SetSide(-1);  // target always goes in backward hemisphere
+  G4bool incidentHasChanged = false;
+  G4bool targetHasChanged = false;
+  G4bool quasiElastic = false;
+  G4FastVector<G4ReactionProduct,GHADLISTSIZE> vec;  // vec will contain the secondary particles
+  G4int vecLen = 0;
+  vec.Initialize(0);
     
-    Cascade( vec, vecLen,
-             originalIncident, currentParticle, targetParticle,
-             incidentHasChanged, targetHasChanged, quasiElastic );
+  Cascade(vec, vecLen, originalIncident, currentParticle, targetParticle,
+          incidentHasChanged, targetHasChanged, quasiElastic);
     
-    CalculateMomenta( vec, vecLen,
-                      originalIncident, originalTarget, modifiedOriginal,
-                      targetNucleus, currentParticle, targetParticle,
-                      incidentHasChanged, targetHasChanged, quasiElastic );
-    
-    SetUpChange( vec, vecLen,
-                 currentParticle, targetParticle,
-                 incidentHasChanged );
+  CalculateMomenta(vec, vecLen, originalIncident, originalTarget,
+                   modifiedOriginal, targetNucleus, currentParticle,
+                   targetParticle, incidentHasChanged, targetHasChanged,
+                   quasiElastic);
     
+  SetUpChange(vec, vecLen, currentParticle, targetParticle, incidentHasChanged);
+   
+  if (isotopeProduction) DoIsotopeCounting(originalIncident, targetNucleus); 
   delete originalTarget;
   return &theParticleChange;
 }
@@ -306,8 +297,8 @@ void G4LENeutronInelastic::Cascade(
     const G4int numSec = 60;
     static G4double protmul[numMul], protnorm[numSec]; // proton constants
     static G4double neutmul[numMul], neutnorm[numSec]; // neutron constants
-    // np = number of pi+, nm = number of pi-, nz = number of pi0
-    G4int counter, nt=0, np=0, nm=0, nz=0;
+    // npos = number of pi+, nneg = number of pi-, nzero = number of pi0
+    G4int counter, nt=0, npos=0, nneg=0, nzero=0;
     const G4double c = 1.25;    
     const G4double b[] = { 0.35, 0.0 };
     if( first )      // compute normalization constants, this will only be Done once
@@ -317,20 +308,20 @@ void G4LENeutronInelastic::Cascade(
       for( i=0; i<numMul; ++i )protmul[i] = 0.0;
       for( i=0; i<numSec; ++i )protnorm[i] = 0.0;
       counter = -1;
-      for( np=0; np<numSec/3; ++np )
+      for( npos=0; npos<numSec/3; ++npos )
       {
-        for( nm=std::max(0,np-1); nm<=(np+1); ++nm )
+        for( nneg=std::max(0,npos-1); nneg<=(npos+1); ++nneg )
         {
-          for( nz=0; nz<numSec/3; ++nz )
+          for( nzero=0; nzero<numSec/3; ++nzero )
           {
             if( ++counter < numMul )
             {
-              nt = np+nm+nz;
+              nt = npos+nneg+nzero;
               if( nt > 0 )
               {
-                protmul[counter] = Pmltpc(np,nm,nz,nt,b[0],c) /
-                  ( theReactionDynamics.Factorial(1-np+nm)*
-                    theReactionDynamics.Factorial(1+np-nm) );
+                protmul[counter] = Pmltpc(npos,nneg,nzero,nt,b[0],c) /
+                  ( theReactionDynamics.Factorial(1-npos+nneg)*
+                    theReactionDynamics.Factorial(1+npos-nneg) );
                 protnorm[nt-1] += protmul[counter];
               }
             }
@@ -340,20 +331,20 @@ void G4LENeutronInelastic::Cascade(
       for( i=0; i<numMul; ++i )neutmul[i] = 0.0;
       for( i=0; i<numSec; ++i )neutnorm[i] = 0.0;
       counter = -1;
-      for( np=0; np<(numSec/3); ++np )
+      for( npos=0; npos<(numSec/3); ++npos )
       {
-        for( nm=np; nm<=(np+2); ++nm )
+        for( nneg=npos; nneg<=(npos+2); ++nneg )
         {
-          for( nz=0; nz<numSec/3; ++nz )
+          for( nzero=0; nzero<numSec/3; ++nzero )
           {
             if( ++counter < numMul )
             {
-              nt = np+nm+nz;
+              nt = npos+nneg+nzero;
               if( (nt>0) && (nt<=numSec) )
               {
-                neutmul[counter] = Pmltpc(np,nm,nz,nt,b[1],c) /
-                  ( theReactionDynamics.Factorial(nm-np)*
-                    theReactionDynamics.Factorial(2-nm+np) );
+                neutmul[counter] = Pmltpc(npos,nneg,nzero,nt,b[1],c) /
+                  ( theReactionDynamics.Factorial(nneg-npos)*
+                    theReactionDynamics.Factorial(2-nneg+npos) );
                 neutnorm[nt-1] += neutmul[counter];
               }
             }
@@ -379,16 +370,16 @@ void G4LENeutronInelastic::Cascade(
       // suppress high multiplicity events at low momentum
       // only one pion will be produced
 
-      nm = np = nz = 0;
+      nneg = npos = nzero = 0;
       if( targetParticle.GetDefinition() == aNeutron )
       {
         test = std::exp( std::min( expxu, std::max( expxl, -(1.0+b[1])*(1.0+b[1])/(2.0*c*c) ) ) );
         w0 = test/2.0;
         wm = test;
         if( G4UniformRand() < w0/(w0+wm) )
-          nz = 1;
+          nzero = 1;
         else
-          nm = 1;
+          nneg = 1;
       } else { // target is a proton
         test = std::exp( std::min( expxu, std::max( expxl, -(1.0+b[0])*(1.0+b[0])/(2.0*c*c) ) ) );
         w0 = test;
@@ -399,11 +390,11 @@ void G4LENeutronInelastic::Cascade(
         wp += w0;
         G4double ran = G4UniformRand();
         if( ran < w0/wt )
-          nz = 1;
+          nzero = 1;
         else if( ran < wp/wt )
-          np = 1;
+          npos = 1;
         else
-          nm = 1;
+          nneg = 1;
       }
     } else {  // (availableEnergy >= 2.0*GeV) || (random number < supp[ieab])
       G4double n, anpn;
@@ -413,15 +404,15 @@ void G4LENeutronInelastic::Cascade(
       if( targetParticle.GetDefinition() == aProton )
       {
         counter = -1;
-        for( np=0; np<numSec/3 && ran>=excs; ++np )
+        for( npos=0; npos<numSec/3 && ran>=excs; ++npos )
         {
-          for( nm=std::max(0,np-1); nm<=(np+1) && ran>=excs; ++nm )
+          for( nneg=std::max(0,npos-1); nneg<=(npos+1) && ran>=excs; ++nneg )
           {
-            for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
+            for( nzero=0; nzero<numSec/3 && ran>=excs; ++nzero )
             {
               if( ++counter < numMul )
               {
-                nt = np+nm+nz;
+                nt = npos+nneg+nzero;
                 if( nt > 0 )
                 {
                   test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -441,18 +432,18 @@ void G4LENeutronInelastic::Cascade(
           quasiElastic = true;
           return;
         }
-        np--; nm--; nz--;
+        npos--; nneg--; nzero--;
       } else { // target must be a neutron
         counter = -1;
-        for( np=0; np<numSec/3 && ran>=excs; ++np )
+        for( npos=0; npos<numSec/3 && ran>=excs; ++npos )
         {
-          for( nm=np; nm<=(np+2) && ran>=excs; ++nm )
+          for( nneg=npos; nneg<=(npos+2) && ran>=excs; ++nneg )
           {
-            for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
+            for( nzero=0; nzero<numSec/3 && ran>=excs; ++nzero )
             {
               if( ++counter < numMul )
               {
-                nt = np+nm+nz;
+                nt = npos+nneg+nzero;
                 if( (nt>=1) && (nt<=numSec) )
                 {
                   test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -472,12 +463,12 @@ void G4LENeutronInelastic::Cascade(
           quasiElastic = true;
           return;
         }
-        np--; nm--; nz--;
+        npos--; nneg--; nzero--;
       }
     }
     if( targetParticle.GetDefinition() == aProton )
     {
-      switch( np-nm )
+      switch( npos-nneg )
       {
        case 0:
          if( G4UniformRand() < 0.33 )
@@ -498,7 +489,7 @@ void G4LENeutronInelastic::Cascade(
          break;
       }
     } else { // target must be a neutron
-      switch( np-nm )
+      switch( npos-nneg )
       {
        case -1:                       // changed from +1 by JLC, 7Jul97
          if( G4UniformRand() < 0.5 )
@@ -520,7 +511,7 @@ void G4LENeutronInelastic::Cascade(
          break;
       }
     }
-    SetUpPions( np, nm, nz, vec, vecLen );
+    SetUpPions( npos, nneg, nzero, vec, vecLen );
 // DEBUG -->    DumpFrames::DumpFrame(vec, vecLen);
     return;
   }
