@@ -42,11 +42,10 @@
 // 100729 Add model name in constructor Problem #1116
 
 #include "G4NeutronHPThermalScattering.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4Neutron.hh"
 #include "G4ElementTable.hh"
 
-
-
 G4NeutronHPThermalScattering::G4NeutronHPThermalScattering()
                              :G4HadronicInteraction("NeutronHPThermalScattering")
 {
@@ -477,7 +476,7 @@ G4HadFinalState* G4NeutronHPThermalScattering::ApplyYourself(const G4HadProjecti
 
          for ( G4int i=1 ; i < n1 ; i++ ) 
          {
-            if ( (*pvE_p_TL)[i]->first != (*pvE_p_TH)[i]->first ) abort();
+            if ( (*pvE_p_TL)[i]->first != (*pvE_p_TH)[i]->first ) G4HadronicException(__FILE__, __LINE__, "A problem is found in Thermal Scattering Data!");
             vE_T.push_back ( (*pvE_p_TL)[i]->first );
             vp_T.push_back ( get_linear_interpolated ( aTemp , std::pair< G4double , G4double > ( tempLH.first , (*pvE_p_TL)[i]->second ) , std::pair< G4double , G4double > ( tempLH.second , (*pvE_p_TL)[i]->second ) ) );  
          }
@@ -852,10 +851,10 @@ std::pair< G4double , E_isoAng > G4NeutronHPThermalScattering::create_sE_and_EPM
          if ( E_isoAng_L.n == E_isoAng_H.n ) 
          {
             anE_isoAng.n =  E_isoAng_L.n; 
-            for ( G4int i=0 ; i < anE_isoAng.n ; i++ )
+            for ( G4int j=0 ; j < anE_isoAng.n ; j++ )
             { 
                G4double angle;
-               angle = get_linear_interpolated ( sE  , std::pair< G4double , G4double > ( sE_L , E_isoAng_L.isoAngle[ i ] ) , std::pair< G4double , G4double > ( sE_H , E_isoAng_H.isoAngle[ i ] ) );  
+               angle = get_linear_interpolated ( sE  , std::pair< G4double , G4double > ( sE_L , E_isoAng_L.isoAngle[ j ] ) , std::pair< G4double , G4double > ( sE_H , E_isoAng_H.isoAngle[ j ] ) );  
                anE_isoAng.isoAngle.push_back( angle ); 
             }
          }
@@ -996,3 +995,9 @@ G4int G4NeutronHPThermalScattering::getTS_ID ( const G4Material* material , cons
       result = dic.find( std::pair < const G4Material* , const G4Element* > ( material , element ) )->second; 
    return result; 
 }
+
+const std::pair<G4double, G4double> G4NeutronHPThermalScattering::GetFatalEnergyCheckLevels() const
+{
+   //return std::pair<G4double, G4double>(10*perCent,10*GeV);
+   return std::pair<G4double, G4double>(10*perCent,DBL_MAX);
+}
