@@ -24,7 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4LundStringFragmentation.cc,v 1.24 2010/12/07 10:42:40 vuzhinsk Exp $
+// $Id$
 // GEANT4 tag $Name:  $ 1.8
 //
 // -----------------------------------------------------------------------------
@@ -60,7 +60,9 @@ G4LundStringFragmentation::G4LundStringFragmentation()
 
 //    SetStringTensionParameter(0.25);                           
     SetStringTensionParameter(1.);                         
+    SetDiquarkSuppression(0.087);                 // Uzhi 18.05.2012
     SetDiquarkBreakProbability(0.05); 
+    SetStrangenessSuppression(0.47);              // Uzhi 18.05.2012
 
 // For treating of small string decays
    for(G4int i=0; i<3; i++)
@@ -204,7 +206,7 @@ G4LundStringFragmentation::G4LundStringFragmentation()
    BaryonWeight[0][1][2][0]=(1.-pspin_barion)*0.5;
 
          Baryon[0][1][2][1]=3212;         // Sigma0
-   BaryonWeight[0][1][2][2]=(1.-pspin_barion)*0.5;
+   BaryonWeight[0][1][2][1]=(1.-pspin_barion)*0.5;
 
          Baryon[0][1][2][2]=3214;         // Sigma*0
    BaryonWeight[0][1][2][2]=pspin_barion;
@@ -347,7 +349,7 @@ G4LundStringFragmentation::G4LundStringFragmentation()
    BaryonWeight[2][1][2][0]=1.-pspin_barion;
 
          Baryon[2][1][2][1]=3324;         // Theta*0
-   BaryonWeight[2][1][2][2]=pspin_barion;
+   BaryonWeight[2][1][2][1]=pspin_barion;
 
 //---------------------------------------
          Baryon[2][2][0][0]=3312;         // Theta-
