@@ -32,13 +32,15 @@
 //
 #include "G4QMDCollision.hh"
 #include "G4Scatterer.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "Randomize.hh"
 
 G4QMDCollision::G4QMDCollision()
 : deltar ( 4 )
 , bcmax0 ( 1.323142 ) // NN maximum impact parameter
 , bcmax1 ( 2.523 )    // others maximum impact parameter
-, sig0 ( 55 )   // NN cross section
+// , sig0 ( 55 )   // NN cross section
 //110617 fix for gcc 4.6 compilation warnings 
 //, sig1 ( 200 )  // others cross section
 , epse ( 0.0001 )
@@ -306,9 +308,10 @@ void G4QMDCollision::CalKinematicsOfBinaryCollisions( G4double dt )
 //       Here we assume elab (beam momentum less than 5 GeV/n )
          if ( rr2 > deltar*deltar ) continue;
 
-         G4double s = (p4i+p4j)*(p4i+p4j);
+         //G4double s = (p4i+p4j)*(p4i+p4j);
+         //G4double srt = std::sqrt ( s );
 
-         G4double srt = std::sqrt ( s );
+         G4double srt = std::sqrt( (p4i+p4j)*(p4i+p4j) );
 
          G4double cutoff = 0.0;
          G4double bcmax = 0.0;
