@@ -62,6 +62,8 @@
 // %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 ///////////////////////////////////////////////////////////////////////////////
 //
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "G4NuclearLevelManager.hh"
 #include "G4NuclearLevelStore.hh"
 #include "G4NuclearDecayChannel.hh"
@@ -88,21 +90,20 @@ const G4double G4NuclearDecayChannel:: pTolerance = 0.001;
 const G4double G4NuclearDecayChannel:: levelTolerance = 2.0*keV;
 //const G4bool G4NuclearDecayChannel:: FermiOn = true;
 
-///////////////////////////////////////////////////////////////////////////////
-//
 //
 // Constructor for one decay product (the nucleus).
 //
-G4NuclearDecayChannel::G4NuclearDecayChannel
-                      (const G4RadioactiveDecayMode &theMode,
-                       G4int Verbose,
-                       const G4ParticleDefinition *theParentNucleus,
-                       G4double theBR,
-                       G4double theQtransition,
-                       G4int A,
-                       G4int Z,
-                       G4double theDaughterExcitation) :
-  G4GeneralPhaseSpaceDecay(Verbose), decayMode(theMode)
+G4NuclearDecayChannel::
+G4NuclearDecayChannel(const G4RadioactiveDecayMode& theMode,
+                      G4int Verbose,
+                      const G4ParticleDefinition* theParentNucleus,
+                      G4double theBR,
+                      G4double theQtransition,
+                      G4int A,
+                      G4int Z,
+                      G4double theDaughterExcitation)
+ :G4GeneralPhaseSpaceDecay(Verbose), decayMode(theMode), dynamicDaughter(0),
+  RandomEnergy(0)
 {
 #ifdef G4VERBOSE
   if (GetVerboseLevel()>1)
@@ -119,22 +120,22 @@ G4NuclearDecayChannel::G4NuclearDecayChannel
   applyICM = true;
   applyARM = true;
 }
-///////////////////////////////////////////////////////////////////////////////
-//
+
 //
 // Constructor for a daughter nucleus and one other particle.
 //
-G4NuclearDecayChannel::G4NuclearDecayChannel
-                      (const G4RadioactiveDecayMode &theMode,
-                       G4int Verbose,
-                       const G4ParticleDefinition *theParentNucleus,
-                       G4double theBR,
-                       G4double theQtransition,
-                       G4int A,
-                       G4int Z,
-                       G4double theDaughterExcitation,
-                       const G4String theDaughterName1) :
-			G4GeneralPhaseSpaceDecay(Verbose), decayMode(theMode)
+G4NuclearDecayChannel::
+G4NuclearDecayChannel(const G4RadioactiveDecayMode& theMode,
+                      G4int Verbose,
+                      const G4ParticleDefinition *theParentNucleus,
+                      G4double theBR,
+                      G4double theQtransition,
+                      G4int A,
+                      G4int Z,
+                      G4double theDaughterExcitation,
+                      const G4String theDaughterName1)
+ :G4GeneralPhaseSpaceDecay(Verbose), decayMode(theMode), dynamicDaughter(0),
+  RandomEnergy(0)
 {
 #ifdef G4VERBOSE
   if (GetVerboseLevel()>1)
@@ -156,21 +157,21 @@ G4NuclearDecayChannel::G4NuclearDecayChannel
 //
 // Constructor for a daughter nucleus and two other particles
 //
-G4NuclearDecayChannel::G4NuclearDecayChannel
-                      (const G4RadioactiveDecayMode &theMode,
-                       G4int Verbose,
-                       const G4ParticleDefinition *theParentNucleus,
-                       G4double theBR,
-                       G4double /* theFFN */,
-		       G4bool /* betaS */, 
-		       CLHEP::RandGeneral* randBeta,
-                       G4double theQtransition,
-                       G4int A,
-                       G4int Z,
-                       G4double theDaughterExcitation,
-                       const G4String theDaughterName1,
-                       const G4String theDaughterName2)
- : G4GeneralPhaseSpaceDecay(Verbose), decayMode(theMode)
+G4NuclearDecayChannel::
+G4NuclearDecayChannel(const G4RadioactiveDecayMode &theMode,
+                      G4int Verbose,
+                      const G4ParticleDefinition *theParentNucleus,
+                      G4double theBR,
+                      G4double /* theFFN */,
+		      G4bool /* betaS */, 
+		      CLHEP::RandGeneral* randBeta,
+                      G4double theQtransition,
+                      G4int A,
+                      G4int Z,
+                      G4double theDaughterExcitation,
+                      const G4String theDaughterName1,
+                      const G4String theDaughterName2)
+ :G4GeneralPhaseSpaceDecay(Verbose), decayMode(theMode), dynamicDaughter(0)
 {
 #ifdef G4VERBOSE
   if (GetVerboseLevel()>1)
@@ -295,177 +296,174 @@ G4DecayProducts* G4NuclearDecayChannel::DecayIt(G4double theParentMass)
     ed << " Parent nucleus " << *parent_name << " was not decayed " << G4endl;
     G4Exception("G4NuclearDecayChannel::DecayIt()", "HAD_RDM_008",
                 JustWarning, ed);
-                 
-  //  G4cerr << "G4NuclearDecayChannel::DecayIt ";
-  //  G4cerr << *parent_name << " can not decay " << G4endl;
     DumpInfo();
-  }
+  } else {
 
-  // If the decay is to an excited state of the daughter nuclide, we need
-  // to apply the photo-evaporation process. This includes the IT decay mode itself.
+    // If the decay is to an excited state of the daughter nuclide, we need
+    // to apply the photo-evaporation process. This includes the IT decay mode itself.
 
-  // needed to hold the shell idex after ICM
-  G4int shellIndex = -1;
+    // Need to hold the shell idex after ICM
+    G4int shellIndex = -1;
 
-  if (daughterExcitation > 0.0) {
-    // Pop the daughter nucleus off the product vector - we need to retain
-    // the momentum of this particle.
+    if (daughterExcitation > 0.0) {
+      // Pop the daughter nucleus off the product vector - we need to retain
+      // the momentum of this particle.
 
-    dynamicDaughter = products->PopProducts();
-    G4LorentzVector daughterMomentum = dynamicDaughter->Get4Momentum();
-    G4ThreeVector const daughterMomentum1(static_cast<const G4LorentzVector> (daughterMomentum));
+      dynamicDaughter = products->PopProducts();
+      G4LorentzVector daughterMomentum = dynamicDaughter->Get4Momentum();
+      G4ThreeVector const daughterMomentum1(static_cast<const G4LorentzVector> (daughterMomentum));
 
-    // Now define a G4Fragment with the correct A, Z and excitation, and declare and
-    // initialise a G4PhotonEvaporation object.    
-    G4Fragment nucleus(daughterA, daughterZ, daughterMomentum);
-    G4PhotonEvaporation* deexcitation = new G4PhotonEvaporation;
-    deexcitation->SetVerboseLevel(GetVerboseLevel());
+      // Now define a G4Fragment with the correct A, Z and excitation,
+      // and declare and initialise a G4PhotonEvaporation object    
+      G4Fragment nucleus(daughterA, daughterZ, daughterMomentum);
+      G4PhotonEvaporation* deexcitation = new G4PhotonEvaporation;
+      deexcitation->SetVerboseLevel(GetVerboseLevel());
 
-    // switch on/off internal electron conversion
-    deexcitation->SetICM(applyICM);
+      // switch on/off internal electron conversion
+      deexcitation->SetICM(applyICM);
 
-    // Set the maximum life-time for a level that will be treated
-    // Level with life-time longer than this will be outputed as meta-stable
-    // isotope
-    deexcitation->SetMaxHalfLife(halflifethreshold);
+      // Set the maximum life-time for a level that will be treated
+      // Level with life-time longer than this will be outputed as meta-stable
+      // isotope
+      deexcitation->SetMaxHalfLife(halflifethreshold);
 
-    // but in IT mode, we need to force the transition 
-    if (decayMode == 0) {
-      deexcitation->RDMForced(true);
-    } else {
-      deexcitation->RDMForced(false);
-    }
+      // but in IT mode, we need to force the transition 
+      if (decayMode == 0) {
+        deexcitation->RDMForced(true);
+      } else {
+        deexcitation->RDMForced(false);
+      }
 
-    ////////////////////////////////////////////////////////////////////////////
-    //                                                                        //
-    // Now apply photo-evaporation                                            //
-    // Use BreakUp() so limit to one transition at a time, if ICM is          //
-    // requested.                                                             //
-    //                                                                        //
-    ////////////////////////////////////////////////////////////////////////////
-    // this change is realted to bug#1001  (F.Lei 07/05/2010)
+      //////////////////////////////////////////////////////////////////////////
+      //                                                                      //
+      //  Now apply photo-evaporation                                         //
+      //  Use BreakUp() so limit to one transition at a time, if ICM is       //
+      //  requested.                                                          //
+      //                                                                      //
+      //////////////////////////////////////////////////////////////////////////
+      //  this change is related to bug #1001  (F.Lei 07/05/2010)
 
-    G4FragmentVector* gammas = 0;	
-    if (applyICM) {
-      gammas = deexcitation->BreakUp(nucleus);	
-    } else {
-      gammas = deexcitation->BreakItUp(nucleus);
-    }
+      G4FragmentVector* gammas = 0;	
+      if (applyICM) {
+        gammas = deexcitation->BreakUp(nucleus);	
+      } else {
+        gammas = deexcitation->BreakItUp(nucleus);
+      }
 
-    // the returned G4FragmentVector contains the residual nuclide
-    // as its last entry.
-    G4int nGammas=gammas->size()-1;
+      // the returned G4FragmentVector contains the residual nuclide
+      // as its last entry.
+      G4int nGammas=gammas->size()-1;
 
-    // Go through each gamma/e- and add it to the decay product.  The angular
-    // distribution of the gammas is isotropic, and the residual nucleus is
-    // assumed not to have suffered any recoil as a result of this de-excitation.
-    for (G4int ig = 0; ig < nGammas; ig++) {
-      G4DynamicParticle* theGammaRay =
-        new G4DynamicParticle(gammas->operator[](ig)->GetParticleDefinition(),
-                              gammas->operator[](ig)->GetMomentum());
-      theGammaRay -> SetProperTime(gammas->operator[](ig)->GetCreationTime());
-      products->PushProducts (theGammaRay);
-    }
+      // Go through each gamma/e- and add it to the decay product.  The angular
+      // distribution of the gammas is isotropic, and the residual nucleus is
+      // assumed not to have suffered any recoil as a result of this de-excitation.
+      for (G4int ig = 0; ig < nGammas; ig++) {
+        G4DynamicParticle* theGammaRay =
+          new G4DynamicParticle(gammas->operator[](ig)->GetParticleDefinition(),
+                                gammas->operator[](ig)->GetMomentum());
+        theGammaRay -> SetProperTime(gammas->operator[](ig)->GetCreationTime());
+        products->PushProducts (theGammaRay);
+      }
 
-    // now the nucleus
-    G4double finalDaughterExcitation = gammas->operator[](nGammas)->GetExcitationEnergy();
-    // f.lei (03/01/03) this is needed to fix the crach in test18 
-    if (finalDaughterExcitation <= 1.0*keV) finalDaughterExcitation = 0 ;
+      // now the nucleus
+      G4double finalDaughterExcitation = gammas->operator[](nGammas)->GetExcitationEnergy();
+      // f.lei (03/01/03) this is needed to fix the crach in test18 
+      if (finalDaughterExcitation <= 1.0*keV) finalDaughterExcitation = 0;
       
-    if (dynamicDaughter) delete dynamicDaughter;
+      if (dynamicDaughter) delete dynamicDaughter;
       
-    G4IonTable* theIonTable = (G4IonTable*)(G4ParticleTable::GetParticleTable()->GetIonTable());      
-    dynamicDaughter = new G4DynamicParticle(
+      G4IonTable* theIonTable =
+          (G4IonTable*)(G4ParticleTable::GetParticleTable()->GetIonTable());      
+      dynamicDaughter = new G4DynamicParticle(
                   theIonTable->GetIon(daughterZ,daughterA,finalDaughterExcitation),
                   daughterMomentum1);
-    products->PushProducts (dynamicDaughter); 
+      products->PushProducts (dynamicDaughter); 
       
-    // retrive the ICM shell index
-    shellIndex = deexcitation->GetVacantShellNumber();
+      // retrive the ICM shell index
+      shellIndex = deexcitation->GetVacantShellNumber();
       
-    // Delete/reset variables associated with the gammas.
-    while (!gammas->empty()) {
-      delete *(gammas->end()-1);
-      gammas->pop_back();
-    }
-    delete gammas;
-    delete deexcitation;
-  } // if daughter excitation
+      // Delete/reset variables associated with the gammas.
+      while (!gammas->empty()) {
+        delete *(gammas->end()-1);
+        gammas->pop_back();
+      }
+      delete gammas;
+      delete deexcitation;
+    } // if daughter excitation > 0
 
-  // now we have to take care of the EC product which have to go through the ARM
-  G4int eShell = -1;
-  if (decayMode == 3 || decayMode == 4 || decayMode == 5) {
-    switch (decayMode)
-      {
-      case KshellEC:
-	//
-	{
-	  eShell = 0; // --> 0 from 1 (f.lei 30/4/2008)
-	}
-	break;
-      case LshellEC:
-	//
-	{
-	  eShell = G4int(G4UniformRand()*3)+1;
-	}
-	break;
-      case MshellEC:
-	//
-	{
-	// limit the shell index to 6 as specified by the ARM (F.Lei 06/05/2010)
-	// eShell = G4int(G4UniformRand()*5)+4;
-	  eShell = G4int(G4UniformRand()*3)+4;
-	}
-	break;
-      case ERROR:
-      default:
+    // Now take care of the EC products which have to go through the ARM
+    G4int eShell = -1;
+    if (decayMode == 3 || decayMode == 4 || decayMode == 5) {
+      switch (decayMode)
+        {
+        case KshellEC:
+	  //
+	  {
+            eShell = 0; // --> 0 from 1 (f.lei 30/4/2008)
+          }
+          break;
+        case LshellEC:
+	  //
+          {
+            eShell = G4int(G4UniformRand()*3)+1;
+          }
+          break;
+        case MshellEC:
+	  //
+          {
+            // limit the shell index to 6 as specified by the ARM (F.Lei 06/05/2010)
+            // eShell = G4int(G4UniformRand()*5)+4;
+            eShell = G4int(G4UniformRand()*3)+4;
+          }
+          break;
+        case ERROR:
+        default:
         G4Exception("G4NuclearDecayChannel::DecayIt()", "HAD_RDM_009",
                     FatalException, "Incorrect decay mode selection");
-//        G4Exception("G4NuclearDecayChannel::DecayIt()", "601",
-//                    FatalException, "Error in decay mode selection");
-      }
-  }
-
-  // For other cases eShell comes from shellIndex resulting from  the photo decay
-  // modeled by G4PhotonEvaporation* de-excitation (see above)
-
-  else eShell = shellIndex;
-
-  // now apply ARM if it is requested and there is a vaccancy
-  if (applyARM && eShell != -1) {
-    G4int aZ = daughterZ;
-
-    // V.Ivanchenko migration to new interface to atomic deexcitation
-    // no check on index of G4MaterialCutsCouple, simplified 
-    // check on secondary energy Esec < 0.1 keV
-    G4VAtomDeexcitation* atomDeex = G4LossTableManager::Instance()->AtomDeexcitation();
-    if (atomDeex) {
-      if(atomDeex->IsFluoActive() && aZ > 5 && aZ < 100) {  // only applies to 5< Z <100 
-        if (eShell >= G4AtomicShells::GetNumberOfShells(aZ)){
-    	  eShell = G4AtomicShells::GetNumberOfShells(aZ)-1;
         }
-	G4AtomicShellEnumerator as = G4AtomicShellEnumerator(eShell);
-	const G4AtomicShell* shell = atomDeex->GetAtomicShell(aZ, as);    
-	std::vector<G4DynamicParticle*> armProducts;
-	const G4double deexLimit = 0.1*keV;
-	atomDeex->GenerateParticles(&armProducts, shell, aZ, deexLimit, deexLimit);
-	size_t narm = armProducts.size();
-	if(narm > 0) {
-	  //L.Desorgher need of initialisation of  dynamicDaughter in some decay cases (for example Hg194)
-	  dynamicDaughter = products->PopProducts();
-	  G4ThreeVector bst = dynamicDaughter->Get4Momentum().boostVector();
-	  for (size_t i = 0; i<narm; ++i) {
-		    G4DynamicParticle* dp = armProducts[i];
-            G4LorentzVector lv = dp->Get4Momentum().boost(bst);
-            dp->Set4Momentum(lv);
-	    products->PushProducts(dp);
-	  }
-	  products->PushProducts(dynamicDaughter);
-	}
+    } else {
+      // For other cases eShell comes from shellIndex resulting from  the photo decay
+      // modeled by G4PhotonEvaporation* de-excitation (see above)
+      eShell = shellIndex;
+    }
 
+    // now apply ARM if it is requested and there is a vaccancy
+    if (applyARM && eShell != -1) {
+      G4int aZ = daughterZ;
+
+      // V.Ivanchenko migration to new interface to atomic deexcitation
+      // no check on index of G4MaterialCutsCouple, simplified 
+      // check on secondary energy Esec < 0.1 keV
+      G4VAtomDeexcitation* atomDeex =
+               G4LossTableManager::Instance()->AtomDeexcitation();
+      if (atomDeex) {
+        if(atomDeex->IsFluoActive() && aZ > 5 && aZ < 100) {  // only applies to 5< Z <100 
+          if (eShell >= G4AtomicShells::GetNumberOfShells(aZ)){
+            eShell = G4AtomicShells::GetNumberOfShells(aZ)-1;
+          }
+          G4AtomicShellEnumerator as = G4AtomicShellEnumerator(eShell);
+          const G4AtomicShell* shell = atomDeex->GetAtomicShell(aZ, as);    
+          std::vector<G4DynamicParticle*> armProducts;
+          const G4double deexLimit = 0.1*keV;
+          atomDeex->GenerateParticles(&armProducts, shell, aZ, deexLimit, deexLimit);
+          size_t narm = armProducts.size();
+          if (narm > 0) {
+	    // L.Desorgher: need to initialize dynamicDaughter in some decay
+            // cases (for example Hg194)
+	    dynamicDaughter = products->PopProducts();
+	    G4ThreeVector bst = dynamicDaughter->Get4Momentum().boostVector();
+            for (size_t i = 0; i<narm; ++i) {
+              G4DynamicParticle* dp = armProducts[i];
+              G4LorentzVector lv = dp->Get4Momentum().boost(bst);
+              dp->Set4Momentum(lv);
+              products->PushProducts(dp);
+            }
+            products->PushProducts(dynamicDaughter);
+          }
+        }
       }
     }
-  }
+  } // Parent nucleus decayed
   /*
 
     if (atomDeex && aZ > 5 && aZ < 100) {  // only applies to 5< Z <100 
