@@ -23,11 +23,12 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4RPGAntiLambdaInelastic.cc,v 1.1 2007-07-18 21:04:20 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
  
 #include "G4RPGAntiLambdaInelastic.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "Randomize.hh"
 
 G4HadFinalState*
@@ -153,8 +154,8 @@ void G4RPGAntiLambdaInelastic::Cascade(
     static G4double neutmul[numMul], neutnorm[numSec]; // neutron constants
     static G4double protmulA[numMulA], protnormA[numSec]; // proton constants
     static G4double neutmulA[numMulA], neutnormA[numSec]; // neutron constants
-    // np = number of pi+, nm = number of pi-, nz = number of pi0
-    G4int nt=0, np=0, nm=0, nz=0;
+    // np = number of pi+, nneg = number of pi-, nz = number of pi0
+    G4int nt=0, np=0, nneg=0, nz=0;
     G4double test;
     const G4double c = 1.25;    
     const G4double b[] = { 0.7, 0.7 };
@@ -167,16 +168,16 @@ void G4RPGAntiLambdaInelastic::Cascade(
       G4int counter = -1;
       for( np=0; np<(numSec/3); ++np )
       {
-        for( nm=std::max(0,np-2); nm<=(np+1); ++nm )
+        for( nneg=std::max(0,np-2); nneg<=(np+1); ++nneg )
         {
           for( nz=0; nz<numSec/3; ++nz )
           {
             if( ++counter < numMul )
             {
-              nt = np+nm+nz;
+              nt = np+nneg+nz;
               if( nt>0 && nt<=numSec )
               {
-                protmul[counter] = Pmltpc(np,nm,nz,nt,b[0],c);
+                protmul[counter] = Pmltpc(np,nneg,nz,nt,b[0],c);
                 protnorm[nt-1] += protmul[counter];
               }
             }
@@ -188,16 +189,16 @@ void G4RPGAntiLambdaInelastic::Cascade(
       counter = -1;
       for( np=0; np<numSec/3; ++np )
       {
-        for( nm=std::max(0,np-1); nm<=(np+2); ++nm )
+        for( nneg=std::max(0,np-1); nneg<=(np+2); ++nneg )
         {
           for( nz=0; nz<numSec/3; ++nz )
           {
             if( ++counter < numMul )
             {
-              nt = np+nm+nz;
+              nt = np+nneg+nz;
               if( nt>0 && nt<=numSec )
               {
-                neutmul[counter] = Pmltpc(np,nm,nz,nt,b[1],c);
+                neutmul[counter] = Pmltpc(np,nneg,nz,nt,b[1],c);
                 neutnorm[nt-1] += neutmul[counter];
               }
             }
@@ -217,15 +218,15 @@ void G4RPGAntiLambdaInelastic::Cascade(
       counter = -1;
       for( np=1; np<(numSec/3); ++np )
       {
-        nm = np-1;
+        nneg = np-1;
         for( nz=0; nz<numSec/3; ++nz )
         {
           if( ++counter < numMulA )
           {
-            nt = np+nm+nz;
+            nt = np+nneg+nz;
             if( nt>1 && nt<=numSec )
             {
-              protmulA[counter] = Pmltpc(np,nm,nz,nt,b[0],c);
+              protmulA[counter] = Pmltpc(np,nneg,nz,nt,b[0],c);
               protnormA[nt-1] += protmulA[counter];
             }
           }
@@ -236,15 +237,15 @@ void G4RPGAntiLambdaInelastic::Cascade(
       counter = -1;
       for( np=0; np<numSec/3; ++np )
       {
-        nm = np;
+        nneg = np;
         for( nz=0; nz<numSec/3; ++nz )
         {
           if( ++counter < numMulA )
           {
-            nt = np+nm+nz;
+            nt = np+nneg+nz;
             if( nt>1 && nt<=numSec )
             {
-              neutmulA[counter] = Pmltpc(np,nm,nz,nt,b[1],c);
+              neutmulA[counter] = Pmltpc(np,nneg,nz,nt,b[1],c);
               neutnormA[nt-1] += neutmulA[counter];
             }
           }
@@ -294,13 +295,13 @@ void G4RPGAntiLambdaInelastic::Cascade(
         G4int counter = -1;
         for( np=0; np<numSec/3 && ran>=excs; ++np )
         {
-          for( nm=std::max(0,np-2); nm<=(np+1) && ran>=excs; ++nm )
+          for( nneg=std::max(0,np-2); nneg<=(np+1) && ran>=excs; ++nneg )
           {
             for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
             {
               if( ++counter < numMul )
               {
-                nt = np+nm+nz;
+                nt = np+nneg+nz;
                 if( nt>0 && nt<=numSec )
                 {
                   test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -321,8 +322,8 @@ void G4RPGAntiLambdaInelastic::Cascade(
           quasiElastic = true;
           return;
         }
-        np--; nm--; nz--;
-        G4int ncht = std::min( 4, std::max( 1, np-nm+2 ) );
+        np--; nneg--; nz--;
+        G4int ncht = std::min( 4, std::max( 1, np-nneg+2 ) );
         switch( ncht )
         {
          case 1:
@@ -399,13 +400,13 @@ void G4RPGAntiLambdaInelastic::Cascade(
         G4int counter = -1;
         for( np=0; np<numSec/3 && ran>=excs; ++np )
         {
-          for( nm=std::max(0,np-1); nm<=(np+2) && ran>=excs; ++nm )
+          for( nneg=std::max(0,np-1); nneg<=(np+2) && ran>=excs; ++nneg )
           {
             for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
             {
               if( ++counter < numMul )
               {
-                nt = np+nm+nz;
+                nt = np+nneg+nz;
                 if( nt>0 && nt<=numSec )
                 {
                   test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -426,8 +427,8 @@ void G4RPGAntiLambdaInelastic::Cascade(
           quasiElastic = true;
           return;
         }
-        np--; nm--; nz--;
-        G4int ncht = std::min( 4, std::max( 1, np-nm+3 ) );
+        np--; nneg--; nz--;
+        G4int ncht = std::min( 4, std::max( 1, np-nneg+3 ) );
         switch( ncht )
         {
          case 1:
@@ -519,12 +520,12 @@ void G4RPGAntiLambdaInelastic::Cascade(
         G4int counter = -1;
         for( np=1; np<numSec/3 && ran>=excs; ++np )
         {
-          nm = np-1;
+          nneg = np-1;
           for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
           {
             if( ++counter < numMulA )
             {
-              nt = np+nm+nz;
+              nt = np+nneg+nz;
               if( nt>1 && nt<=numSec )
               {
                 test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -545,12 +546,12 @@ void G4RPGAntiLambdaInelastic::Cascade(
         G4int counter = -1;
         for( np=0; np<numSec/3 && ran>=excs; ++np )
         {
-          nm = np;
+          nneg = np;
           for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
           {
             if( ++counter < numMulA )
             {
-              nt = np+nm+nz;
+              nt = np+nneg+nz;
               if( nt>1 && nt<=numSec )
               {
                 test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -575,12 +576,12 @@ void G4RPGAntiLambdaInelastic::Cascade(
       currentParticle.SetMass( 0.0 );
       targetParticle.SetMass( 0.0 );
     }
-    SetUpPions( np, nm, nz, vec, vecLen );
+    SetUpPions( np, nneg, nz, vec, vecLen );
     if( currentParticle.GetMass() == 0.0 )
     {
       if( nz == 0 )
       {
-        if( nm > 0 )
+        if( nneg > 0 )
         {
           for( G4int i=0; i<vecLen; ++i )
           {
@@ -594,7 +595,7 @@ void G4RPGAntiLambdaInelastic::Cascade(
       }
       else  // nz > 0
       {
-        if( nm == 0 )
+        if( nneg == 0 )
         {
           for( G4int i=0; i<vecLen; ++i )
           {
@@ -605,11 +606,11 @@ void G4RPGAntiLambdaInelastic::Cascade(
             }
           }
         }
-        else //  nm > 0
+        else //  nneg > 0
         {
           if( G4UniformRand() < 0.5 )
           {
-            if( nm > 0 )
+            if( nneg > 0 )
             {
               for( G4int i=0; i<vecLen; ++i )
               {
