@@ -23,11 +23,12 @@
 // * acceptance of all terms of the Geant4 Software license.          *
 // ********************************************************************
 //
-// $Id: G4RPGAntiNeutronInelastic.cc,v 1.1 2007-07-18 21:04:20 dennis Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
  
 #include "G4RPGAntiNeutronInelastic.hh"
+#include "G4PhysicalConstants.hh"
+#include "G4SystemOfUnits.hh"
 #include "Randomize.hh"
 
 G4HadFinalState*
@@ -149,59 +150,54 @@ void G4RPGAntiNeutronInelastic::Cascade(
                                       2.0*targetMass*etOriginal );
   G4double availableEnergy = centerofmassEnergy-(targetMass+mOriginal);
     
-    static G4bool first = true;
-    const G4int numMul = 1200;
-    const G4int numMulA = 400;
-    const G4int numSec = 60;
-    static G4double protmul[numMul], protnorm[numSec]; // proton constants
-    static G4double neutmul[numMul], neutnorm[numSec]; // neutron constants
-    static G4double protmulA[numMulA], protnormA[numSec]; // proton constants
-    static G4double neutmulA[numMulA], neutnormA[numSec]; // neutron constants
-    // np = number of pi+, nm = number of pi-, nz = number of pi0
-    G4int counter, nt=0, np=0, nm=0, nz=0;
-    G4double test;
-    const G4double c = 1.25;    
-    const G4double b[] = { 0.70, 0.70 };
-    if( first )       // compute normalization constants, this will only be Done once
-    {
-      first = false;
-      G4int i;
-      for( i=0; i<numMul; ++i )protmul[i] = 0.0;
-      for( i=0; i<numSec; ++i )protnorm[i] = 0.0;
-      counter = -1;
-      for( np=0; np<(numSec/3); ++np )
-      {
-        for( nm=std::max(0,np-2); nm<=np; ++nm )
-        {
-          for( nz=0; nz<numSec/3; ++nz )
-          {
-            if( ++counter < numMul )
-            {
-              nt = np+nm+nz;
-              if( nt>0 && nt<=numSec )
-              {
-                protmul[counter] = Pmltpc(np,nm,nz,nt,b[0],c);
-                protnorm[nt-1] += protmul[counter];
-              }
+  static G4bool first = true;
+  const G4int numMul = 1200;
+  const G4int numMulA = 400;
+  const G4int numSec = 60;
+  static G4double protmul[numMul], protnorm[numSec]; // proton constants
+  static G4double neutmul[numMul], neutnorm[numSec]; // neutron constants
+  static G4double protmulA[numMulA], protnormA[numSec]; // proton constants
+  static G4double neutmulA[numMulA], neutnormA[numSec]; // neutron constants
+
+  // np = number of pi+, nneg = number of pi-, nz = number of pi0
+  G4int counter, nt=0, np=0, nneg=0, nz=0;
+  G4double test;
+  const G4double c = 1.25;    
+  const G4double b[] = { 0.70, 0.70 };
+  if (first) {  // Computation of normalization constants will only be done once
+    first = false;
+    G4int i;
+    for (i = 0; i < numMul; ++i) protmul[i] = 0.0;
+    for (i = 0; i < numSec; ++i) protnorm[i] = 0.0;
+    counter = -1;
+    for (np = 0; np < (numSec/3); ++np) {
+      for (nneg = std::max(0,np-2); nneg <= np; ++nneg) {
+        for (nz = 0; nz < numSec/3; ++nz) {
+          if (++counter < numMul) {
+            nt = np+nneg+nz;
+            if (nt > 0 && nt <= numSec) {
+              protmul[counter] = Pmltpc(np,nneg,nz,nt,b[0],c);
+              protnorm[nt-1] += protmul[counter];
             }
           }
         }
       }
-      for( i=0; i<numMul; ++i )neutmul[i] = 0.0;
-      for( i=0; i<numSec; ++i )neutnorm[i] = 0.0;
-      counter = -1;
-      for( np=0; np<numSec/3; ++np )
-      {
-        for( nm=std::max(0,np-1); nm<=(np+1); ++nm )
+    }
+
+    for( i=0; i<numMul; ++i )neutmul[i] = 0.0;
+    for( i=0; i<numSec; ++i )neutnorm[i] = 0.0;
+    counter = -1;
+    for (np = 0; np < numSec/3; ++np) {
+        for( nneg=std::max(0,np-1); nneg<=(np+1); ++nneg )
         {
           for( nz=0; nz<numSec/3; ++nz )
           {
             if( ++counter < numMul )
             {
-              nt = np+nm+nz;
+              nt = np+nneg+nz;
               if( (nt>0) && (nt<=numSec) )
               {
-                neutmul[counter] = Pmltpc(np,nm,nz,nt,b[1],c);
+                neutmul[counter] = Pmltpc(np,nneg,nz,nt,b[1],c);
                 neutnorm[nt-1] += neutmul[counter];
               }
             }
@@ -221,15 +217,15 @@ void G4RPGAntiNeutronInelastic::Cascade(
       counter = -1;
       for( np=1; np<(numSec/3); ++np )
       {
-        nm = np-1;
+        nneg = np-1;
         for( nz=0; nz<numSec/3; ++nz )
         {
           if( ++counter < numMulA )
           {
-            nt = np+nm+nz;
+            nt = np+nneg+nz;
             if( nt>1 && nt<=numSec )
             {
-              protmulA[counter] = Pmltpc(np,nm,nz,nt,b[0],c);
+              protmulA[counter] = Pmltpc(np,nneg,nz,nt,b[0],c);
               protnormA[nt-1] += protmulA[counter];
             }
           }
@@ -240,15 +236,15 @@ void G4RPGAntiNeutronInelastic::Cascade(
       counter = -1;
       for( np=0; np<numSec/3; ++np )
       {
-        nm = np;
+        nneg = np;
         for( nz=0; nz<numSec/3; ++nz )
         {
           if( ++counter < numMulA )
           {
-            nt = np+nm+nz;
+            nt = np+nneg+nz;
             if( nt>1 && nt<=numSec )
             {
-              neutmulA[counter] = Pmltpc(np,nm,nz,nt,b[1],c);
+              neutmulA[counter] = Pmltpc(np,nneg,nz,nt,b[1],c);
               neutnormA[nt-1] += neutmulA[counter];
             }
           }
@@ -293,7 +289,7 @@ void G4RPGAntiNeutronInelastic::Cascade(
         // suppress high multiplicity events at low momentum
         // only one pion will be produced
         //
-        np = nm = nz = 0;
+        np = nneg = nz = 0;
         if( targetParticle.GetDefinition() == aProton )
         {
           test = std::exp( std::min( expxu, std::max( expxl, -(1.0+b[0])*(1.0+b[0])/(2.0*c*c) ) ) );
@@ -319,7 +315,7 @@ void G4RPGAntiNeutronInelastic::Cascade(
           else if( ran < wp/wt )
             np = 1;
           else
-            nm = 1;
+            nneg = 1;
         }
       }
       else   // (availableEnergy >= 2.0*GeV) || (random number < supp[ieab])
@@ -333,13 +329,13 @@ void G4RPGAntiNeutronInelastic::Cascade(
           counter = -1;
           for( np=0; np<numSec/3 && ran>=excs; ++np )
           {
-            for( nm=std::max(0,np-2); nm<=np && ran>=excs; ++nm )
+            for( nneg=std::max(0,np-2); nneg<=np && ran>=excs; ++nneg )
             {
               for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
               {
                 if( ++counter < numMul )
                 {
-                  nt = np+nm+nz;
+                  nt = np+nneg+nz;
                   if( nt > 0 )
                   {
                     test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -360,20 +356,20 @@ void G4RPGAntiNeutronInelastic::Cascade(
             quasiElastic = true;
             return;
           }
-          np--; nm--; nz--;
+          np--; nneg--; nz--;
         }
         else  // target must be a neutron
         {
           counter = -1;
           for( np=0; np<numSec/3 && ran>=excs; ++np )
           {
-            for( nm=std::max(0,np-1); nm<=(np+1) && ran>=excs; ++nm )
+            for( nneg=std::max(0,np-1); nneg<=(np+1) && ran>=excs; ++nneg )
             {
               for( nz=0; nz<numSec/3 && ran>=excs; ++nz )
               {
                 if( ++counter < numMul )
                 {
-                  nt = np+nm+nz;
+                  nt = np+nneg+nz;
                   if( (nt>=1) && (nt<=numSec) )
                   {
                     test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -394,12 +390,12 @@ void G4RPGAntiNeutronInelastic::Cascade(
             quasiElastic = true;
             return;
           }
-          np--; nm--; nz--;
+          np--; nneg--; nz--;
         }
       }
       if( targetParticle.GetDefinition() == aProton )
       {
-        switch( np-nm )
+        switch( np-nneg )
         {
          case 1:
            if( G4UniformRand() < 0.5 )
@@ -425,7 +421,7 @@ void G4RPGAntiNeutronInelastic::Cascade(
       }
       else  // target must be a neutron
       {
-        switch( np-nm )
+        switch( np-nneg )
         {
          case 0:
            if( G4UniformRand() < 0.33 )
@@ -466,12 +462,12 @@ void G4RPGAntiNeutronInelastic::Cascade(
         counter = -1;
         for( np=1; (np<numSec/3) && (ran>=excs); ++np )
         {
-          nm = np-1;
+          nneg = np-1;
           for( nz=0; (nz<numSec/3) && (ran>=excs); ++nz )
           {
             if( ++counter < numMulA )
             {
-              nt = np+nm+nz;
+              nt = np+nneg+nz;
               if( nt>1 && nt<=numSec )
               {
                 test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -492,12 +488,12 @@ void G4RPGAntiNeutronInelastic::Cascade(
         counter = -1;
         for( np=0; (np<numSec/3) && (ran>=excs); ++np )
         {
-          nm = np;
+          nneg = np;
           for( nz=0; (nz<numSec/3) && (ran>=excs); ++nz )
           {
             if( ++counter < numMulA )
             {
-              nt = np+nm+nz;
+              nt = np+nneg+nz;
               if( (nt>1) && (nt<=numSec) )
               {
                 test = std::exp( std::min( expxu, std::max( expxl, -(pi/4.0)*(nt*nt)/(n*n) ) ) );
@@ -522,9 +518,9 @@ void G4RPGAntiNeutronInelastic::Cascade(
       currentParticle.SetMass( 0.0 );
       targetParticle.SetMass( 0.0 );
     }
-    while(np+nm+nz<3) nz++;
+    while(np+nneg+nz<3) nz++;
 
-  SetUpPions( np, nm, nz, vec, vecLen );
+  SetUpPions( np, nneg, nz, vec, vecLen );
   return;
 }
 
