@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4RunManagerKernel.cc,v 1.54 2010-12-05 12:12:43 allison Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 //
 
@@ -131,10 +130,13 @@ G4RunManagerKernel::G4RunManagerKernel()
 
 G4RunManagerKernel::~G4RunManagerKernel()
 {
-  // set the application state to the quite state
-  if(verboseLevel>0) G4cout << "G4 kernel has come to Quit state." << G4endl;
   G4StateManager* pStateManager = G4StateManager::GetStateManager();
-  pStateManager->SetNewState(G4State_Quit);
+  // set the application state to the quite state
+  if(pStateManager->GetCurrentState()!=G4State_Quit)
+  {
+    if(verboseLevel>0) G4cout << "G4 kernel has come to Quit state." << G4endl;
+    pStateManager->SetNewState(G4State_Quit);
+  }
 
   // open geometry for deletion
   G4GeometryManager::GetInstance()->OpenGeometry();
