@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4SteppingManager2.cc,v 1.38 2010-07-19 13:41:21 gcosmo Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id: G4SteppingManager2.cc 69894 2013-05-17 09:47:23Z gcosmo $
 //
 //---------------------------------------------------------------
 //
@@ -302,6 +301,8 @@ void G4SteppingManager::InvokeAtRestDoItProcs()
      lifeTime =
        fCurrentProcess->AtRestGPIL( *fTrack, &fCondition );
 
+     
+
      if(fCondition==Forced && fCurrentProcess){
        (*fSelectedAtRestDoItVector)[ri] = Forced;
      }
@@ -310,18 +311,17 @@ void G4SteppingManager::InvokeAtRestDoItProcs()
        if(lifeTime < shortestLifeTime ){
           shortestLifeTime = lifeTime;
           fAtRestDoItProcTriggered =  G4int(ri);
-          (*fSelectedAtRestDoItVector)[fAtRestDoItProcTriggered] = NotForced;
        }
      }
    }
 
+  (*fSelectedAtRestDoItVector)[fAtRestDoItProcTriggered] = NotForced;
+
 // at least one process is necessary to destroy the particle  
 // exit with warning 
    if(NofInactiveProc==MAXofAtRestLoops){ 
-     G4cerr << "ERROR - G4SteppingManager::InvokeAtRestDoItProcs()" << G4endl
-            << "        No AtRestDoIt process is active!" << G4endl;
-     // G4Exception("G4SteppingManager::InvokeAtRestDoItProcs", "Tracking0013",
-     //             FatalException, "No AtRestDoIt process is active." );
+     G4Exception("G4SteppingManager::InvokeAtRestDoItProcs()", "Tracking0013",
+                 JustWarning, "No AtRestDoIt process is active!" );
    }
 
    fStep->SetStepLength( 0. );  //the particle has stopped
