@@ -24,8 +24,7 @@
 // ********************************************************************
 //
 //
-// $Id: G4Scene.cc,v 1.24 2009-11-04 12:49:16 allison Exp $
-// GEANT4 tag $Name: not supported by cvs2svn $
+// $Id$
 //
 // 
 // Scene data  John Allison  19th July 1996.
@@ -48,11 +47,11 @@ G4Scene::G4Scene (const G4String& name):
 G4Scene::~G4Scene () {}
 
 G4bool G4Scene::AddRunDurationModel (G4VModel* pModel, G4bool warn) {
-  std::vector<G4VModel*>::const_iterator i;
+  std::vector<Model>::const_iterator i;
   for (i = fRunDurationModelList.begin ();
        i != fRunDurationModelList.end (); ++i) {
     if (pModel -> GetGlobalDescription () ==
-	(*i) -> GetGlobalDescription ()) break;
+	i->fpModel->GetGlobalDescription ()) break;
   }
   if (i != fRunDurationModelList.end ()) {
     if (warn) {
@@ -65,24 +64,91 @@ G4bool G4Scene::AddRunDurationModel (G4VModel* pModel, G4bool warn) {
     }
     return false;
   }
-  fRunDurationModelList.push_back (pModel);
+  fRunDurationModelList.push_back (Model(pModel));
   CalculateExtent ();
   return true;
 }
 
-void G4Scene::CalculateExtent () {
-  G4int nModels = fRunDurationModelList.size ();
+void G4Scene::CalculateExtent ()
+{
   G4BoundingSphereScene boundingSphereScene;
-  for (G4int i = 0; i < nModels; i++) {
-    const G4VisExtent& thisExtent =
-      fRunDurationModelList[i] -> GetExtent ();
-    G4Point3D thisCentre = thisExtent.GetExtentCentre ();
-    G4double thisRadius = thisExtent.GetExtentRadius ();
-    thisCentre.transform (fRunDurationModelList[i] -> GetTransformation ());
-    boundingSphereScene.AccrueBoundingSphere (thisCentre, thisRadius);
+
+  for (size_t i = 0; i < fRunDurationModelList.size(); i++) {
+    if (fRunDurationModelList[i].fActive) {
+      G4VModel* model = fRunDurationModelList[i].fpModel;
+      if (model -> Validate()) {  // Validates and also recomputes extent.
+	const G4VisExtent& thisExtent = model -> GetExtent ();
+	G4double thisRadius = thisExtent.GetExtentRadius ();
+	if (thisRadius > 0.) {
+	  G4Point3D thisCentre = thisExtent.GetExtentCentre ();
+	  thisCentre.transform (model -> GetTransformation ());
+	  boundingSphereScene.AccrueBoundingSphere (thisCentre, thisRadius);
+	}
+      } else {
+	G4ExceptionDescription ed;
+	ed << "Invalid model \"" << model->GetGlobalDescription()
+	   << "\".\n  Not included in extent calculation.";
+	G4Exception
+	  ("G4Scene::CalculateExtent",
+	   "visman0201", JustWarning, ed);
+      }
+    }
   }
+
+  for (size_t i = 0; i < fEndOfEventModelList.size(); i++) {
+    if (fEndOfEventModelList[i].fActive) {
+      G4VModel* model = fEndOfEventModelList[i].fpModel;
+      if (model -> Validate()) {  // Validates and also recomputes extent.
+	const G4VisExtent& thisExtent = model -> GetExtent ();
+	G4double thisRadius = thisExtent.GetExtentRadius ();
+	if (thisRadius > 0.) {
+	  G4Point3D thisCentre = thisExtent.GetExtentCentre ();
+	  thisCentre.transform (model -> GetTransformation ());
+	  boundingSphereScene.AccrueBoundingSphere (thisCentre, thisRadius);
+	}
+      } else {
+	G4ExceptionDescription ed;
+	ed << "Invalid model \"" << model->GetGlobalDescription()
+	   << "\".\n  Not included in extent calculation.";
+	G4Exception
+	  ("G4Scene::CalculateExtent",
+	   "visman0201", JustWarning, ed);
+      }
+    }
+  }
+
+  for (size_t i = 0; i < fEndOfRunModelList.size(); i++) {
+    if (fEndOfRunModelList[i].fActive) {
+      G4VModel* model = fEndOfRunModelList[i].fpModel;
+      if (model -> Validate()) {  // Validates and also recomputes extent.
+	const G4VisExtent& thisExtent = model -> GetExtent ();
+	G4double thisRadius = thisExtent.GetExtentRadius ();
+	if (thisRadius > 0.) {
+	  G4Point3D thisCentre = thisExtent.GetExtentCentre ();
+	  thisCentre.transform (model -> GetTransformation ());
+	  boundingSphereScene.AccrueBoundingSphere (thisCentre, thisRadius);
+	}
+      } else {
+	G4ExceptionDescription ed;
+	ed << "Invalid model \"" << model->GetGlobalDescription()
+	   << "\".\n  Not included in extent calculation.";
+	G4Exception
+	  ("G4Scene::CalculateExtent",
+	   "visman0201", JustWarning, ed);
+      }
+    }
+  }
+
   fExtent = boundingSphereScene.GetBoundingSphereExtent ();
   fStandardTargetPoint = fExtent.GetExtentCentre ();
+  if (fExtent.GetExtentRadius() <= 0.) {
+	G4Exception
+	  ("G4Scene::CalculateExtent",
+	   "visman0202", JustWarning,
+	   "Scene has no extent.  Please activate or add something."
+	   "\nThe camera needs to have something to point at!"
+	   "\n\"/vis/scene/list\" to see list of models.");
+  }
 }
 
 G4bool G4Scene::AddWorldIfEmpty (G4bool warn) {
@@ -125,22 +191,19 @@ G4bool G4Scene::AddEndOfEventModel (G4VModel* pModel, G4bool warn) {
   G4int i, nModels = fEndOfEventModelList.size ();
   for (i = 0; i < nModels; i++) {
     if (pModel -> GetGlobalDescription () ==
-	fEndOfEventModelList [i] -> GetGlobalDescription ()) break;
+	fEndOfEventModelList[i].fpModel -> GetGlobalDescription ()) break;
   }
   if (i < nModels) {
-    delete fEndOfEventModelList[i];
-    fEndOfEventModelList[i] = pModel;
     if (warn) {
       G4cout << "G4Scene::AddEndOfEventModel: a model \""
 	     << pModel -> GetGlobalDescription ()
 	     << "\"\n  is already in the end-of-event list of scene \""
-	     << fName <<
-	"\".\n  The old model has been deleted; this new model replaces it."
+	     << fName << "\"."
 	     << G4endl;
     }
-    return true;  // Model replaced sucessfully.
+    return false;
   }
-  fEndOfEventModelList.push_back (pModel);
+  fEndOfEventModelList.push_back (Model(pModel));
   return true;
 }
 
@@ -148,82 +211,109 @@ G4bool G4Scene::AddEndOfRunModel (G4VModel* pModel, G4bool warn) {
   G4int i, nModels = fEndOfRunModelList.size ();
   for (i = 0; i < nModels; i++) {
     if (pModel -> GetGlobalDescription () ==
-	fEndOfRunModelList [i] -> GetGlobalDescription ()) break;
+	fEndOfRunModelList[i].fpModel -> GetGlobalDescription ()) break;
   }
   if (i < nModels) {
-    delete fEndOfRunModelList[i];
-    fEndOfRunModelList[i] = pModel;
     if (warn) {
       G4cout << "G4Scene::AddEndOfRunModel: a model \""
 	     << pModel -> GetGlobalDescription ()
 	     << "\"\n  is already in the end-of-run list of scene \""
-	     << fName <<
-	"\".\n  The old model has been deleted; this new model replaces it."
+	     << fName << "\"."
 	     << G4endl;
     }
-    return true;  // Model replaced sucessfully.
+    return false;
   }
   fEndOfRunModelList.push_back (pModel);
   return true;
 }
 
-std::ostream& operator << (std::ostream& os, const G4Scene& s) {
+std::ostream& operator << (std::ostream& os, const G4Scene& scene) {
 
   size_t i;
 
   os << "Scene data:";
 
   os << "\n  Run-duration model list:";
-  for (i = 0; i < s.fRunDurationModelList.size (); i++) {
-    os << "\n  " << *(s.fRunDurationModelList[i]);
+  for (i = 0; i < scene.fRunDurationModelList.size (); i++) {
+    if (scene.fRunDurationModelList[i].fActive) os << "\n  Active:   ";
+    else os << "\n  Inactive: ";
+    os << *(scene.fRunDurationModelList[i].fpModel);
   }
 
   os << "\n  End-of-event model list:";
-  for (i = 0; i < s.fEndOfEventModelList.size (); i++) {
-    os << "\n  " << *(s.fEndOfEventModelList[i]);
+  for (i = 0; i < scene.fEndOfEventModelList.size (); i++) {
+    if (scene.fEndOfEventModelList[i].fActive) os << "\n  Active:   ";
+    else os << "\n  Inactive: ";
+    os << *(scene.fEndOfEventModelList[i].fpModel);
   }
 
   os << "\n  End-of-run model list:";
-  for (i = 0; i < s.fEndOfRunModelList.size (); i++) {
-    os << "\n  " << *(s.fEndOfRunModelList[i]);
+  for (i = 0; i < scene.fEndOfRunModelList.size (); i++) {
+    if (scene.fEndOfRunModelList[i].fActive) os << "\n  Active:   ";
+    else os << "\n  Inactive: ";
+    os << *(scene.fEndOfRunModelList[i].fpModel);
   }
 
-  os << "\n  Extent or bounding box: " << s.fExtent;
+  os << "\n  Extent or bounding box: " << scene.fExtent;
 
-  os << "\n  Standard target point:  " << s.fStandardTargetPoint;
+  os << "\n  Standard target point:  " << scene.fStandardTargetPoint;
 
   os << "\n  End of event action set to \"";
-  if (s.fRefreshAtEndOfEvent) os << "refresh\"";
+  if (scene.fRefreshAtEndOfEvent) os << "refresh\"";
   else {
     os << "accumulate (maximum number of kept events: ";
-    if (s.fMaxNumberOfKeptEvents >= 0) os << s.fMaxNumberOfKeptEvents;
+    if (scene.fMaxNumberOfKeptEvents >= 0) os << scene.fMaxNumberOfKeptEvents;
     else os << "unlimited";
     os << ")";
   }
 
   os << "\n  End of run action set to \"";
-  if (s.fRefreshAtEndOfRun) os << "refresh";
+  if (scene.fRefreshAtEndOfRun) os << "refresh";
   else os << "accumulate";
   os << "\"";
 
   return os;
 }
 
-G4bool G4Scene::operator != (const G4Scene& s) const {
+G4bool G4Scene::operator != (const G4Scene& scene) const {
   if (
       (fRunDurationModelList.size () !=
-       s.fRunDurationModelList.size ())                 ||
-      (fExtent               != s.fExtent)              ||
-      !(fStandardTargetPoint == s.fStandardTargetPoint) ||
-      fRefreshAtEndOfEvent   != s.fRefreshAtEndOfEvent  ||
-      fRefreshAtEndOfRun     != s.fRefreshAtEndOfRun    ||
-      fMaxNumberOfKeptEvents != s.fMaxNumberOfKeptEvents
+       scene.fRunDurationModelList.size ())                 ||
+      (fEndOfEventModelList.size () !=
+       scene.fEndOfEventModelList.size ())                  ||
+      (fEndOfRunModelList.size () !=
+       scene.fEndOfRunModelList.size ())                    ||
+      (fExtent               != scene.fExtent)              ||
+      !(fStandardTargetPoint == scene.fStandardTargetPoint) ||
+      fRefreshAtEndOfEvent   != scene.fRefreshAtEndOfEvent  ||
+      fRefreshAtEndOfRun     != scene.fRefreshAtEndOfRun    ||
+      fMaxNumberOfKeptEvents != scene.fMaxNumberOfKeptEvents
       ) return true;
 
+  /* A complete comparison should, perhaps, include a comparison of
+     individual models, but it is not easy to implement operator!= for
+     all models.  Also, it would be unfeasible to ask users to
+     implement opeerator!= if we ever get round to allowing
+     user-defined models.  Moreover, there is no editing of G4Scene
+     objects, apart from changing fRefreshAtEndOfEvent, etc; as far as
+     models are concerned, all you can ever do is add them, so a test
+     on size (above) is enough.
+
   for (size_t i = 0; i < fRunDurationModelList.size (); i++) {
-    if (fRunDurationModelList[i] != s.fRunDurationModelList[i])
+    if (fRunDurationModelList[i] != scene.fRunDurationModelList[i])
       return true;
   }
 
+  for (size_t i = 0; i < fEndOfEventModelList.size (); i++) {
+    if (fEndOfEventModelList[i] != scene.fEndOfEventModelList[i])
+      return true;
+  }
+
+  for (size_t i = 0; i < fEndOfRunModelList.size (); i++) {
+    if (fEndOfRunModelList[i] != scene.fEndOfRunModelList[i])
+      return true;
+  }
+  */
+
   return false;
 }
